import type { TextlintRuleModule } from "@textlint/types";
import { tokenize } from "kuromojin";

interface HtdicWord {
  variants: string;
}

const htdic: { [index: string]: HtdicWord | undefined } = JSON.parse(
  '{"行きあう":{"variants":"行きあう/行き逢う/行き合う/行合う"},"行き合う":{"variants":"行きあう/行き合う/行合う"},"行合う":{"variants":"行きあう/行き合う/行合う"},"行き交う":{"variants":"行き交う/行交う"},"行交う":{"variants":"行き交う/行交う"},"行きつく":{"variants":"行きつく/行き着く/行着く"},"行き着く":{"variants":"行きつく/行き着く/行着く"},"行着く":{"variants":"行きつく/行き着く/行着く"},"行":{"variants":"行/行き"},"行き":{"variants":"行/行き"},"行きあたる":{"variants":"行きあたる/行き当る"},"行き当る":{"variants":"行きあたる/行き当る"},"行き暮れる":{"variants":"行き暮れる/行暮れる"},"行暮れる":{"variants":"行き暮れる/行暮れる"},"行き過ぎる":{"variants":"行き過ぎる/行過ぎる"},"行過ぎる":{"variants":"行き過ぎる/行過ぎる"},"行き詰まる":{"variants":"行き詰まる/行き詰る/行詰る"},"行き詰る":{"variants":"行き詰まる/行き詰る/行詰る"},"行詰る":{"variants":"行き詰まる/行き詰る/行詰る"},"行き届く":{"variants":"行き届く/行届く"},"行届く":{"variants":"行き届く/行届く"},"行き悩む":{"variants":"行き悩む/行悩む"},"行悩む":{"variants":"行き悩む/行悩む"},"行き渡る":{"variants":"行き渡る/行渡る"},"行渡る":{"variants":"行き渡る/行渡る"},"行きあたり":{"variants":"行きあたり/行き当り"},"行き当り":{"variants":"行きあたり/行き当り"},"行きあたりばったり":{"variants":"行きあたりばったり/行き当りばったり/行当りばったり"},"行き当りばったり":{"variants":"行きあたりばったり/行き当りばったり/行当りばったり"},"行当りばったり":{"variants":"行きあたりばったり/行き当りばったり/行当りばったり"},"行きがかり":{"variants":"行きがかり/行き掛かり/行き掛り"},"行き掛かり":{"variants":"行きがかり/行き掛かり/行き掛り"},"行き掛り":{"variants":"行きがかり/行き掛かり/行き掛り"},"行きがけ":{"variants":"行きがけ/行き掛け/行掛け"},"行き掛け":{"variants":"行きがけ/行き掛け/行掛け"},"行掛け":{"variants":"行きがけ/行き掛け/行掛け"},"行き来":{"variants":"行き来/行来"},"行来":{"variants":"行き来/行来"},"行きだおれ":{"variants":"行きだおれ/行き倒れ/行倒れ"},"行き倒れ":{"variants":"行きだおれ/行き倒れ/行倒れ"},"行倒れ":{"variants":"行きだおれ/行き倒れ/行倒れ"},"行きちがい":{"variants":"行きちがい/行き違い/行違い"},"行き違い":{"variants":"行きちがい/行き違い/行違い"},"行違い":{"variants":"行きちがい/行き違い/行違い"},"行きつけ":{"variants":"行きつけ/行き付け/行付け"},"行き付け":{"variants":"行きつけ/行き付け/行付け"},"行付け":{"variants":"行きつけ/行き付け/行付け"},"行きどまり":{"variants":"行きどまり/行き止まり/行き止り/行止り"},"行き止まり":{"variants":"行きどまり/行き止まり/行き止り/行止り"},"行き止り":{"variants":"行きどまり/行き止まり/行き止り/行止り"},"行止り":{"variants":"行きどまり/行き止まり/行き止り/行止り"},"行き抜け":{"variants":"行き抜け/行抜け"},"行抜け":{"variants":"行き抜け/行抜け"},"行き場":{"variants":"行き場/行場"},"行場":{"variants":"行き場/行場"},"行き戻り":{"variants":"行き戻り/行戻り"},"行戻り":{"variants":"行き戻り/行戻り"},"選りごのみ":{"variants":"選りごのみ/選り好み"},"選り好み":{"variants":"選りごのみ/選り好み"},"買":{"variants":"買/買い"},"買い":{"variants":"買/買い"},"済々":{"variants":"済々/済済"},"済済":{"variants":"済々/済済"},"種々":{"variants":"種々/種種"},"種種":{"variants":"種々/種種"},"すき腹":{"variants":"すき腹/空き腹"},"空き腹":{"variants":"すき腹/空き腹"},"立ち振舞":{"variants":"立ち振舞/立振舞"},"立振舞":{"variants":"立ち振舞/立振舞"},"日本晴":{"variants":"日本晴/日本晴れ"},"日本晴れ":{"variants":"日本晴/日本晴れ"},"よそ行き":{"variants":"よそ行き/余所行き"},"余所行き":{"variants":"よそ行き/余所行き"},"ａ":{"variants":"ａ/アール"},"アール":{"variants":"ａ/アール"},"あゝ":{"variants":"あゝ/ああ/嗚呼"},"ああ":{"variants":"あゝ/ああ/嗚呼"},"嗚呼":{"variants":"あゝ/ああ/嗚呼"},"あい":{"variants":"あい/愛/藍"},"あいあい":{"variants":"あいあい/藹々/藹藹"},"藹々":{"variants":"あいあい/藹々/藹藹"},"藹藹":{"variants":"あいあい/藹々/藹藹"},"相合い傘":{"variants":"相合い傘/相合傘"},"相合傘":{"variants":"相合い傘/相合傘"},"あいいとなむ":{"variants":"あいいとなむ/相営む"},"相営む":{"variants":"あいいとなむ/相営む"},"あいいれない":{"variants":"あいいれない/相容れない"},"相容れない":{"variants":"あいいれない/相容れない"},"あいいれる":{"variants":"あいいれる/相いれる/相入れる"},"相いれる":{"variants":"あいいれる/相いれる/相入れる"},"相入れる":{"variants":"あいいれる/相いれる/相入れる"},"合いかぎ":{"variants":"合いかぎ/合い鍵/合かぎ/合鍵"},"合い鍵":{"variants":"合いかぎ/合い鍵/合かぎ/合鍵"},"合かぎ":{"variants":"合いかぎ/合い鍵/合かぎ/合鍵"},"合鍵":{"variants":"合いかぎ/合い鍵/合かぎ/合鍵"},"合方":{"variants":"合い方/合方"},"合い方":{"variants":"合い方/合方"},"あいかわる":{"variants":"あいかわる/あい変わる/相変わる"},"あい変わる":{"variants":"あいかわる/あい変わる/相変わる"},"相変わる":{"variants":"あいかわる/あい変わる/相変わる"},"アイガモ":{"variants":"アイガモ/間鴨/合鴨"},"愛きょう":{"variants":"愛きょう/愛郷/愛敬/愛嬌"},"合着":{"variants":"合い着/合着"},"合い着":{"variants":"合い着/合着"},"合い口":{"variants":"合い口/合口"},"合口":{"variants":"合い口/合口"},"あいくるしい":{"variants":"あいくるしい/愛くるしい"},"愛くるしい":{"variants":"あいくるしい/愛くるしい"},"合い言葉":{"variants":"合い言葉/合言葉"},"合言葉":{"variants":"合い言葉/合言葉"},"あいさつ":{"variants":"あいさつ/挨拶"},"挨拶":{"variants":"あいさつ/挨拶"},"あいしあう":{"variants":"あいしあう/愛し合う"},"愛し合う":{"variants":"あいしあう/愛し合う"},"あいしあえる":{"variants":"あいしあえる/愛し合える"},"愛し合える":{"variants":"あいしあえる/愛し合える"},"あいす":{"variants":"あいす/愛す"},"愛す":{"variants":"あいす/愛す"},"Ｉｃｅ":{"variants":"Ｉｃｅ/アイス"},"アイス":{"variants":"Ｉｃｅ/アイス"},"あいする":{"variants":"あいする/愛する"},"愛する":{"variants":"あいする/愛する"},"あいせる":{"variants":"あいせる/愛せる"},"愛せる":{"variants":"あいせる/愛せる"},"アイゼン":{"variants":"アイゼン/愛染"},"愛染":{"variants":"アイゼン/愛染"},"あいぞめ":{"variants":"あいぞめ/藍染"},"藍染":{"variants":"あいぞめ/藍染"},"間がら":{"variants":"間がら/間柄"},"間柄":{"variants":"間がら/間柄"},"あいつ":{"variants":"あいつ/彼奴"},"彼奴":{"variants":"あいつ/彼奴"},"あいつぐ":{"variants":"あいつぐ/相継ぐ/相次ぐ"},"あいつづく":{"variants":"あいつづく/相続く"},"相続く":{"variants":"あいつづく/相続く"},"相づち":{"variants":"相づち/相槌"},"相槌":{"variants":"相づち/相槌"},"あいてどる":{"variants":"あいてどる/相手取る"},"相手取る":{"variants":"あいてどる/相手取る"},"あいともなう":{"variants":"あいともなう/相伴う"},"相伴う":{"variants":"あいともなう/相伴う"},"あいなる":{"variants":"あいなる/相成る"},"相成る":{"variants":"あいなる/相成る"},"あいの子":{"variants":"あいの子/間の子/合の子"},"あいの手":{"variants":"あいの手/間の手/合いの手/合の手"},"合の手":{"variants":"あいの手/合いの手/合の手"},"合いの手":{"variants":"あいの手/合いの手/合の手"},"合いびき":{"variants":"合いびき/合い挽き"},"合い挽き":{"variants":"合いびき/合い挽き"},"合い札":{"variants":"合い札/合札"},"合札":{"variants":"合い札/合札"},"あいま":{"variants":"あいま/合間"},"合間":{"variants":"あいま/合間"},"あいまい":{"variants":"あいまい/あい昧/曖昧"},"あい昧":{"variants":"あいまい/あい昧/曖昧"},"曖昧":{"variants":"あいまい/あい昧/曖昧"},"あいらしい":{"variants":"あいらしい/愛らしい"},"愛らしい":{"variants":"あいらしい/愛らしい"},"あい路":{"variants":"あい路/隘路"},"隘路":{"variants":"あい路/隘路"},"あう":{"variants":"あう/合う"},"合う":{"variants":"あう/合う"},"阿うん":{"variants":"阿うん/阿吽"},"阿吽":{"variants":"阿うん/阿吽"},"あえぐ":{"variants":"あえぐ/喘ぐ"},"喘ぐ":{"variants":"あえぐ/喘ぐ"},"あえて":{"variants":"あえて/敢えて"},"敢えて":{"variants":"あえて/敢えて"},"あえない":{"variants":"あえない/敢ない/敢無い"},"敢ない":{"variants":"あえない/敢ない/敢無い"},"敢無い":{"variants":"あえない/敢ない/敢無い"},"あえ物":{"variants":"あえ物/和え物/和物"},"和え物":{"variants":"あえ物/和え物/和物"},"和物":{"variants":"あえ物/和え物/和物"},"あえる":{"variants":"あえる/逢える/会える/合える/和える"},"青々":{"variants":"青々/青青"},"青青":{"variants":"青々/青青"},"あおい":{"variants":"あおい/青い/蒼い"},"アオイ":{"variants":"アオイ/葵"},"葵":{"variants":"アオイ/葵"},"葵祭":{"variants":"葵祭/葵祭り"},"葵祭り":{"variants":"葵祭/葵祭り"},"アオエンドウ":{"variants":"アオエンドウ/青豌豆"},"青豌豆":{"variants":"アオエンドウ/青豌豆"},"アオカビ":{"variants":"アオカビ/青かび/青カビ/青黴"},"青かび":{"variants":"アオカビ/青かび/青カビ/青黴"},"青カビ":{"variants":"アオカビ/青かび/青カビ/青黴"},"青黴":{"variants":"アオカビ/青かび/青カビ/青黴"},"アオガエル":{"variants":"アオガエル/青蛙"},"青蛙":{"variants":"アオガエル/青蛙"},"アオキ":{"variants":"アオキ/青木"},"青木":{"variants":"アオキ/青木"},"アオギリ":{"variants":"アオギリ/梧桐/青桐"},"あおくさい":{"variants":"あおくさい/青臭い"},"青臭い":{"variants":"あおくさい/青臭い"},"あおぐ":{"variants":"あおぐ/仰ぐ/扇ぐ/煽ぐ"},"あおぐろい":{"variants":"あおぐろい/青黒い"},"青黒い":{"variants":"あおぐろい/青黒い"},"あおげる":{"variants":"あおげる/仰げる"},"仰げる":{"variants":"あおげる/仰げる"},"アオサ":{"variants":"アオサ/石蓴"},"石蓴":{"variants":"アオサ/石蓴"},"あおざめる":{"variants":"あおざめる/青ざめる"},"青ざめる":{"variants":"あおざめる/青ざめる"},"あおじろい":{"variants":"あおじろい/青白い/蒼白い"},"アオダイショウ":{"variants":"アオダイショウ/青大将"},"青大将":{"variants":"アオダイショウ/青大将"},"あおっぽい":{"variants":"あおっぽい/青っぽい"},"青っぽい":{"variants":"あおっぽい/青っぽい"},"あおのける":{"variants":"あおのける/仰ける"},"仰ける":{"variants":"あおのける/仰ける"},"アオノリ":{"variants":"アオノリ/青のり/青海苔"},"青のり":{"variants":"アオノリ/青のり/青海苔"},"青海苔":{"variants":"アオノリ/青のり/青海苔"},"アオバエ":{"variants":"アオバエ/青蝿/蒼蝿"},"アオバト":{"variants":"アオバト/緑鳩"},"緑鳩":{"variants":"アオバト/緑鳩"},"あおばむ":{"variants":"あおばむ/青ばむ"},"青ばむ":{"variants":"あおばむ/青ばむ"},"アオマメ":{"variants":"アオマメ/青豆"},"青豆":{"variants":"アオマメ/青豆"},"あおみがかる":{"variants":"あおみがかる/青みがかる"},"青みがかる":{"variants":"あおみがかる/青みがかる"},"あおむ":{"variants":"あおむ/青む"},"青む":{"variants":"あおむ/青む"},"あおむく":{"variants":"あおむく/仰向く"},"仰向く":{"variants":"あおむく/仰向く"},"あお向け":{"variants":"あお向け/仰向け"},"仰向け":{"variants":"あお向け/仰向け"},"あおむける":{"variants":"あおむける/仰向ける"},"仰向ける":{"variants":"あおむける/仰向ける"},"アオムシ":{"variants":"アオムシ/青虫"},"青虫":{"variants":"アオムシ/青虫"},"青やぎ":{"variants":"青やぎ/青柳"},"青柳":{"variants":"青やぎ/青柳"},"あおり":{"variants":"あおり/障泥/煽り/泥障"},"あおる":{"variants":"あおる/呷る"},"呷る":{"variants":"あおる/呷る"},"アカ":{"variants":"アカ/垢/赤/淦/閼伽"},"あかあかと":{"variants":"あかあかと/赤赤と/明明と"},"あかい":{"variants":"あかい/紅い/赤い/明い"},"アカエイ":{"variants":"アカエイ/赤えい"},"赤えい":{"variants":"アカエイ/赤えい"},"アカガイ":{"variants":"アカガイ/赤貝"},"赤貝":{"variants":"アカガイ/赤貝"},"アカガエル":{"variants":"アカガエル/赤蛙"},"赤蛙":{"variants":"アカガエル/赤蛙"},"アカガシ":{"variants":"アカガシ/赤樫"},"赤樫":{"variants":"アカガシ/赤樫"},"あかぐろい":{"variants":"あかぐろい/赤黒い"},"赤黒い":{"variants":"あかぐろい/赤黒い"},"あかゲット":{"variants":"あかゲット/赤ゲット"},"赤ゲット":{"variants":"あかゲット/赤ゲット"},"赤さび":{"variants":"赤さび/赤錆"},"赤錆":{"variants":"赤さび/赤錆"},"アカザ":{"variants":"アカザ/藜"},"藜":{"variants":"アカザ/藜"},"あかし":{"variants":"あかし/証"},"証":{"variants":"あかし/証"},"アカシオ":{"variants":"アカシオ/赤潮"},"赤潮":{"variants":"アカシオ/赤潮"},"あかす":{"variants":"あかす/証す/飽かす/明かす"},"あかちゃける":{"variants":"あかちゃける/赤茶ける"},"赤茶ける":{"variants":"あかちゃける/赤茶ける"},"あかチン":{"variants":"あかチン/アカチン/赤チン"},"アカチン":{"variants":"あかチン/アカチン/赤チン"},"赤チン":{"variants":"あかチン/アカチン/赤チン"},"あかつき":{"variants":"あかつき/暁/曉"},"アカトンボ":{"variants":"アカトンボ/赤とんぼ/赤蜻蛉"},"赤とんぼ":{"variants":"アカトンボ/赤とんぼ/赤蜻蛉"},"赤蜻蛉":{"variants":"アカトンボ/赤とんぼ/赤蜻蛉"},"アカナス":{"variants":"アカナス/赤茄子"},"赤茄子":{"variants":"アカナス/赤茄子"},"あかぬける":{"variants":"あかぬける/あか抜ける/垢抜ける"},"あか抜ける":{"variants":"あかぬける/あか抜ける/垢抜ける"},"垢抜ける":{"variants":"あかぬける/あか抜ける/垢抜ける"},"アカネ":{"variants":"アカネ/茜"},"茜":{"variants":"アカネ/茜"},"茜いろ":{"variants":"茜いろ/茜色"},"茜色":{"variants":"茜いろ/茜色"},"赤のまんま":{"variants":"赤のまんま/赤の飯"},"赤の飯":{"variants":"赤のまんま/赤の飯"},"アカハラ":{"variants":"アカハラ/赤腹"},"赤腹":{"variants":"アカハラ/赤腹"},"アカマツ":{"variants":"アカマツ/赤松"},"赤松":{"variants":"アカマツ/赤松"},"赤み":{"variants":"赤み/赤身"},"赤身":{"variants":"赤み/赤身"},"あかみがかる":{"variants":"あかみがかる/赤みがかる"},"赤みがかる":{"variants":"あかみがかる/赤みがかる"},"赤みそ":{"variants":"赤みそ/赤味噌"},"赤味噌":{"variants":"赤みそ/赤味噌"},"赤むけ":{"variants":"赤むけ/赤剥け"},"赤剥け":{"variants":"赤むけ/赤剥け"},"アカメ":{"variants":"アカメ/赤目"},"赤目":{"variants":"アカメ/赤目"},"アカメイモ":{"variants":"アカメイモ/赤芽芋"},"赤芽芋":{"variants":"アカメイモ/赤芽芋"},"アカメガシワ":{"variants":"アカメガシワ/赤芽柏"},"赤芽柏":{"variants":"アカメガシワ/赤芽柏"},"あかめる":{"variants":"あかめる/赤める"},"赤める":{"variants":"あかめる/赤める"},"あからむ":{"variants":"あからむ/赤らむ/明らむ"},"あからめる":{"variants":"あからめる/赤らめる"},"赤らめる":{"variants":"あからめる/赤らめる"},"明かり":{"variants":"明かり/明り"},"灯":{"variants":"灯/灯り"},"明り":{"variants":"明かり/明り"},"灯り":{"variants":"灯/灯り"},"明りさき":{"variants":"明りさき/明り先"},"明り先":{"variants":"明りさき/明り先"},"明かり障子":{"variants":"明かり障子/明り障子/明障子"},"明り障子":{"variants":"明かり障子/明り障子/明障子"},"明障子":{"variants":"明かり障子/明り障子/明障子"},"明かりとり":{"variants":"明かりとり/明り取り"},"明り取り":{"variants":"明かりとり/明り取り"},"あかるい":{"variants":"あかるい/明るい"},"明るい":{"variants":"あかるい/明るい"},"あかるむ":{"variants":"あかるむ/明るむ"},"明るむ":{"variants":"あかるむ/明るむ"},"赤んぼう":{"variants":"赤んぼう/赤ん坊/赤ン坊/赤坊"},"赤ん坊":{"variants":"赤んぼう/赤ん坊/赤ン坊/赤坊"},"赤ン坊":{"variants":"赤んぼう/赤ん坊/赤ン坊/赤坊"},"赤坊":{"variants":"赤んぼう/赤ん坊/赤ン坊/赤坊"},"アカンボク":{"variants":"アカンボク/亜潅木"},"亜潅木":{"variants":"アカンボク/亜潅木"},"あがき":{"variants":"あがき/足掻き"},"足掻き":{"variants":"あがき/足掻き"},"あがく":{"variants":"あがく/足掻く"},"足掻く":{"variants":"あがく/足掻く"},"あがなう":{"variants":"あがなう/購う/贖う"},"あがめる":{"variants":"あがめる/崇める"},"崇める":{"variants":"あがめる/崇める"},"上がりかまち":{"variants":"上がりかまち/上がり框"},"上がり框":{"variants":"上がりかまち/上がり框"},"上がりぐち":{"variants":"上がりぐち/上がり口"},"上がり口":{"variants":"上がりぐち/上がり口"},"あがりこむ":{"variants":"あがりこむ/上がり込む"},"上がり込む":{"variants":"あがりこむ/上がり込む"},"あがり目":{"variants":"あがり目/上がり目"},"上がり目":{"variants":"あがり目/上がり目"},"あがる":{"variants":"あがる/アガる/挙がる/上がる/騰がる/騰る/揚がる/揚る"},"アガる":{"variants":"あがる/アガる/挙がる/上がる/騰がる/騰る/揚がる/揚る"},"騰る":{"variants":"あがる/アガる/騰がる/騰る"},"騰がる":{"variants":"あがる/アガる/騰がる/騰る"},"揚る":{"variants":"あがる/アガる/揚がる/揚る"},"揚がる":{"variants":"あがる/アガる/揚がる/揚る"},"あがれる":{"variants":"あがれる/上がれる"},"上がれる":{"variants":"あがれる/上がれる"},"あきあきする":{"variants":"あきあきする/厭き厭きする/飽き飽きする"},"空きかん":{"variants":"空きかん/空き缶"},"空き缶":{"variants":"空きかん/空き缶"},"明きがら":{"variants":"明きがら/明き殻"},"明き殻":{"variants":"明きがら/明き殻"},"厭性":{"variants":"厭き性/厭性"},"厭き性":{"variants":"厭き性/厭性"},"空き巣":{"variants":"空き巣/空巣"},"空巣":{"variants":"空き巣/空巣"},"空き地":{"variants":"空き地/空地"},"空地":{"variants":"空き地/空地"},"あきなう":{"variants":"あきなう/商う"},"商う":{"variants":"あきなう/商う"},"秋晴":{"variants":"秋晴/秋晴れ"},"秋晴れ":{"variants":"秋晴/秋晴れ"},"秋まつり":{"variants":"秋まつり/秋祭り"},"秋祭り":{"variants":"秋まつり/秋祭り"},"あきめく":{"variants":"あきめく/秋めく"},"秋めく":{"variants":"あきめく/秋めく"},"明きめくら":{"variants":"明きめくら/明き盲/明盲"},"明き盲":{"variants":"明きめくら/明き盲/明盲"},"明盲":{"variants":"明きめくら/明き盲/明盲"},"秋もの":{"variants":"秋もの/秋物"},"秋物":{"variants":"秋もの/秋物"},"空家":{"variants":"空き家/空家"},"空き家":{"variants":"空き家/空家"},"アキョウボク":{"variants":"アキョウボク/亜喬木"},"亜喬木":{"variants":"アキョウボク/亜喬木"},"あきらめる":{"variants":"あきらめる/諦める/明らめる"},"あきる":{"variants":"あきる/厭きる/飽きる"},"あきれかえる":{"variants":"あきれかえる/あきれ返る/呆れかえる/呆れ返る"},"あきれ返る":{"variants":"あきれかえる/あきれ返る/呆れかえる/呆れ返る"},"呆れかえる":{"variants":"あきれかえる/あきれ返る/呆れかえる/呆れ返る"},"呆れ返る":{"variants":"あきれかえる/あきれ返る/呆れかえる/呆れ返る"},"アキレスけん":{"variants":"アキレスけん/アキレス腱"},"アキレス腱":{"variants":"アキレスけん/アキレス腱"},"あきれる":{"variants":"あきれる/呆れる/惘れる"},"あく":{"variants":"あく/厭く/飽く/明く"},"アク":{"variants":"アク/灰汁"},"灰汁":{"variants":"アク/灰汁"},"あくせく":{"variants":"あくせく/あく促/齷齪"},"あくたれる":{"variants":"あくたれる/悪たれる"},"悪たれる":{"variants":"あくたれる/悪たれる"},"あくま":{"variants":"あくま/悪魔"},"悪魔":{"variants":"あくま/悪魔"},"あくまで":{"variants":"あくまで/飽くまで/飽く迄"},"飽くまで":{"variants":"あくまで/飽くまで/飽く迄"},"飽く迄":{"variants":"あくまで/飽くまで/飽く迄"},"あくまでも":{"variants":"あくまでも/飽くまでも/飽く迄も"},"飽くまでも":{"variants":"あくまでも/飽くまでも/飽く迄も"},"飽く迄も":{"variants":"あくまでも/飽くまでも/飽く迄も"},"あくる日":{"variants":"あくる日/明くる日"},"明くる日":{"variants":"あくる日/明くる日"},"あぐら":{"variants":"あぐら/胡座"},"胡座":{"variants":"あぐら/胡座"},"明けがた":{"variants":"明けがた/明け方/明方"},"明け方":{"variants":"明けがた/明け方/明方"},"明方":{"variants":"明けがた/明け方/明方"},"あけくれる":{"variants":"あけくれる/明け暮れる"},"明け暮れる":{"variants":"あけくれる/明け暮れる"},"開けっぱなし":{"variants":"開けっぱなし/開けっ放し"},"明けっ放し":{"variants":"明けっぱなし/明けっ放し"},"開けっ放し":{"variants":"開けっぱなし/開けっ放し"},"明けっぱなし":{"variants":"明けっぱなし/明けっ放し"},"あけっぴろげ":{"variants":"あけっぴろげ/開けっぴろげ/明けっぴろげ/明けっ広げ"},"明けっ広げ":{"variants":"あけっぴろげ/明けっぴろげ/明けっ広げ"},"明けっぴろげ":{"variants":"あけっぴろげ/明けっぴろげ/明けっ広げ"},"あけのこる":{"variants":"あけのこる/明け残る"},"明け残る":{"variants":"あけのこる/明け残る"},"あけはなす":{"variants":"あけはなす/開け放す/明け放す"},"あけはなせる":{"variants":"あけはなせる/開け放せる"},"開け放せる":{"variants":"あけはなせる/開け放せる"},"あけはなつ":{"variants":"あけはなつ/開け放つ/明け放つ"},"あけはなれる":{"variants":"あけはなれる/明け離れる"},"明け離れる":{"variants":"あけはなれる/明け離れる"},"あけはらう":{"variants":"あけはらう/開け払う/明け払う"},"アケビ":{"variants":"アケビ/通草/木通"},"あける":{"variants":"あける/空ける/明ける"},"あけわたす":{"variants":"あけわたす/明け渡す"},"明け渡す":{"variants":"あけわたす/明け渡す"},"あけわたる":{"variants":"あけわたる/明け渡る"},"明け渡る":{"variants":"あけわたる/明け渡る"},"揚げ足":{"variants":"揚げ足/揚足"},"揚足":{"variants":"揚げ足/揚足"},"揚げ油":{"variants":"揚げ油/揚油"},"揚油":{"variants":"揚げ油/揚油"},"上げ舵":{"variants":"上げ舵/上舵"},"上舵":{"variants":"上げ舵/上舵"},"挙げ句":{"variants":"挙げ句/挙句"},"挙句":{"variants":"挙げ句/挙句"},"揚げ句":{"variants":"揚げ句/揚句"},"揚句":{"variants":"揚げ句/揚句"},"上げ潮":{"variants":"上げ潮/上潮"},"上潮":{"variants":"上げ潮/上潮"},"上げ底":{"variants":"上げ底/上底"},"上底":{"variants":"上げ底/上底"},"揚げ玉":{"variants":"揚げ玉/揚玉"},"揚玉":{"variants":"揚げ玉/揚玉"},"あげつらる":{"variants":"あげつらる/論る"},"論る":{"variants":"あげつらる/論る"},"アゲハチョウ":{"variants":"アゲハチョウ/揚羽蝶"},"揚羽蝶":{"variants":"アゲハチョウ/揚羽蝶"},"アゲマキ":{"variants":"アゲマキ/総角/揚げ巻/揚巻"},"揚げ巻":{"variants":"アゲマキ/揚げ巻/揚巻"},"揚巻":{"variants":"アゲマキ/揚げ巻/揚巻"},"揚げ幕":{"variants":"揚げ幕/揚幕"},"揚幕":{"variants":"揚げ幕/揚幕"},"揚げ物":{"variants":"揚げ物/揚物"},"揚物":{"variants":"揚げ物/揚物"},"あげる":{"variants":"あげる/上げる"},"上げる":{"variants":"あげる/上げる"},"あこう鯛":{"variants":"あこう鯛/アコウダイ"},"アコウダイ":{"variants":"あこう鯛/アコウダイ"},"アコウボク":{"variants":"アコウボク/亜高木"},"亜高木":{"variants":"アコウボク/亜高木"},"あこがれる":{"variants":"あこがれる/憧れる/憬れる"},"アコヤガイ":{"variants":"アコヤガイ/阿古屋貝"},"阿古屋貝":{"variants":"アコヤガイ/阿古屋貝"},"あご":{"variants":"あご/顎/吾子"},"アサ":{"variants":"アサ/麻"},"麻":{"variants":"アサ/麻"},"あさい":{"variants":"あさい/浅い"},"浅い":{"variants":"あさい/浅い"},"アサガオ":{"variants":"アサガオ/朝顔"},"朝顔":{"variants":"アサガオ/朝顔"},"朝がけ":{"variants":"朝がけ/朝駆け/朝駈け"},"アサクサノリ":{"variants":"アサクサノリ/浅草のり/浅草海苔"},"浅草のり":{"variants":"アサクサノリ/浅草のり/浅草海苔"},"浅草海苔":{"variants":"アサクサノリ/浅草のり/浅草海苔"},"あさぐろい":{"variants":"あさぐろい/浅黒い"},"浅黒い":{"variants":"あさぐろい/浅黒い"},"あさなあさな":{"variants":"あさなあさな/朝な朝な"},"朝な朝な":{"variants":"あさなあさな/朝な朝な"},"朝ぶろ":{"variants":"朝ぶろ/朝風呂"},"朝風呂":{"variants":"朝ぶろ/朝風呂"},"あさまい":{"variants":"あさまい/浅まい"},"浅まい":{"variants":"あさまい/浅まい"},"あさましい":{"variants":"あさましい/浅ましい"},"浅ましい":{"variants":"あさましい/浅ましい"},"朝めし":{"variants":"朝めし/朝飯"},"朝飯":{"variants":"朝めし/朝飯"},"朝もや":{"variants":"朝もや/朝靄"},"朝靄":{"variants":"朝もや/朝靄"},"アサリ":{"variants":"アサリ/浅蜊/鯏"},"あざける":{"variants":"あざける/嘲る"},"嘲る":{"variants":"あざける/嘲る"},"あざなう":{"variants":"あざなう/糾う"},"糾う":{"variants":"あざなう/糾う"},"アザミ":{"variants":"アザミ/薊"},"薊":{"variants":"アザミ/薊"},"あざむく":{"variants":"あざむく/欺く"},"欺く":{"variants":"あざむく/欺く"},"あざむける":{"variants":"あざむける/欺ける"},"欺ける":{"variants":"あざむける/欺ける"},"あざやか":{"variants":"あざやか/鮮やか"},"鮮やか":{"variants":"あざやか/鮮やか"},"アザラシ":{"variants":"アザラシ/海豹"},"海豹":{"variants":"アザラシ/海豹"},"あざわらう":{"variants":"あざわらう/あざ笑う/嘲笑う"},"あざ笑う":{"variants":"あざわらう/あざ笑う/嘲笑う"},"嘲笑う":{"variants":"あざわらう/あざ笑う/嘲笑う"},"あし":{"variants":"あし/アシ/芦/脚"},"アシ":{"variants":"あし/アシ/芦/脚"},"あしい":{"variants":"あしい/悪しい"},"悪しい":{"variants":"あしい/悪しい"},"アシカ":{"variants":"アシカ/海驢"},"海驢":{"variants":"アシカ/海驢"},"足かけ":{"variants":"足かけ/足掛け"},"足掛け":{"variants":"足かけ/足掛け"},"足かせ":{"variants":"足かせ/足カセ/足枷"},"足カセ":{"variants":"足かせ/足カセ/足枷"},"足枷":{"variants":"足かせ/足カセ/足枷"},"あしからず":{"variants":"あしからず/悪しからず"},"悪しからず":{"variants":"あしからず/悪しからず"},"足がかり":{"variants":"足がかり/足掛かり/足掛り"},"足掛かり":{"variants":"足がかり/足掛かり/足掛り"},"足掛り":{"variants":"足がかり/足掛かり/足掛り"},"あ式蹴球":{"variants":"あ式蹴球/ア式蹴球"},"ア式蹴球":{"variants":"あ式蹴球/ア式蹴球"},"足げ":{"variants":"足げ/足蹴"},"足蹴":{"variants":"足げ/足蹴"},"悪しざま":{"variants":"悪しざま/悪様"},"悪様":{"variants":"悪しざま/悪様"},"足どめ":{"variants":"足どめ/足留め"},"足留め":{"variants":"足どめ/足留め"},"あしなが":{"variants":"あしなが/脚長"},"脚長":{"variants":"あしなが/脚長"},"アシナガバチ":{"variants":"アシナガバチ/足長蜂"},"足長蜂":{"variants":"アシナガバチ/足長蜂"},"足並":{"variants":"足並/足並み"},"足並み":{"variants":"足並/足並み"},"足ならし":{"variants":"足ならし/足慣し/足馴し"},"足ぶみ":{"variants":"足ぶみ/足踏み"},"足踏み":{"variants":"足ぶみ/足踏み"},"足もと":{"variants":"足もと/足許/足元"},"あしゅら":{"variants":"あしゅら/阿修羅"},"阿修羅":{"variants":"あしゅら/阿修羅"},"アジ":{"variants":"アジ/鯵/味/鰺"},"あじけ":{"variants":"あじけ/味け/味気"},"味け":{"variants":"あじけ/味け/味気"},"味気":{"variants":"あじけ/味け/味気"},"アジサイ":{"variants":"アジサイ/紫陽花"},"紫陽花":{"variants":"アジサイ/紫陽花"},"味つけ":{"variants":"味つけ/味付け"},"味付け":{"variants":"味つけ/味付け"},"あじる":{"variants":"あじる/アジる"},"アジる":{"variants":"あじる/アジる"},"あじわう":{"variants":"あじわう/味わう"},"味わう":{"variants":"あじわう/味わう"},"あじわえる":{"variants":"あじわえる/味わえる"},"味わえる":{"variants":"あじわえる/味わえる"},"アスナロ":{"variants":"アスナロ/翌桧"},"翌桧":{"variants":"アスナロ/翌桧"},"あずかる":{"variants":"あずかる/与る/預かる/預る"},"預かる":{"variants":"あずかる/預かる/預る"},"預る":{"variants":"あずかる/預かる/預る"},"あずかれる":{"variants":"あずかれる/預かれる"},"預かれる":{"variants":"あずかれる/預かれる"},"アズキ":{"variants":"アズキ/小豆"},"小豆":{"variants":"アズキ/小豆"},"アズキイロ":{"variants":"アズキイロ/小豆色"},"小豆色":{"variants":"アズキイロ/小豆色"},"アズサ":{"variants":"アズサ/梓"},"梓":{"variants":"アズサ/梓"},"あずま屋":{"variants":"あずま屋/東屋"},"東屋":{"variants":"あずま屋/東屋"},"あせする":{"variants":"あせする/汗する"},"汗する":{"variants":"あせする/汗する"},"汗だく":{"variants":"汗だく/汗ダク"},"汗ダク":{"variants":"汗だく/汗ダク"},"あせばむ":{"variants":"あせばむ/汗ばむ"},"汗ばむ":{"variants":"あせばむ/汗ばむ"},"あせる":{"variants":"あせる/焦る"},"褪せる":{"variants":"あせる/褪せる"},"焦る":{"variants":"あせる/焦る"},"あぜ道":{"variants":"あぜ道/畦道"},"畦道":{"variants":"あぜ道/畦道"},"あぜん":{"variants":"あぜん/あ然/ア然/唖然"},"あ然":{"variants":"あぜん/あ然/ア然/唖然"},"ア然":{"variants":"あぜん/あ然/ア然/唖然"},"唖然":{"variants":"あぜん/あ然/ア然/唖然"},"あそこ":{"variants":"あそこ/彼処"},"彼処":{"variants":"あそこ/彼処"},"あそばす":{"variants":"あそばす/遊ばす"},"遊ばす":{"variants":"あそばす/遊ばす"},"あそばせ言葉":{"variants":"あそばせ言葉/遊ばせことば/遊ばせ言葉"},"遊ばせことば":{"variants":"あそばせ言葉/遊ばせことば/遊ばせ言葉"},"遊ばせ言葉":{"variants":"あそばせ言葉/遊ばせことば/遊ばせ言葉"},"あそびあきる":{"variants":"あそびあきる/遊びあきる"},"遊びあきる":{"variants":"あそびあきる/遊びあきる"},"あそびあるく":{"variants":"あそびあるく/遊び歩く"},"遊び歩く":{"variants":"あそびあるく/遊び歩く"},"あそびほうける":{"variants":"あそびほうける/遊び呆ける"},"遊び呆ける":{"variants":"あそびほうける/遊び呆ける"},"あそびまわる":{"variants":"あそびまわる/遊び回る"},"遊び回る":{"variants":"あそびまわる/遊び回る"},"あそびまわれる":{"variants":"あそびまわれる/遊び回れる"},"遊び回れる":{"variants":"あそびまわれる/遊び回れる"},"あそぶ":{"variants":"あそぶ/遊ぶ"},"遊ぶ":{"variants":"あそぶ/遊ぶ"},"あそべる":{"variants":"あそべる/遊べる"},"遊べる":{"variants":"あそべる/遊べる"},"あたいする":{"variants":"あたいする/価する/値する"},"あたう":{"variants":"あたう/能う"},"能う":{"variants":"あたう/能う"},"あたえる":{"variants":"あたえる/与える/與える"},"あたかも":{"variants":"あたかも/恰も"},"恰も":{"variants":"あたかも/恰も"},"あたたかい":{"variants":"あたたかい/温かい/暖かい"},"あたたまる":{"variants":"あたたまる/暖まる"},"暖まる":{"variants":"あたたまる/暖まる"},"あたためる":{"variants":"あたためる/暖める"},"暖める":{"variants":"あたためる/暖める"},"アタマ":{"variants":"アタマ/頭"},"頭":{"variants":"アタマ/頭"},"頭割":{"variants":"頭割/頭割り"},"頭割り":{"variants":"頭割/頭割り"},"あたらしい":{"variants":"あたらしい/新しい"},"新しい":{"variants":"あたらしい/新しい"},"あたり":{"variants":"あたり/当たり/当り/辺り"},"当り":{"variants":"あたり/当たり/当り"},"当たり":{"variants":"あたり/当たり/当り"},"当たり狂言":{"variants":"当たり狂言/当り狂言/当狂言"},"当り狂言":{"variants":"当たり狂言/当り狂言/当狂言"},"当狂言":{"variants":"当たり狂言/当り狂言/当狂言"},"当たりさわり":{"variants":"当たりさわり/当たり障り/当りさわり/当り障り"},"当たり障り":{"variants":"当たりさわり/当たり障り/当りさわり/当り障り"},"当りさわり":{"variants":"当たりさわり/当たり障り/当りさわり/当り障り"},"当り障り":{"variants":"当たりさわり/当たり障り/当りさわり/当り障り"},"あたりちらす":{"variants":"あたりちらす/当たり散らす/当り散らす"},"当たり散らす":{"variants":"あたりちらす/当たり散らす/当り散らす"},"当り散らす":{"variants":"あたりちらす/当たり散らす/当り散らす"},"当たり年":{"variants":"当たり年/当り年"},"当り年":{"variants":"当たり年/当り年"},"あたりまえ":{"variants":"あたりまえ/あたり前/当たりまえ/当たり前/当り前"},"あたり前":{"variants":"あたりまえ/あたり前/当たりまえ/当たり前/当り前"},"当たりまえ":{"variants":"あたりまえ/あたり前/当たりまえ/当たり前/当り前"},"当たり前":{"variants":"あたりまえ/あたり前/当たりまえ/当たり前/当り前"},"当り前":{"variants":"あたりまえ/あたり前/当たりまえ/当たり前/当り前"},"あたる":{"variants":"あたる/中る/当たる/当る"},"当る":{"variants":"あたる/当たる/当る"},"当たる":{"variants":"あたる/当たる/当る"},"あたれる":{"variants":"あたれる/当たれる"},"当たれる":{"variants":"あたれる/当たれる"},"あだ討ち":{"variants":"あだ討ち/仇討"},"仇討":{"variants":"あだ討ち/仇討"},"あだする":{"variants":"あだする/仇する/寇する"},"あだっぽい":{"variants":"あだっぽい/婀娜っぽい"},"婀娜っぽい":{"variants":"あだっぽい/婀娜っぽい"},"あだ名":{"variants":"あだ名/仇名/徒名/渾名"},"あだめく":{"variants":"あだめく/婀娜めく"},"婀娜めく":{"variants":"あだめく/婀娜めく"},"あっ":{"variants":"あっ/あッ/アッ"},"あッ":{"variants":"あっ/あッ/アッ"},"アッ":{"variants":"あっ/あッ/アッ"},"あっかんべー":{"variants":"あっかんべー/アッカンベー"},"アッカンベー":{"variants":"あっかんべー/アッカンベー"},"あっけ":{"variants":"あっけ/あっ気/呆気"},"あっ気":{"variants":"あっけ/あっ気/呆気"},"呆気":{"variants":"あっけ/あっ気/呆気"},"あっけない":{"variants":"あっけない/呆気ない"},"呆気ない":{"variants":"あっけない/呆気ない"},"あっする":{"variants":"あっする/圧する"},"圧する":{"variants":"あっする/圧する"},"あっせん":{"variants":"あっせん/あっ旋/斡旋"},"あっ旋":{"variants":"あっせん/あっ旋/斡旋"},"斡旋":{"variants":"あっせん/あっ旋/斡旋"},"あっという間に":{"variants":"あっという間に/あっと言う間に/アッという間に/アッと言う間に"},"あっと言う間に":{"variants":"あっという間に/あっと言う間に/アッという間に/アッと言う間に"},"アッという間に":{"variants":"あっという間に/あっと言う間に/アッという間に/アッと言う間に"},"アッと言う間に":{"variants":"あっという間に/あっと言う間に/アッという間に/アッと言う間に"},"あっぷあっぷ":{"variants":"あっぷあっぷ/アップアップ"},"アップアップ":{"variants":"あっぷあっぷ/アップアップ"},"熱々":{"variants":"熱々/熱熱"},"熱熱":{"variants":"熱々/熱熱"},"あつあつ":{"variants":"あつあつ/アツアツ"},"アツアツ":{"variants":"あつあつ/アツアツ"},"あつい":{"variants":"あつい/厚い/暑い/篤い/熱い"},"あつかう":{"variants":"あつかう/扱う"},"扱う":{"variants":"あつかう/扱う"},"あつかえる":{"variants":"あつかえる/扱える"},"扱える":{"variants":"あつかえる/扱える"},"あつかましい":{"variants":"あつかましい/厚かましい"},"厚かましい":{"variants":"あつかましい/厚かましい"},"熱かん":{"variants":"熱かん/熱澗/熱燗"},"あつくるしい":{"variants":"あつくるしい/暑苦しい/熱苦しい"},"あつぼったい":{"variants":"あつぼったい/厚ぼったい"},"厚ぼったい":{"variants":"あつぼったい/厚ぼったい"},"集まり":{"variants":"集まり/集り"},"集り":{"variants":"集まり/集り"},"あつまる":{"variants":"あつまる/集まる"},"集まる":{"variants":"あつまる/集まる"},"あつめる":{"variants":"あつめる/集める"},"集める":{"variants":"あつめる/集める"},"あつらえる":{"variants":"あつらえる/誂える"},"誂える":{"variants":"あつらえる/誂える"},"あづま":{"variants":"あづま/吾妻"},"吾妻":{"variants":"あづま/吾妻"},"あて":{"variants":"あて/宛て"},"アテ":{"variants":"あて/アテ/宛/宛て/当て"},"宛":{"variants":"あて/アテ/宛/宛て"},"宛て":{"variants":"あて/宛て"},"アテイボク":{"variants":"アテイボク/亜低木"},"亜低木":{"variants":"アテイボク/亜低木"},"あて馬":{"variants":"あて馬/当て馬"},"当て馬":{"variants":"あて馬/当て馬"},"あてがう":{"variants":"あてがう/宛てがう/充てがう"},"あてこする":{"variants":"あてこする/当てこする/当て擦る"},"当てこする":{"variants":"あてこする/当てこする/当て擦る"},"当て擦る":{"variants":"あてこする/当てこする/当て擦る"},"あてこむ":{"variants":"あてこむ/当てこむ/当て込む/当込む"},"当てこむ":{"variants":"あてこむ/当てこむ/当て込む/当込む"},"当て込む":{"variants":"あてこむ/当てこむ/当て込む/当込む"},"当込む":{"variants":"あてこむ/当てこむ/当て込む/当込む"},"あてこめる":{"variants":"あてこめる/当て込める"},"当て込める":{"variants":"あてこめる/当て込める"},"当てごと":{"variants":"当てごと/当て事"},"当て事":{"variants":"当てごと/当て事"},"あて先":{"variants":"あて先/宛先"},"宛先":{"variants":"あて先/宛先"},"あて字":{"variants":"あて字/宛字/当て字/当字"},"当字":{"variants":"あて字/当て字/当字"},"当て字":{"variants":"あて字/当て字/当字"},"当て推量":{"variants":"当て推量/当推量"},"当推量":{"variants":"当て推量/当推量"},"あてずっぽう":{"variants":"あてずっぽう/当てずっぽう"},"当てずっぽう":{"variants":"あてずっぽう/当てずっぽう"},"あてつける":{"variants":"あてつける/当てつける/当て付ける"},"当てつける":{"variants":"あてつける/当てつける/当て付ける"},"当て付ける":{"variants":"あてつける/当てつける/当て付ける"},"あて名":{"variants":"あて名/宛名"},"宛名":{"variants":"あて名/宛名"},"あて無し":{"variants":"あて無し/当てなし/当て無し"},"当てなし":{"variants":"あて無し/当てなし/当て無し"},"当て無し":{"variants":"あて無し/当てなし/当て無し"},"あて外れ":{"variants":"あて外れ/当てはずれ/当て外れ"},"当てはずれ":{"variants":"あて外れ/当てはずれ/当て外れ"},"当て外れ":{"variants":"あて外れ/当てはずれ/当て外れ"},"あてはまる":{"variants":"あてはまる/当てはまる/当て嵌る"},"当てはまる":{"variants":"あてはまる/当てはまる/当て嵌る"},"当て嵌る":{"variants":"あてはまる/当てはまる/当て嵌る"},"あてはめる":{"variants":"あてはめる/当てはめる/当て嵌める"},"当てはめる":{"variants":"あてはめる/当てはめる/当て嵌める"},"当て嵌める":{"variants":"あてはめる/当てはめる/当て嵌める"},"当て身":{"variants":"当て身/当身"},"当身":{"variants":"当て身/当身"},"当てもの":{"variants":"当てもの/当て物"},"当て物":{"variants":"当てもの/当て物"},"あてる":{"variants":"あてる/アテる/宛てる/充てる/当てる"},"アテる":{"variants":"あてる/アテる/宛てる/充てる/当てる"},"あてレコ":{"variants":"あてレコ/アテレコ/当てレコ"},"アテレコ":{"variants":"あてレコ/アテレコ/当てレコ"},"当てレコ":{"variants":"あてレコ/アテレコ/当てレコ"},"あで姿":{"variants":"あで姿/艶姿/艷姿"},"あと":{"variants":"あと/後"},"後":{"variants":"あと/後"},"あとあと":{"variants":"あとあと/後々/後後"},"後々":{"variants":"あとあと/後々/後後"},"後後":{"variants":"あとあと/後々/後後"},"あとがき":{"variants":"あとがき/後書/後書き"},"後書":{"variants":"あとがき/後書/後書き"},"後書き":{"variants":"あとがき/後書/後書き"},"後がま":{"variants":"後がま/後釜"},"後釜":{"variants":"後がま/後釜"},"あとずさる":{"variants":"あとずさる/後ずさる"},"後ずさる":{"variants":"あとずさる/後ずさる"},"あとづける":{"variants":"あとづける/跡づける/跡付ける"},"跡づける":{"variants":"あとづける/跡づける/跡付ける"},"跡付ける":{"variants":"あとづける/跡づける/跡付ける"},"後まわし":{"variants":"後まわし/後回し/後廻し"},"アトリ":{"variants":"アトリ/花鶏"},"花鶏":{"variants":"アトリ/花鶏"},"アナ":{"variants":"アナ/坑/孔"},"アナグマ":{"variants":"アナグマ/穴熊"},"穴熊":{"variants":"アナグマ/穴熊"},"穴ぐら":{"variants":"穴ぐら/穴蔵"},"穴蔵":{"variants":"穴ぐら/穴蔵"},"アナゴ":{"variants":"アナゴ/穴子"},"穴子":{"variants":"アナゴ/穴子"},"あなた":{"variants":"あなた/貴方"},"貴方":{"variants":"あなた/貴方"},"あなた任せ":{"variants":"あなた任せ/貴方任せ"},"貴方任せ":{"variants":"あなた任せ/貴方任せ"},"あなどる":{"variants":"あなどる/侮る"},"侮る":{"variants":"あなどる/侮る"},"あなどれる":{"variants":"あなどれる/侮れる"},"侮れる":{"variants":"あなどれる/侮れる"},"アナ場":{"variants":"アナ場/穴場"},"穴場":{"variants":"アナ場/穴場"},"あに":{"variants":"あに/豈"},"豈":{"variants":"あに/豈"},"兄たち":{"variants":"兄たち/兄達"},"兄達":{"variants":"兄たち/兄達"},"あねさん被り":{"variants":"あねさん被り/姉さんかぶり/姉さん被り"},"姉さんかぶり":{"variants":"あねさん被り/姉さんかぶり/姉さん被り"},"姉さん被り":{"variants":"あねさん被り/姉さんかぶり/姉さん被り"},"姉たち":{"variants":"姉たち/姉達"},"姉達":{"variants":"姉たち/姉達"},"あの世":{"variants":"あの世/彼の世"},"彼の世":{"variants":"あの世/彼の世"},"あばきだす":{"variants":"あばきだす/暴き出す"},"暴き出す":{"variants":"あばきだす/暴き出す"},"あばく":{"variants":"あばく/発く/暴く"},"あばける":{"variants":"あばける/暴ける"},"暴ける":{"variants":"あばける/暴ける"},"あばら屋":{"variants":"あばら屋/荒屋"},"荒屋":{"variants":"あばら屋/荒屋"},"あばれだす":{"variants":"あばれだす/暴れだす/暴れ出す"},"暴れだす":{"variants":"あばれだす/暴れだす/暴れ出す"},"暴れ出す":{"variants":"あばれだす/暴れだす/暴れ出す"},"あばれまくる":{"variants":"あばれまくる/暴れまくる"},"暴れまくる":{"variants":"あばれまくる/暴れまくる"},"あばれる":{"variants":"あばれる/暴れる"},"暴れる":{"variants":"あばれる/暴れる"},"アヒル":{"variants":"アヒル/家鴨"},"家鴨":{"variants":"アヒル/家鴨"},"あびせかける":{"variants":"あびせかける/浴びせかける"},"浴びせかける":{"variants":"あびせかける/浴びせかける"},"あびせる":{"variants":"あびせる/浴びせる"},"浴びせる":{"variants":"あびせる/浴びせる"},"あびる":{"variants":"あびる/浴びる"},"浴びる":{"variants":"あびる/浴びる"},"アブ":{"variants":"アブ/虻"},"虻":{"variants":"アブ/虻"},"あぶない":{"variants":"あぶない/危ない"},"危ない":{"variants":"あぶない/危ない"},"あぶなっかしい":{"variants":"あぶなっかしい/危なっかしい"},"危なっかしい":{"variants":"あぶなっかしい/危なっかしい"},"油絵の具":{"variants":"油絵の具/油絵具"},"油絵具":{"variants":"油絵の具/油絵具"},"あぶらぎる":{"variants":"あぶらぎる/脂ぎる"},"脂ぎる":{"variants":"あぶらぎる/脂ぎる"},"あぶらじみる":{"variants":"あぶらじみる/油染みる"},"油染みる":{"variants":"あぶらじみる/油染みる"},"アブラゼミ":{"variants":"アブラゼミ/油蝉"},"油蝉":{"variants":"アブラゼミ/油蝉"},"あぶらっこい":{"variants":"あぶらっこい/油っこい"},"油っこい":{"variants":"あぶらっこい/油っこい"},"アブラナ":{"variants":"アブラナ/油菜"},"油菜":{"variants":"アブラナ/油菜"},"あぶら身":{"variants":"あぶら身/脂身"},"脂身":{"variants":"あぶら身/脂身"},"あぶら虫":{"variants":"あぶら虫/アブラムシ/油虫"},"アブラムシ":{"variants":"あぶら虫/アブラムシ/油虫"},"油虫":{"variants":"あぶら虫/アブラムシ/油虫"},"あぶり出し":{"variants":"あぶり出し/炙りだし/炙り出し/炙出し"},"炙りだし":{"variants":"あぶり出し/炙りだし/炙り出し/炙出し"},"炙り出し":{"variants":"あぶり出し/炙りだし/炙り出し/炙出し"},"炙出し":{"variants":"あぶり出し/炙りだし/炙り出し/炙出し"},"あぶり物":{"variants":"あぶり物/炙りもの/炙り物"},"炙りもの":{"variants":"あぶり物/炙りもの/炙り物"},"炙り物":{"variants":"あぶり物/炙りもの/炙り物"},"あぶる":{"variants":"あぶる/炙る/焙る"},"アヘン":{"variants":"アヘン/阿片/鴉片"},"安倍川もち":{"variants":"安倍川もち/安倍川餅"},"安倍川餅":{"variants":"安倍川もち/安倍川餅"},"アホ":{"variants":"アホ/阿呆"},"阿呆":{"variants":"アホ/阿呆"},"アホウドリ":{"variants":"アホウドリ/信天翁"},"信天翁":{"variants":"アホウドリ/信天翁"},"アマ":{"variants":"アマ/亜麻/阿媽/海女/海人/尼/蜑"},"あまえる":{"variants":"あまえる/甘える"},"甘える":{"variants":"あまえる/甘える"},"あまえん坊":{"variants":"あまえん坊/甘えんぼう/甘えん坊"},"甘えんぼう":{"variants":"あまえん坊/甘えんぼう/甘えん坊"},"甘えん坊":{"variants":"あまえん坊/甘えんぼう/甘えん坊"},"あまからい":{"variants":"あまからい/甘辛い"},"甘辛い":{"variants":"あまからい/甘辛い"},"アマガエル":{"variants":"アマガエル/雨蛙"},"雨蛙":{"variants":"アマガエル/雨蛙"},"あまがける":{"variants":"あまがける/天翔る"},"天翔る":{"variants":"あまがける/天翔る"},"雨がさ":{"variants":"雨がさ/雨ガサ/雨笠/雨傘"},"雨ガサ":{"variants":"雨がさ/雨ガサ/雨笠/雨傘"},"雨がっぱ":{"variants":"雨がっぱ/雨合羽"},"雨合羽":{"variants":"雨がっぱ/雨合羽"},"甘グリ":{"variants":"甘グリ/甘栗"},"甘栗":{"variants":"甘グリ/甘栗"},"雨ごい":{"variants":"雨ごい/雨乞い"},"雨乞い":{"variants":"雨ごい/雨乞い"},"雨ざらし":{"variants":"雨ざらし/雨曝し"},"雨曝し":{"variants":"雨ざらし/雨曝し"},"あます":{"variants":"あます/余す"},"余す":{"variants":"あます/余す"},"あまずっぱい":{"variants":"あまずっぱい/甘ずっぱい/甘酸っぱい"},"甘ずっぱい":{"variants":"あまずっぱい/甘ずっぱい/甘酸っぱい"},"甘酸っぱい":{"variants":"あまずっぱい/甘ずっぱい/甘酸っぱい"},"あまた":{"variants":"あまた/数多"},"数多":{"variants":"あまた/数多"},"アマダイ":{"variants":"アマダイ/甘鯛"},"甘鯛":{"variants":"アマダイ/甘鯛"},"雨だれ":{"variants":"雨だれ/雨垂れ"},"雨垂れ":{"variants":"雨だれ/雨垂れ"},"あまちょろい":{"variants":"あまちょろい/甘ちょろい"},"甘ちょろい":{"variants":"あまちょろい/甘ちょろい"},"あまっさえ":{"variants":"あまっさえ/剰え"},"剰え":{"variants":"あまっさえ/剰え"},"あまったるい":{"variants":"あまったるい/甘ったるい"},"甘ったるい":{"variants":"あまったるい/甘ったるい"},"あまったれる":{"variants":"あまったれる/甘ったれる"},"甘ったれる":{"variants":"あまったれる/甘ったれる"},"あまねい":{"variants":"あまねい/普い/遍い/洽い"},"あまねく":{"variants":"あまねく/普く/遍く/洽く"},"天の邪鬼":{"variants":"天の邪鬼/天邪鬼"},"天邪鬼":{"variants":"天の邪鬼/天邪鬼"},"アマノリ":{"variants":"アマノリ/甘海苔"},"甘海苔":{"variants":"アマノリ/甘海苔"},"甘みそ":{"variants":"甘みそ/甘味噌"},"甘味噌":{"variants":"甘みそ/甘味噌"},"あまやかす":{"variants":"あまやかす/甘やかす"},"甘やかす":{"variants":"あまやかす/甘やかす"},"雨よけ":{"variants":"雨よけ/雨避け"},"雨避け":{"variants":"雨よけ/雨避け"},"あまり":{"variants":"あまり/余り"},"余り":{"variants":"あまり/余り"},"あまりに":{"variants":"あまりに/余りに"},"余りに":{"variants":"あまりに/余りに"},"余りもの":{"variants":"余りもの/余り者/余り物"},"あまる":{"variants":"あまる/剰る/余る"},"あまんじる":{"variants":"あまんじる/甘んじる"},"甘んじる":{"variants":"あまんじる/甘んじる"},"あまんずる":{"variants":"あまんずる/甘んずる"},"甘んずる":{"variants":"あまんずる/甘んずる"},"アミ":{"variants":"アミ/阿弥/糠蝦/醤蝦/編み/網"},"あみあげる":{"variants":"あみあげる/編み上げる"},"編み上げる":{"variants":"あみあげる/編み上げる"},"あみこむ":{"variants":"あみこむ/編み込む"},"編み込む":{"variants":"あみこむ/編み込む"},"あみだす":{"variants":"あみだす/あみ出す/編みだす/編み出す/編出す"},"あみ出す":{"variants":"あみだす/あみ出す/編みだす/編み出す/編出す"},"編みだす":{"variants":"あみだす/あみ出す/編みだす/編み出す/編出す"},"編み出す":{"variants":"あみだす/あみ出す/編みだす/編み出す/編出す"},"編出す":{"variants":"あみだす/あみ出す/編みだす/編み出す/編出す"},"網だな":{"variants":"網だな/網棚"},"網棚":{"variants":"網だな/網棚"},"編針":{"variants":"編み針/編針"},"編み針":{"variants":"編み針/編針"},"編み棒":{"variants":"編み棒/編棒"},"編棒":{"variants":"編み棒/編棒"},"編みもの":{"variants":"編みもの/編み物/編物"},"編み物":{"variants":"編みもの/編み物/編物"},"編物":{"variants":"編みもの/編み物/編物"},"あむ":{"variants":"あむ/編む"},"編む":{"variants":"あむ/編む"},"あめ":{"variants":"あめ/アメ/飴/雨"},"アメ":{"variants":"あめ/アメ/飴/雨"},"雨上がり":{"variants":"雨上がり/雨上り"},"雨上り":{"variants":"雨上がり/雨上り"},"雨あられ":{"variants":"雨あられ/雨霰"},"雨霰":{"variants":"雨あられ/雨霰"},"あめ色":{"variants":"あめ色/飴色"},"飴色":{"variants":"あめ色/飴色"},"雨ふり":{"variants":"雨ふり/雨降り"},"雨降り":{"variants":"雨ふり/雨降り"},"アメリカシロヒトリ":{"variants":"アメリカシロヒトリ/アメリカ白火取"},"アメリカ白火取":{"variants":"アメリカシロヒトリ/アメリカ白火取"},"あめる":{"variants":"あめる/編める"},"編める":{"variants":"あめる/編める"},"アメンボ":{"variants":"アメンボ/水黽"},"水黽":{"variants":"アメンボ/水黽"},"アヤ":{"variants":"アヤ/絢/綾/彪"},"あやい":{"variants":"あやい/異い/怪い"},"あやうい":{"variants":"あやうい/危うい"},"危うい":{"variants":"あやうい/危うい"},"あや織り":{"variants":"あや織り/綾織"},"綾織":{"variants":"あや織り/綾織"},"あやかる":{"variants":"あやかる/肖る"},"肖る":{"variants":"あやかる/肖る"},"あやしい":{"variants":"あやしい/怪しい/妖しい"},"怪しげ":{"variants":"怪しげ/怪し気"},"怪し気":{"variants":"怪しげ/怪し気"},"あやしむ":{"variants":"あやしむ/怪しむ"},"怪しむ":{"variants":"あやしむ/怪しむ"},"あやつる":{"variants":"あやつる/操る"},"操る":{"variants":"あやつる/操る"},"あやつれる":{"variants":"あやつれる/操れる"},"操れる":{"variants":"あやつれる/操れる"},"あやとり":{"variants":"あやとり/綾取り"},"綾取り":{"variants":"あやとり/綾取り"},"あやどる":{"variants":"あやどる/綾取る"},"綾取る":{"variants":"あやどる/綾取る"},"あやなす":{"variants":"あやなす/綾なす"},"綾なす":{"variants":"あやなす/綾なす"},"あやぶむ":{"variants":"あやぶむ/危ぶむ"},"危ぶむ":{"variants":"あやぶむ/危ぶむ"},"あやまつ":{"variants":"あやまつ/過つ"},"過つ":{"variants":"あやまつ/過つ"},"あやまらす":{"variants":"あやまらす/誤らす"},"誤らす":{"variants":"あやまらす/誤らす"},"あやまる":{"variants":"あやまる/誤る/謝る"},"あやまれる":{"variants":"あやまれる/謝れる"},"謝れる":{"variants":"あやまれる/謝れる"},"アヤメ":{"variants":"アヤメ/文目"},"文目":{"variants":"アヤメ/文目"},"あやめる":{"variants":"あやめる/殺める"},"殺める":{"variants":"あやめる/殺める"},"アユ":{"variants":"アユ/鮎"},"鮎":{"variants":"アユ/鮎"},"あゆみよる":{"variants":"あゆみよる/歩みよる/歩み寄る"},"歩みよる":{"variants":"あゆみよる/歩みよる/歩み寄る"},"歩み寄る":{"variants":"あゆみよる/歩みよる/歩み寄る"},"あゆみよれる":{"variants":"あゆみよれる/歩み寄れる"},"歩み寄れる":{"variants":"あゆみよれる/歩み寄れる"},"あゆむ":{"variants":"あゆむ/歩む"},"歩む":{"variants":"あゆむ/歩む"},"あらあらしい":{"variants":"あらあらしい/荒々しい/荒荒しい"},"荒々しい":{"variants":"あらあらしい/荒々しい/荒荒しい"},"荒荒しい":{"variants":"あらあらしい/荒々しい/荒荒しい"},"あらい":{"variants":"あらい/荒い/粗い"},"洗":{"variants":"洗/洗い"},"洗い":{"variants":"洗/洗い"},"あらいあげる":{"variants":"あらいあげる/洗い上げる/洗上げる"},"洗い上げる":{"variants":"あらいあげる/洗い上げる/洗上げる"},"洗上げる":{"variants":"あらいあげる/洗い上げる/洗上げる"},"あらいおとす":{"variants":"あらいおとす/洗い落とす"},"洗い落とす":{"variants":"あらいおとす/洗い落とす"},"あらいおとせる":{"variants":"あらいおとせる/洗い落とせる"},"洗い落とせる":{"variants":"あらいおとせる/洗い落とせる"},"洗い粉":{"variants":"洗い粉/洗粉"},"洗粉":{"variants":"洗い粉/洗粉"},"洗いざらい":{"variants":"洗いざらい/洗い浚い"},"洗い浚い":{"variants":"洗いざらい/洗い浚い"},"洗いざらし":{"variants":"洗いざらし/洗い晒し"},"洗い晒し":{"variants":"洗いざらし/洗い晒し"},"洗いすすぎ":{"variants":"洗いすすぎ/洗い濯ぎ"},"洗い濯ぎ":{"variants":"洗いすすぎ/洗い濯ぎ"},"洗いたて":{"variants":"洗いたて/洗い立て"},"洗い立て":{"variants":"洗いたて/洗い立て"},"あらいたてる":{"variants":"あらいたてる/洗い立てる"},"洗い立てる":{"variants":"あらいたてる/洗い立てる"},"あらいだす":{"variants":"あらいだす/洗い出す"},"洗い出す":{"variants":"あらいだす/洗い出す"},"あらいながす":{"variants":"あらいながす/洗い流す"},"洗い流す":{"variants":"あらいながす/洗い流す"},"あらいながせる":{"variants":"あらいながせる/洗い流せる"},"洗い流せる":{"variants":"あらいながせる/洗い流せる"},"洗いもの":{"variants":"洗いもの/洗い物"},"洗い物":{"variants":"洗いもの/洗い物"},"あらう":{"variants":"あらう/洗う/濯う"},"あらえる":{"variants":"あらえる/洗える"},"洗える":{"variants":"あらえる/洗える"},"ア・ラ・カルト":{"variants":"ア・ラ・カルト/アラカルト"},"アラカルト":{"variants":"ア・ラ・カルト/アラカルト"},"あらがう":{"variants":"あらがう/抗う"},"抗う":{"variants":"あらがう/抗う"},"あらごなし":{"variants":"あらごなし/粗ごなし"},"粗ごなし":{"variants":"あらごなし/粗ごなし"},"あらし":{"variants":"あらし/嵐"},"嵐":{"variants":"あらし/嵐"},"あら塩":{"variants":"あら塩/粗塩"},"粗塩":{"variants":"あら塩/粗塩"},"あらしまわる":{"variants":"あらしまわる/荒し回る"},"荒し回る":{"variants":"あらしまわる/荒し回る"},"あらす":{"variants":"あらす/荒す/荒らす"},"荒す":{"variants":"あらす/荒す/荒らす"},"荒らす":{"variants":"あらす/荒す/荒らす"},"あらせる":{"variants":"あらせる/荒らせる"},"荒らせる":{"variants":"あらせる/荒らせる"},"あらそう":{"variants":"あらそう/争う"},"争う":{"variants":"あらそう/争う"},"あらそえる":{"variants":"あらそえる/争える"},"争える":{"variants":"あらそえる/争える"},"あらた":{"variants":"あらた/新た"},"新た":{"variants":"あらた/新た"},"あらたまる":{"variants":"あらたまる/改まる/革まる"},"改":{"variants":"改/改め"},"改め":{"variants":"改/改め"},"あらためる":{"variants":"あらためる/改める/革める/検める"},"あらだつ":{"variants":"あらだつ/荒立つ"},"荒立つ":{"variants":"あらだつ/荒立つ"},"あらだてる":{"variants":"あらだてる/荒立てる"},"荒立てる":{"variants":"あらだてる/荒立てる"},"あらっぽい":{"variants":"あらっぽい/荒っぽい"},"荒っぽい":{"variants":"あらっぽい/荒っぽい"},"アラメ":{"variants":"アラメ/荒布"},"荒布":{"variants":"アラメ/荒布"},"あらわ":{"variants":"あらわ/顕/露"},"荒わざ":{"variants":"荒わざ/荒業"},"荒業":{"variants":"荒わざ/荒業"},"あらわす":{"variants":"あらわす/顕す/現す/著す/表す/表わす"},"表す":{"variants":"あらわす/表す/表わす"},"表わす":{"variants":"あらわす/表す/表わす"},"あらわれ":{"variants":"あらわれ/現れ/表れ"},"あらわれる":{"variants":"あらわれる/顕れる/現れる/現われる/表れる"},"現れる":{"variants":"あらわれる/現れる/現われる"},"現われる":{"variants":"あらわれる/現れる/現われる"},"アリ":{"variants":"アリ/蟻"},"蟻":{"variants":"アリ/蟻"},"ありあまる":{"variants":"ありあまる/有り余る/有余る"},"有り余る":{"variants":"ありあまる/有り余る/有余る"},"有余る":{"variants":"ありあまる/有り余る/有余る"},"有り合わせ":{"variants":"有り合わせ/有合せ"},"有合せ":{"variants":"有り合わせ/有合せ"},"ありあわせる":{"variants":"ありあわせる/あり合せる/在りあわせる/在り合せる/在り合わせる/有りあわせる/有り合せる/有り合わせる"},"あり合せる":{"variants":"ありあわせる/あり合せる/在りあわせる/在り合せる/在り合わせる/有りあわせる/有り合せる/有り合わせる"},"在り合わせる":{"variants":"ありあわせる/あり合せる/在りあわせる/在り合せる/在り合わせる"},"有り合わせる":{"variants":"ありあわせる/あり合せる/有りあわせる/有り合せる/有り合わせる"},"在り合せる":{"variants":"ありあわせる/あり合せる/在りあわせる/在り合せる/在り合わせる"},"在りあわせる":{"variants":"ありあわせる/あり合せる/在りあわせる/在り合せる/在り合わせる"},"有り合せる":{"variants":"ありあわせる/あり合せる/有りあわせる/有り合せる/有り合わせる"},"有りあわせる":{"variants":"ありあわせる/あり合せる/有りあわせる/有り合せる/有り合わせる"},"ありえる":{"variants":"ありえる/有り得る"},"有り得る":{"variants":"ありえる/有り得る"},"あり方":{"variants":"あり方/在りかた/在り方"},"在りかた":{"variants":"あり方/在りかた/在り方"},"在り方":{"variants":"あり方/在りかた/在り方"},"ありがたい":{"variants":"ありがたい/有り難い/有難い"},"有り難い":{"variants":"ありがたい/有り難い/有難い"},"有難い":{"variants":"ありがたい/有り難い/有難い"},"ありがたがる":{"variants":"ありがたがる/有難がる"},"有難がる":{"variants":"ありがたがる/有難がる"},"ありがたみ":{"variants":"ありがたみ/ありがた味/有難み/有難味"},"ありがた味":{"variants":"ありがたみ/ありがた味/有難み/有難味"},"有難み":{"variants":"ありがたみ/ありがた味/有難み/有難味"},"有難味":{"variants":"ありがたみ/ありがた味/有難み/有難味"},"ありがた迷惑":{"variants":"ありがた迷惑/有難迷惑"},"有難迷惑":{"variants":"ありがた迷惑/有難迷惑"},"ありがとう":{"variants":"ありがとう/アリガトウ/有難う"},"アリガトウ":{"variants":"ありがとう/アリガトウ/有難う"},"有難う":{"variants":"ありがとう/アリガトウ/有難う"},"アリクイ":{"variants":"アリクイ/蟻食"},"蟻食":{"variants":"アリクイ/蟻食"},"有り様":{"variants":"有り様/有様"},"有様":{"variants":"有り様/有様"},"アリジゴク":{"variants":"アリジゴク/蟻地獄"},"蟻地獄":{"variants":"アリジゴク/蟻地獄"},"アリヅカ":{"variants":"アリヅカ/蟻塚"},"蟻塚":{"variants":"アリヅカ/蟻塚"},"ありてい":{"variants":"ありてい/有体"},"有体":{"variants":"ありてい/有体"},"アリノトウ":{"variants":"アリノトウ/蟻の塔"},"蟻の塔":{"variants":"アリノトウ/蟻の塔"},"ありふれる":{"variants":"ありふれる/有りふれる/有り触れる/有触れる"},"有りふれる":{"variants":"ありふれる/有りふれる/有り触れる/有触れる"},"有り触れる":{"variants":"ありふれる/有りふれる/有り触れる/有触れる"},"有触れる":{"variants":"ありふれる/有りふれる/有り触れる/有触れる"},"アリマキ":{"variants":"アリマキ/蟻巻"},"蟻巻":{"variants":"アリマキ/蟻巻"},"ある":{"variants":"ある/或"},"或":{"variants":"ある/或"},"あるいは":{"variants":"あるいは/或いは/或は"},"或いは":{"variants":"あるいは/或いは/或は"},"或は":{"variants":"あるいは/或いは/或は"},"あるきつかれる":{"variants":"あるきつかれる/歩き疲れる"},"歩き疲れる":{"variants":"あるきつかれる/歩き疲れる"},"あるきつめる":{"variants":"あるきつめる/歩きつめる"},"歩きつめる":{"variants":"あるきつめる/歩きつめる"},"あるきまわる":{"variants":"あるきまわる/歩き回る"},"歩き回る":{"variants":"あるきまわる/歩き回る"},"あるきまわれる":{"variants":"あるきまわれる/歩き回れる"},"歩き回れる":{"variants":"あるきまわれる/歩き回れる"},"あるく":{"variants":"あるく/歩く"},"歩く":{"variants":"あるく/歩く"},"あるける":{"variants":"あるける/歩ける"},"歩ける":{"variants":"あるける/歩ける"},"アルファ線":{"variants":"アルファ線/α線"},"α線":{"variants":"アルファ線/α線"},"アレイ":{"variants":"アレイ/亜鈴/唖鈴"},"あれくるう":{"variants":"あれくるう/荒れ狂う"},"荒れ狂う":{"variants":"あれくるう/荒れ狂う"},"あれこれ":{"variants":"あれこれ/彼是"},"彼是":{"variants":"あれこれ/彼是"},"あれ性":{"variants":"あれ性/荒れ性/荒性"},"荒れ性":{"variants":"あれ性/荒れ性/荒性"},"荒性":{"variants":"あれ性/荒れ性/荒性"},"荒れ地":{"variants":"荒れ地/荒地"},"荒地":{"variants":"荒れ地/荒地"},"あれ肌":{"variants":"あれ肌/荒れはだ/荒れ肌/荒肌"},"荒れはだ":{"variants":"あれ肌/荒れはだ/荒れ肌/荒肌"},"荒れ肌":{"variants":"あれ肌/荒れはだ/荒れ肌/荒肌"},"荒肌":{"variants":"あれ肌/荒れはだ/荒れ肌/荒肌"},"あれる":{"variants":"あれる/荒れる"},"荒れる":{"variants":"あれる/荒れる"},"あわ":{"variants":"あわ/アワ/粟/泡/沫"},"アワ":{"variants":"あわ/アワ/粟/泡/沫"},"あわい":{"variants":"あわい/淡い"},"淡い":{"variants":"あわい/淡い"},"あわさる":{"variants":"あわさる/合さる/合わさる"},"合さる":{"variants":"あわさる/合さる/合わさる"},"合わさる":{"variants":"あわさる/合さる/合わさる"},"あわす":{"variants":"あわす/会わす/合す/合わす"},"合わす":{"variants":"あわす/合す/合わす"},"合す":{"variants":"あわす/合す/合わす"},"合わせ":{"variants":"合せ/合わせ"},"合せ":{"variants":"合せ/合わせ"},"あわせ糸":{"variants":"あわせ糸/合せ糸"},"合せ糸":{"variants":"あわせ糸/合せ糸"},"あわせ鏡":{"variants":"あわせ鏡/合せ鏡"},"合せ鏡":{"variants":"あわせ鏡/合せ鏡"},"あわせ酢":{"variants":"あわせ酢/合せ酢"},"合せ酢":{"variants":"あわせ酢/合せ酢"},"あわせて":{"variants":"あわせて/併せて"},"併せて":{"variants":"あわせて/併せて"},"あわせる":{"variants":"あわせる/合せる/合わせる/併せる"},"合わせる":{"variants":"あわせる/合せる/合わせる"},"合せる":{"variants":"あわせる/合せる/合わせる"},"あわただしい":{"variants":"あわただしい/慌しい/慌ただしい/遽しい"},"慌ただしい":{"variants":"あわただしい/慌しい/慌ただしい"},"慌しい":{"variants":"あわただしい/慌しい/慌ただしい"},"あわだつ":{"variants":"あわだつ/あわ立つ/粟立つ/泡立つ"},"あわ立つ":{"variants":"あわだつ/あわ立つ/粟立つ/泡立つ"},"あわだてる":{"variants":"あわだてる/泡立てる"},"泡立てる":{"variants":"あわだてる/泡立てる"},"あわてる":{"variants":"あわてる/慌てる/周章てる"},"アワビ":{"variants":"アワビ/鮑"},"鮑":{"variants":"アワビ/鮑"},"あわれがる":{"variants":"あわれがる/哀れがる"},"哀れがる":{"variants":"あわれがる/哀れがる"},"あわれむ":{"variants":"あわれむ/哀れむ/憐れむ"},"あん":{"variants":"あん/案/餡"},"暗々":{"variants":"暗々/暗暗"},"暗暗":{"variants":"暗々/暗暗"},"暗々裏":{"variants":"暗々裏/暗暗裏"},"暗暗裏":{"variants":"暗々裏/暗暗裏"},"暗きょ":{"variants":"暗きょ/暗渠"},"暗渠":{"variants":"暗きょ/暗渠"},"安・近・短":{"variants":"安・近・短/安近短"},"安近短":{"variants":"安・近・短/安近短"},"アンコウ":{"variants":"アンコウ/暗紅/鮟/鮟鱇/鱇"},"あんころ餅":{"variants":"あんころ餅/餡ころもち/餡ころ餅"},"餡ころもち":{"variants":"あんころ餅/餡ころもち/餡ころ餅"},"餡ころ餅":{"variants":"あんころ餅/餡ころもち/餡ころ餅"},"アンゴラうさぎ":{"variants":"アンゴラうさぎ/アンゴラウサギ/アンゴラ兎"},"アンゴラウサギ":{"variants":"アンゴラうさぎ/アンゴラウサギ/アンゴラ兎"},"アンゴラ兎":{"variants":"アンゴラうさぎ/アンゴラウサギ/アンゴラ兎"},"アンゴラやぎ":{"variants":"アンゴラやぎ/アンゴラヤギ"},"アンゴラヤギ":{"variants":"アンゴラやぎ/アンゴラヤギ"},"あんしん":{"variants":"あんしん/安心/安神"},"あんじる":{"variants":"あんじる/按じる/案じる"},"アンズ":{"variants":"アンズ/杏/杏子"},"あんずる":{"variants":"あんずる/按ずる/案ずる"},"アンソクコウ":{"variants":"アンソクコウ/安息香"},"安息香":{"variants":"アンソクコウ/安息香"},"暗たん":{"variants":"暗たん/暗澹"},"暗澹":{"variants":"暗たん/暗澹"},"アンダ":{"variants":"アンダ/安打"},"安打":{"variants":"アンダ/安打"},"あんど":{"variants":"あんど/安ど/安堵"},"安ど":{"variants":"あんど/安ど/安堵"},"安堵":{"variants":"あんど/安ど/安堵"},"あんに":{"variants":"あんに/暗に"},"暗に":{"variants":"あんに/暗に"},"あん馬":{"variants":"あん馬/鞍馬"},"鞍馬":{"variants":"あん馬/鞍馬"},"塩ばい":{"variants":"塩ばい/塩梅"},"塩梅":{"variants":"塩ばい/塩梅"},"あんぱん":{"variants":"あんぱん/アンパン"},"アンパン":{"variants":"あんぱん/アンパン"},"あん分":{"variants":"あん分/按分/案分"},"あん摩":{"variants":"あん摩/按摩"},"按摩":{"variants":"あん摩/按摩"},"あんゆ":{"variants":"あんゆ/暗ゆ/暗喩"},"暗ゆ":{"variants":"あんゆ/暗ゆ/暗喩"},"暗喩":{"variants":"あんゆ/暗ゆ/暗喩"},"安楽いす":{"variants":"安楽いす/安楽椅子"},"安楽椅子":{"variants":"安楽いす/安楽椅子"},"居合い":{"variants":"居合/居合い"},"居合":{"variants":"居合/居合い"},"いあわせる":{"variants":"いあわせる/居合せる/居合わせる"},"居合せる":{"variants":"いあわせる/居合せる/居合わせる"},"居合わせる":{"variants":"いあわせる/居合せる/居合わせる"},"唯唯":{"variants":"唯々/唯唯"},"易々":{"variants":"易々/易易"},"唯々":{"variants":"唯々/唯唯"},"易易":{"variants":"易々/易易"},"いいあう":{"variants":"いいあう/言いあう/言い合う/言合う"},"言いあう":{"variants":"いいあう/言いあう/言い合う/言合う"},"言い合う":{"variants":"いいあう/言いあう/言い合う/言合う"},"言合う":{"variants":"いいあう/言いあう/言い合う/言合う"},"いいあてる":{"variants":"いいあてる/言い当てる"},"言い当てる":{"variants":"いいあてる/言い当てる"},"いいあやまる":{"variants":"いいあやまる/言い誤る/言誤る"},"言い誤る":{"variants":"いいあやまる/言い誤る/言誤る"},"言誤る":{"variants":"いいあやまる/言い誤る/言誤る"},"いいあらそう":{"variants":"いいあらそう/言い争う"},"言い争う":{"variants":"いいあらそう/言い争う"},"いいあらそえる":{"variants":"いいあらそえる/言い争える"},"言い争える":{"variants":"いいあらそえる/言い争える"},"いいあらわす":{"variants":"いいあらわす/いい表す/言い表す/言ひ現す"},"言い表す":{"variants":"いいあらわす/いい表す/言い表す"},"いい表す":{"variants":"いいあらわす/いい表す/言い表す"},"いいあらわせる":{"variants":"いいあらわせる/言い表せる"},"言い表せる":{"variants":"いいあらわせる/言い表せる"},"いいあわせる":{"variants":"いいあわせる/言いあわせる/言い合せる"},"言いあわせる":{"variants":"いいあわせる/言いあわせる/言い合せる"},"言い合せる":{"variants":"いいあわせる/言いあわせる/言い合せる"},"いいおく":{"variants":"いいおく/言いおく"},"言いおく":{"variants":"いいおく/言いおく"},"いいおとす":{"variants":"いいおとす/言い落す"},"言い落す":{"variants":"いいおとす/言い落す"},"いいおよぼす":{"variants":"いいおよぼす/言い及す"},"言い及す":{"variants":"いいおよぼす/言い及す"},"いいおわる":{"variants":"いいおわる/言い終わる"},"言い終わる":{"variants":"いいおわる/言い終わる"},"いいかえす":{"variants":"いいかえす/言い返す/言返す"},"言い返す":{"variants":"いいかえす/言い返す/言返す"},"言返す":{"variants":"いいかえす/言い返す/言返す"},"いいかえせる":{"variants":"いいかえせる/言い返せる"},"言い返せる":{"variants":"いいかえせる/言い返せる"},"いいかえる":{"variants":"いいかえる/言い換える/言い替える"},"いいかげん":{"variants":"いいかげん/いい加減/好い加減"},"いい加減":{"variants":"いいかげん/いい加減/好い加減"},"好い加減":{"variants":"いいかげん/いい加減/好い加減"},"いいかねる":{"variants":"いいかねる/言い兼ねる"},"言い兼ねる":{"variants":"いいかねる/言い兼ねる"},"いいかわす":{"variants":"いいかわす/言い交す/言い交わす"},"言い交す":{"variants":"いいかわす/言い交す/言い交わす"},"言い交わす":{"variants":"いいかわす/言い交す/言い交わす"},"言いがかり":{"variants":"言いがかり/言い掛かり/言い掛り"},"言い掛かり":{"variants":"言いがかり/言い掛かり/言い掛り"},"言い掛り":{"variants":"言いがかり/言い掛かり/言い掛り"},"いいきかす":{"variants":"いいきかす/言い聞かす"},"言い聞かす":{"variants":"いいきかす/言い聞かす"},"いいきかせる":{"variants":"いいきかせる/言い聞かせる"},"言い聞かせる":{"variants":"いいきかせる/言い聞かせる"},"いいきる":{"variants":"いいきる/言いきる/言い切る/言切る"},"言いきる":{"variants":"いいきる/言いきる/言い切る/言切る"},"言い切る":{"variants":"いいきる/言いきる/言い切る/言切る"},"言切る":{"variants":"いいきる/言いきる/言い切る/言切る"},"いいくらす":{"variants":"いいくらす/言いくらす/言い暮す"},"言いくらす":{"variants":"いいくらす/言いくらす/言い暮す"},"言い暮す":{"variants":"いいくらす/言いくらす/言い暮す"},"いいくるめる":{"variants":"いいくるめる/言いくるめる"},"言いくるめる":{"variants":"いいくるめる/言いくるめる"},"言いぐさ":{"variants":"言いぐさ/言い種/言い草"},"いいけす":{"variants":"いいけす/言い消す/言消す"},"言い消す":{"variants":"いいけす/言い消す/言消す"},"言消す":{"variants":"いいけす/言い消す/言消す"},"いいこめる":{"variants":"いいこめる/言いこめる/言い込める"},"言いこめる":{"variants":"いいこめる/言いこめる/言い込める"},"言い込める":{"variants":"いいこめる/言いこめる/言い込める"},"いいすてる":{"variants":"いいすてる/言いすてる/言い捨てる/言捨てる"},"言いすてる":{"variants":"いいすてる/言いすてる/言い捨てる/言捨てる"},"言い捨てる":{"variants":"いいすてる/言いすてる/言い捨てる/言捨てる"},"言捨てる":{"variants":"いいすてる/言いすてる/言い捨てる/言捨てる"},"いいそこなう":{"variants":"いいそこなう/言いそこなう/言い損なう/言損なう"},"言いそこなう":{"variants":"いいそこなう/言いそこなう/言い損なう/言損なう"},"言い損なう":{"variants":"いいそこなう/言いそこなう/言い損なう/言損なう"},"言損なう":{"variants":"いいそこなう/言いそこなう/言い損なう/言損なう"},"いいそびれる":{"variants":"いいそびれる/言いそびれる"},"言いそびれる":{"variants":"いいそびれる/言いそびれる"},"いいたてる":{"variants":"いいたてる/言いたてる/言い立てる/言立てる"},"言いたてる":{"variants":"いいたてる/言いたてる/言い立てる/言立てる"},"言い立てる":{"variants":"いいたてる/言いたてる/言い立てる/言立てる"},"言立てる":{"variants":"いいたてる/言いたてる/言い立てる/言立てる"},"イイダコ":{"variants":"イイダコ/飯蛸"},"飯蛸":{"variants":"イイダコ/飯蛸"},"言いだしっぺ":{"variants":"言いだしっぺ/言い出しっぺ/言出しっぺ/言出しっ屁"},"言い出しっぺ":{"variants":"言いだしっぺ/言い出しっぺ/言出しっぺ/言出しっ屁"},"言出しっぺ":{"variants":"言いだしっぺ/言い出しっぺ/言出しっぺ/言出しっ屁"},"言出しっ屁":{"variants":"言いだしっぺ/言い出しっぺ/言出しっぺ/言出しっ屁"},"いいだす":{"variants":"いいだす/言いだす/言い出す"},"言いだす":{"variants":"いいだす/言いだす/言い出す"},"言い出す":{"variants":"いいだす/言いだす/言い出す"},"いいだせる":{"variants":"いいだせる/言い出せる"},"言い出せる":{"variants":"いいだせる/言い出せる"},"いいつかる":{"variants":"いいつかる/言いつかる/言い付かる"},"言いつかる":{"variants":"いいつかる/言いつかる/言い付かる"},"言い付かる":{"variants":"いいつかる/言いつかる/言い付かる"},"いいつくす":{"variants":"いいつくす/言いつくす/言い尽くす/言い尽す/言尽す"},"言いつくす":{"variants":"いいつくす/言いつくす/言い尽くす/言い尽す/言尽す"},"言い尽くす":{"variants":"いいつくす/言いつくす/言い尽くす/言い尽す/言尽す"},"言い尽す":{"variants":"いいつくす/言いつくす/言い尽くす/言い尽す/言尽す"},"言尽す":{"variants":"いいつくす/言いつくす/言い尽くす/言い尽す/言尽す"},"いいつける":{"variants":"いいつける/言いつける/言い付ける"},"言いつける":{"variants":"いいつける/言いつける/言い付ける"},"言い付ける":{"variants":"いいつける/言いつける/言い付ける"},"言い伝え":{"variants":"言い伝え/言伝え"},"言伝え":{"variants":"言い伝え/言伝え"},"いいつたえる":{"variants":"いいつたえる/言い伝える"},"言い伝える":{"variants":"いいつたえる/言い伝える"},"いいつのる":{"variants":"いいつのる/言いつのる/言い募る/言募る"},"言いつのる":{"variants":"いいつのる/言いつのる/言い募る/言募る"},"言い募る":{"variants":"いいつのる/言いつのる/言い募る/言募る"},"言募る":{"variants":"いいつのる/言いつのる/言い募る/言募る"},"いいなおす":{"variants":"いいなおす/言い直す"},"言い直す":{"variants":"いいなおす/言い直す"},"いいなおせる":{"variants":"いいなおせる/言い直せる"},"言い直せる":{"variants":"いいなおせる/言い直せる"},"いいなす":{"variants":"いいなす/言いなす/言い做す"},"言いなす":{"variants":"いいなす/言いなす/言い做す"},"言い做す":{"variants":"いいなす/言いなす/言い做す"},"いいならわす":{"variants":"いいならわす/言いならわす/言い習わす/言習わす"},"言いならわす":{"variants":"いいならわす/言いならわす/言い習わす/言習わす"},"言い習わす":{"variants":"いいならわす/言いならわす/言い習わす/言習わす"},"言習わす":{"variants":"いいならわす/言いならわす/言い習わす/言習わす"},"いいのがれる":{"variants":"いいのがれる/言いのがれる/言い逃れる/言逃れる"},"言いのがれる":{"variants":"いいのがれる/言いのがれる/言い逃れる/言逃れる"},"言い逃れる":{"variants":"いいのがれる/言いのがれる/言い逃れる/言逃れる"},"言逃れる":{"variants":"いいのがれる/言いのがれる/言い逃れる/言逃れる"},"いいのこす":{"variants":"いいのこす/言い残す"},"言い残す":{"variants":"いいのこす/言い残す"},"いいはなす":{"variants":"いいはなす/言い放す"},"言い放す":{"variants":"いいはなす/言い放す"},"いいはなつ":{"variants":"いいはなつ/言い放つ/言放つ"},"言い放つ":{"variants":"いいはなつ/言い放つ/言放つ"},"言放つ":{"variants":"いいはなつ/言い放つ/言放つ"},"いいはる":{"variants":"いいはる/言い張る/言張る"},"言い張る":{"variants":"いいはる/言い張る/言張る"},"言張る":{"variants":"いいはる/言い張る/言張る"},"いいふくめる":{"variants":"いいふくめる/言いふくめる/言い含める/言含める"},"言いふくめる":{"variants":"いいふくめる/言いふくめる/言い含める/言含める"},"言い含める":{"variants":"いいふくめる/言いふくめる/言い含める/言含める"},"言含める":{"variants":"いいふくめる/言いふくめる/言い含める/言含める"},"いいふらす":{"variants":"いいふらす/言いふらす/言い触らす/言触らす"},"言いふらす":{"variants":"いいふらす/言いふらす/言い触らす/言触らす"},"言い触らす":{"variants":"いいふらす/言いふらす/言い触らす/言触らす"},"言触らす":{"variants":"いいふらす/言いふらす/言い触らす/言触らす"},"いいふるす":{"variants":"いいふるす/言い旧す/言い古す"},"言いぶん":{"variants":"言いぶん/言い分"},"言い分":{"variants":"言いぶん/言い分"},"いいまくる":{"variants":"いいまくる/言いまくる"},"言いまくる":{"variants":"いいまくる/言いまくる"},"いいまるめる":{"variants":"いいまるめる/言い丸める"},"言い丸める":{"variants":"いいまるめる/言い丸める"},"言い回し":{"variants":"言い回し/言回し"},"言回し":{"variants":"言い回し/言回し"},"いいまわす":{"variants":"いいまわす/言い回す"},"言い回す":{"variants":"いいまわす/言い回す"},"いいもらす":{"variants":"いいもらす/言い漏らす"},"言い漏らす":{"variants":"いいもらす/言い漏らす"},"言いよう":{"variants":"言いよう/言い様"},"言い様":{"variants":"言いよう/言い様"},"いいよどむ":{"variants":"いいよどむ/言いよどむ/言い淀む"},"言いよどむ":{"variants":"いいよどむ/言いよどむ/言い淀む"},"言い淀む":{"variants":"いいよどむ/言いよどむ/言い淀む"},"いいよる":{"variants":"いいよる/言い寄る/言寄る"},"言い寄る":{"variants":"いいよる/言い寄る/言寄る"},"言寄る":{"variants":"いいよる/言い寄る/言寄る"},"いいよれる":{"variants":"いいよれる/言い寄れる"},"言い寄れる":{"variants":"いいよれる/言い寄れる"},"いいわけ":{"variants":"いいわけ/言い分け/言分け/言訳"},"言分け":{"variants":"いいわけ/言い分け/言分け"},"言い分け":{"variants":"いいわけ/言い分け/言分け"},"いいわたす":{"variants":"いいわたす/言い渡す/言渡す"},"言い渡す":{"variants":"いいわたす/言い渡す/言渡す"},"言渡す":{"variants":"いいわたす/言い渡す/言渡す"},"いいわたせる":{"variants":"いいわたせる/言い渡せる"},"言い渡せる":{"variants":"いいわたせる/言い渡せる"},"いう":{"variants":"いう/言う"},"言う":{"variants":"いう/言う"},"イエダニ":{"variants":"イエダニ/家だに/家壁蝨"},"家だに":{"variants":"イエダニ/家だに/家壁蝨"},"家壁蝨":{"variants":"イエダニ/家だに/家壁蝨"},"イエバエ":{"variants":"イエバエ/家蝿"},"家蝿":{"variants":"イエバエ/家蝿"},"いえる":{"variants":"いえる/言える/癒える"},"い音便":{"variants":"い音便/イ音便"},"イ音便":{"variants":"い音便/イ音便"},"イカ":{"variants":"イカ/易化/医家/医科/烏賊"},"胃かいよう":{"variants":"胃かいよう/胃潰瘍"},"胃潰瘍":{"variants":"胃かいよう/胃潰瘍"},"いかが":{"variants":"いかが/如何"},"如何":{"variants":"いかが/如何"},"いかがわしい":{"variants":"いかがわしい/如何わしい"},"如何わしい":{"variants":"いかがわしい/如何わしい"},"威かく":{"variants":"威かく/威嚇"},"威嚇":{"variants":"威かく/威嚇"},"鋳掛":{"variants":"鋳掛/鋳掛け"},"鋳掛け":{"variants":"鋳掛/鋳掛け"},"いかける":{"variants":"いかける/射掛ける"},"射掛ける":{"variants":"いかける/射掛ける"},"いかさま":{"variants":"いかさま/如何様"},"如何様":{"variants":"いかさま/如何様"},"いかす":{"variants":"いかす/活かす/行かす/生かす"},"いかつい":{"variants":"いかつい/厳つい"},"厳つい":{"variants":"いかつい/厳つい"},"いかなる":{"variants":"いかなる/如何なる"},"如何なる":{"variants":"いかなる/如何なる"},"いかに":{"variants":"いかに/如何に"},"如何に":{"variants":"いかに/如何に"},"いかにも":{"variants":"いかにも/如何にも"},"如何にも":{"variants":"いかにも/如何にも"},"いかほど":{"variants":"いかほど/如何程"},"如何程":{"variants":"いかほど/如何程"},"いからす":{"variants":"いからす/怒らす"},"怒らす":{"variants":"いからす/怒らす"},"いかり肩":{"variants":"いかり肩/怒り肩"},"怒り肩":{"variants":"いかり肩/怒り肩"},"いかりくるう":{"variants":"いかりくるう/怒り狂う"},"怒り狂う":{"variants":"いかりくるう/怒り狂う"},"イカリソウ":{"variants":"イカリソウ/碇草/錨草"},"いかる":{"variants":"いかる/活かる/生かる/埋かる"},"イカル":{"variants":"イカル/斑鳩/鵤"},"いかん":{"variants":"いかん/偉観/尉官/異観/衣冠/遺感/奈何"},"いかんせん":{"variants":"いかんせん/如何せん"},"如何せん":{"variants":"いかんせん/如何せん"},"いかんなく":{"variants":"いかんなく/遺憾無く"},"遺憾無く":{"variants":"いかんなく/遺憾無く"},"イガイ":{"variants":"イガイ/遺がい/遺骸/貽貝"},"遺骸":{"variants":"イガイ/遺がい/遺骸"},"遺がい":{"variants":"イガイ/遺がい/遺骸"},"いがぐり":{"variants":"いがぐり/毬栗"},"毬栗":{"variants":"いがぐり/毬栗"},"いがみあう":{"variants":"いがみあう/いがみ合う/啀み合う"},"いがみ合う":{"variants":"いがみあう/いがみ合う/啀み合う"},"啀み合う":{"variants":"いがみあう/いがみ合う/啀み合う"},"胃ガン":{"variants":"胃がん/胃ガン/胃癌"},"胃癌":{"variants":"胃がん/胃ガン/胃癌"},"胃がん":{"variants":"胃がん/胃ガン/胃癌"},"いき":{"variants":"いき/意気"},"意気":{"variants":"いき/意気"},"いきいき":{"variants":"いきいき/生き生き"},"生き生き":{"variants":"イキイキ/生きいき/生き生き"},"イキイキ":{"variants":"イキイキ/活き活き/生きいき/生き生き"},"生きいき":{"variants":"イキイキ/生きいき/生き生き"},"生きうつし":{"variants":"生きうつし/生き写し"},"生き写し":{"variants":"生きうつし/生き写し"},"生き埋め":{"variants":"生き埋め/生埋め"},"生埋め":{"variants":"生き埋め/生埋め"},"いきおい":{"variants":"いきおい/勢い"},"勢い":{"variants":"いきおい/勢い"},"いきおいこむ":{"variants":"いきおいこむ/勢い込む"},"勢い込む":{"variants":"いきおいこむ/勢い込む"},"いきおいづく":{"variants":"いきおいづく/勢いづく/勢い付く"},"勢いづく":{"variants":"いきおいづく/勢いづく/勢い付く"},"勢い付く":{"variants":"いきおいづく/勢いづく/勢い付く"},"いきおいづける":{"variants":"いきおいづける/勢いづける"},"勢いづける":{"variants":"いきおいづける/勢いづける"},"いきか":{"variants":"いきか/閾下"},"閾下":{"variants":"いきか/閾下"},"いきかえる":{"variants":"いきかえる/生きかえる/生き返る"},"生きかえる":{"variants":"いきかえる/生きかえる/生き返る"},"生き返る":{"variants":"いきかえる/生きかえる/生き返る"},"いきかえれる":{"variants":"いきかえれる/生き返れる"},"生き返れる":{"variants":"いきかえれる/生き返れる"},"いき方":{"variants":"いき方/生き方"},"生き方":{"variants":"いき方/生き方"},"生甲斐":{"variants":"生きがい/生き甲斐/生甲斐"},"生きがい":{"variants":"生きがい/生き甲斐/生甲斐"},"生き甲斐":{"variants":"生きがい/生き甲斐/生甲斐"},"生きぎも":{"variants":"生きぎも/生き肝/生き胆/生肝"},"生肝":{"variants":"生きぎも/生き肝/生肝"},"生き肝":{"variants":"生きぎも/生き肝/生肝"},"息ぎれ":{"variants":"息ぎれ/息切れ"},"息切れ":{"variants":"息ぎれ/息切れ"},"いきぐるしい":{"variants":"いきぐるしい/息苦しい"},"息苦しい":{"variants":"いきぐるしい/息苦しい"},"意気ごみ":{"variants":"意気ごみ/意気込み"},"意気込み":{"variants":"意気ごみ/意気込み"},"いきごむ":{"variants":"いきごむ/意気込む"},"意気込む":{"variants":"いきごむ/意気込む"},"生き字引":{"variants":"生き字引/生字引"},"生字引":{"variants":"生き字引/生字引"},"いきせききる":{"variants":"いきせききる/息せききる/息せき切る"},"息せききる":{"variants":"いきせききる/息せききる/息せき切る"},"息せき切る":{"variants":"いきせききる/息せききる/息せき切る"},"息づかい":{"variants":"息づかい/息遣い"},"息遣い":{"variants":"息づかい/息遣い"},"いきづく":{"variants":"いきづく/息づく/息衝く"},"息づく":{"variants":"いきづく/息づく/息衝く"},"息衝く":{"variants":"いきづく/息づく/息衝く"},"いきづまる":{"variants":"いきづまる/息詰まる/息詰る"},"息詰まる":{"variants":"いきづまる/息詰まる/息詰る"},"息詰る":{"variants":"いきづまる/息詰まる/息詰る"},"いきどおる":{"variants":"いきどおる/憤る"},"憤る":{"variants":"いきどおる/憤る"},"いきながらえる":{"variants":"いきながらえる/生きながらえる"},"生きながらえる":{"variants":"いきながらえる/生きながらえる"},"いきぬく":{"variants":"いきぬく/生きぬく/生き抜く"},"生きぬく":{"variants":"いきぬく/生きぬく/生き抜く"},"生き抜く":{"variants":"いきぬく/生きぬく/生き抜く"},"いきぬける":{"variants":"いきぬける/生き抜ける"},"生き抜ける":{"variants":"いきぬける/生き抜ける"},"いきのこる":{"variants":"いきのこる/生き残る"},"生き残る":{"variants":"いきのこる/生き残る"},"いきのこれる":{"variants":"いきのこれる/生き残れる"},"生き残れる":{"variants":"いきのこれる/生き残れる"},"いきのびる":{"variants":"いきのびる/生きのびる/生き延びる/生延びる"},"生きのびる":{"variants":"いきのびる/生きのびる/生き延びる/生延びる"},"生き延びる":{"variants":"いきのびる/生きのびる/生き延びる/生延びる"},"生延びる":{"variants":"いきのびる/生きのびる/生き延びる/生延びる"},"いきばる":{"variants":"いきばる/息張る"},"息張る":{"variants":"いきばる/息張る"},"いきまく":{"variants":"いきまく/息まく/息巻く"},"息まく":{"variants":"いきまく/息まく/息巻く"},"息巻く":{"variants":"いきまく/息まく/息巻く"},"いきむ":{"variants":"いきむ/息む"},"息む":{"variants":"いきむ/息む"},"生きもの":{"variants":"生きもの/生き物"},"生き物":{"variants":"生きもの/生き物"},"意気揚々":{"variants":"意気揚々/意気揚揚"},"意気揚揚":{"variants":"意気揚々/意気揚揚"},"いきりたつ":{"variants":"いきりたつ/いきり立つ"},"いきり立つ":{"variants":"いきりたつ/いきり立つ"},"いきる":{"variants":"いきる/活きる/生きる"},"生きわかれ":{"variants":"生きわかれ/生き別れ/生別れ"},"生き別れ":{"variants":"生きわかれ/生き別れ/生別れ"},"生別れ":{"variants":"生きわかれ/生き別れ/生別れ"},"いぎたない":{"variants":"いぎたない/寝穢い"},"寝穢い":{"variants":"いぎたない/寝穢い"},"いく":{"variants":"いく/幾"},"行く":{"variants":"ゆく/行く"},"幾":{"variants":"いく/幾"},"郁々":{"variants":"郁々/郁郁"},"郁郁":{"variants":"郁々/郁郁"},"いく重":{"variants":"いく重/幾重"},"幾重":{"variants":"いく重/幾重"},"いくえにも":{"variants":"いくえにも/幾重にも"},"幾重にも":{"variants":"いくえにも/幾重にも"},"いくた":{"variants":"いくた/幾多"},"幾多":{"variants":"いくた/幾多"},"いくつ":{"variants":"いくつ/幾つ"},"幾つ":{"variants":"いくつ/幾つ"},"幾とせ":{"variants":"幾とせ/幾年"},"幾年":{"variants":"幾とせ/幾年"},"いくばく":{"variants":"いくばく/幾許"},"幾許":{"variants":"いくばく/幾許"},"いくぶん":{"variants":"いくぶん/いく分/幾分"},"いく分":{"variants":"いくぶん/いく分/幾分"},"幾分":{"variants":"いくぶん/いく分/幾分"},"いくら":{"variants":"いくら/イクラ/幾ら"},"イクラ":{"variants":"いくら/イクラ/幾ら"},"幾ら":{"variants":"いくら/イクラ/幾ら"},"いくらか":{"variants":"いくらか/幾らか"},"幾らか":{"variants":"いくらか/幾らか"},"い草":{"variants":"い草/イグサ/藺草"},"イグサ":{"variants":"い草/イグサ/藺草"},"藺草":{"variants":"い草/イグサ/藺草"},"胃けいれん":{"variants":"胃けいれん/胃痙攣"},"胃痙攣":{"variants":"胃けいれん/胃痙攣"},"生け垣":{"variants":"生け垣/生垣"},"生垣":{"variants":"生け垣/生垣"},"生け簀":{"variants":"生け簀/生簀"},"生簀":{"variants":"生け簀/生簀"},"いけすかない":{"variants":"いけすかない/いけ好かない"},"いけ好かない":{"variants":"いけすかない/いけ好かない"},"いけずうずうしい":{"variants":"いけずうずうしい/いけ図々しい/いけ図図しい"},"いけ図々しい":{"variants":"いけずうずうしい/いけ図々しい/いけ図図しい"},"いけ図図しい":{"variants":"いけずうずうしい/いけ図々しい/いけ図図しい"},"生け捕り":{"variants":"生け捕り/生捕り"},"生捕り":{"variants":"生け捕り/生捕り"},"いけどる":{"variants":"いけどる/生け捕る"},"生け捕る":{"variants":"いけどる/生け捕る"},"いけどれる":{"variants":"いけどれる/生け捕れる"},"生け捕れる":{"variants":"いけどれる/生け捕れる"},"生けにえ":{"variants":"生けにえ/生け贄/生贄"},"生け贄":{"variants":"生けにえ/生け贄/生贄"},"生贄":{"variants":"生けにえ/生け贄/生贄"},"いける":{"variants":"いける/活ける/生ける/埋ける"},"井げた":{"variants":"井げた/井桁"},"井桁":{"variants":"井げた/井桁"},"憩":{"variants":"憩/憩い"},"憩い":{"variants":"憩/憩い"},"いこう":{"variants":"いこう/憩う"},"憩う":{"variants":"いこう/憩う"},"いこぼれる":{"variants":"いこぼれる/居溢れる"},"居溢れる":{"variants":"いこぼれる/居溢れる"},"いこむ":{"variants":"いこむ/鋳込む"},"鋳込む":{"variants":"いこむ/鋳込む"},"いごこち":{"variants":"いごこち/居心地"},"居心地":{"variants":"いごこち/居心地"},"いさかい":{"variants":"いさかい/諍"},"諍":{"variants":"いさかい/諍"},"いさぎよい":{"variants":"いさぎよい/潔い"},"潔い":{"variants":"いさぎよい/潔い"},"いさましい":{"variants":"いさましい/勇ましい"},"勇ましい":{"variants":"いさましい/勇ましい"},"いさみ足":{"variants":"いさみ足/勇みあし/勇み足/勇足"},"勇みあし":{"variants":"いさみ足/勇みあし/勇み足/勇足"},"勇み足":{"variants":"いさみ足/勇みあし/勇み足/勇足"},"勇足":{"variants":"いさみ足/勇みあし/勇み足/勇足"},"いさみたつ":{"variants":"いさみたつ/勇み立つ"},"勇み立つ":{"variants":"いさみたつ/勇み立つ"},"いさみたてる":{"variants":"いさみたてる/勇み立てる"},"勇み立てる":{"variants":"いさみたてる/勇み立てる"},"勇みはだ":{"variants":"勇みはだ/勇み肌"},"勇み肌":{"variants":"勇みはだ/勇み肌"},"いさむ":{"variants":"いさむ/諌む/勇む"},"いさめる":{"variants":"いさめる/諌める"},"諌める":{"variants":"いさめる/諌める"},"いざ":{"variants":"いざ/イザ"},"イザ":{"variants":"いざ/イザ"},"いざる":{"variants":"いざる/躄る"},"躄る":{"variants":"いざる/躄る"},"石うす":{"variants":"石うす/石臼"},"石臼":{"variants":"石うす/石臼"},"イシガメ":{"variants":"イシガメ/石龜"},"石龜":{"variants":"イシガメ/石龜"},"いしくも":{"variants":"いしくも/美しくも"},"美しくも":{"variants":"いしくも/美しくも"},"石組":{"variants":"石組/石組み"},"石組み":{"variants":"石組/石組み"},"イシタタキ":{"variants":"イシタタキ/石敲き"},"石敲き":{"variants":"イシタタキ/石敲き"},"イシダイ":{"variants":"イシダイ/石鯛"},"石鯛":{"variants":"イシダイ/石鯛"},"石だたみ":{"variants":"石だたみ/石畳"},"石畳":{"variants":"石だたみ/石畳"},"石づき":{"variants":"石づき/石突"},"石突":{"variants":"石づき/石突"},"石ばし":{"variants":"石ばし/石橋"},"石橋":{"variants":"石ばし/石橋"},"イシモチ":{"variants":"イシモチ/石持/石首魚"},"いじきたない":{"variants":"いじきたない/意地汚い"},"意地汚い":{"variants":"いじきたない/意地汚い"},"意地っぱり":{"variants":"意地っぱり/意地っ張り/意地張り"},"意地っ張り":{"variants":"意地っぱり/意地っ張り/意地張り"},"意地張り":{"variants":"意地っぱり/意地っ張り/意地張り"},"いじめる":{"variants":"いじめる/苛める/虐める"},"いじわる":{"variants":"いじわる/意地悪"},"意地悪":{"variants":"いじわる/意地悪"},"いす":{"variants":"いす/イス/椅子"},"イス":{"variants":"いす/イス/椅子"},"椅子":{"variants":"いす/イス/椅子"},"イスカ":{"variants":"イスカ/交喙"},"交喙":{"variants":"イスカ/交喙"},"いすくまる":{"variants":"いすくまる/居すくまる/居竦まる"},"居すくまる":{"variants":"いすくまる/居すくまる/居竦まる"},"居竦まる":{"variants":"いすくまる/居すくまる/居竦まる"},"いすくめる":{"variants":"いすくめる/射すくめる/射竦める"},"射すくめる":{"variants":"いすくめる/射すくめる/射竦める"},"射竦める":{"variants":"いすくめる/射すくめる/射竦める"},"いする":{"variants":"いする/委する/慰する/医する"},"いすわる":{"variants":"いすわる/居坐る/居座る"},"いすわれる":{"variants":"いすわれる/居座れる"},"居座れる":{"variants":"いすわれる/居座れる"},"いずくんぞ":{"variants":"いずくんぞ/安んぞ/焉んぞ"},"居住い":{"variants":"居住い/居住まい"},"居住まい":{"variants":"居住い/居住まい"},"出雲の神":{"variants":"出雲の神/出雲神"},"出雲神":{"variants":"出雲の神/出雲神"},"いずれ":{"variants":"いずれ/何れ"},"何れ":{"variants":"いずれ/何れ"},"伊勢まいり":{"variants":"伊勢まいり/伊勢参り"},"伊勢参り":{"variants":"伊勢まいり/伊勢参り"},"いぜん":{"variants":"いぜん/依然"},"依然":{"variants":"いぜん/依然"},"いそ":{"variants":"いそ/磯"},"磯":{"variants":"いそ/磯"},"いそがす":{"variants":"いそがす/急がす"},"急がす":{"variants":"いそがす/急がす"},"いそぎ足":{"variants":"いそぎ足/急ぎあし/急ぎ足/急足"},"急ぎあし":{"variants":"いそぎ足/急ぎあし/急ぎ足/急足"},"急ぎ足":{"variants":"いそぎ足/急ぎあし/急ぎ足/急足"},"急足":{"variants":"いそぎ足/急ぎあし/急ぎ足/急足"},"イソギンチャク":{"variants":"イソギンチャク/磯巾着"},"磯巾着":{"variants":"イソギンチャク/磯巾着"},"いそくさい":{"variants":"いそくさい/磯臭い"},"磯臭い":{"variants":"いそくさい/磯臭い"},"いそぐ":{"variants":"いそぐ/急ぐ"},"急ぐ":{"variants":"いそぐ/急ぐ"},"いそげる":{"variants":"いそげる/急げる"},"急げる":{"variants":"いそげる/急げる"},"いそしむ":{"variants":"いそしむ/勤しむ"},"勤しむ":{"variants":"いそしむ/勤しむ"},"イソメ":{"variants":"イソメ/磯蚯蚓"},"磯蚯蚓":{"variants":"イソメ/磯蚯蚓"},"いたい":{"variants":"いたい/痛い"},"痛い":{"variants":"いたい/痛い"},"イタイイタイ病":{"variants":"イタイイタイ病/痛い痛い病"},"痛い痛い病":{"variants":"イタイイタイ病/痛い痛い病"},"いたいたしい":{"variants":"いたいたしい/痛々しい/痛痛しい"},"痛々しい":{"variants":"いたいたしい/痛々しい/痛痛しい"},"痛痛しい":{"variants":"いたいたしい/痛々しい/痛痛しい"},"板ガラス":{"variants":"板ガラス/板硝子"},"板硝子":{"variants":"板ガラス/板硝子"},"いたし方":{"variants":"いたし方/致し方/致方"},"致し方":{"variants":"いたし方/致し方/致方"},"致方":{"variants":"いたし方/致し方/致方"},"板敷":{"variants":"板敷/板敷き"},"板敷き":{"variants":"板敷/板敷き"},"いたす":{"variants":"いたす/致す"},"致す":{"variants":"いたす/致す"},"いたずら":{"variants":"いたずら/悪戯/徒"},"悪戯":{"variants":"いたずら/悪戯"},"いたずらに":{"variants":"いたずらに/徒に"},"徒に":{"variants":"いたずらに/徒に"},"いたたまらない":{"variants":"いたたまらない/居たたまらない/居た堪らない"},"居たたまらない":{"variants":"いたたまらない/居たたまらない/居た堪らない"},"居た堪らない":{"variants":"いたたまらない/居たたまらない/居た堪らない"},"いただく":{"variants":"いただく/頂く"},"頂く":{"variants":"いただく/頂く"},"いただける":{"variants":"いただける/戴ける/頂ける"},"イタチ":{"variants":"イタチ/鼬"},"鼬":{"variants":"イタチ/鼬"},"いたちごっこ":{"variants":"いたちごっこ/鼬ごっこ"},"鼬ごっこ":{"variants":"いたちごっこ/鼬ごっこ"},"いたって":{"variants":"いたって/至って"},"至って":{"variants":"いたって/至って"},"イタドリ":{"variants":"イタドリ/虎杖"},"虎杖":{"variants":"イタドリ/虎杖"},"板の間":{"variants":"板の間/板間"},"板間":{"variants":"板の間/板間"},"板ばさみ":{"variants":"板ばさみ/板挟み"},"板挟み":{"variants":"板ばさみ/板挟み"},"板張":{"variants":"板張/板張り"},"板張り":{"variants":"板張/板張り"},"板葺":{"variants":"板葺/板葺き"},"板葺き":{"variants":"板葺/板葺き"},"いたましい":{"variants":"いたましい/痛ましい"},"痛ましい":{"variants":"いたましい/痛ましい"},"いたみいる":{"variants":"いたみいる/痛みいる/痛み入る"},"痛みいる":{"variants":"いたみいる/痛みいる/痛み入る"},"痛み入る":{"variants":"いたみいる/痛みいる/痛み入る"},"いたむ":{"variants":"いたむ/傷む/痛む/悼む"},"いため":{"variants":"いため/板目"},"板目":{"variants":"いため/板目"},"いためつける":{"variants":"いためつける/痛めつける/痛め付ける"},"痛めつける":{"variants":"いためつける/痛めつける/痛め付ける"},"痛め付ける":{"variants":"いためつける/痛めつける/痛め付ける"},"いためる":{"variants":"いためる/傷める/痛める/炒める"},"至":{"variants":"至/至り"},"至り":{"variants":"至/至り"},"いたる":{"variants":"いたる/至る/到る"},"いたわしい":{"variants":"いたわしい/労しい"},"労しい":{"variants":"いたわしい/労しい"},"いだてん走り":{"variants":"いだてん走り/韋駄天走り"},"韋駄天走り":{"variants":"いだてん走り/韋駄天走り"},"イチ":{"variants":"イチ/位地/壱"},"１":{"variants":"１/一"},"一":{"variants":"１/一"},"イチイ":{"variants":"イチイ/一葦/一位/一意"},"いちいち":{"variants":"いちいち/一々/一一"},"一々":{"variants":"いちいち/一々/一一"},"一一":{"variants":"いちいち/一々/一一"},"いちえん":{"variants":"いちえん/一円"},"一円":{"variants":"いちえん/一円"},"いちおう":{"variants":"いちおう/一応"},"一応":{"variants":"いちおう/一応"},"いちがいに":{"variants":"いちがいに/一概に"},"一概に":{"variants":"いちがいに/一概に"},"１月":{"variants":"１月/一月"},"一月":{"variants":"１月/一月"},"いちげん":{"variants":"いちげん/一元"},"一元":{"variants":"いちげん/一元"},"イチゴ":{"variants":"イチゴ/一語/苺/莓"},"イチジク":{"variants":"イチジク/無花果"},"無花果":{"variants":"イチジク/無花果"},"一時しのぎ":{"variants":"一時しのぎ/一時凌ぎ"},"一時凌ぎ":{"variants":"一時しのぎ/一時凌ぎ"},"いちじるしい":{"variants":"いちじるしい/著しい"},"著しい":{"variants":"いちじるしい/著しい"},"いちだんと":{"variants":"いちだんと/一段と"},"一段と":{"variants":"いちだんと/一段と"},"位置づけ":{"variants":"位置づけ/位置付け"},"位置付け":{"variants":"位置づけ/位置付け"},"いちづける":{"variants":"いちづける/位置づける/位置付ける"},"位置づける":{"variants":"いちづける/位置づける/位置付ける"},"位置付ける":{"variants":"いちづける/位置づける/位置付ける"},"いちどきに":{"variants":"いちどきに/一時に"},"一時に":{"variants":"いちどきに/一時に"},"いちどに":{"variants":"いちどに/一度に"},"一度に":{"variants":"いちどに/一度に"},"一の酉":{"variants":"一の酉/一酉"},"一酉":{"variants":"一の酉/一酉"},"いちはやい":{"variants":"いちはやい/いち早い/逸早い"},"いち早い":{"variants":"いちはやい/いち早い/逸早い"},"逸早い":{"variants":"いちはやい/いち早い/逸早い"},"いちはやく":{"variants":"いちはやく/いち早く/逸早く"},"いち早く":{"variants":"いちはやく/いち早く/逸早く"},"逸早く":{"variants":"いちはやく/いち早く/逸早く"},"いちばん":{"variants":"１番/いちばん/一番"},"一番":{"variants":"１番/いちばん/一番"},"１番":{"variants":"１番/いちばん/一番"},"一番やり":{"variants":"一番やり/一番槍"},"一番槍":{"variants":"一番やり/一番槍"},"一べつ":{"variants":"一べつ/一瞥"},"一瞥":{"variants":"一べつ/一瞥"},"一目りょう然":{"variants":"一目りょう然/一目瞭然"},"一目瞭然":{"variants":"一目りょう然/一目瞭然"},"いちゃもん":{"variants":"いちゃもん/イチャモン"},"イチャモン":{"variants":"いちゃもん/イチャモン"},"一夜漬":{"variants":"一夜漬/一夜漬け"},"一夜漬け":{"variants":"一夜漬/一夜漬け"},"イチョウ":{"variants":"イチョウ/異朝/胃腸/医長/鴨脚/銀杏/公孫樹"},"イッカク":{"variants":"イッカク/一廓/一角/一郭"},"イッカクジュウ":{"variants":"イッカクジュウ/一角獣"},"一角獣":{"variants":"イッカクジュウ/一角獣"},"一閑張":{"variants":"一閑張/一閑張り"},"一閑張り":{"variants":"一閑張/一閑張り"},"イッキ":{"variants":"イッキ/一基/一期/一気/一季/一揆"},"いっきに":{"variants":"いっきに/一気に"},"一気に":{"variants":"いっきに/一気に"},"溢血":{"variants":"いっ血/溢血"},"いっ血":{"variants":"いっ血/溢血"},"いっけん":{"variants":"いっけん/一見"},"一見":{"variants":"いっけん/一見"},"いっこう":{"variants":"いっこう/一向"},"一向":{"variants":"いっこう/一向"},"いっこうに":{"variants":"いっこうに/一向に"},"一向に":{"variants":"いっこうに/一向に"},"いっさい":{"variants":"いっさい/一再/一切"},"一昨々月":{"variants":"一昨々月/一昨昨月"},"一昨昨月":{"variants":"一昨々月/一昨昨月"},"一昨々週":{"variants":"一昨々週/一昨昨週"},"一昨昨週":{"variants":"一昨々週/一昨昨週"},"いっしょ":{"variants":"いっしょ/一所/逸書/佚書"},"一生けん命":{"variants":"一生けん命/一生懸命"},"一生懸命":{"variants":"一生けん命/一生懸命"},"いっしんに":{"variants":"いっしんに/一心に"},"一心に":{"variants":"いっしんに/一心に"},"いっする":{"variants":"いっする/逸する"},"逸する":{"variants":"いっする/逸する"},"いっせん":{"variants":"いっせん/一千/一線"},"いっそう":{"variants":"いっそう/一層"},"一層":{"variants":"いっそう/一層"},"いったい":{"variants":"いったい/一体"},"一体":{"variants":"いったい/一体"},"いったいぜんたい":{"variants":"いったいぜんたい/いったい全体/一体全体"},"いったい全体":{"variants":"いったいぜんたい/いったい全体/一体全体"},"一体全体":{"variants":"いったいぜんたい/いったい全体/一体全体"},"いったん":{"variants":"いったん/一旦"},"一旦":{"variants":"いったん/一旦"},"いっちょう":{"variants":"いっちょう/一朝"},"一朝":{"variants":"いっちょう/一朝"},"一点ばり":{"variants":"一点ばり/一点張り"},"一点張り":{"variants":"一点ばり/一点張り"},"いっぱい":{"variants":"いっぱい/一杯"},"一杯":{"variants":"いっぱい/一杯"},"一ぱい":{"variants":"一ぱい/一敗"},"一敗":{"variants":"一ぱい/一敗"},"いっぱし":{"variants":"いっぱし/一端"},"一端":{"variants":"いっぱし/一端"},"一ぷく":{"variants":"一ぷく/一服"},"一服":{"variants":"一ぷく/一服"},"いっぺん":{"variants":"いっぺん/一遍"},"一遍":{"variants":"いっぺん/一遍"},"いっぽう":{"variants":"いっぽう/一法"},"一方":{"variants":"いっぽう/一方"},"一法":{"variants":"いっぽう/一法"},"一本やり":{"variants":"一本やり/一本槍"},"一本槍":{"variants":"一本やり/一本槍"},"いつ":{"variants":"いつ/何時"},"何時":{"variants":"いつ/何時"},"いつかしら":{"variants":"いつかしら/何時かしら"},"何時かしら":{"variants":"いつかしら/何時かしら"},"いつく":{"variants":"いつく/居着く/斎く"},"いつくしむ":{"variants":"いつくしむ/慈しむ"},"慈しむ":{"variants":"いつくしむ/慈しむ"},"いつしか":{"variants":"いつしか/何時しか"},"何時しか":{"variants":"いつしか/何時しか"},"いつぞや":{"variants":"いつぞや/何時ぞや"},"何時ぞや":{"variants":"いつぞや/何時ぞや"},"５つ":{"variants":"５つ/五つ"},"五つ":{"variants":"５つ/五つ"},"いつのまに":{"variants":"いつのまに/いつの間に/何時のまに/何時の間に"},"いつの間に":{"variants":"いつのまに/いつの間に/何時のまに/何時の間に"},"何時のまに":{"variants":"いつのまに/いつの間に/何時のまに/何時の間に"},"何時の間に":{"variants":"いつのまに/いつの間に/何時のまに/何時の間に"},"いつのまにか":{"variants":"いつのまにか/いつの間にか/何時のまにか/何時の間にか"},"いつの間にか":{"variants":"いつのまにか/いつの間にか/何時のまにか/何時の間にか"},"何時のまにか":{"variants":"いつのまにか/いつの間にか/何時のまにか/何時の間にか"},"何時の間にか":{"variants":"いつのまにか/いつの間にか/何時のまにか/何時の間にか"},"いつぶす":{"variants":"いつぶす/鋳潰す"},"鋳潰す":{"variants":"いつぶす/鋳潰す"},"いつわる":{"variants":"いつわる/偽る"},"偽る":{"variants":"いつわる/偽る"},"いてつく":{"variants":"いてつく/凍てつく"},"凍てつく":{"variants":"いてつく/凍てつく"},"いてる":{"variants":"いてる/凍てる"},"凍てる":{"variants":"いてる/凍てる"},"出で立ち":{"variants":"出で立ち/出立"},"出立":{"variants":"出で立ち/出立"},"いでたつ":{"variants":"いでたつ/出で立つ/出立つ"},"出で立つ":{"variants":"いでたつ/出で立つ/出立つ"},"出立つ":{"variants":"いでたつ/出で立つ/出立つ"},"いで湯":{"variants":"いで湯/出湯"},"出湯":{"variants":"いで湯/出湯"},"糸あやつり":{"variants":"糸あやつり/糸操"},"糸操":{"variants":"糸あやつり/糸操"},"いとう":{"variants":"いとう/厭う"},"厭う":{"variants":"いとう/厭う"},"糸切り歯":{"variants":"糸切り歯/糸切歯"},"糸切歯":{"variants":"糸切り歯/糸切歯"},"糸繰りぐるま":{"variants":"糸繰りぐるま/糸繰り車/糸繰車"},"糸繰り車":{"variants":"糸繰りぐるま/糸繰り車/糸繰車"},"糸繰車":{"variants":"糸繰りぐるま/糸繰り車/糸繰車"},"いとけない":{"variants":"いとけない/稚い"},"稚い":{"variants":"いとけない/稚い"},"いとこ":{"variants":"いとこ/従兄弟/従姉妹"},"いとしい":{"variants":"いとしい/愛しい"},"愛しい":{"variants":"いとしい/愛しい"},"愛し子":{"variants":"愛し子/愛子"},"愛子":{"variants":"愛し子/愛子"},"イトスギ":{"variants":"イトスギ/糸杉"},"糸杉":{"variants":"イトスギ/糸杉"},"いとなむ":{"variants":"いとなむ/営む"},"営む":{"variants":"いとなむ/営む"},"糸へん":{"variants":"糸へん/糸偏"},"糸偏":{"variants":"糸へん/糸偏"},"糸巻":{"variants":"糸巻/糸巻き"},"糸巻き":{"variants":"糸巻/糸巻き"},"イトミミズ":{"variants":"イトミミズ/糸蚯蚓"},"糸蚯蚓":{"variants":"イトミミズ/糸蚯蚓"},"イトメ":{"variants":"イトメ/糸目"},"糸目":{"variants":"イトメ/糸目"},"いとめる":{"variants":"いとめる/射止める"},"射止める":{"variants":"いとめる/射止める"},"イトヤナギ":{"variants":"イトヤナギ/糸柳"},"糸柳":{"variants":"イトヤナギ/糸柳"},"いとわしい":{"variants":"いとわしい/厭わしい"},"厭わしい":{"variants":"いとわしい/厭わしい"},"いどむ":{"variants":"いどむ/挑む"},"挑む":{"variants":"いどむ/挑む"},"居直り強盗":{"variants":"居直り強盗/居直強盗"},"居直強盗":{"variants":"居直り強盗/居直強盗"},"いなおる":{"variants":"いなおる/居直る"},"居直る":{"variants":"いなおる/居直る"},"いなか":{"variants":"いなか/イナカ/田舎"},"イナカ":{"variants":"いなか/イナカ/田舎"},"田舎":{"variants":"いなか/イナカ/田舎"},"いなかっぺ":{"variants":"いなかっぺ/田舎っぺ"},"田舎っぺ":{"variants":"いなかっぺ/田舎っぺ"},"いなかびる":{"variants":"いなかびる/田舎びる"},"田舎びる":{"variants":"いなかびる/田舎びる"},"いなか者":{"variants":"いなか者/田舎者"},"田舎者":{"variants":"いなか者/田舎者"},"いななく":{"variants":"いななく/嘶く"},"嘶く":{"variants":"いななく/嘶く"},"いなむ":{"variants":"いなむ/辞む/否む"},"いならぶ":{"variants":"いならぶ/居並ぶ"},"居並ぶ":{"variants":"いならぶ/居並ぶ"},"いなりずし":{"variants":"いなりずし/稲荷鮨"},"稲荷鮨":{"variants":"いなりずし/稲荷鮨"},"いぬ":{"variants":"いぬ/イヌ/狗/犬/戌"},"往ぬ":{"variants":"いぬ/往ぬ"},"イヌ":{"variants":"いぬ/イヌ/狗/犬/戌"},"犬かき":{"variants":"犬かき/犬掻き"},"犬掻き":{"variants":"犬かき/犬掻き"},"犬死":{"variants":"犬死/犬死に"},"犬死に":{"variants":"犬死/犬死に"},"イヌタデ":{"variants":"イヌタデ/犬蓼"},"犬蓼":{"variants":"イヌタデ/犬蓼"},"犬張り子":{"variants":"犬張り子/犬張子"},"犬張子":{"variants":"犬張り子/犬張子"},"いね":{"variants":"いね/イネ/稲"},"イネ":{"variants":"いね/イネ/稲"},"稲":{"variants":"いね/イネ/稲"},"イノコズチ":{"variants":"イノコズチ/牛膝"},"牛膝":{"variants":"イノコズチ/牛膝"},"いのこる":{"variants":"いのこる/居残る"},"居残る":{"variants":"いのこる/居残る"},"いのこれる":{"variants":"いのこれる/居残れる"},"居残れる":{"variants":"いのこれる/居残れる"},"イノシシ":{"variants":"イノシシ/猪"},"猪":{"variants":"イノシシ/猪"},"いのち":{"variants":"いのち/命"},"命":{"variants":"いのち/命"},"命がけ":{"variants":"命がけ/命懸け"},"命懸け":{"variants":"命がけ/命懸け"},"命とり":{"variants":"命とり/命取り"},"命取り":{"variants":"命とり/命取り"},"いのる":{"variants":"いのる/祈る/祷る"},"いのれる":{"variants":"いのれる/祈れる/祷れる"},"位はい":{"variants":"位はい/位牌"},"位牌":{"variants":"位はい/位牌"},"いばえる":{"variants":"いばえる/嘶える"},"嘶える":{"variants":"いばえる/嘶える"},"いばら":{"variants":"いばら/イバラ/茨"},"イバラ":{"variants":"いばら/イバラ/茨"},"茨":{"variants":"いばら/イバラ/茨"},"いばる":{"variants":"いばる/威張る"},"威張る":{"variants":"いばる/威張る"},"いばれる":{"variants":"いばれる/威張れる"},"威張れる":{"variants":"いばれる/威張れる"},"いびき":{"variants":"いびき/鼾"},"鼾":{"variants":"いびき/鼾"},"いびつ":{"variants":"いびつ/歪"},"歪":{"variants":"いびつ/歪"},"いびりだす":{"variants":"いびりだす/いびり出す"},"いびり出す":{"variants":"いびりだす/いびり出す"},"イブ":{"variants":"イブ/威武"},"威武":{"variants":"イブ/威武"},"いぶかしい":{"variants":"いぶかしい/訝しい"},"訝しい":{"variants":"いぶかしい/訝しい"},"いぶかる":{"variants":"いぶかる/訝る"},"訝る":{"variants":"いぶかる/訝る"},"息吹":{"variants":"息吹/息吹き"},"息吹き":{"variants":"息吹/息吹き"},"いぶく":{"variants":"いぶく/息吹く"},"息吹く":{"variants":"いぶく/息吹く"},"いぶし銀":{"variants":"いぶし銀/燻銀"},"燻銀":{"variants":"いぶし銀/燻銀"},"いぶす":{"variants":"いぶす/燻す"},"燻す":{"variants":"いぶす/燻す"},"いぼ":{"variants":"いぼ/異母/疣"},"イボダイ":{"variants":"イボダイ/疣鯛"},"疣鯛":{"variants":"イボダイ/疣鯛"},"いま":{"variants":"いま/今"},"今":{"variants":"いま/今"},"いまいましい":{"variants":"いまいましい/忌々しい/忌忌しい"},"忌々しい":{"variants":"いまいましい/忌々しい/忌忌しい"},"忌忌しい":{"variants":"いまいましい/忌々しい/忌忌しい"},"いまごろ":{"variants":"いまごろ/今ごろ"},"今ごろ":{"variants":"今ごろ/今頃"},"今頃":{"variants":"今ごろ/今頃"},"今さら":{"variants":"今さら/今更"},"今更":{"variants":"今さら/今更"},"今しがた":{"variants":"今しがた/今し方"},"今し方":{"variants":"今しがた/今し方"},"いましめる":{"variants":"いましめる/戒める/警める/縛める"},"いまだに":{"variants":"いまだに/未だに"},"未だに":{"variants":"いまだに/未だに"},"居待の月":{"variants":"居待の月/居待月"},"居待月":{"variants":"居待の月/居待月"},"いまどき":{"variants":"いまどき/今どき/今時"},"今どき":{"variants":"いまどき/今どき/今時"},"今時":{"variants":"いまどき/今どき/今時"},"いまに":{"variants":"いまに/今に"},"今に":{"variants":"いまに/今に"},"いまにも":{"variants":"いまにも/今にも"},"今にも":{"variants":"いまにも/今にも"},"いまひとつ":{"variants":"いまひとつ/いま一つ/今ひとつ"},"いま一つ":{"variants":"いまひとつ/いま一つ/今ひとつ"},"今ひとつ":{"variants":"いまひとつ/いま一つ/今ひとつ"},"いままで":{"variants":"いままで/今まで"},"今まで":{"variants":"いままで/今まで"},"いまや":{"variants":"いまや/今や"},"今や":{"variants":"いまや/今や"},"いまわ":{"variants":"いまわ/今わ/今際"},"今わ":{"variants":"いまわ/今わ/今際"},"今際":{"variants":"いまわ/今わ/今際"},"いまわしい":{"variants":"いまわしい/忌まわしい/忌わしい"},"忌まわしい":{"variants":"いまわしい/忌まわしい/忌わしい"},"忌わしい":{"variants":"いまわしい/忌まわしい/忌わしい"},"意味あい":{"variants":"意味あい/意味合い"},"意味合い":{"variants":"意味あい/意味合い"},"いみきらう":{"variants":"いみきらう/忌み嫌う"},"忌み嫌う":{"variants":"いみきらう/忌み嫌う"},"忌みことば":{"variants":"忌みことば/忌み詞/忌詞"},"忌み詞":{"variants":"忌みことば/忌み詞/忌詞"},"忌詞":{"variants":"忌みことば/忌み詞/忌詞"},"いみづける":{"variants":"いみづける/意味付ける"},"意味付ける":{"variants":"いみづける/意味付ける"},"いむ":{"variants":"いむ/忌む"},"忌む":{"variants":"いむ/忌む"},"いも":{"variants":"いも/イモ/芋/薯/藷"},"イモ":{"variants":"いも/イモ/芋/薯/藷"},"芋づる":{"variants":"芋づる/芋蔓"},"芋蔓":{"variants":"芋づる/芋蔓"},"いもづる式":{"variants":"いもづる式/芋蔓式"},"芋蔓式":{"variants":"いもづる式/芋蔓式"},"イモムシ":{"variants":"イモムシ/芋虫"},"芋虫":{"variants":"イモムシ/芋虫"},"イモリ":{"variants":"イモリ/井守"},"井守":{"variants":"イモリ/井守"},"いや":{"variants":"いや/イヤ/厭/嫌"},"イヤ":{"variants":"いや/イヤ/厭/嫌"},"彌":{"variants":"いや/彌"},"いやいや":{"variants":"いやいや/イヤイヤ/嫌々/嫌嫌"},"イヤイヤ":{"variants":"いやいや/イヤイヤ/嫌々/嫌嫌"},"嫌々":{"variants":"嫌々/嫌嫌"},"嫌嫌":{"variants":"嫌々/嫌嫌"},"いやいやながら":{"variants":"いやいやながら/嫌々ながら/嫌嫌ながら"},"嫌々ながら":{"variants":"いやいやながら/嫌々ながら/嫌嫌ながら"},"嫌嫌ながら":{"variants":"いやいやながら/嫌々ながら/嫌嫌ながら"},"いやおうなしに":{"variants":"いやおうなしに/否応なしに"},"否応なしに":{"variants":"いやおうなしに/否応なしに"},"いやがらせ":{"variants":"いやがらせ/嫌がらせ"},"嫌がらせ":{"variants":"いやがらせ/嫌がらせ"},"いやがる":{"variants":"いやがる/嫌がる"},"嫌がる":{"variants":"いやがる/嫌がる"},"いやしい":{"variants":"いやしい/賎しい/卑しい"},"いやしくも":{"variants":"いやしくも/苟も"},"苟も":{"variants":"いやしくも/苟も"},"いやしめる":{"variants":"いやしめる/賎しめる/卑しめる"},"卑しんぼう":{"variants":"卑しんぼう/卑しん坊"},"卑しん坊":{"variants":"卑しんぼう/卑しん坊"},"いやす":{"variants":"いやす/癒す"},"癒す":{"variants":"いやす/癒す"},"いやせる":{"variants":"いやせる/癒せる"},"癒せる":{"variants":"いやせる/癒せる"},"いやに":{"variants":"いやに/嫌に"},"嫌に":{"variants":"いやに/嫌に"},"いやまさる":{"variants":"いやまさる/彌増さる"},"彌増さる":{"variants":"いやまさる/彌増さる"},"いやます":{"variants":"いやます/彌増す"},"彌増す":{"variants":"いやます/彌増す"},"嫌み":{"variants":"嫌み/嫌味"},"嫌味":{"variants":"嫌み/嫌味"},"愈":{"variants":"愈/愈々"},"愈々":{"variants":"愈/愈々"},"いらい":{"variants":"いらい/以来"},"以来":{"variants":"いらい/以来"},"いらいら":{"variants":"いらいら/イライラ"},"苛苛":{"variants":"いらいら/苛苛"},"イライラ":{"variants":"いらいら/イライラ"},"いらう":{"variants":"いらう/弄う"},"弄う":{"variants":"いらう/弄う"},"イラクサ":{"variants":"イラクサ/刺草/蕁麻"},"いらだち":{"variants":"いらだち/いら立ち"},"いら立ち":{"variants":"いらだち/いら立ち"},"いらだつ":{"variants":"いらだつ/いら立つ/苛立つ"},"いら立つ":{"variants":"いらだつ/いら立つ/苛立つ"},"苛立つ":{"variants":"いらだつ/いら立つ/苛立つ"},"いらだてる":{"variants":"いらだてる/苛立てる"},"苛立てる":{"variants":"いらだてる/苛立てる"},"イラムシ":{"variants":"イラムシ/刺虫"},"刺虫":{"variants":"イラムシ/刺虫"},"入り海":{"variants":"入り海/入海"},"入海":{"variants":"入り海/入海"},"入り江":{"variants":"入り江/入江"},"入江":{"variants":"入り江/入江"},"イリオモテヤマネコ":{"variants":"イリオモテヤマネコ/西表山猫"},"西表山猫":{"variants":"イリオモテヤマネコ/西表山猫"},"いりかわる":{"variants":"いりかわる/入りかわる/入り替る"},"入りかわる":{"variants":"いりかわる/入りかわる/入り替る"},"入り替る":{"variants":"いりかわる/入りかわる/入り替る"},"いりくむ":{"variants":"いりくむ/入り組む/入組む"},"入り組む":{"variants":"いりくむ/入り組む/入組む"},"入組む":{"variants":"いりくむ/入り組む/入組む"},"いりこ":{"variants":"いりこ/いり子/海参/炒り子/炒り粉/熬り子/熬り粉/熬海鼠"},"炒り子":{"variants":"いりこ/いり子/炒り子"},"いり子":{"variants":"いりこ/いり子/炒り子/熬り子"},"熬り子":{"variants":"いりこ/いり子/熬り子"},"いりこむ":{"variants":"いりこむ/入込む"},"入込む":{"variants":"いりこむ/入込む"},"いりつける":{"variants":"いりつける/煎りつける/煎り付ける"},"煎りつける":{"variants":"いりつける/煎りつける/煎り付ける"},"煎り付ける":{"variants":"いりつける/煎りつける/煎り付ける"},"入り日":{"variants":"入り日/入日"},"入日":{"variants":"入り日/入日"},"いりびたる":{"variants":"いりびたる/入りびたる/入り浸る/入浸る"},"入りびたる":{"variants":"いりびたる/入りびたる/入り浸る/入浸る"},"入り浸る":{"variants":"いりびたる/入りびたる/入り浸る/入浸る"},"入浸る":{"variants":"いりびたる/入りびたる/入り浸る/入浸る"},"入り船":{"variants":"入り船/入船"},"入船":{"variants":"入り船/入船"},"いり干し":{"variants":"いり干し/炒り干し/熬り干し"},"いりまじる":{"variants":"いりまじる/入りまじる/入り交じる/入り雑じる/入雑じる"},"入りまじる":{"variants":"いりまじる/入りまじる/入り交じる/入り雑じる/入雑じる"},"入り雑じる":{"variants":"いりまじる/入りまじる/入り雑じる/入雑じる"},"入雑じる":{"variants":"いりまじる/入りまじる/入り雑じる/入雑じる"},"炒りまめ":{"variants":"炒りまめ/炒り豆/炒豆"},"炒り豆":{"variants":"炒りまめ/炒り豆/炒豆"},"炒豆":{"variants":"炒りまめ/炒り豆/炒豆"},"いりみだれる":{"variants":"いりみだれる/入り乱れる/入乱れる"},"入り乱れる":{"variants":"いりみだれる/入り乱れる/入乱れる"},"入乱れる":{"variants":"いりみだれる/入り乱れる/入乱れる"},"入り母屋":{"variants":"入り母屋/入母屋"},"入母屋":{"variants":"入り母屋/入母屋"},"入り用":{"variants":"入り用/入用"},"入用":{"variants":"入り用/入用"},"いる":{"variants":"いる/煎る/要る/炒る/熬る"},"イルカ":{"variants":"イルカ/海豚"},"海豚":{"variants":"イルカ/海豚"},"いれあげる":{"variants":"いれあげる/入れあげる/入れ揚げる"},"入れあげる":{"variants":"いれあげる/入れあげる/入れ揚げる"},"入れ揚げる":{"variants":"いれあげる/入れあげる/入れ揚げる"},"いれあわせる":{"variants":"いれあわせる/入れ合せる"},"入れ合せる":{"variants":"いれあわせる/入れ合せる"},"入れ替え":{"variants":"入れ替え/入替え"},"入替え":{"variants":"入れ替え/入替え"},"いれかえる":{"variants":"いれかえる/入れかえる/入れ換える/入れ替える/入替える"},"入れかえる":{"variants":"いれかえる/入れかえる/入れ換える/入れ替える/入替える"},"入替える":{"variants":"いれかえる/入れかえる/入れ替える/入替える"},"入れ替える":{"variants":"いれかえる/入れかえる/入れ替える/入替える"},"入れ替り立ち替り":{"variants":"入れ替り立ち替り/入替り立ち替り"},"入替り立ち替り":{"variants":"入れ替り立ち替り/入替り立ち替り"},"いれかわる":{"variants":"いれかわる/入れ替る/入れ替わる/入れ代わる/入替る"},"入れ替わる":{"variants":"いれかわる/入れ替る/入れ替わる/入替る"},"入替る":{"variants":"いれかわる/入れ替る/入れ替わる/入替る"},"入れ替る":{"variants":"いれかわる/入れ替る/入れ替わる/入替る"},"いれかわれる":{"variants":"いれかわれる/入れ替われる"},"入れ替われる":{"variants":"いれかわれる/入れ替われる"},"入れ子":{"variants":"入れ子/入子"},"入子":{"variants":"入れ子/入子"},"入れこみ":{"variants":"入れこみ/入れ込み/入込み"},"入れ込み":{"variants":"入れこみ/入れ込み/入込み"},"入込み":{"variants":"入れこみ/入れ込み/入込み"},"入れ墨":{"variants":"入れ墨/入墨"},"入墨":{"variants":"入れ墨/入墨"},"いれちがう":{"variants":"いれちがう/入れちがう/入れ違う"},"入れちがう":{"variants":"いれちがう/入れちがう/入れ違う"},"入れ違う":{"variants":"いれちがう/入れちがう/入れ違う"},"入れ知恵":{"variants":"入れ知恵/入知恵"},"入知恵":{"variants":"入れ知恵/入知恵"},"いれなおす":{"variants":"いれなおす/入れ直す"},"入れ直す":{"variants":"いれなおす/入れ直す"},"入れ歯":{"variants":"入れ歯/入歯"},"入歯":{"variants":"入れ歯/入歯"},"入れぼくろ":{"variants":"入れぼくろ/入れ黒子"},"入れ黒子":{"variants":"入れぼくろ/入れ黒子"},"入れ物":{"variants":"入れ物/入物"},"入物":{"variants":"入れ物/入物"},"いれる":{"variants":"いれる/容れる"},"容れる":{"variants":"いれる/容れる"},"色あい":{"variants":"色あい/色合/色合い"},"色合":{"variants":"色あい/色合/色合い"},"色合い":{"variants":"色あい/色合/色合い"},"いろあせる":{"variants":"いろあせる/色あせる/色褪せる"},"色あせる":{"variants":"いろあせる/色あせる/色褪せる"},"色褪せる":{"variants":"いろあせる/色あせる/色褪せる"},"色いろ":{"variants":"いろいろ/色々/色いろ/色色"},"色色":{"variants":"いろいろ/色々/色いろ/色色"},"いろいろ":{"variants":"いろいろ/色々/色いろ/色色"},"イロイロ":{"variants":"いろいろ/イロイロ/色々"},"色々":{"variants":"いろいろ/色々/色いろ/色色"},"色変り":{"variants":"色変り/色変わり"},"色変わり":{"variants":"色変り/色変わり"},"いろこい":{"variants":"いろこい/色濃い"},"色濃い":{"variants":"いろこい/色濃い"},"色刷":{"variants":"色刷/色刷り"},"色刷り":{"variants":"色刷/色刷り"},"いろっぽい":{"variants":"いろっぽい/色っぽい"},"色っぽい":{"variants":"いろっぽい/色っぽい"},"色つや":{"variants":"色つや/色艷"},"色艷":{"variants":"色つや/色艷"},"いろづく":{"variants":"いろづく/色づく/色付く"},"色づく":{"variants":"いろづく/色づく/色付く"},"色付く":{"variants":"いろづく/色づく/色付く"},"いろどる":{"variants":"いろどる/彩る"},"彩る":{"variants":"いろどる/彩る"},"いろどれる":{"variants":"いろどれる/彩れる"},"彩れる":{"variants":"いろどれる/彩れる"},"いろは":{"variants":"いろは/伊呂波"},"伊呂波":{"variants":"いろは/伊呂波"},"いろは歌":{"variants":"いろは歌/伊呂波歌"},"伊呂波歌":{"variants":"いろは歌/伊呂波歌"},"色めがね":{"variants":"色めがね/色眼鏡"},"色眼鏡":{"variants":"色めがね/色眼鏡"},"いろめく":{"variants":"いろめく/色めく"},"色めく":{"variants":"いろめく/色めく"},"いろんな":{"variants":"いろんな/色んな"},"色んな":{"variants":"いろんな/色んな"},"祝い酒":{"variants":"祝い酒/祝酒"},"祝酒":{"variants":"祝い酒/祝酒"},"祝いばし":{"variants":"祝いばし/祝箸"},"祝箸":{"variants":"祝いばし/祝箸"},"いわう":{"variants":"いわう/斎う/祝う"},"いわえる":{"variants":"いわえる/祝える"},"祝える":{"variants":"いわえる/祝える"},"いわき":{"variants":"いわき/岩木/磐城"},"いわく":{"variants":"いわく/曰く"},"曰く":{"variants":"いわく/曰く"},"いわく付き":{"variants":"いわく付き/曰く付き"},"曰く付き":{"variants":"いわく付き/曰く付き"},"イワシ":{"variants":"イワシ/鰯/鰮"},"いわし雲":{"variants":"いわし雲/鰯雲"},"鰯雲":{"variants":"いわし雲/鰯雲"},"いわす":{"variants":"いわす/言わす"},"言わす":{"variants":"いわす/言わす"},"イワタケ":{"variants":"イワタケ/岩茸/石茸"},"イワツツジ":{"variants":"イワツツジ/岩つつじ/岩躑躅"},"岩つつじ":{"variants":"イワツツジ/岩つつじ/岩躑躅"},"岩躑躅":{"variants":"イワツツジ/岩つつじ/岩躑躅"},"イワツバメ":{"variants":"イワツバメ/岩燕"},"岩燕":{"variants":"イワツバメ/岩燕"},"イワナ":{"variants":"イワナ/岩魚"},"岩魚":{"variants":"イワナ/岩魚"},"いわば":{"variants":"いわば/言わば"},"言わば":{"variants":"いわば/言わば"},"いわれ":{"variants":"いわれ/謂れ"},"謂れ":{"variants":"いわれ/謂れ"},"謂れ因縁":{"variants":"謂れ因縁/謂因縁"},"謂因縁":{"variants":"謂れ因縁/謂因縁"},"いわんや":{"variants":"いわんや/況や"},"況や":{"variants":"いわんや/況や"},"イン":{"variants":"ｉｎ/イン/員/院/韻/婬"},"殷々":{"variants":"殷々/殷殷"},"陰々":{"variants":"陰々/陰陰"},"殷殷":{"variants":"殷々/殷殷"},"陰陰":{"variants":"陰々/陰陰"},"陰うつ":{"variants":"陰うつ/陰鬱"},"陰鬱":{"variants":"陰うつ/陰鬱"},"インカ":{"variants":"インカ/陰火"},"陰火":{"variants":"インカ/陰火"},"インカショクブツ":{"variants":"インカショクブツ/隠花植物"},"隠花植物":{"variants":"インカショクブツ/隠花植物"},"インキ":{"variants":"インキ/引起/陰気"},"いんきくさい":{"variants":"いんきくさい/陰気臭い"},"陰気臭い":{"variants":"いんきくさい/陰気臭い"},"いんぎん無礼":{"variants":"いんぎん無礼/慇懃無礼"},"慇懃無礼":{"variants":"いんぎん無礼/慇懃無礼"},"インゲン":{"variants":"インゲン/隠元"},"隠元":{"variants":"インゲン/隠元"},"いんげん豆":{"variants":"いんげん豆/隠元豆"},"隠元豆":{"variants":"いんげん豆/隠元豆"},"インコ":{"variants":"インコ/鸚哥"},"鸚哥":{"variants":"インコ/鸚哥"},"いんしょうづける":{"variants":"いんしょうづける/印象づける"},"印象づける":{"variants":"いんしょうづける/印象づける"},"いんする":{"variants":"いんする/印する/淫する"},"隕石":{"variants":"いん石/隕石"},"姻せき":{"variants":"姻せき/姻戚"},"姻戚":{"variants":"姻せき/姻戚"},"いん石":{"variants":"いん石/隕石"},"インチ":{"variants":"インチ/印池/韻致/吋"},"隠とん":{"variants":"隠とん/隠遁"},"隠遁":{"variants":"隠とん/隠遁"},"隠ぺい":{"variants":"隠ぺい/隠蔽"},"隠蔽":{"variants":"隠ぺい/隠蔽"},"印ろう":{"variants":"印ろう/印篭/印籠"},"ウーロン茶":{"variants":"ウーロン茶/烏竜茶/烏龍茶"},"ウーン":{"variants":"うーん/ウーン"},"うーん":{"variants":"うーん/ウーン"},"うい":{"variants":"うい/憂い"},"憂い":{"variants":"うい/憂い"},"ういういしい":{"variants":"ういういしい/初々しい/初初しい"},"初々しい":{"variants":"ういういしい/初々しい/初初しい"},"初初しい":{"variants":"ういういしい/初々しい/初初しい"},"ウイキョウ":{"variants":"ウイキョウ/茴香"},"茴香":{"variants":"ウイキョウ/茴香"},"うえ":{"variants":"うえ/上"},"上":{"variants":"うえ/上"},"植え込み":{"variants":"植え込み/植込み"},"植込み":{"variants":"植え込み/植込み"},"うえこむ":{"variants":"うえこむ/植え込む"},"植え込む":{"variants":"うえこむ/植え込む"},"うえこめる":{"variants":"うえこめる/植え込める"},"植え込める":{"variants":"うえこめる/植え込める"},"飢え死に":{"variants":"飢え死に/飢死"},"飢死":{"variants":"飢え死に/飢死"},"植え付け":{"variants":"植え付け/植付け"},"植付け":{"variants":"植え付け/植付け"},"うえつける":{"variants":"うえつける/植え付ける"},"植え付ける":{"variants":"うえつける/植え付ける"},"うえる":{"variants":"うえる/植える"},"植える":{"variants":"うえる/植える"},"うおの目":{"variants":"うおの目/魚の目"},"魚の目":{"variants":"うおの目/魚の目"},"う音便":{"variants":"う音便/ウ音便"},"ウ音便":{"variants":"う音便/ウ音便"},"う化":{"variants":"う化/羽化"},"羽化":{"variants":"う化/羽化"},"鵜飼い":{"variants":"鵜飼/鵜飼い"},"鵜飼":{"variants":"鵜飼/鵜飼い"},"うかがう":{"variants":"うかがう/窺う/伺う"},"うかがえる":{"variants":"うかがえる/窺える/伺える"},"うかされる":{"variants":"うかされる/浮かされる"},"浮かされる":{"variants":"うかされる/浮かされる"},"うかす":{"variants":"うかす/浮かす"},"浮かす":{"variants":"うかす/浮かす"},"うかつ":{"variants":"うかつ/迂闊"},"迂闊":{"variants":"うかつ/迂闊"},"うかびあがる":{"variants":"うかびあがる/浮かび上がる/浮びあがる/浮び上がる/浮び上る"},"浮かび上がる":{"variants":"うかびあがる/浮かび上がる/浮びあがる/浮び上がる/浮び上る"},"浮びあがる":{"variants":"うかびあがる/浮かび上がる/浮びあがる/浮び上がる/浮び上る"},"浮び上がる":{"variants":"うかびあがる/浮かび上がる/浮びあがる/浮び上がる/浮び上る"},"浮び上る":{"variants":"うかびあがる/浮かび上がる/浮びあがる/浮び上がる/浮び上る"},"うかびあがれる":{"variants":"うかびあがれる/浮かび上がれる"},"浮かび上がれる":{"variants":"うかびあがれる/浮かび上がれる"},"うかぶ":{"variants":"うかぶ/浮かぶ/浮ぶ"},"浮かぶ":{"variants":"うかぶ/浮かぶ/浮ぶ"},"浮ぶ":{"variants":"うかぶ/浮かぶ/浮ぶ"},"うかべる":{"variants":"うかべる/浮かべる/浮べる"},"浮かべる":{"variants":"うかべる/浮かべる/浮べる"},"浮べる":{"variants":"うかべる/浮かべる/浮べる"},"うかる":{"variants":"うかる/受かる"},"受かる":{"variants":"うかる/受かる"},"うかれだす":{"variants":"うかれだす/浮かれだす/浮かれ出す"},"浮かれだす":{"variants":"うかれだす/浮かれだす/浮かれ出す"},"浮かれ出す":{"variants":"うかれだす/浮かれだす/浮かれ出す"},"うかれでる":{"variants":"うかれでる/浮かれ出でる"},"浮かれ出でる":{"variants":"うかれでる/浮かれ出でる"},"うかれる":{"variants":"うかれる/浮かれる"},"浮かれる":{"variants":"うかれる/浮かれる"},"うかんむり":{"variants":"うかんむり/ウ冠"},"ウ冠":{"variants":"うかんむり/ウ冠"},"うがつ":{"variants":"うがつ/穿つ"},"穿つ":{"variants":"うがつ/穿つ"},"うきあがる":{"variants":"うきあがる/浮き上がる/浮上がる"},"浮き上がる":{"variants":"うきあがる/浮き上がる/浮上がる"},"浮上がる":{"variants":"うきあがる/浮き上がる/浮上がる"},"うきあがれる":{"variants":"うきあがれる/浮き上がれる"},"浮き上がれる":{"variants":"うきあがれる/浮き上がれる"},"浮き足":{"variants":"浮き足/浮足"},"浮足":{"variants":"浮き足/浮足"},"うきあしだつ":{"variants":"うきあしだつ/浮き足立つ/浮足立つ"},"浮き足立つ":{"variants":"うきあしだつ/浮き足立つ/浮足立つ"},"浮足立つ":{"variants":"うきあしだつ/浮き足立つ/浮足立つ"},"うきうき":{"variants":"うきうき/ウキウキ/浮きうき/浮き浮き"},"ウキウキ":{"variants":"うきうき/ウキウキ/浮きうき/浮き浮き"},"浮きうき":{"variants":"うきうき/ウキウキ/浮きうき/浮き浮き"},"浮き浮き":{"variants":"うきうき/ウキウキ/浮きうき/浮き浮き"},"浮き腰":{"variants":"浮き腰/浮腰"},"浮腰":{"variants":"浮き腰/浮腰"},"浮き島":{"variants":"浮き島/浮島"},"浮島":{"variants":"浮き島/浮島"},"浮き巣":{"variants":"浮き巣/浮巣"},"浮巣":{"variants":"浮き巣/浮巣"},"うきたつ":{"variants":"うきたつ/浮きたつ/浮き立つ/浮立つ"},"浮きたつ":{"variants":"うきたつ/浮きたつ/浮き立つ/浮立つ"},"浮き立つ":{"variants":"うきたつ/浮きたつ/浮き立つ/浮立つ"},"浮立つ":{"variants":"うきたつ/浮きたつ/浮き立つ/浮立つ"},"うきたてる":{"variants":"うきたてる/浮き立てる"},"浮き立てる":{"variants":"うきたてる/浮き立てる"},"うきだす":{"variants":"うきだす/浮き出す/浮出す"},"浮き出す":{"variants":"うきだす/浮き出す/浮出す"},"浮出す":{"variants":"うきだす/浮き出す/浮出す"},"うきでる":{"variants":"うきでる/浮きでる/浮き出る"},"浮きでる":{"variants":"うきでる/浮きでる/浮き出る"},"浮き出る":{"variants":"うきでる/浮きでる/浮き出る"},"うきドック":{"variants":"うきドック/浮ドック"},"浮ドック":{"variants":"うきドック/浮ドック"},"浮き名":{"variants":"浮き名/浮名"},"浮名":{"variants":"浮き名/浮名"},"ウキブクロ":{"variants":"ウキブクロ/浮き袋/浮袋"},"浮き袋":{"variants":"ウキブクロ/浮き袋/浮袋"},"浮袋":{"variants":"ウキブクロ/浮き袋/浮袋"},"浮き彫り":{"variants":"浮き彫り/浮彫"},"浮彫":{"variants":"浮き彫り/浮彫"},"憂き身":{"variants":"憂き身/憂身"},"憂身":{"variants":"憂き身/憂身"},"うく":{"variants":"うく/浮く"},"浮く":{"variants":"うく/浮く"},"ウグイ":{"variants":"ウグイ/石斑魚"},"石斑魚":{"variants":"ウグイ/石斑魚"},"ウグイス":{"variants":"ウグイス/鴬"},"鴬":{"variants":"ウグイス/鴬"},"うぐいす色":{"variants":"うぐいす色/鴬色"},"鴬色":{"variants":"うぐいす色/鴬色"},"ウケ":{"variants":"ウケ/受け/請け/有卦"},"請合い":{"variants":"請け合い/請合い"},"請け合い":{"variants":"請け合い/請合い"},"うけあう":{"variants":"うけあう/受けあう/受け合う/受合う/請けあう/請け合う/請合う"},"請け合う":{"variants":"うけあう/請けあう/請け合う/請合う"},"受け合う":{"variants":"うけあう/受けあう/受け合う/受合う"},"請合う":{"variants":"うけあう/請けあう/請け合う/請合う"},"受合う":{"variants":"うけあう/受けあう/受け合う/受合う"},"請けあう":{"variants":"うけあう/請けあう/請け合う/請合う"},"受けあう":{"variants":"うけあう/受けあう/受け合う/受合う"},"うけあえる":{"variants":"うけあえる/受け合える/請け合える"},"受け入れ":{"variants":"受け入れ/受入/受入れ"},"受入":{"variants":"受け入れ/受入/受入れ"},"受入れ":{"variants":"受け入れ/受入/受入れ"},"うけいれる":{"variants":"うけいれる/受けいれる/受け入れる/受入れる"},"受けいれる":{"variants":"うけいれる/受けいれる/受け入れる/受入れる"},"受け入れる":{"variants":"うけいれる/受けいれる/受け入れる/受入れる"},"受入れる":{"variants":"うけいれる/受けいれる/受け入れる/受入れる"},"受け売り":{"variants":"受け売り/受売り"},"受売り":{"variants":"受け売り/受売り"},"請け負い":{"variants":"請け負い/請負"},"請負":{"variants":"請け負い/請負"},"うけおう":{"variants":"うけおう/請けおう/請け負う/請負う"},"請けおう":{"variants":"うけおう/請けおう/請け負う/請負う"},"請け負う":{"variants":"うけおう/請けおう/請け負う/請負う"},"請負う":{"variants":"うけおう/請けおう/請け負う/請負う"},"うけおえる":{"variants":"うけおえる/請け負える"},"請け負える":{"variants":"うけおえる/請け負える"},"受け口":{"variants":"受け口/受口"},"受口":{"variants":"受け口/受口"},"受けこたえ":{"variants":"受けこたえ/受答え"},"受答え":{"variants":"受けこたえ/受答え"},"受け腰":{"variants":"受け腰/受腰"},"受腰":{"variants":"受け腰/受腰"},"受け皿":{"variants":"受け皿/受皿"},"受皿":{"variants":"受け皿/受皿"},"請け書":{"variants":"請け書/請書"},"請書":{"variants":"請け書/請書"},"うけたまわる":{"variants":"うけたまわる/承る"},"承る":{"variants":"うけたまわる/承る"},"うけだす":{"variants":"うけだす/受け出す/請け出す/請出す"},"請け出す":{"variants":"うけだす/請け出す/請出す"},"請出す":{"variants":"うけだす/請け出す/請出す"},"うけだせる":{"variants":"うけだせる/受け出せる"},"受け出せる":{"variants":"うけだせる/受け出せる"},"受け太刀":{"variants":"受け太刀/受太刀"},"受太刀":{"variants":"受け太刀/受太刀"},"うけつぐ":{"variants":"うけつぐ/受け継ぐ/受継ぐ"},"受け継ぐ":{"variants":"うけつぐ/受け継ぐ/受継ぐ"},"受継ぐ":{"variants":"うけつぐ/受け継ぐ/受継ぐ"},"受け付け":{"variants":"受け付け/受付"},"受付":{"variants":"受け付け/受付"},"うけつける":{"variants":"うけつける/受けつける/受け付ける/受付ける"},"受けつける":{"variants":"うけつける/受けつける/受け付ける/受付ける"},"受け付ける":{"variants":"うけつける/受けつける/受け付ける/受付ける"},"受付ける":{"variants":"うけつける/受けつける/受け付ける/受付ける"},"うけつげる":{"variants":"うけつげる/受け継げる"},"受け継げる":{"variants":"うけつげる/受け継げる"},"うけとめる":{"variants":"うけとめる/受けとめる/受け止める/受止める"},"受けとめる":{"variants":"うけとめる/受けとめる/受け止める/受止める"},"受け止める":{"variants":"うけとめる/受けとめる/受け止める/受止める"},"受止める":{"variants":"うけとめる/受けとめる/受け止める/受止める"},"受け取り":{"variants":"受けとり/受け取り/受取"},"受けとり":{"variants":"受けとり/受け取り/受取"},"受取":{"variants":"受けとり/受け取り/受取"},"うけとる":{"variants":"うけとる/受けとる/受け取る/受取る"},"受けとる":{"variants":"うけとる/受けとる/受け取る/受取る"},"受け取る":{"variants":"うけとる/受けとる/受け取る/受取る"},"受取る":{"variants":"うけとる/受けとる/受け取る/受取る"},"うけとれる":{"variants":"うけとれる/受け取れる"},"受け取れる":{"variants":"うけとれる/受け取れる"},"うけながす":{"variants":"うけながす/受け流す/受流す"},"受け流す":{"variants":"うけながす/受け流す/受流す"},"受流す":{"variants":"うけながす/受け流す/受流す"},"うけながせる":{"variants":"うけながせる/受け流せる"},"受け流せる":{"variants":"うけながせる/受け流せる"},"請け人":{"variants":"請け人/請人"},"請人":{"variants":"請け人/請人"},"うけひく":{"variants":"うけひく/受け引く"},"受け引く":{"variants":"うけひく/受け引く"},"受け身":{"variants":"受け身/受身"},"受身":{"variants":"受け身/受身"},"受け持ち":{"variants":"受け持ち/受持"},"受持":{"variants":"受け持ち/受持"},"うけもつ":{"variants":"うけもつ/受け持つ/受持つ"},"受け持つ":{"variants":"うけもつ/受け持つ/受持つ"},"受持つ":{"variants":"うけもつ/受け持つ/受持つ"},"うけもてる":{"variants":"うけもてる/受け持てる"},"受け持てる":{"variants":"うけもてる/受け持てる"},"うける":{"variants":"うける/ウケる/受ける/承ける/請ける"},"ウケる":{"variants":"うける/ウケる/受ける/承ける/請ける"},"受け渡し":{"variants":"受け渡し/受渡し"},"受渡し":{"variants":"受け渡し/受渡し"},"ウコギ":{"variants":"ウコギ/五加"},"五加":{"variants":"ウコギ/五加"},"右顧左べん":{"variants":"右顧左べん/右顧左眄"},"右顧左眄":{"variants":"右顧左べん/右顧左眄"},"ウコン":{"variants":"ウコン/右近/鬱金"},"右近の橘":{"variants":"右近の橘/右近橘"},"右近橘":{"variants":"右近の橘/右近橘"},"ウゴ":{"variants":"ウゴ/雨後"},"雨後":{"variants":"ウゴ/雨後"},"うごかす":{"variants":"うごかす/動かす"},"動かす":{"variants":"うごかす/動かす"},"動きだす":{"variants":"動きだす/動き出す"},"動き出す":{"variants":"動きだす/動き出す"},"うごく":{"variants":"うごく/動く"},"動く":{"variants":"うごく/動く"},"うごける":{"variants":"うごける/動ける"},"動ける":{"variants":"うごける/動ける"},"うごめかす":{"variants":"うごめかす/蠢かす"},"蠢かす":{"variants":"うごめかす/蠢かす"},"うごめく":{"variants":"うごめく/蠕く/蠢く"},"うさ":{"variants":"うさ/憂さ"},"憂さ":{"variants":"うさ/憂さ"},"うさぎ":{"variants":"うさぎ/ウサギ/菟/兔"},"ウサギ":{"variants":"うさぎ/ウサギ/菟/兔"},"ウサギウマ":{"variants":"ウサギウマ/兎馬"},"兎馬":{"variants":"ウサギウマ/兎馬"},"憂さばらし":{"variants":"憂さばらし/憂さ晴らし/憂晴らし"},"憂さ晴らし":{"variants":"憂さばらし/憂さ晴らし/憂晴らし"},"憂晴らし":{"variants":"憂さばらし/憂さ晴らし/憂晴らし"},"うさんい":{"variants":"うさんい/胡散い"},"胡散い":{"variants":"うさんい/胡散い"},"うさんくさい":{"variants":"うさんくさい/胡散臭い"},"胡散臭い":{"variants":"うさんくさい/胡散臭い"},"うし":{"variants":"うし/ウシ/丑/牛"},"ウシ":{"variants":"うし/ウシ/丑/牛"},"ウシガエル":{"variants":"ウシガエル/牛蛙"},"牛蛙":{"variants":"ウシガエル/牛蛙"},"ウシコロシ":{"variants":"ウシコロシ/牛殺し"},"牛殺し":{"variants":"ウシコロシ/牛殺し"},"うしなう":{"variants":"うしなう/失う/喪う"},"丑の刻参り":{"variants":"丑の刻参り/丑刻参り"},"丑刻参り":{"variants":"丑の刻参り/丑刻参り"},"丑の日":{"variants":"丑の日/丑日"},"丑日":{"variants":"丑の日/丑日"},"うしろ足":{"variants":"うしろ足/後ろ足"},"後ろ足":{"variants":"うしろ足/後ろ足"},"後ろ髪":{"variants":"後ろ髪/後髪"},"後髪":{"variants":"後ろ髪/後髪"},"うしろぐらい":{"variants":"うしろぐらい/後暗い"},"後暗い":{"variants":"うしろぐらい/後暗い"},"うしろ姿":{"variants":"うしろ姿/後ろ姿/後姿"},"後ろ姿":{"variants":"うしろ姿/後ろ姿/後姿"},"後姿":{"variants":"うしろ姿/後ろ姿/後姿"},"後ろだて":{"variants":"後ろだて/後ろ楯/後楯"},"後ろ楯":{"variants":"後ろだて/後ろ楯/後楯"},"後楯":{"variants":"後ろだて/後ろ楯/後楯"},"後ろ前":{"variants":"後ろ前/後前"},"後前":{"variants":"後ろ前/後前"},"後ろ向き":{"variants":"後ろ向き/後向き"},"後向き":{"variants":"後ろ向き/後向き"},"うしろめたい":{"variants":"うしろめたい/後ろめたい"},"後ろめたい":{"variants":"うしろめたい/後ろめたい"},"後ろ指":{"variants":"後ろ指/後指"},"後指":{"variants":"後ろ指/後指"},"ウジ":{"variants":"ウジ/蛆"},"蛆":{"variants":"ウジ/蛆"},"うじ虫":{"variants":"うじ虫/ウジムシ/蛆虫"},"ウジムシ":{"variants":"うじ虫/ウジムシ/蛆虫"},"蛆虫":{"variants":"うじ虫/ウジムシ/蛆虫"},"うすい":{"variants":"うすい/薄い"},"薄い":{"variants":"うすい/薄い"},"薄々":{"variants":"薄々/薄薄"},"薄薄":{"variants":"薄々/薄薄"},"うす皮":{"variants":"うす皮/薄皮"},"薄皮":{"variants":"うす皮/薄皮"},"うすきみわるい":{"variants":"うすきみわるい/薄気味悪い"},"薄気味悪い":{"variants":"うすきみわるい/薄気味悪い"},"うすぎたない":{"variants":"うすぎたない/うす汚い/薄汚い"},"うす汚い":{"variants":"うすぎたない/うす汚い/薄汚い"},"薄汚い":{"variants":"うすぎたない/うす汚い/薄汚い"},"うす切り":{"variants":"うす切り/薄切り"},"薄切り":{"variants":"うす切り/薄切り"},"うす口":{"variants":"うす口/薄口"},"薄口":{"variants":"うす口/薄口"},"薄曇":{"variants":"薄曇/薄曇り"},"薄曇り":{"variants":"薄曇/薄曇り"},"うすぐらい":{"variants":"うすぐらい/薄暗い"},"薄暗い":{"variants":"うすぐらい/薄暗い"},"うすずく":{"variants":"うすずく/舂く"},"舂く":{"variants":"うすずく/舂く"},"うす茶":{"variants":"うす茶/薄茶"},"薄茶":{"variants":"うす茶/薄茶"},"うすっぺら":{"variants":"うすっぺら/薄っぺら"},"薄っぺら":{"variants":"うすっぺら/薄っぺら"},"ウスバカゲロウ":{"variants":"ウスバカゲロウ/薄羽蜉蝣"},"薄羽蜉蝣":{"variants":"ウスバカゲロウ/薄羽蜉蝣"},"うすまる":{"variants":"うすまる/薄まる"},"薄まる":{"variants":"うすまる/薄まる"},"うすめる":{"variants":"うすめる/薄める"},"薄める":{"variants":"うすめる/薄める"},"薄もの":{"variants":"薄もの/薄物"},"薄物":{"variants":"薄もの/薄物"},"うす焼き":{"variants":"うす焼き/薄焼き"},"薄焼き":{"variants":"うす焼き/薄焼き"},"うすらぐ":{"variants":"うすらぐ/薄らぐ"},"薄らぐ":{"variants":"うすらぐ/薄らぐ"},"うすらさむい":{"variants":"うすらさむい/うすら寒い/薄ら寒い/薄寒い"},"うすら寒い":{"variants":"うすらさむい/うすら寒い/薄ら寒い/薄寒い"},"薄ら寒い":{"variants":"うすらさむい/うすら寒い/薄ら寒い/薄寒い"},"薄寒い":{"variants":"うすらさむい/うすら寒い/薄ら寒い/薄寒い"},"うすれる":{"variants":"うすれる/薄れる"},"薄れる":{"variants":"うすれる/薄れる"},"うず":{"variants":"うず/渦/髻華"},"うずく":{"variants":"うずく/疼く"},"疼く":{"variants":"うずく/疼く"},"うずくまる":{"variants":"うずくまる/踞る/蹲る"},"うずたかい":{"variants":"うずたかい/堆い"},"堆い":{"variants":"うずたかい/堆い"},"渦巻":{"variants":"渦巻/渦巻き"},"渦巻き":{"variants":"渦巻/渦巻き"},"うずまく":{"variants":"うずまく/うず巻く/渦まく/渦巻く"},"うず巻く":{"variants":"うずまく/うず巻く/渦まく/渦巻く"},"渦まく":{"variants":"うずまく/うず巻く/渦まく/渦巻く"},"渦巻く":{"variants":"うずまく/うず巻く/渦まく/渦巻く"},"うずもる":{"variants":"うずもる/埋もる"},"埋もる":{"variants":"うずもる/埋もる"},"ウズラ":{"variants":"ウズラ/鶉"},"鶉":{"variants":"ウズラ/鶉"},"ウズラマメ":{"variants":"ウズラマメ/鶉豆"},"鶉豆":{"variants":"ウズラマメ/鶉豆"},"失せもの":{"variants":"失せもの/失せ物"},"失せ物":{"variants":"失せもの/失せ物"},"うせる":{"variants":"うせる/失せる"},"失せる":{"variants":"うせる/失せる"},"うそ":{"variants":"うそ/ウソ/嘘/鷽"},"ウソ":{"variants":"うそ/ウソ/嘘/鷽"},"うそさむい":{"variants":"うそさむい/うそ寒い"},"うそ寒い":{"variants":"うそさむい/うそ寒い"},"ウソっぱち":{"variants":"ウソっぱち/嘘っぱち"},"嘘っぱち":{"variants":"ウソっぱち/嘘っぱち"},"ウソつき":{"variants":"ウソつき/嘘つき"},"嘘つき":{"variants":"ウソつき/嘘つき"},"うそ八百":{"variants":"うそ八百/嘘八百"},"嘘八百":{"variants":"うそ八百/嘘八百"},"うそぶく":{"variants":"うそぶく/嘯く"},"嘯く":{"variants":"うそぶく/嘯く"},"うた":{"variants":"うた/唄/歌"},"歌合":{"variants":"歌合/歌合わせ"},"歌合わせ":{"variants":"歌合/歌合わせ"},"謡":{"variants":"謡/謡い"},"謡い":{"variants":"謡/謡い"},"うたいあげる":{"variants":"うたいあげる/歌い上げる"},"歌い上げる":{"variants":"うたいあげる/歌い上げる"},"うたいまくる":{"variants":"うたいまくる/歌いまくる"},"歌いまくる":{"variants":"うたいまくる/歌いまくる"},"うたい文句":{"variants":"うたい文句/歌い文句/謳い文句/謳文句"},"謳文句":{"variants":"うたい文句/謳い文句/謳文句"},"謳い文句":{"variants":"うたい文句/謳い文句/謳文句"},"うたう":{"variants":"うたう/唄う/詠う/歌う/唱う/謡う/謳う"},"うたえる":{"variants":"うたえる/唄える/詠える/歌える/謡える"},"うたがいぶかい":{"variants":"うたがいぶかい/疑いぶかい/疑い深い/疑深い"},"疑いぶかい":{"variants":"うたがいぶかい/疑いぶかい/疑い深い/疑深い"},"疑い深い":{"variants":"うたがいぶかい/疑いぶかい/疑い深い/疑深い"},"疑深い":{"variants":"うたがいぶかい/疑いぶかい/疑い深い/疑深い"},"うたがう":{"variants":"うたがう/疑う"},"疑う":{"variants":"うたがう/疑う"},"うたがえる":{"variants":"うたがえる/疑える"},"疑える":{"variants":"うたがえる/疑える"},"うたガルタ":{"variants":"うたガルタ/歌ガルタ/歌加留多"},"歌ガルタ":{"variants":"うたガルタ/歌ガルタ/歌加留多"},"歌加留多":{"variants":"うたガルタ/歌ガルタ/歌加留多"},"うたがわしい":{"variants":"うたがわしい/疑わしい"},"疑わしい":{"variants":"うたがわしい/疑わしい"},"うたぐる":{"variants":"うたぐる/疑る"},"疑る":{"variants":"うたぐる/疑る"},"うたた":{"variants":"うたた/転た"},"転た":{"variants":"うたた/転た"},"うたた寝":{"variants":"うたた寝/転た寝/転寝"},"転た寝":{"variants":"うたた寝/転た寝/転寝"},"転寝":{"variants":"うたた寝/転た寝/転寝"},"うたて":{"variants":"うたて/漸/転"},"歌まくら":{"variants":"歌まくら/歌枕"},"歌枕":{"variants":"歌まくら/歌枕"},"うち":{"variants":"うち/内"},"ウチ":{"variants":"うち/ウチ"},"内":{"variants":"うち/内"},"うちあう":{"variants":"うちあう/撃ち合う/打ちあう/打ち合う/打合う"},"打ち合う":{"variants":"うちあう/打ちあう/打ち合う/打合う"},"打合う":{"variants":"うちあう/打ちあう/打ち合う/打合う"},"打ちあう":{"variants":"うちあう/打ちあう/打ち合う/打合う"},"うちあぐむ":{"variants":"うちあぐむ/打あぐむ/打ちあぐむ"},"打あぐむ":{"variants":"うちあぐむ/打あぐむ/打ちあぐむ"},"打ちあぐむ":{"variants":"うちあぐむ/打あぐむ/打ちあぐむ"},"うちあける":{"variants":"うちあける/打ちあける/打ち明ける/打明ける"},"打ちあける":{"variants":"うちあける/打ちあける/打ち明ける/打明ける"},"打ち明ける":{"variants":"うちあける/打ちあける/打ち明ける/打明ける"},"打明ける":{"variants":"うちあける/打ちあける/打ち明ける/打明ける"},"打ち上げ花火":{"variants":"打ち上げ花火/打上げ花火/打上花火"},"打上げ花火":{"variants":"打ち上げ花火/打上げ花火/打上花火"},"打上花火":{"variants":"打ち上げ花火/打上げ花火/打上花火"},"うちあげる":{"variants":"うちあげる/打ちあげる/打ち上げる/打上げる"},"打ちあげる":{"variants":"うちあげる/打ちあげる/打ち上げる/打上げる"},"打ち上げる":{"variants":"うちあげる/打ちあげる/打ち上げる/打上げる"},"打上げる":{"variants":"うちあげる/打ちあげる/打ち上げる/打上げる"},"うちあわす":{"variants":"うちあわす/打ちあわす/打ち合す/打ち合わす/打合わす"},"打ちあわす":{"variants":"うちあわす/打ちあわす/打ち合す/打ち合わす/打合わす"},"打ち合す":{"variants":"うちあわす/打ちあわす/打ち合す/打ち合わす/打合わす"},"打ち合わす":{"variants":"うちあわす/打ちあわす/打ち合す/打ち合わす/打合わす"},"打合わす":{"variants":"うちあわす/打ちあわす/打ち合す/打ち合わす/打合わす"},"打合せ":{"variants":"打合せ/打合わせ"},"打合わせ":{"variants":"打合せ/打合わせ"},"うちあわせる":{"variants":"うちあわせる/打ちあわせる/打ち合せる/打ち合わせる/打合せる"},"打ちあわせる":{"variants":"うちあわせる/打ちあわせる/打ち合せる/打ち合わせる/打合せる"},"打ち合せる":{"variants":"うちあわせる/打ちあわせる/打ち合せる/打ち合わせる/打合せる"},"打ち合わせる":{"variants":"うちあわせる/打ちあわせる/打ち合せる/打ち合わせる/打合せる"},"打合せる":{"variants":"うちあわせる/打ちあわせる/打ち合せる/打ち合わせる/打合せる"},"討ち入り":{"variants":"討ち入り/討入"},"討入":{"variants":"討ち入り/討入"},"内祝":{"variants":"内祝/内祝い"},"内祝い":{"variants":"内祝/内祝い"},"内々":{"variants":"内々/内内"},"内内":{"variants":"内々/内内"},"うちおとす":{"variants":"うちおとす/撃ち落とす/打ち落す/打ち落とす/打落す"},"打落す":{"variants":"うちおとす/打ち落す/打ち落とす/打落す"},"打ち落とす":{"variants":"うちおとす/打ち落す/打ち落とす/打落す"},"打ち落す":{"variants":"うちおとす/打ち落す/打ち落とす/打落す"},"うちおとせる":{"variants":"うちおとせる/撃ち落とせる/打ち落とせる/打落とせる"},"打ち落とせる":{"variants":"うちおとせる/打ち落とせる/打落とせる"},"打落とせる":{"variants":"うちおとせる/打ち落とせる/打落とせる"},"うちかえす":{"variants":"うちかえす/打ちかえす/打ち返す/打返す"},"打ちかえす":{"variants":"うちかえす/打ちかえす/打ち返す/打返す"},"打ち返す":{"variants":"うちかえす/打ちかえす/打ち返す/打返す"},"打返す":{"variants":"うちかえす/打ちかえす/打ち返す/打返す"},"うちかえせる":{"variants":"うちかえせる/打ち返せる/打返せる"},"打ち返せる":{"variants":"うちかえせる/打ち返せる/打返せる"},"打返せる":{"variants":"うちかえせる/打ち返せる/打返せる"},"打ち掛け":{"variants":"打ち掛け/打掛け"},"打掛け":{"variants":"打ち掛け/打掛け"},"うちかつ":{"variants":"うちかつ/打ち勝つ/打勝つ"},"打ち勝つ":{"variants":"うちかつ/打ち勝つ/打勝つ"},"打勝つ":{"variants":"うちかつ/打ち勝つ/打勝つ"},"うちかてる":{"variants":"うちかてる/打ち勝てる/打勝てる"},"打ち勝てる":{"variants":"うちかてる/打ち勝てる/打勝てる"},"打勝てる":{"variants":"うちかてる/打ち勝てる/打勝てる"},"打ち傷":{"variants":"打ち傷/打傷"},"打傷":{"variants":"打ち傷/打傷"},"打ち切り":{"variants":"打ち切り/打切/打切り"},"打切":{"variants":"打ち切り/打切/打切り"},"打切り":{"variants":"打ち切り/打切/打切り"},"うちきる":{"variants":"うちきる/打ちきる/打ち切る/打切る"},"打ちきる":{"variants":"うちきる/打ちきる/打ち切る/打切る"},"打ち切る":{"variants":"うちきる/打ちきる/打ち切る/打切る"},"打切る":{"variants":"うちきる/打ちきる/打ち切る/打切る"},"うちきれる":{"variants":"うちきれる/打ち切れる/打切れる"},"打ち切れる":{"variants":"うちきれる/打ち切れる/打切れる"},"打切れる":{"variants":"うちきれる/打ち切れる/打切れる"},"うちくだく":{"variants":"うちくだく/打ちくだく/打ち砕く/打砕く"},"打ちくだく":{"variants":"うちくだく/打ちくだく/打ち砕く/打砕く"},"打ち砕く":{"variants":"うちくだく/打ちくだく/打ち砕く/打砕く"},"打砕く":{"variants":"うちくだく/打ちくだく/打ち砕く/打砕く"},"うちくだける":{"variants":"うちくだける/打ち砕ける/打砕ける"},"打ち砕ける":{"variants":"うちくだける/打ち砕ける/打砕ける"},"打砕ける":{"variants":"うちくだける/打ち砕ける/打砕ける"},"うちけす":{"variants":"うちけす/打ち消す/打消す"},"打ち消す":{"variants":"うちけす/打ち消す/打消す"},"打消す":{"variants":"うちけす/打ち消す/打消す"},"うちけせる":{"variants":"うちけせる/打ち消せる/打消せる"},"打ち消せる":{"variants":"うちけせる/打ち消せる/打消せる"},"打消せる":{"variants":"うちけせる/打ち消せる/打消せる"},"うちこむ":{"variants":"うちこむ/撃ち込む/打ちこむ/打ち込む/打込む"},"打ち込む":{"variants":"うちこむ/打ちこむ/打ち込む/打込む"},"打ちこむ":{"variants":"うちこむ/打ちこむ/打ち込む/打込む"},"打込む":{"variants":"うちこむ/打ちこむ/打ち込む/打込む"},"うちこめる":{"variants":"うちこめる/撃ち込める/打ち込める/打込める"},"打ち込める":{"variants":"うちこめる/打ち込める/打込める"},"打込める":{"variants":"うちこめる/打ち込める/打込める"},"うちころす":{"variants":"うちころす/撃ち殺す/打ち殺す/打殺す"},"打ち殺す":{"variants":"うちころす/打ち殺す/打殺す"},"打殺す":{"variants":"うちころす/打ち殺す/打殺す"},"うちころせる":{"variants":"うちころせる/撃ち殺せる"},"撃ち殺せる":{"variants":"うちころせる/撃ち殺せる"},"打ち壊し":{"variants":"打ち壊し/打壊し"},"打壊し":{"variants":"打ち壊し/打壊し"},"うちこわす":{"variants":"うちこわす/打ち壊す/打壊す"},"打ち壊す":{"variants":"うちこわす/打ち壊す/打壊す"},"打壊す":{"variants":"うちこわす/打ち壊す/打壊す"},"うちしずむ":{"variants":"うちしずむ/打ち沈む/打沈む"},"打ち沈む":{"variants":"うちしずむ/打ち沈む/打沈む"},"打沈む":{"variants":"うちしずむ/打ち沈む/打沈む"},"討ち死に":{"variants":"討ち死に/討死"},"討死":{"variants":"討ち死に/討死"},"うちすえる":{"variants":"うちすえる/打ちすえる/打ち据える/打据える"},"打ちすえる":{"variants":"うちすえる/打ちすえる/打ち据える/打据える"},"打ち据える":{"variants":"うちすえる/打ちすえる/打ち据える/打据える"},"打据える":{"variants":"うちすえる/打ちすえる/打ち据える/打据える"},"うちすてる":{"variants":"うちすてる/うち捨てる/打ち捨てる/打捨てる"},"うち捨てる":{"variants":"うちすてる/うち捨てる/打ち捨てる/打捨てる"},"打ち捨てる":{"variants":"うちすてる/うち捨てる/打ち捨てる/打捨てる"},"打捨てる":{"variants":"うちすてる/うち捨てる/打ち捨てる/打捨てる"},"うちたおす":{"variants":"うちたおす/打ち倒す/打倒す"},"打ち倒す":{"variants":"うちたおす/打ち倒す/打倒す"},"打倒す":{"variants":"うちたおす/打ち倒す/打倒す"},"うちたおせる":{"variants":"うちたおせる/打ち倒せる/打倒せる"},"打ち倒せる":{"variants":"うちたおせる/打ち倒せる/打倒せる"},"打倒せる":{"variants":"うちたおせる/打ち倒せる/打倒せる"},"うちたてる":{"variants":"うちたてる/打ち立てる/打立てる"},"打ち立てる":{"variants":"うちたてる/打ち立てる/打立てる"},"打立てる":{"variants":"うちたてる/打ち立てる/打立てる"},"打ち出し":{"variants":"打ち出し/打出し"},"打出し":{"variants":"打ち出し/打出し"},"うちだす":{"variants":"うちだす/打ちだす/打ち出す/打出す"},"打ちだす":{"variants":"うちだす/打ちだす/打ち出す/打出す"},"打ち出す":{"variants":"うちだす/打ちだす/打ち出す/打出す"},"打出す":{"variants":"うちだす/打ちだす/打ち出す/打出す"},"うちだせる":{"variants":"うちだせる/打ちだせる/打ち出せる/打出せる"},"打ちだせる":{"variants":"うちだせる/打ちだせる/打ち出せる/打出せる"},"打ち出せる":{"variants":"うちだせる/打ちだせる/打ち出せる/打出せる"},"打出せる":{"variants":"うちだせる/打ちだせる/打ち出せる/打出せる"},"打ちっぱなし":{"variants":"打ちっぱなし/打ちっ放し"},"打ちっ放し":{"variants":"打ちっぱなし/打ちっ放し"},"うちつける":{"variants":"うちつける/打ちつける/打ち付ける/打付ける"},"打ちつける":{"variants":"うちつける/打ちつける/打ち付ける/打付ける"},"打ち付ける":{"variants":"うちつける/打ちつける/打ち付ける/打付ける"},"打付ける":{"variants":"うちつける/打ちつける/打ち付ける/打付ける"},"うちつづく":{"variants":"うちつづく/うち続く/打ちつづく/打ち続く/打続く"},"うち続く":{"variants":"うちつづく/うち続く/打ちつづく/打ち続く/打続く"},"打ちつづく":{"variants":"うちつづく/うち続く/打ちつづく/打ち続く/打続く"},"打ち続く":{"variants":"うちつづく/うち続く/打ちつづく/打ち続く/打続く"},"打続く":{"variants":"うちつづく/うち続く/打ちつづく/打ち続く/打続く"},"うちつれる":{"variants":"うちつれる/うち連れる/打ち連れる/打連れる"},"うち連れる":{"variants":"うちつれる/うち連れる/打ち連れる/打連れる"},"打ち連れる":{"variants":"うちつれる/うち連れる/打ち連れる/打連れる"},"打連れる":{"variants":"うちつれる/うち連れる/打ち連れる/打連れる"},"打ち出の小づち":{"variants":"打ち出の小づち/打出の小槌/打出小槌"},"打出の小槌":{"variants":"打ち出の小づち/打出の小槌/打出小槌"},"打出小槌":{"variants":"打ち出の小づち/打出の小槌/打出小槌"},"うちとける":{"variants":"うちとける/打ちとける/打ち解ける/打解ける"},"打ちとける":{"variants":"うちとける/打ちとける/打ち解ける/打解ける"},"打ち解ける":{"variants":"うちとける/打ちとける/打ち解ける/打解ける"},"打解ける":{"variants":"うちとける/打ちとける/打ち解ける/打解ける"},"うちとめる":{"variants":"うちとめる/撃ち止める/撃止める/討ち止める/討止める"},"討止める":{"variants":"うちとめる/討ち止める/討止める"},"撃ち止める":{"variants":"うちとめる/撃ち止める/撃止める"},"討ち止める":{"variants":"うちとめる/討ち止める/討止める"},"撃止める":{"variants":"うちとめる/撃ち止める/撃止める"},"うちとる":{"variants":"うちとる/撃ち取る/打ち取る/打取る/討ちとる/討ち取る/討取る"},"打ち取る":{"variants":"うちとる/打ち取る/打取る"},"討ち取る":{"variants":"うちとる/討ちとる/討ち取る/討取る"},"討ちとる":{"variants":"うちとる/討ちとる/討ち取る/討取る"},"打取る":{"variants":"うちとる/打ち取る/打取る"},"討取る":{"variants":"うちとる/討ちとる/討ち取る/討取る"},"うちとれる":{"variants":"うちとれる/打ち取れる/打取れる"},"打ち取れる":{"variants":"うちとれる/打ち取れる/打取れる"},"打取れる":{"variants":"うちとれる/打ち取れる/打取れる"},"打ちどころ":{"variants":"打ちどころ/打ち所"},"打ち所":{"variants":"打ちどころ/打ち所"},"打止め":{"variants":"打ち止め/打止め"},"打ち止め":{"variants":"打ち止め/打止め"},"うちなおす":{"variants":"うちなおす/打ち直す/打直す"},"打ち直す":{"variants":"うちなおす/打ち直す/打直す"},"打直す":{"variants":"うちなおす/打ち直す/打直す"},"うちなおせる":{"variants":"うちなおせる/打ち直せる/打直せる"},"打ち直せる":{"variants":"うちなおせる/打ち直せる/打直せる"},"打直せる":{"variants":"うちなおせる/打ち直せる/打直せる"},"打ち抜き":{"variants":"打ち抜き/打抜き"},"打抜き":{"variants":"打ち抜き/打抜き"},"うちぬく":{"variants":"うちぬく/撃ち抜く/打ち抜く/打抜く"},"打抜く":{"variants":"うちぬく/打ち抜く/打抜く"},"打ち抜く":{"variants":"うちぬく/打ち抜く/打抜く"},"うちぬける":{"variants":"うちぬける/打ち抜ける/打抜ける"},"打ち抜ける":{"variants":"うちぬける/打ち抜ける/打抜ける"},"打抜ける":{"variants":"うちぬける/打ち抜ける/打抜ける"},"うちの人":{"variants":"うちの人/内の人"},"内の人":{"variants":"うちの人/内の人"},"うちのめす":{"variants":"うちのめす/打ちのめす"},"打ちのめす":{"variants":"うちのめす/打ちのめす"},"内のり":{"variants":"内のり/内法"},"内法":{"variants":"内のり/内法"},"うちはたす":{"variants":"うちはたす/討ち果す/討ち果たす/討果す"},"討ち果す":{"variants":"うちはたす/討ち果す/討ち果たす/討果す"},"討ち果たす":{"variants":"うちはたす/討ち果す/討ち果たす/討果す"},"討果す":{"variants":"うちはたす/討ち果す/討ち果たす/討果す"},"うちはたせる":{"variants":"うちはたせる/討ち果たせる"},"討ち果たせる":{"variants":"うちはたせる/討ち果たせる"},"うちはなす":{"variants":"うちはなす/打ち放す/打放す"},"打ち放す":{"variants":"うちはなす/打ち放す/打放す"},"打放す":{"variants":"うちはなす/打ち放す/打放す"},"うちはらう":{"variants":"うちはらう/打ちはらう/打ち払う/打払う"},"打ちはらう":{"variants":"うちはらう/打ちはらう/打ち払う/打払う"},"打ち払う":{"variants":"うちはらう/打ちはらう/打ち払う/打払う"},"打払う":{"variants":"うちはらう/打ちはらう/打ち払う/打払う"},"うちはらえる":{"variants":"うちはらえる/打ち払える/打払える"},"打ち払える":{"variants":"うちはらえる/打ち払える/打払える"},"打払える":{"variants":"うちはらえる/打ち払える/打払える"},"内ぶろ":{"variants":"内ぶろ/内風呂"},"内風呂":{"variants":"内ぶろ/内風呂"},"うちほろぼす":{"variants":"うちほろぼす/討ち滅ぼす"},"討ち滅ぼす":{"variants":"うちほろぼす/討ち滅ぼす"},"うちまくる":{"variants":"うちまくる/撃ちまくる/打ちまくる"},"内また":{"variants":"内また/内股"},"内股":{"variants":"内また/内股"},"打ち身":{"variants":"打ち身/打身"},"打身":{"variants":"打ち身/打身"},"うちみる":{"variants":"うちみる/打ちみる/打ち見る/打見る"},"打ちみる":{"variants":"うちみる/打ちみる/打ち見る/打見る"},"打ち見る":{"variants":"うちみる/打ちみる/打ち見る/打見る"},"打見る":{"variants":"うちみる/打ちみる/打ち見る/打見る"},"内もも":{"variants":"内もも/内腿"},"内腿":{"variants":"内もも/内腿"},"うちやぶる":{"variants":"うちやぶる/撃ち破る/打ち破る/打破る"},"打破る":{"variants":"うちやぶる/打ち破る/打破る"},"打ち破る":{"variants":"うちやぶる/打ち破る/打破る"},"うちやぶれる":{"variants":"うちやぶれる/撃ち破れる/打ち破れる/打破れる"},"打破れる":{"variants":"うちやぶれる/打ち破れる/打破れる"},"打ち破れる":{"variants":"うちやぶれる/打ち破れる/打破れる"},"うちよせる":{"variants":"うちよせる/打ちよせる/打ち寄せる/打寄せる"},"打ちよせる":{"variants":"うちよせる/打ちよせる/打ち寄せる/打寄せる"},"打ち寄せる":{"variants":"うちよせる/打ちよせる/打ち寄せる/打寄せる"},"打寄せる":{"variants":"うちよせる/打ちよせる/打ち寄せる/打寄せる"},"うちわ":{"variants":"うちわ/団扇/内輪"},"打ち綿":{"variants":"打ち綿/打綿"},"打綿":{"variants":"打ち綿/打綿"},"うちわ太鼓":{"variants":"うちわ太鼓/団扇太鼓"},"団扇太鼓":{"variants":"うちわ太鼓/団扇太鼓"},"内輪もめ":{"variants":"内輪もめ/内輪揉め"},"内輪揉め":{"variants":"内輪もめ/内輪揉め"},"うっ屈":{"variants":"うっ屈/鬱屈"},"鬱屈":{"variants":"うっ屈/鬱屈"},"うっ血":{"variants":"うっ血/鬱血"},"鬱血":{"variants":"うっ血/鬱血"},"ウッコンコウ":{"variants":"ウッコンコウ/鬱金香"},"鬱金香":{"variants":"ウッコンコウ/鬱金香"},"うっする":{"variants":"うっする/鬱する"},"鬱する":{"variants":"うっする/鬱する"},"うっ積":{"variants":"うっ積/鬱積"},"鬱積":{"variants":"うっ積/鬱積"},"うったえる":{"variants":"うったえる/訴える"},"訴える":{"variants":"うったえる/訴える"},"打ってがえし":{"variants":"打ってがえし/打って返し"},"打って返し":{"variants":"打ってがえし/打って返し"},"うっとうしい":{"variants":"うっとうしい/鬱陶しい"},"鬱陶しい":{"variants":"うっとうしい/鬱陶しい"},"うっぷん":{"variants":"うっぷん/うっ憤/鬱憤"},"うっ憤":{"variants":"うっぷん/うっ憤/鬱憤"},"鬱憤":{"variants":"うっぷん/うっ憤/鬱憤"},"うつ":{"variants":"うつ/欝"},"欝":{"variants":"うつ/欝"},"鬱々":{"variants":"鬱々/鬱鬱"},"鬱鬱":{"variants":"鬱々/鬱鬱"},"ウツギ":{"variants":"ウツギ/卯木/空木"},"うつくしい":{"variants":"うつくしい/美しい"},"美しい":{"variants":"うつくしい/美しい"},"写":{"variants":"写/写し"},"写し":{"variants":"写/写し"},"うつし絵":{"variants":"うつし絵/移し絵/写し絵/写絵"},"写絵":{"variants":"うつし絵/写し絵/写絵"},"写し絵":{"variants":"うつし絵/写し絵/写絵"},"うつしだす":{"variants":"うつしだす/映し出す/写し出す"},"うつしだせる":{"variants":"うつしだせる/映し出せる/写し出せる"},"うつしとる":{"variants":"うつしとる/写し取る"},"写し取る":{"variants":"うつしとる/写し取る"},"うつしとれる":{"variants":"うつしとれる/写し取れる"},"写し取れる":{"variants":"うつしとれる/写し取れる"},"写しもの":{"variants":"写しもの/写し物"},"写し物":{"variants":"写しもの/写し物"},"うつす":{"variants":"うつす/移す/映す/撮す/写す/遷す/寫す"},"ウツセガイ":{"variants":"ウツセガイ/虚貝"},"虚貝":{"variants":"ウツセガイ/虚貝"},"うつせみ":{"variants":"うつせみ/空蝉/現身"},"うつせる":{"variants":"うつせる/移せる/映せる/写せる/寫せる"},"うつ病":{"variants":"うつ病/鬱病"},"鬱病":{"variants":"うつ病/鬱病"},"うつぶす":{"variants":"うつぶす/うつ伏す"},"うつ伏す":{"variants":"うつぶす/うつ伏す"},"うつぶせる":{"variants":"うつぶせる/うつ伏せる/俯せる"},"ウツボ":{"variants":"ウツボ/空穂/靭"},"ウツボカズラ":{"variants":"ウツボカズラ/靫葛/靫蔓"},"うつむく":{"variants":"うつむく/うつ向く/俯く"},"うつむける":{"variants":"うつむける/俯ける"},"俯ける":{"variants":"うつむける/俯ける"},"うつりかわる":{"variants":"うつりかわる/移り変る/移り変わる/遷り変る"},"移り変る":{"variants":"うつりかわる/移り変る/移り変わる"},"移り変わる":{"variants":"うつりかわる/移り変る/移り変わる"},"うつり香":{"variants":"うつり香/移り香"},"移り香":{"variants":"うつり香/移り香"},"うつり気":{"variants":"うつり気/移り気"},"移り気":{"variants":"うつり気/移り気"},"うつりすむ":{"variants":"うつりすむ/移り住む"},"移り住む":{"variants":"うつりすむ/移り住む"},"移りばし":{"variants":"移りばし/移り箸"},"移り箸":{"variants":"移りばし/移り箸"},"うつる":{"variants":"うつる/移る/映る/写る"},"うつれる":{"variants":"うつれる/移れる"},"移れる":{"variants":"うつれる/移れる"},"うつろ":{"variants":"うつろ/虚ろ/空ろ"},"うつろう":{"variants":"うつろう/映ろう"},"映ろう":{"variants":"うつろう/映ろう"},"うてる":{"variants":"うてる/撃てる/打てる/討てる"},"腕きき":{"variants":"腕きき/腕利き"},"腕利き":{"variants":"腕きき/腕利き"},"腕くらべ":{"variants":"腕くらべ/腕競べ/腕比べ"},"腕組":{"variants":"腕組/腕組み"},"腕組み":{"variants":"腕組/腕組み"},"腕ずもう":{"variants":"腕ずもう/腕相撲"},"腕相撲":{"variants":"腕ずもう/腕相撲"},"腕っぷし":{"variants":"腕っぷし/腕っ節/腕節"},"腕っ節":{"variants":"腕っぷし/腕っ節/腕節"},"腕節":{"variants":"腕っぷし/腕っ節/腕節"},"腕まくり":{"variants":"腕まくり/腕捲くり"},"腕捲くり":{"variants":"腕まくり/腕捲くり"},"うとい":{"variants":"うとい/疎い"},"疎い":{"variants":"うとい/疎い"},"ウトウ":{"variants":"ウトウ/右党/善知鳥"},"うとうと":{"variants":"うとうと/ウトウト"},"ウトウト":{"variants":"うとうと/ウトウト"},"うとうとしい":{"variants":"うとうとしい/疎々しい/疎疎しい"},"疎々しい":{"variants":"うとうとしい/疎々しい/疎疎しい"},"疎疎しい":{"variants":"うとうとしい/疎々しい/疎疎しい"},"うとましい":{"variants":"うとましい/疎ましい"},"疎ましい":{"variants":"うとましい/疎ましい"},"うとむ":{"variants":"うとむ/疎む"},"疎む":{"variants":"うとむ/疎む"},"うとんずる":{"variants":"うとんずる/疎んずる"},"疎んずる":{"variants":"うとんずる/疎んずる"},"ウド":{"variants":"ウド/独活"},"独活":{"variants":"ウド/独活"},"うどん":{"variants":"うどん/ウドン/饂飩"},"ウドン":{"variants":"うどん/ウドン/饂飩"},"饂飩":{"variants":"うどん/ウドン/饂飩"},"ウドンゲ":{"variants":"ウドンゲ/優曇華"},"優曇華":{"variants":"ウドンゲ/優曇華"},"うどん粉":{"variants":"うどん粉/饂飩粉"},"饂飩粉":{"variants":"うどん粉/饂飩粉"},"うながす":{"variants":"うながす/促す"},"促す":{"variants":"うながす/促す"},"うなぎ":{"variants":"うなぎ/ウナギ/鰻"},"ウナギ":{"variants":"うなぎ/ウナギ/鰻"},"鰻":{"variants":"うなぎ/ウナギ/鰻"},"ウナギ登り":{"variants":"ウナギ登り/鰻登り"},"鰻登り":{"variants":"ウナギ登り/鰻登り"},"うなされる":{"variants":"うなされる/魘される"},"魘される":{"variants":"うなされる/魘される"},"うな重":{"variants":"うな重/鰻重"},"鰻重":{"variants":"うな重/鰻重"},"うなずく":{"variants":"うなずく/肯く/首肯く/点頭く/頷く"},"うなだれる":{"variants":"うなだれる/項垂れる"},"項垂れる":{"variants":"うなだれる/項垂れる"},"うなづける":{"variants":"うなづける/頷ける"},"頷ける":{"variants":"うなづける/頷ける"},"うなる":{"variants":"うなる/唸る"},"唸る":{"variants":"うなる/唸る"},"ウニ":{"variants":"ウニ/雲丹/海胆"},"うぬぼれる":{"variants":"うぬぼれる/己惚れる/自惚れる"},"うの花":{"variants":"うの花/ウノハナ/卯の花/卯花"},"ウノハナ":{"variants":"うの花/ウノハナ/卯の花/卯花"},"卯の花":{"variants":"うの花/ウノハナ/卯の花/卯花"},"卯花":{"variants":"うの花/ウノハナ/卯の花/卯花"},"うのみ":{"variants":"うのみ/鵜呑み"},"鵜呑み":{"variants":"うのみ/鵜呑み"},"うばいあう":{"variants":"うばいあう/奪い合う"},"奪い合う":{"variants":"うばいあう/奪い合う"},"うばいあえる":{"variants":"うばいあえる/奪い合える"},"奪い合える":{"variants":"うばいあえる/奪い合える"},"うばいかえす":{"variants":"うばいかえす/奪い返す"},"奪い返す":{"variants":"うばいかえす/奪い返す"},"うばいとる":{"variants":"うばいとる/奪い取る"},"奪い取る":{"variants":"うばいとる/奪い取る"},"うばいとれる":{"variants":"うばいとれる/奪い取れる"},"奪い取れる":{"variants":"うばいとれる/奪い取れる"},"うばう":{"variants":"うばう/奪う"},"奪う":{"variants":"うばう/奪う"},"うばえる":{"variants":"うばえる/奪える"},"奪える":{"variants":"うばえる/奪える"},"ウバガイ":{"variants":"ウバガイ/姥貝"},"姥貝":{"variants":"ウバガイ/姥貝"},"うば桜":{"variants":"うば桜/ウバザクラ/姥桜"},"ウバザクラ":{"variants":"うば桜/ウバザクラ/姥桜"},"姥桜":{"variants":"うば桜/ウバザクラ/姥桜"},"うぶ":{"variants":"うぶ/初/初心"},"初":{"variants":"うぶ/初/初心"},"初心":{"variants":"うぶ/初/初心"},"うぶ声":{"variants":"うぶ声/産声"},"産声":{"variants":"うぶ声/産声"},"うべなう":{"variants":"うべなう/諾う"},"諾う":{"variants":"うべなう/諾う"},"うま":{"variants":"うま/ウマ/午/馬"},"ウマ":{"variants":"うま/ウマ/午/馬"},"うまい":{"variants":"うまい/旨い/上手い/美味い"},"ウマオイ":{"variants":"ウマオイ/馬追"},"馬追":{"variants":"ウマオイ/馬追"},"ウマオイムシ":{"variants":"ウマオイムシ/馬追虫"},"馬追虫":{"variants":"ウマオイムシ/馬追虫"},"ウマゴヤシ":{"variants":"ウマゴヤシ/苜蓿"},"苜蓿":{"variants":"ウマゴヤシ/苜蓿"},"馬跳び":{"variants":"馬跳/馬跳び"},"馬跳":{"variants":"馬跳/馬跳び"},"うま煮":{"variants":"うま煮/甘煮/旨煮"},"馬のほね":{"variants":"馬のほね/馬の骨"},"馬の骨":{"variants":"馬のほね/馬の骨"},"ウマバエ":{"variants":"ウマバエ/馬蝿"},"馬蝿":{"variants":"ウマバエ/馬蝿"},"うまみ":{"variants":"うまみ/うま味/旨み/旨味"},"うま味":{"variants":"うまみ/うま味/旨み/旨味"},"旨み":{"variants":"うまみ/うま味/旨み/旨味"},"旨味":{"variants":"うまみ/うま味/旨み/旨味"},"うまる":{"variants":"うまる/埋る"},"埋る":{"variants":"うまる/埋る"},"生まれ":{"variants":"生まれ/生れ"},"生れ":{"variants":"生まれ/生れ"},"うまれあわす":{"variants":"うまれあわす/生まれ合わす"},"生まれ合わす":{"variants":"うまれあわす/生まれ合わす"},"うまれおちる":{"variants":"うまれおちる/生まれ落ちる/生れおちる/生れ落ちる"},"生まれ落ちる":{"variants":"うまれおちる/生まれ落ちる/生れおちる/生れ落ちる"},"生れおちる":{"variants":"うまれおちる/生まれ落ちる/生れおちる/生れ落ちる"},"生れ落ちる":{"variants":"うまれおちる/生まれ落ちる/生れおちる/生れ落ちる"},"うまれかわる":{"variants":"うまれかわる/生まれ変わる/生れかわる/生れ変る"},"生まれ変わる":{"variants":"うまれかわる/生まれ変わる/生れかわる/生れ変る"},"生れかわる":{"variants":"うまれかわる/生まれ変わる/生れかわる/生れ変る"},"生れ変る":{"variants":"うまれかわる/生まれ変わる/生れかわる/生れ変る"},"うまれかわれる":{"variants":"うまれかわれる/生まれ変われる"},"生まれ変われる":{"variants":"うまれかわれる/生まれ変われる"},"生まれつき":{"variants":"生まれつき/生れつき"},"生れつき":{"variants":"生まれつき/生れつき"},"うまれつく":{"variants":"うまれつく/生まれつく"},"生まれつく":{"variants":"うまれつく/生まれつく"},"うまれでる":{"variants":"うまれでる/生まれでる"},"生まれでる":{"variants":"うまれでる/生まれでる"},"うまれる":{"variants":"うまれる/産まれる/生まれる/生れる"},"生まれる":{"variants":"うまれる/生まれる/生れる"},"生れる":{"variants":"うまれる/生まれる/生れる"},"ウミウシ":{"variants":"ウミウシ/海牛"},"海牛":{"variants":"ウミウシ/海牛"},"うみおとす":{"variants":"うみおとす/産みおとす/産み落す/産み落とす/生み落す"},"産み落す":{"variants":"うみおとす/産みおとす/産み落す/産み落とす"},"産み落とす":{"variants":"うみおとす/産みおとす/産み落す/産み落とす"},"産みおとす":{"variants":"うみおとす/産みおとす/産み落す/産み落とす"},"うみおとせる":{"variants":"うみおとせる/産み落とせる"},"産み落とせる":{"variants":"うみおとせる/産み落とせる"},"ウミガメ":{"variants":"ウミガメ/海ガメ/海龜"},"海ガメ":{"variants":"ウミガメ/海ガメ/海龜"},"海龜":{"variants":"ウミガメ/海ガメ/海龜"},"うみだす":{"variants":"うみだす/生みだす/生み出す"},"生みだす":{"variants":"うみだす/生みだす/生み出す"},"生み出す":{"variants":"うみだす/生みだす/生み出す"},"うみだせる":{"variants":"うみだせる/生み出せる"},"生み出せる":{"variants":"うみだせる/生み出せる"},"うみつける":{"variants":"うみつける/産みつける/産み付ける/生みつける/生み付ける"},"産み付ける":{"variants":"うみつける/産みつける/産み付ける"},"産みつける":{"variants":"うみつける/産みつける/産み付ける"},"生み付ける":{"variants":"うみつける/生みつける/生み付ける"},"生みつける":{"variants":"うみつける/生みつける/生み付ける"},"ウミツバメ":{"variants":"ウミツバメ/海燕"},"海燕":{"variants":"ウミツバメ/海燕"},"ウミネコ":{"variants":"ウミネコ/海猫"},"海猫":{"variants":"ウミネコ/海猫"},"ウミヘビ":{"variants":"ウミヘビ/海蛇"},"海蛇":{"variants":"ウミヘビ/海蛇"},"ウミホオズキ":{"variants":"ウミホオズキ/海酸漿"},"海酸漿":{"variants":"ウミホオズキ/海酸漿"},"ウミボウズ":{"variants":"ウミボウズ/海坊主"},"海坊主":{"variants":"ウミボウズ/海坊主"},"うむ":{"variants":"うむ/産む/熟む/生む/績む/膿む"},"ウメ":{"variants":"ウメ/梅"},"梅":{"variants":"ウメ/梅"},"うめあわす":{"variants":"うめあわす/埋めあわす/埋め合す/埋め合わす"},"埋めあわす":{"variants":"うめあわす/埋めあわす/埋め合す/埋め合わす"},"埋め合す":{"variants":"うめあわす/埋めあわす/埋め合す/埋め合わす"},"埋め合わす":{"variants":"うめあわす/埋めあわす/埋め合す/埋め合わす"},"埋め合せ":{"variants":"埋め合せ/埋め合わせ"},"埋め合わせ":{"variants":"埋め合せ/埋め合わせ"},"うめあわせる":{"variants":"うめあわせる/埋めあわせる/埋め合せる/埋め合わせる"},"埋めあわせる":{"variants":"うめあわせる/埋めあわせる/埋め合せる/埋め合わせる"},"埋め合せる":{"variants":"うめあわせる/埋めあわせる/埋め合せる/埋め合わせる"},"埋め合わせる":{"variants":"うめあわせる/埋めあわせる/埋め合せる/埋め合わせる"},"うめく":{"variants":"うめく/呻く"},"呻く":{"variants":"うめく/呻く"},"埋めこみ":{"variants":"埋めこみ/埋込み"},"埋込み":{"variants":"埋めこみ/埋込み"},"うめこむ":{"variants":"うめこむ/埋め込む"},"埋め込む":{"variants":"うめこむ/埋め込む"},"うめこめる":{"variants":"うめこめる/埋め込める"},"埋め込める":{"variants":"うめこめる/埋め込める"},"埋め立て":{"variants":"埋め立て/埋立"},"埋立":{"variants":"埋め立て/埋立"},"うめたてる":{"variants":"うめたてる/埋めたてる/埋め立てる"},"埋めたてる":{"variants":"うめたてる/埋めたてる/埋め立てる"},"埋め立てる":{"variants":"うめたてる/埋めたてる/埋め立てる"},"梅漬":{"variants":"梅漬/梅漬け"},"梅漬け":{"variants":"梅漬/梅漬け"},"梅ぼし":{"variants":"梅ぼし/梅干/梅干し"},"梅干":{"variants":"梅ぼし/梅干/梅干し"},"梅干し":{"variants":"梅ぼし/梅干/梅干し"},"ウメモドキ":{"variants":"ウメモドキ/梅擬き"},"梅擬き":{"variants":"ウメモドキ/梅擬き"},"うめる":{"variants":"うめる/産める/生める"},"うもれる":{"variants":"うもれる/埋れる"},"埋れる":{"variants":"うもれる/埋れる"},"うやうやしい":{"variants":"うやうやしい/恭しい"},"恭しい":{"variants":"うやうやしい/恭しい"},"うやまう":{"variants":"うやまう/敬う"},"敬う":{"variants":"うやまう/敬う"},"うやまえる":{"variants":"うやまえる/敬える"},"敬える":{"variants":"うやまえる/敬える"},"う余曲折":{"variants":"う余曲折/紆余曲折"},"紆余曲折":{"variants":"う余曲折/紆余曲折"},"うらがえす":{"variants":"うらがえす/裏返す"},"裏返す":{"variants":"うらがえす/裏返す"},"うらがえせる":{"variants":"うらがえせる/裏返せる"},"裏返せる":{"variants":"うらがえせる/裏返せる"},"うらがえる":{"variants":"うらがえる/裏返る"},"裏返る":{"variants":"うらがえる/裏返る"},"うらがなしい":{"variants":"うらがなしい/うら悲しい"},"うら悲しい":{"variants":"うらがなしい/うら悲しい"},"うらがれる":{"variants":"うらがれる/うら枯れる"},"うら枯れる":{"variants":"うらがれる/うら枯れる"},"うらぎる":{"variants":"うらぎる/裏切る"},"裏切る":{"variants":"うらぎる/裏切る"},"うらぎれる":{"variants":"うらぎれる/裏切れる"},"裏切れる":{"variants":"うらぎれる/裏切れる"},"うら口":{"variants":"うら口/裏口"},"裏口":{"variants":"うら口/裏口"},"裏ごし":{"variants":"裏ごし/裏漉し"},"裏漉し":{"variants":"裏ごし/裏漉し"},"うらさびしい":{"variants":"うらさびしい/うら寂しい/うら淋しい"},"ウラジロ":{"variants":"ウラジロ/裏白"},"裏白":{"variants":"ウラジロ/裏白"},"裏づけ":{"variants":"裏づけ/裏付け"},"裏付け":{"variants":"裏づけ/裏付け"},"うらづける":{"variants":"うらづける/裏づける/裏付ける"},"裏づける":{"variants":"うらづける/裏づける/裏付ける"},"裏付ける":{"variants":"うらづける/裏づける/裏付ける"},"占い":{"variants":"占/占い"},"占":{"variants":"占/占い"},"占い師":{"variants":"占い師/占師"},"占師":{"variants":"占い師/占師"},"うらなう":{"variants":"うらなう/占う"},"占う":{"variants":"うらなう/占う"},"うらなえる":{"variants":"うらなえる/占える"},"占える":{"variants":"うらなえる/占える"},"うらはずかしい":{"variants":"うらはずかしい/うら恥しい"},"うら恥しい":{"variants":"うらはずかしい/うら恥しい"},"うらはら":{"variants":"うらはら/裏腹"},"裏腹":{"variants":"うらはら/裏腹"},"うら盆":{"variants":"うら盆/盂蘭盆"},"盂蘭盆":{"variants":"うら盆/盂蘭盆"},"うらみ":{"variants":"うらみ/怨み/憾み/恨み"},"恨みごと":{"variants":"恨みごと/恨み言"},"怨み言":{"variants":"怨みごと/怨み言"},"恨み言":{"variants":"恨みごと/恨み言"},"怨みごと":{"variants":"怨みごと/怨み言"},"恨み辛み":{"variants":"恨みつらみ/恨み辛み"},"恨みつらみ":{"variants":"恨みつらみ/恨み辛み"},"うらむ":{"variants":"うらむ/怨む/憾む/恨む"},"うらめしい":{"variants":"うらめしい/怨めしい/恨めしい"},"うらやましい":{"variants":"うらやましい/羨ましい"},"羨ましい":{"variants":"うらやましい/羨ましい"},"うらやむ":{"variants":"うらやむ/羨む"},"羨む":{"variants":"うらやむ/羨む"},"うらわかい":{"variants":"うらわかい/うら若い"},"うら若い":{"variants":"うらわかい/うら若い"},"ウリ":{"variants":"ウリ/瓜"},"瓜":{"variants":"ウリ/瓜"},"売":{"variants":"売/売り"},"売り":{"variants":"売/売り"},"売り上げ":{"variants":"売り上げ/売上/売上げ"},"売上":{"variants":"売り上げ/売上/売上げ"},"売上げ":{"variants":"売り上げ/売上/売上げ"},"うりあげる":{"variants":"うりあげる/売り上げる"},"売り上げる":{"variants":"うりあげる/売り上げる"},"うりいそぐ":{"variants":"うりいそぐ/売り急ぐ/売急ぐ"},"売り急ぐ":{"variants":"うりいそぐ/売り急ぐ/売急ぐ"},"売急ぐ":{"variants":"うりいそぐ/売り急ぐ/売急ぐ"},"売り掛け":{"variants":"売り掛け/売掛け"},"売掛け":{"variants":"売り掛け/売掛け"},"うりきれる":{"variants":"うりきれる/売りきれる/売り切れる/売切れる"},"売りきれる":{"variants":"うりきれる/売りきれる/売り切れる/売切れる"},"売り切れる":{"variants":"うりきれる/売りきれる/売り切れる/売切れる"},"売切れる":{"variants":"うりきれる/売りきれる/売り切れる/売切れる"},"売り口":{"variants":"売り口/売口"},"売口":{"variants":"売り口/売口"},"売り子":{"variants":"売り子/売子"},"売子":{"variants":"売り子/売子"},"売り言葉":{"variants":"売り言葉/売言葉"},"売言葉":{"variants":"売り言葉/売言葉"},"うりこむ":{"variants":"うりこむ/売りこむ/売り込む/売込む"},"売りこむ":{"variants":"うりこむ/売りこむ/売り込む/売込む"},"売り込む":{"variants":"うりこむ/売りこむ/売り込む/売込む"},"売込む":{"variants":"うりこむ/売りこむ/売り込む/売込む"},"うりこめる":{"variants":"うりこめる/売り込める"},"売り込める":{"variants":"うりこめる/売り込める"},"売り声":{"variants":"売り声/売声"},"売声":{"variants":"売り声/売声"},"うりさばく":{"variants":"うりさばく/売りさばく/売り捌く"},"売りさばく":{"variants":"うりさばく/売りさばく/売り捌く"},"売り捌く":{"variants":"うりさばく/売りさばく/売り捌く"},"うりさばける":{"variants":"うりさばける/売りさばける"},"売りさばける":{"variants":"うりさばける/売りさばける"},"うりざね顔":{"variants":"うりざね顔/瓜実顔"},"瓜実顔":{"variants":"うりざね顔/瓜実顔"},"売り出し":{"variants":"売り出し/売出/売出し"},"売出":{"variants":"売り出し/売出/売出し"},"売出し":{"variants":"売り出し/売出/売出し"},"うりだす":{"variants":"うりだす/売り出す"},"売り出す":{"variants":"うりだす/売り出す"},"うりだせる":{"variants":"うりだせる/売り出せる"},"売り出せる":{"variants":"うりだせる/売り出せる"},"うりつくす":{"variants":"うりつくす/売りつくす"},"売りつくす":{"variants":"うりつくす/売りつくす"},"うりつける":{"variants":"うりつける/売りつける/売り付ける/売付ける"},"売りつける":{"variants":"うりつける/売りつける/売り付ける/売付ける"},"売り付ける":{"variants":"うりつける/売りつける/売り付ける/売付ける"},"売付ける":{"variants":"うりつける/売りつける/売り付ける/売付ける"},"売り手":{"variants":"売り手/売手"},"売手":{"variants":"売り手/売手"},"うりとばす":{"variants":"うりとばす/売りとばす/売り飛ばす/売飛ばす"},"売りとばす":{"variants":"うりとばす/売りとばす/売り飛ばす/売飛ばす"},"売り飛ばす":{"variants":"うりとばす/売りとばす/売り飛ばす/売飛ばす"},"売飛ばす":{"variants":"うりとばす/売りとばす/売り飛ばす/売飛ばす"},"うりとばせる":{"variants":"うりとばせる/売り飛ばせる"},"売り飛ばせる":{"variants":"うりとばせる/売り飛ばせる"},"うりなやむ":{"variants":"うりなやむ/売り悩む"},"売り悩む":{"variants":"うりなやむ/売り悩む"},"売り主":{"variants":"売り主/売主"},"売主":{"variants":"売り主/売主"},"売り値":{"variants":"売り値/売値"},"売値":{"variants":"売り値/売値"},"うりはらう":{"variants":"うりはらう/売りはらう/売り払う/売払う"},"売りはらう":{"variants":"うりはらう/売りはらう/売り払う/売払う"},"売り払う":{"variants":"うりはらう/売りはらう/売り払う/売払う"},"売払う":{"variants":"うりはらう/売りはらう/売り払う/売払う"},"うりはらえる":{"variants":"うりはらえる/売り払える"},"売り払える":{"variants":"うりはらえる/売り払える"},"売り場":{"variants":"売り場/売場"},"売場":{"variants":"売り場/売場"},"うり二つ":{"variants":"うり二つ/ウリ二つ"},"ウリ二つ":{"variants":"うり二つ/ウリ二つ"},"うりまくる":{"variants":"うりまくる/売りまくる"},"売りまくる":{"variants":"うりまくる/売りまくる"},"うりまくれる":{"variants":"うりまくれる/売りまくれる"},"売りまくれる":{"variants":"うりまくれる/売りまくれる"},"うりわたす":{"variants":"うりわたす/売り渡す"},"売り渡す":{"variants":"うりわたす/売り渡す"},"うる":{"variants":"うる/得る"},"得る":{"variants":"える/得る"},"うるう":{"variants":"うるう/閏"},"閏":{"variants":"うるう/閏"},"うるう年":{"variants":"うるう年/閏年"},"閏年":{"variants":"うるう年/閏年"},"うるおう":{"variants":"うるおう/潤う"},"潤う":{"variants":"うるおう/潤う"},"うるおす":{"variants":"うるおす/潤す"},"潤す":{"variants":"うるおす/潤す"},"うるさい":{"variants":"うるさい/五月蝿い/煩い"},"ウルシ":{"variants":"ウルシ/漆"},"漆":{"variants":"ウルシ/漆"},"うるち米":{"variants":"うるち米/粳米"},"粳米":{"variants":"うるち米/粳米"},"うるむ":{"variants":"うるむ/潤む"},"潤む":{"variants":"うるむ/潤む"},"うるわしい":{"variants":"うるわしい/麗しい"},"麗しい":{"variants":"うるわしい/麗しい"},"うれえる":{"variants":"うれえる/愁える/憂える"},"うれしい":{"variants":"うれしい/嬉しい"},"嬉しい":{"variants":"うれしい/嬉しい"},"うれし泣き":{"variants":"うれし泣き/嬉泣き"},"嬉泣き":{"variants":"うれし泣き/嬉泣き"},"嬉しなみだ":{"variants":"嬉しなみだ/嬉し涙/嬉涙"},"嬉し涙":{"variants":"嬉しなみだ/嬉し涙/嬉涙"},"嬉涙":{"variants":"嬉しなみだ/嬉し涙/嬉涙"},"売れっこ":{"variants":"売れっこ/売れっ子"},"売れっ子":{"variants":"売れっこ/売れっ子"},"売れのこり":{"variants":"売れのこり/売れ残り/売残り"},"売れ残り":{"variants":"売れのこり/売れ残り/売残り"},"売残り":{"variants":"売れのこり/売れ残り/売残り"},"うれのこる":{"variants":"うれのこる/売れ残る"},"売れ残る":{"variants":"うれのこる/売れ残る"},"売れ行き":{"variants":"売れ行き/売行き"},"売行き":{"variants":"売れ行き/売行き"},"うれる":{"variants":"うれる/売れる/賣れる"},"うろうろ":{"variants":"うろうろ/ウロウロ"},"ウロウロ":{"variants":"うろうろ/ウロウロ"},"うろこ":{"variants":"うろこ/鱗"},"鱗":{"variants":"うろこ/鱗"},"うろたえる":{"variants":"うろたえる/狼狽える"},"狼狽える":{"variants":"うろたえる/狼狽える"},"うろつく":{"variants":"うろつく/彷徨く"},"彷徨く":{"variants":"うろつく/彷徨く"},"うろぬく":{"variants":"うろぬく/うろ抜く"},"うろ抜く":{"variants":"うろぬく/うろ抜く"},"うわ薬":{"variants":"うわ薬/上薬/釉薬"},"うわ言":{"variants":"うわ言/囈言/譫言"},"うわさ":{"variants":"うわさ/ウワサ/噂"},"ウワサ":{"variants":"うわさ/ウワサ/噂"},"噂":{"variants":"うわさ/ウワサ/噂"},"上敷":{"variants":"上敷/上敷き"},"上敷き":{"variants":"上敷/上敷き"},"うわずる":{"variants":"うわずる/上ずる/上擦る"},"上ずる":{"variants":"うわずる/上ずる/上擦る"},"上擦る":{"variants":"うわずる/上ずる/上擦る"},"上っつら":{"variants":"上っつら/上っ面"},"上っ面":{"variants":"上っつら/上っ面"},"うわっ張り":{"variants":"うわっ張り/上っぱり/上っ張り"},"上っぱり":{"variants":"うわっ張り/上っぱり/上っ張り"},"上っ張り":{"variants":"うわっ張り/上っぱり/上っ張り"},"うわつく":{"variants":"うわつく/浮つく"},"浮つく":{"variants":"うわつく/浮つく"},"うわの空":{"variants":"うわの空/上の空"},"上の空":{"variants":"うわの空/上の空"},"上履":{"variants":"上履/上履き"},"上履き":{"variants":"上履/上履き"},"うわべ":{"variants":"うわべ/上辺"},"上辺":{"variants":"うわべ/上辺"},"うわまわる":{"variants":"うわまわる/上回る/上廻る"},"うわむく":{"variants":"うわむく/上向く"},"上向く":{"variants":"うわむく/上向く"},"うわむける":{"variants":"うわむける/上向ける"},"上向ける":{"variants":"うわむける/上向ける"},"うわる":{"variants":"うわる/植わる"},"植わる":{"variants":"うわる/植わる"},"うん":{"variants":"うん/ウン"},"ウン":{"variants":"うん/ウン"},"ウンカ":{"variants":"ウンカ/雲霞/浮塵子"},"うん気":{"variants":"うん気/運気/雲気/温気"},"うんちく":{"variants":"うんちく/蘊蓄"},"蘊蓄":{"variants":"うんちく/蘊蓄"},"うんぬん":{"variants":"うんぬん/云々/云云"},"云々":{"variants":"云々/云云"},"云云":{"variants":"云々/云云"},"えーっ":{"variants":"えーっ/えーッ"},"えーッ":{"variants":"えーっ/えーッ"},"絵合せ":{"variants":"絵合せ/絵合わせ"},"絵合わせ":{"variants":"絵合せ/絵合わせ"},"エイ":{"variants":"エイ/英/酔ひ/纓"},"えいい":{"variants":"えいい/鋭意"},"鋭意":{"variants":"えいい/鋭意"},"営々":{"variants":"営々/営営"},"営営":{"variants":"営々/営営"},"えい航":{"variants":"えい航/曳航"},"曳航":{"variants":"えい航/曳航"},"えい光弾":{"variants":"えい光弾/曳光弾"},"曳光弾":{"variants":"えい光弾/曳光弾"},"永ごう":{"variants":"永ごう/永劫"},"永劫":{"variants":"永ごう/永劫"},"えいじる":{"variants":"えいじる/映じる/詠じる"},"えいずる":{"variants":"えいずる/映ずる/詠ずる"},"エイト":{"variants":"エイト/英図"},"英図":{"variants":"エイト/英図"},"絵かき":{"variants":"絵かき/絵描き"},"絵描き":{"variants":"絵かき/絵描き"},"えがお":{"variants":"えがお/笑顔"},"笑顔":{"variants":"えがお/笑顔"},"えがきだす":{"variants":"えがきだす/描きだす/描き出す"},"描きだす":{"variants":"えがきだす/描きだす/描き出す"},"描き出す":{"variants":"えがきだす/描きだす/描き出す"},"えがきだせる":{"variants":"えがきだせる/描き出せる"},"描き出せる":{"variants":"えがきだせる/描き出せる"},"えがく":{"variants":"えがく/画く"},"画く":{"variants":"えがく/画く"},"えがける":{"variants":"えがける/描ける"},"描ける":{"variants":"えがける/描ける"},"えがたい":{"variants":"えがたい/得難い"},"得難い":{"variants":"えがたい/得難い"},"えきする":{"variants":"えきする/益する/役する"},"エキチョウ":{"variants":"エキチョウ/益鳥/駅長"},"エクボ":{"variants":"エクボ/笑窪/靨"},"エゴノリ":{"variants":"エゴノリ/恵胡海苔"},"恵胡海苔":{"variants":"エゴノリ/恵胡海苔"},"エゴマ":{"variants":"エゴマ/荏胡麻"},"荏胡麻":{"variants":"エゴマ/荏胡麻"},"えさ":{"variants":"えさ/エサ/餌"},"エサ":{"variants":"えさ/エサ/餌"},"餌":{"variants":"えさ/エサ/餌"},"絵さがし":{"variants":"絵さがし/絵捜し/絵探し"},"えじき":{"variants":"えじき/餌食"},"餌食":{"variants":"えじき/餌食"},"ＳＦ":{"variants":"ＳＦ/エスエフ"},"エスエフ":{"variants":"ＳＦ/エスエフ"},"ＳＯＳ":{"variants":"ＳＯＳ/エスオーエス"},"エスオーエス":{"variants":"ＳＯＳ/エスオーエス"},"絵空ごと":{"variants":"絵空ごと/絵空事"},"絵空事":{"variants":"絵空ごと/絵空事"},"エゾギク":{"variants":"エゾギク/蝦夷菊"},"蝦夷菊":{"variants":"エゾギク/蝦夷菊"},"エゾマツ":{"variants":"エゾマツ/エゾ松/蝦夷松"},"エゾ松":{"variants":"エゾマツ/エゾ松/蝦夷松"},"蝦夷松":{"variants":"エゾマツ/エゾ松/蝦夷松"},"えたい":{"variants":"えたい/得体"},"得体":{"variants":"えたい/得体"},"えっ":{"variants":"えっ/えッ/エッ"},"えッ":{"variants":"えっ/えッ/エッ"},"エッ":{"variants":"えっ/えッ/エッ"},"Ｘ線":{"variants":"Ｘ線/エックス線"},"エックス線":{"variants":"Ｘ線/エックス線"},"越中ふんどし":{"variants":"越中ふんどし/越中褌"},"越中褌":{"variants":"越中ふんどし/越中褌"},"えつにいる":{"variants":"えつにいる/悦に入る"},"悦に入る":{"variants":"えつにいる/悦に入る"},"えづく":{"variants":"えづく/餌付く"},"餌付く":{"variants":"えづく/餌付く"},"えて":{"variants":"えて/得て"},"得て":{"variants":"えて/得て"},"えてして":{"variants":"えてして/得てして"},"得てして":{"variants":"えてして/得てして"},"江戸詰":{"variants":"江戸詰/江戸詰め"},"江戸詰め":{"variants":"江戸詰/江戸詰め"},"えどる":{"variants":"えどる/絵取る"},"絵取る":{"variants":"えどる/絵取る"},"エニシダ":{"variants":"エニシダ/金雀児"},"金雀児":{"variants":"エニシダ/金雀児"},"ＮＧ":{"variants":"ＮＧ/エヌジー"},"エヌジー":{"variants":"ＮＧ/エヌジー"},"エノキ":{"variants":"エノキ/榎"},"榎":{"variants":"エノキ/榎"},"絵の具":{"variants":"絵の具/絵具"},"絵具":{"variants":"絵の具/絵具"},"エノコログサ":{"variants":"エノコログサ/狗尾草"},"狗尾草":{"variants":"エノコログサ/狗尾草"},"絵はがき":{"variants":"絵はがき/絵葉書"},"絵葉書":{"variants":"絵はがき/絵葉書"},"エビ":{"variants":"エビ/蝦/海老/鰕"},"エビガニ":{"variants":"エビガニ/蝦蟹"},"蝦蟹":{"variants":"エビガニ/蝦蟹"},"えびす顔":{"variants":"えびす顔/恵比寿顔/恵比須顔"},"えびす講":{"variants":"えびす講/恵比寿講/恵比須講"},"えび茶":{"variants":"えび茶/海老茶/葡萄茶"},"エビネ":{"variants":"エビネ/蝦根/海老根"},"えみわれる":{"variants":"えみわれる/笑み割れる/笑割れる"},"笑み割れる":{"variants":"えみわれる/笑み割れる/笑割れる"},"笑割れる":{"variants":"えみわれる/笑み割れる/笑割れる"},"えむ":{"variants":"えむ/笑む"},"笑む":{"variants":"えむ/笑む"},"エラ":{"variants":"エラ/鰓"},"鰓":{"variants":"エラ/鰓"},"えらい":{"variants":"えらい/エラい/偉い/豪い"},"エラい":{"variants":"えらい/エラい/偉い/豪い"},"えらびだす":{"variants":"えらびだす/選びだす/選び出す"},"選びだす":{"variants":"えらびだす/選びだす/選び出す"},"選び出す":{"variants":"えらびだす/選びだす/選び出す"},"えらびだせる":{"variants":"えらびだせる/選び出せる"},"選び出せる":{"variants":"えらびだせる/選び出せる"},"選びとれる":{"variants":"選びとれる/選び取れる"},"選び取れる":{"variants":"選びとれる/選び取れる"},"えらぶ":{"variants":"えらぶ/撰ぶ/選ぶ/択ぶ"},"えらべる":{"variants":"えらべる/撰べる/選べる"},"えり":{"variants":"えり/エリ/衿/襟"},"エリ":{"variants":"えり/エリ/衿/襟"},"えり足":{"variants":"えり足/襟足"},"襟足":{"variants":"えり足/襟足"},"選りぎらい":{"variants":"選りぎらい/選り嫌い"},"選り嫌い":{"variants":"選りぎらい/選り嫌い"},"襟ぐり":{"variants":"襟ぐり/襟刳/襟刳り"},"襟刳":{"variants":"襟ぐり/襟刳/襟刳り"},"襟刳り":{"variants":"襟ぐり/襟刳/襟刳り"},"えりすぐる":{"variants":"えりすぐる/選りすぐる"},"選りすぐる":{"variants":"えりすぐる/選りすぐる"},"えり抜き":{"variants":"えり抜き/選り抜き"},"選り抜き":{"variants":"えり抜き/選り抜き"},"えりぬく":{"variants":"えりぬく/えり抜く/選り抜く"},"えり抜く":{"variants":"えりぬく/えり抜く/選り抜く"},"選り抜く":{"variants":"えりぬく/えり抜く/選り抜く"},"襟まき":{"variants":"襟まき/襟巻"},"襟巻":{"variants":"襟まき/襟巻"},"えりわける":{"variants":"えりわける/えり分ける/選りわける/選り分ける"},"えり分ける":{"variants":"えりわける/えり分ける/選りわける/選り分ける"},"選りわける":{"variants":"えりわける/えり分ける/選りわける/選り分ける"},"選り分ける":{"variants":"えりわける/えり分ける/選りわける/選り分ける"},"える":{"variants":"える/得る"},"えん":{"variants":"えん/円/園"},"えんえん":{"variants":"えんえん/延々/延延"},"延々":{"variants":"延々/延延"},"延延":{"variants":"延々/延延"},"蜿蜿":{"variants":"蜿々/蜿蜿"},"蜿々":{"variants":"蜿々/蜿蜿"},"炎々":{"variants":"炎々/炎炎"},"蜒々":{"variants":"蜒々/蜒蜒"},"炎炎":{"variants":"炎々/炎炎"},"奄奄":{"variants":"奄々/奄奄"},"蜒蜒":{"variants":"蜒々/蜒蜒"},"奄々":{"variants":"奄々/奄奄"},"えん曲":{"variants":"えん曲/婉曲"},"宴曲":{"variants":"えん曲/宴曲"},"婉曲":{"variants":"えん曲/婉曲"},"縁起もの":{"variants":"縁起もの/縁起物"},"縁起物":{"variants":"縁起もの/縁起物"},"縁組":{"variants":"縁組/縁組み"},"縁組み":{"variants":"縁組/縁組み"},"えん恨":{"variants":"えん恨/怨恨"},"怨恨":{"variants":"えん恨/怨恨"},"えん罪":{"variants":"えん罪/冤罪"},"冤罪":{"variants":"えん罪/冤罪"},"エンジュ":{"variants":"エンジュ/槐"},"槐":{"variants":"エンジュ/槐"},"えんじる":{"variants":"えんじる/演じる"},"演じる":{"variants":"えんじる/演じる"},"エンジン":{"variants":"エンジン/厭人/円陣"},"円すい":{"variants":"円すい/円錐"},"円錐":{"variants":"円すい/円錐"},"えんする":{"variants":"えんする/怨する"},"怨する":{"variants":"えんする/怨する"},"えんずる":{"variants":"えんずる/演ずる"},"演ずる":{"variants":"えんずる/演ずる"},"縁石":{"variants":"縁せき/縁石"},"縁せき":{"variants":"縁せき/縁戚/縁石"},"縁戚":{"variants":"縁せき/縁戚"},"えんせん":{"variants":"えんせん/えん戦/厭戦/沿線"},"えん戦":{"variants":"えんせん/えん戦/厭戦"},"厭戦":{"variants":"えんせん/えん戦/厭戦"},"円タク":{"variants":"円タク/円卓"},"円卓":{"variants":"円タク/円卓"},"えんづく":{"variants":"えんづく/縁付く"},"縁付く":{"variants":"えんづく/縁付く"},"えんづける":{"variants":"えんづける/縁付ける"},"縁付ける":{"variants":"えんづける/縁付ける"},"円筒":{"variants":"円とう/円筒"},"円とう":{"variants":"円とう/円筒"},"えんとして":{"variants":"えんとして/宛として"},"宛として":{"variants":"えんとして/宛として"},"エンドウ":{"variants":"エンドウ/円堂/沿道/羨道/豌豆"},"えんどおい":{"variants":"えんどおい/縁遠い"},"縁遠い":{"variants":"えんどおい/縁遠い"},"えん麦":{"variants":"えん麦/エンバク/燕麦"},"エンバク":{"variants":"えん麦/エンバク/燕麦"},"燕麦":{"variants":"えん麦/エンバク/燕麦"},"えんび":{"variants":"えんび/燕尾/艷美"},"えん尾服":{"variants":"えん尾服/燕尾服"},"燕尾服":{"variants":"えん尾服/燕尾服"},"エンマコオロギ":{"variants":"エンマコオロギ/閻魔蟋蟀"},"閻魔蟋蟀":{"variants":"エンマコオロギ/閻魔蟋蟀"},"お":{"variants":"お/雄"},"御":{"variants":"お/御"},"雄":{"variants":"お/雄"},"ＯＫ":{"variants":"ＯＫ/オーケイ"},"オーケイ":{"variants":"ＯＫ/オーケイ"},"ＡＵＴＵＭＮ":{"variants":"ＡＵＴＵＭＮ/オータム"},"オータム":{"variants":"ＡＵＴＵＭＮ/オータム"},"オーム":{"variants":"オーム/Ω"},"Ω":{"variants":"オーム/Ω"},"おい":{"variants":"おい/甥/笈/老/老い"},"老":{"variants":"おい/老/老い"},"老い":{"variants":"おい/老/老い"},"おいあげる":{"variants":"おいあげる/追い上げる"},"追い上げる":{"variants":"おいあげる/追い上げる"},"お家":{"variants":"お家/御家"},"御家":{"variants":"お家/御家"},"お家芸":{"variants":"お家芸/御家芸"},"御家芸":{"variants":"お家芸/御家芸"},"おいおい":{"variants":"おいおい/追追"},"追追":{"variants":"おいおい/追追"},"おいかえす":{"variants":"おいかえす/追い返す/追返す"},"追い返す":{"variants":"おいかえす/追い返す/追返す"},"追返す":{"variants":"おいかえす/追い返す/追返す"},"おいかえせる":{"variants":"おいかえせる/追い返せる"},"追い返せる":{"variants":"おいかえせる/追い返せる"},"おいかける":{"variants":"おいかける/追いかける/追い掛ける"},"追いかける":{"variants":"おいかける/追いかける/追い掛ける"},"追い掛ける":{"variants":"おいかける/追いかける/追い掛ける"},"追い風":{"variants":"追い風/追風"},"追風":{"variants":"追い風/追風"},"おいこす":{"variants":"おいこす/追いこす/追い越す/追越す"},"追いこす":{"variants":"おいこす/追いこす/追い越す/追越す"},"追い越す":{"variants":"おいこす/追いこす/追い越す/追越す"},"追越す":{"variants":"おいこす/追いこす/追い越す/追越す"},"おいこせる":{"variants":"おいこせる/追い越せる"},"追い越せる":{"variants":"おいこせる/追い越せる"},"追い込み":{"variants":"追い込み/追込み"},"追込み":{"variants":"追い込み/追込み"},"おいこむ":{"variants":"おいこむ/追いこむ/追い込む/追込む/老い込む/老込む"},"追い込む":{"variants":"おいこむ/追いこむ/追い込む/追込む"},"追いこむ":{"variants":"おいこむ/追いこむ/追い込む/追込む"},"老込む":{"variants":"おいこむ/老い込む/老込む"},"追込む":{"variants":"おいこむ/追いこむ/追い込む/追込む"},"老い込む":{"variants":"おいこむ/老い込む/老込む"},"おいこめる":{"variants":"おいこめる/追い込める"},"追い込める":{"variants":"おいこめる/追い込める"},"老い先":{"variants":"老いさき/老い先"},"老いさき":{"variants":"老いさき/老い先"},"生い先":{"variants":"生いさき/生い先"},"生いさき":{"variants":"生いさき/生い先"},"おいさらばえる":{"variants":"おいさらばえる/老いさらばえる"},"老いさらばえる":{"variants":"おいさらばえる/老いさらばえる"},"おいしい":{"variants":"おいしい/美味しい"},"美味しい":{"variants":"おいしい/美味しい"},"おいしげる":{"variants":"おいしげる/生い茂る/生茂る"},"生い茂る":{"variants":"おいしげる/生い茂る/生茂る"},"生茂る":{"variants":"おいしげる/生い茂る/生茂る"},"おいすがる":{"variants":"おいすがる/追いすがる/追い縋る"},"追いすがる":{"variants":"おいすがる/追いすがる/追い縋る"},"追い縋る":{"variants":"おいすがる/追いすがる/追い縋る"},"おいそだつ":{"variants":"おいそだつ/生い育つ"},"生い育つ":{"variants":"おいそだつ/生い育つ"},"生いたち":{"variants":"生いたち/生い立ち/生立ち"},"生い立ち":{"variants":"生いたち/生い立ち/生立ち"},"生立ち":{"variants":"生いたち/生い立ち/生立ち"},"おいたつ":{"variants":"おいたつ/生い立つ"},"生い立つ":{"variants":"おいたつ/生い立つ"},"おいたてる":{"variants":"おいたてる/追いたてる/追い立てる"},"追いたてる":{"variants":"おいたてる/追いたてる/追い立てる"},"追い立てる":{"variants":"おいたてる/追いたてる/追い立てる"},"おいだす":{"variants":"おいだす/追い出す/追出す"},"追い出す":{"variants":"おいだす/追い出す/追出す"},"追出す":{"variants":"おいだす/追い出す/追出す"},"おいだせる":{"variants":"おいだせる/追い出せる"},"追い出せる":{"variants":"おいだせる/追い出せる"},"おいちらす":{"variants":"おいちらす/追いちらす/追い散らす"},"追いちらす":{"variants":"おいちらす/追いちらす/追い散らす"},"追い散らす":{"variants":"おいちらす/追いちらす/追い散らす"},"おいつかう":{"variants":"おいつかう/追い使う/追使う"},"追い使う":{"variants":"おいつかう/追い使う/追使う"},"追使う":{"variants":"おいつかう/追い使う/追使う"},"おいつく":{"variants":"おいつく/追いつく/追い付く/追付く"},"追いつく":{"variants":"おいつく/追いつく/追い付く/追付く"},"追い付く":{"variants":"おいつく/追いつく/追い付く/追付く"},"追付く":{"variants":"おいつく/追いつく/追い付く/追付く"},"おいつける":{"variants":"おいつける/追いつける/追い付ける"},"追いつける":{"variants":"おいつける/追いつける/追い付ける"},"追い付ける":{"variants":"おいつける/追いつける/追い付ける"},"おいつめる":{"variants":"おいつめる/追いつめる/追い詰める/追詰める"},"追いつめる":{"variants":"おいつめる/追いつめる/追い詰める/追詰める"},"追い詰める":{"variants":"おいつめる/追いつめる/追い詰める/追詰める"},"追詰める":{"variants":"おいつめる/追いつめる/追い詰める/追詰める"},"おいで":{"variants":"おいで/お出で"},"お出で":{"variants":"おいで/お出で"},"おいぬく":{"variants":"おいぬく/追い抜く/追抜く"},"追い抜く":{"variants":"おいぬく/追い抜く/追抜く"},"追抜く":{"variants":"おいぬく/追い抜く/追抜く"},"おいぬける":{"variants":"おいぬける/追い抜ける"},"追い抜ける":{"variants":"おいぬける/追い抜ける"},"追いはぎ":{"variants":"追いはぎ/追い剥ぎ/追剥"},"追い剥ぎ":{"variants":"追いはぎ/追い剥ぎ/追剥"},"追剥":{"variants":"追いはぎ/追い剥ぎ/追剥"},"おいはらう":{"variants":"おいはらう/追いはらう/追い払う"},"追いはらう":{"variants":"おいはらう/追いはらう/追い払う"},"追い払う":{"variants":"おいはらう/追いはらう/追い払う"},"おいはらえる":{"variants":"おいはらえる/追い払える"},"追い払える":{"variants":"おいはらえる/追い払える"},"追い羽根":{"variants":"追い羽根/追羽根"},"追羽根":{"variants":"追い羽根/追羽根"},"おいぼれる":{"variants":"おいぼれる/老いぼれる/老い耄れる"},"老いぼれる":{"variants":"おいぼれる/老いぼれる/老い耄れる"},"老い耄れる":{"variants":"おいぼれる/老いぼれる/老い耄れる"},"おいまくる":{"variants":"おいまくる/追いまくる/追い捲る"},"追いまくる":{"variants":"おいまくる/追いまくる/追い捲る"},"追い捲る":{"variants":"おいまくる/追いまくる/追い捲る"},"おいまわす":{"variants":"おいまわす/追いまわす/追い回す/追い廻す/追ひ廻す/追回す/追廻す"},"追いまわす":{"variants":"おいまわす/追いまわす/追い回す/追い廻す/追ひ廻す/追回す/追廻す"},"追廻す":{"variants":"おいまわす/追いまわす/追い廻す/追ひ廻す/追廻す"},"追い回す":{"variants":"おいまわす/追いまわす/追い回す/追回す"},"追ひ廻す":{"variants":"おいまわす/追いまわす/追い廻す/追ひ廻す/追廻す"},"追い廻す":{"variants":"おいまわす/追いまわす/追い廻す/追ひ廻す/追廻す"},"追回す":{"variants":"おいまわす/追いまわす/追い回す/追回す"},"おいまわせる":{"variants":"おいまわせる/追い回せる"},"追い回せる":{"variants":"おいまわせる/追い回せる"},"負い目":{"variants":"負い目/負目"},"負目":{"variants":"負い目/負目"},"おいもとめる":{"variants":"おいもとめる/追い求める"},"追い求める":{"variants":"おいもとめる/追い求める"},"おいやる":{"variants":"おいやる/追いやる"},"追いやる":{"variants":"おいやる/追いやる"},"おいやれる":{"variants":"おいやれる/追いやれる"},"追いやれる":{"variants":"おいやれる/追いやれる"},"オイランソウ":{"variants":"オイランソウ/花魁草"},"花魁草":{"variants":"オイランソウ/花魁草"},"おいる":{"variants":"おいる/老いる"},"老いる":{"variants":"おいる/老いる"},"お祝い":{"variants":"お祝い/御祝い"},"御祝い":{"variants":"お祝い/御祝い"},"追分":{"variants":"追分/追分け"},"追分け":{"variants":"追分/追分け"},"おう":{"variants":"おう/逐う/追う/負う"},"おうおう":{"variants":"おうおう/往々/往往"},"往々":{"variants":"おうおう/往々/往往"},"往往":{"variants":"おうおう/往々/往往"},"怏々":{"variants":"怏々/怏怏"},"怏怏":{"variants":"怏々/怏怏"},"おう歌":{"variants":"おう歌/謳歌"},"謳歌":{"variants":"おう歌/謳歌"},"王さま":{"variants":"王さま/王様"},"王様":{"variants":"王さま/王様"},"オウショッキ":{"variants":"オウショッキ/黄蜀葵"},"黄蜀葵":{"variants":"オウショッキ/黄蜀葵"},"おうじる":{"variants":"おうじる/応じる"},"応じる":{"variants":"おうじる/応じる"},"おうずる":{"variants":"おうずる/応ずる"},"応ずる":{"variants":"おうずる/応ずる"},"おう盛":{"variants":"おう盛/旺盛"},"旺盛":{"variants":"おう盛/旺盛"},"おうせいあめ":{"variants":"おうせいあめ/黄精飴"},"黄精飴":{"variants":"おうせいあめ/黄精飴"},"お歌":{"variants":"お歌/御歌"},"御歌":{"variants":"お歌/御歌"},"黄だん":{"variants":"黄だん/黄疸"},"黄疸":{"variants":"黄だん/黄疸"},"おう吐":{"variants":"おう吐/嘔吐"},"嘔吐":{"variants":"おう吐/嘔吐"},"オウトウ":{"variants":"オウトウ/桜桃"},"桜桃":{"variants":"オウトウ/桜桃"},"押なつ":{"variants":"押なつ/押捺"},"押捺":{"variants":"押なつ/押捺"},"おう悩":{"variants":"おう悩/懊悩"},"懊悩":{"variants":"おう悩/懊悩"},"オウバイ":{"variants":"オウバイ/黄梅"},"黄梅":{"variants":"オウバイ/黄梅"},"オウバク":{"variants":"オウバク/黄蘗"},"黄蘗":{"variants":"オウバク/黄蘗"},"逢魔が時":{"variants":"逢魔が時/逢魔時"},"逢魔時":{"variants":"逢魔が時/逢魔時"},"オウム":{"variants":"オウム/王蟲/鸚鵡"},"おうレンズ":{"variants":"おうレンズ/凹レンズ"},"凹レンズ":{"variants":"おうレンズ/凹レンズ"},"おえら方":{"variants":"おえら方/お偉方"},"お偉方":{"variants":"おえら方/お偉方"},"おえる":{"variants":"おえる/終える/追える/負える"},"大当たり":{"variants":"大当たり/大当り"},"大当り":{"variants":"大当たり/大当り"},"おおい":{"variants":"おおい/多い"},"多い":{"variants":"おおい/多い"},"おおいなる":{"variants":"おおいなる/大いなる"},"大いなる":{"variants":"おおいなる/大いなる"},"おおいに":{"variants":"おおいに/大いに"},"大いに":{"variants":"おおいに/大いに"},"大入":{"variants":"大入/大入り"},"大入り":{"variants":"大入/大入り"},"大入り袋":{"variants":"大入り袋/大入袋"},"大入袋":{"variants":"大入り袋/大入袋"},"おおう":{"variants":"おおう/被う/覆う/蔽う"},"大売り出し":{"variants":"大売り出し/大売出し"},"大売出し":{"variants":"大売り出し/大売出し"},"おおえる":{"variants":"おおえる/被える/覆える"},"オオカミ":{"variants":"オオカミ/狼"},"狼":{"variants":"オオカミ/狼"},"おおがかり":{"variants":"おおがかり/大がかり/大掛かり/大掛り"},"大がかり":{"variants":"おおがかり/大がかり/大掛かり/大掛り"},"大掛かり":{"variants":"おおがかり/大がかり/大掛かり/大掛り"},"大掛り":{"variants":"おおがかり/大がかり/大掛かり/大掛り"},"おおきな":{"variants":"おおきな/大きな"},"大きな":{"variants":"おおきな/大きな"},"おおきに":{"variants":"おおきに/大きに"},"大きに":{"variants":"おおきに/大きに"},"大きめ":{"variants":"大きめ/大き目"},"大き目":{"variants":"大きめ/大き目"},"大げさ":{"variants":"おおげさ/大げさ/大袈裟"},"大袈裟":{"variants":"おおげさ/大げさ/大袈裟"},"おおげさ":{"variants":"おおげさ/大げさ/大袈裟"},"大ざっぱ":{"variants":"大ざっぱ/大雑把"},"大雑把":{"variants":"大ざっぱ/大雑把"},"おおしい":{"variants":"おおしい/男々しい/男男しい/雄々しい/雄雄しい"},"雄雄しい":{"variants":"おおしい/雄々しい/雄雄しい"},"雄々しい":{"variants":"おおしい/雄々しい/雄雄しい"},"男々しい":{"variants":"おおしい/男々しい/男男しい"},"男男しい":{"variants":"おおしい/男々しい/男男しい"},"オオシカ":{"variants":"オオシカ/大鹿"},"大鹿":{"variants":"オオシカ/大鹿"},"大島つむぎ":{"variants":"大島つむぎ/大島紬"},"大島紬":{"variants":"大島つむぎ/大島紬"},"仰せごと":{"variants":"仰せごと/仰せ言"},"仰せ言":{"variants":"仰せごと/仰せ言"},"おおせつかる":{"variants":"おおせつかる/仰せつかる"},"仰せつかる":{"variants":"おおせつかる/仰せつかる"},"おおせつける":{"variants":"おおせつける/仰せつける/仰せ付ける"},"仰せつける":{"variants":"おおせつける/仰せつける/仰せ付ける"},"仰せ付ける":{"variants":"おおせつける/仰せつける/仰せ付ける"},"おおせる":{"variants":"おおせる/果せる/仰せる/遂せる"},"大立て者":{"variants":"大立て者/大立者"},"大立者":{"variants":"大立て者/大立者"},"おおっぴら":{"variants":"おおっぴら/大っぴら"},"大っぴら":{"variants":"おおっぴら/大っぴら"},"おおつごもり":{"variants":"おおつごもり/大つごもり/大晦"},"大つごもり":{"variants":"おおつごもり/大つごもり/大晦"},"大晦":{"variants":"おおつごもり/大つごもり/大晦"},"大つぶ":{"variants":"大つぶ/大粒"},"大粒":{"variants":"大つぶ/大粒"},"大づかみ":{"variants":"大づかみ/大掴み"},"大掴み":{"variants":"大づかみ/大掴み"},"大詰":{"variants":"大詰/大詰め"},"大詰め":{"variants":"大詰/大詰め"},"大なた":{"variants":"大なた/大鉈"},"大鉈":{"variants":"大なた/大鉈"},"オオバコ":{"variants":"オオバコ/車前草"},"車前草":{"variants":"オオバコ/車前草"},"大盤振る舞い":{"variants":"大盤振る舞い/大盤振舞"},"大盤振舞":{"variants":"大盤振る舞い/大盤振舞"},"大ぶり":{"variants":"大ぶり/大降り/大振り"},"おおまか":{"variants":"おおまか/大まか"},"大まか":{"variants":"おおまか/大まか"},"大見え":{"variants":"大見え/大見得"},"大見得":{"variants":"大見え/大見得"},"大みそか":{"variants":"大みそか/大晦日"},"大晦日":{"variants":"大みそか/大晦日"},"オオムギ":{"variants":"オオムギ/大麦"},"大麦":{"variants":"オオムギ/大麦"},"オオムラサキ":{"variants":"オオムラサキ/大紫"},"大紫":{"variants":"オオムラサキ/大紫"},"多め":{"variants":"多め/多目"},"多目":{"variants":"多め/多目"},"大もうけ":{"variants":"大もうけ/大儲け"},"大儲け":{"variants":"大もうけ/大儲け"},"おおよう":{"variants":"おおよう/大様"},"大様":{"variants":"おおよう/大様"},"おおわらわ":{"variants":"おおわらわ/大わらわ/大童"},"大わらわ":{"variants":"おおわらわ/大わらわ/大童"},"大童":{"variants":"おおわらわ/大わらわ/大童"},"お母さま":{"variants":"お母さま/お母様"},"お母様":{"variants":"お母さま/お母様"},"おかげ":{"variants":"おかげ/お蔭/お陰/御蔭/御陰"},"御陰":{"variants":"おかげ/お陰/御陰"},"お陰":{"variants":"おかげ/お陰/御陰"},"御蔭":{"variants":"おかげ/お蔭/御蔭"},"お蔭":{"variants":"おかげ/お蔭/御蔭"},"御蔭様":{"variants":"お蔭さま/お蔭様/御蔭様"},"お蔭様":{"variants":"お蔭さま/お蔭様/御蔭様"},"お蔭さま":{"variants":"お蔭さま/お蔭様/御蔭様"},"お陰様":{"variants":"お陰さま/お陰様"},"お陰さま":{"variants":"お陰さま/お陰様"},"お飾り":{"variants":"お飾り/御飾り"},"御飾り":{"variants":"お飾り/御飾り"},"おかし":{"variants":"おかし/お菓子"},"お菓子":{"variants":"おかし/お菓子"},"おかしい":{"variants":"おかしい/可笑しい"},"可笑しい":{"variants":"おかしい/可笑しい"},"尾頭つき":{"variants":"尾頭つき/尾頭付/尾頭付き"},"尾頭付":{"variants":"尾頭つき/尾頭付/尾頭付き"},"尾頭付き":{"variants":"尾頭つき/尾頭付/尾頭付き"},"おかす":{"variants":"おかす/侵す/犯す/冒す"},"おかせる":{"variants":"おかせる/侵せる/犯せる/冒せる"},"お方":{"variants":"お方/御方"},"御方":{"variants":"お方/御方"},"岡っ引き":{"variants":"岡っ引き/岡引"},"岡引":{"variants":"岡っ引き/岡引"},"おか釣り":{"variants":"おか釣り/陸釣/陸釣り"},"陸釣":{"variants":"おか釣り/陸釣/陸釣り"},"陸釣り":{"variants":"おか釣り/陸釣/陸釣り"},"おかど違い":{"variants":"おかど違い/お門違い"},"お門違い":{"variants":"おかど違い/お門違い"},"オカボ":{"variants":"オカボ/陸稲"},"陸稲":{"variants":"オカボ/陸稲"},"お構い":{"variants":"お構い/御構"},"御構":{"variants":"お構い/御構"},"おかみ":{"variants":"おかみ/お上/御上/女将"},"おかゆ":{"variants":"おかゆ/陸湯"},"陸湯":{"variants":"おかゆ/陸湯"},"おがくず":{"variants":"おがくず/おが屑/大鋸屑"},"おが屑":{"variants":"おがくず/おが屑/大鋸屑"},"大鋸屑":{"variants":"おがくず/おが屑/大鋸屑"},"オガタマノキ":{"variants":"オガタマノキ/黄心樹/小賀玉木"},"おがみたおす":{"variants":"おがみたおす/拝み倒す"},"拝み倒す":{"variants":"おがみたおす/拝み倒す"},"おがむ":{"variants":"おがむ/拝む"},"拝む":{"variants":"おがむ/拝む"},"おがめる":{"variants":"おがめる/拝める"},"拝める":{"variants":"おがめる/拝める"},"沖合":{"variants":"沖合/沖合い"},"沖合い":{"variants":"沖合/沖合い"},"起きあがりこぼし":{"variants":"起きあがりこぼし/起き上り小法師/起上り小法師"},"起き上り小法師":{"variants":"起きあがりこぼし/起き上り小法師/起上り小法師"},"起上り小法師":{"variants":"起きあがりこぼし/起き上り小法師/起上り小法師"},"おきあがる":{"variants":"おきあがる/起きあがる/起き上がる"},"起きあがる":{"variants":"おきあがる/起きあがる/起き上がる"},"起き上がる":{"variants":"おきあがる/起きあがる/起き上がる"},"おきあがれる":{"variants":"おきあがれる/起きあがれる/起き上がれる"},"起きあがれる":{"variants":"おきあがれる/起きあがれる/起き上がれる"},"起き上がれる":{"variants":"おきあがれる/起きあがれる/起き上がれる"},"おきかえる":{"variants":"おきかえる/置きかえる/置き換える/置換える"},"置きかえる":{"variants":"おきかえる/置きかえる/置き換える/置換える"},"置き換える":{"variants":"おきかえる/置きかえる/置き換える/置換える"},"置換える":{"variants":"おきかえる/置きかえる/置き換える/置換える"},"おきかわる":{"variants":"おきかわる/置きかわる/置き換わる/置換わる"},"置きかわる":{"variants":"おきかわる/置きかわる/置き換わる/置換わる"},"置き換わる":{"variants":"おきかわる/置きかわる/置き換わる/置換わる"},"置換わる":{"variants":"おきかわる/置きかわる/置き換わる/置換わる"},"起きがけ":{"variants":"起きがけ/起き掛け"},"起き掛け":{"variants":"起きがけ/起き掛け"},"置き傘":{"variants":"置き傘/置傘"},"置傘":{"variants":"置き傘/置傘"},"置きざり":{"variants":"置きざり/置き去り"},"置き去り":{"variants":"置きざり/置き去り"},"おきだす":{"variants":"おきだす/起き出す"},"起き出す":{"variants":"おきだす/起き出す"},"おきだせる":{"variants":"おきだせる/起き出せる"},"起き出せる":{"variants":"おきだせる/起き出せる"},"置き手紙":{"variants":"置き手紙/置手紙"},"置手紙":{"variants":"置き手紙/置手紙"},"置き時計":{"variants":"置き時計/置時計"},"置時計":{"variants":"置き時計/置時計"},"おきなおる":{"variants":"おきなおる/起き直る"},"起き直る":{"variants":"おきなおる/起き直る"},"おきなおれる":{"variants":"おきなおれる/起き直れる"},"起き直れる":{"variants":"おきなおれる/起き直れる"},"オキナグサ":{"variants":"オキナグサ/翁草"},"翁草":{"variants":"オキナグサ/翁草"},"お気にいり":{"variants":"お気にいり/お気に入り"},"お気に入り":{"variants":"お気にいり/お気に入り"},"起きぬけ":{"variants":"起きぬけ/起き抜け"},"起き抜け":{"variants":"起きぬけ/起き抜け"},"置き引き":{"variants":"置き引き/置引"},"置引":{"variants":"置き引き/置引"},"起き伏し":{"variants":"起き伏し/起伏し"},"起伏し":{"variants":"起き伏し/起伏し"},"お決まり":{"variants":"お決まり/お決り"},"お決り":{"variants":"お決まり/お決り"},"置き物":{"variants":"置き物/置物"},"置物":{"variants":"置き物/置物"},"置き屋":{"variants":"置き屋/置屋"},"置屋":{"variants":"置き屋/置屋"},"おきる":{"variants":"おきる/起きる/熾きる"},"おきわすれる":{"variants":"おきわすれる/置きわすれる/置き忘れる/置忘れる"},"置きわすれる":{"variants":"おきわすれる/置きわすれる/置き忘れる/置忘れる"},"置き忘れる":{"variants":"おきわすれる/置きわすれる/置き忘れる/置忘れる"},"置忘れる":{"variants":"おきわすれる/置きわすれる/置き忘れる/置忘れる"},"おぎないあう":{"variants":"おぎないあう/補い合う"},"補い合う":{"variants":"おぎないあう/補い合う"},"おぎなう":{"variants":"おぎなう/補う"},"補う":{"variants":"おぎなう/補う"},"おぎなえる":{"variants":"おぎなえる/補える"},"補える":{"variants":"おぎなえる/補える"},"おく":{"variants":"おく/於く/措く/置く"},"奥さま":{"variants":"奥さま/奥様"},"奥様":{"variants":"奥さま/奥様"},"おくする":{"variants":"おくする/臆する"},"臆する":{"variants":"おくする/臆する"},"おくふかい":{"variants":"おくふかい/奥深い"},"奥深い":{"variants":"おくふかい/奥深い"},"おくまる":{"variants":"おくまる/奥まる"},"奥まる":{"variants":"おくまる/奥まる"},"おくゆかしい":{"variants":"おくゆかしい/奥ゆかしい/奥床しい"},"奥ゆかしい":{"variants":"おくゆかしい/奥ゆかしい/奥床しい"},"奥床しい":{"variants":"おくゆかしい/奥ゆかしい/奥床しい"},"奥ゆき":{"variants":"奥ゆき/奥行/奥行き"},"奥行":{"variants":"奥ゆき/奥行/奥行き"},"奥行き":{"variants":"奥ゆき/奥行/奥行き"},"おくらす":{"variants":"おくらす/後らす/遅らす"},"おくらせる":{"variants":"おくらせる/後らせる/遅らせる"},"おくりかえす":{"variants":"おくりかえす/送り返す"},"送り返す":{"variants":"おくりかえす/送り返す"},"おくりかえせる":{"variants":"おくりかえせる/送り返せる"},"送り返せる":{"variants":"おくりかえせる/送り返せる"},"送りがな":{"variants":"送りがな/送仮名"},"送仮名":{"variants":"送りがな/送仮名"},"送りこみ":{"variants":"送りこみ/送り込み"},"送り込み":{"variants":"送りこみ/送り込み"},"おくりこむ":{"variants":"おくりこむ/送りこむ/送り込む"},"送りこむ":{"variants":"おくりこむ/送りこむ/送り込む"},"送り込む":{"variants":"おくりこむ/送りこむ/送り込む"},"おくりこめる":{"variants":"おくりこめる/送り込める"},"送り込める":{"variants":"おくりこめる/送り込める"},"送り状":{"variants":"送り状/送状"},"送状":{"variants":"送り状/送状"},"おくりだす":{"variants":"おくりだす/送りだす/送り出す"},"送りだす":{"variants":"おくりだす/送りだす/送り出す"},"送り出す":{"variants":"おくりだす/送りだす/送り出す"},"おくりだせる":{"variants":"おくりだせる/送り出せる"},"送り出せる":{"variants":"おくりだせる/送り出せる"},"おくりとどける":{"variants":"おくりとどける/送り届ける"},"送り届ける":{"variants":"おくりとどける/送り届ける"},"贈り物":{"variants":"贈り物/贈物"},"贈物":{"variants":"贈り物/贈物"},"おくる":{"variants":"おくる/送る/贈る"},"おくれ毛":{"variants":"おくれ毛/後れ毛"},"後れ毛":{"variants":"おくれ毛/後れ毛"},"遅ればせ":{"variants":"遅ればせ/遅れ馳せ"},"遅れ馳せ":{"variants":"遅ればせ/遅れ馳せ"},"おくればせながら":{"variants":"おくればせながら/遅ればせながら"},"遅ればせながら":{"variants":"おくればせながら/遅ればせながら"},"おくれる":{"variants":"おくれる/後れる/送れる/贈れる/遅れる"},"おぐら":{"variants":"おぐら/小倉"},"小倉":{"variants":"おぐら/小倉"},"おける":{"variants":"おける/置ける"},"置ける":{"variants":"おける/置ける"},"おこがましい":{"variants":"おこがましい/烏滸がましい"},"烏滸がましい":{"variants":"おこがましい/烏滸がましい"},"お子さま":{"variants":"お子さま/お子様"},"お子様":{"variants":"お子さま/お子様"},"おこし":{"variants":"おこし/お越し/お腰/起し"},"おこす":{"variants":"おこす/起こす/起す/興す/熾す"},"起す":{"variants":"おこす/起こす/起す"},"起こす":{"variants":"おこす/起こす/起す"},"おこせる":{"variants":"おこせる/起こせる/興せる"},"オコゼ":{"variants":"オコゼ/虎魚"},"虎魚":{"variants":"オコゼ/虎魚"},"おこたる":{"variants":"おこたる/怠る"},"怠る":{"variants":"おこたる/怠る"},"おこないすます":{"variants":"おこないすます/行い澄ます"},"行い澄ます":{"variants":"おこないすます/行い澄ます"},"おこなう":{"variants":"おこなう/行う/行なう"},"行う":{"variants":"おこなう/行う/行なう"},"行なう":{"variants":"おこなう/行う/行なう"},"おこなえる":{"variants":"おこなえる/行える"},"行える":{"variants":"おこなえる/行える"},"おこる":{"variants":"おこる/起こる/起る/興る/熾る"},"起る":{"variants":"おこる/起こる/起る"},"起こる":{"variants":"おこる/起こる/起る"},"おこれる":{"variants":"おこれる/怒れる"},"怒れる":{"variants":"おこれる/怒れる"},"おごそか":{"variants":"おごそか/厳か"},"厳か":{"variants":"おごそか/厳か"},"おごり":{"variants":"おごり/傲り/奢り/驕り"},"おごる":{"variants":"おごる/奢る/驕る"},"押さえ":{"variants":"押え/押さえ"},"押え":{"variants":"押え/押さえ"},"おさえこむ":{"variants":"おさえこむ/押え込む/押さえ込む/抑え込む"},"押さえ込む":{"variants":"おさえこむ/押え込む/押さえ込む"},"押え込む":{"variants":"おさえこむ/押え込む/押さえ込む"},"おさえつける":{"variants":"おさえつける/押えつける/押え付ける/押さえつける/押さえ付ける"},"押えつける":{"variants":"おさえつける/押えつける/押え付ける/押さえつける/押さえ付ける"},"押え付ける":{"variants":"おさえつける/押えつける/押え付ける/押さえつける/押さえ付ける"},"押さえつける":{"variants":"おさえつける/押えつける/押え付ける/押さえつける/押さえ付ける"},"押さえ付ける":{"variants":"おさえつける/押えつける/押え付ける/押さえつける/押さえ付ける"},"おさえる":{"variants":"おさえる/押える/押さえる/抑える"},"押さえる":{"variants":"おさえる/押える/押さえる"},"押える":{"variants":"おさえる/押える/押さえる"},"おさきに":{"variants":"おさきに/お先に"},"お先に":{"variants":"おさきに/お先に"},"おさない":{"variants":"おさない/幼い"},"幼い":{"variants":"おさない/幼い"},"幼友だち":{"variants":"幼友だち/幼友達"},"幼友達":{"variants":"幼友だち/幼友達"},"幼なじみ":{"variants":"幼なじみ/幼馴染/幼馴染み"},"幼馴染":{"variants":"幼なじみ/幼馴染/幼馴染み"},"幼馴染み":{"variants":"幼なじみ/幼馴染/幼馴染み"},"おさまる":{"variants":"おさまる/治まる/収まる/修まる/納まる"},"おさめる":{"variants":"おさめる/治める/収める/修める/納める"},"オシ":{"variants":"オシ/唖/圧し/押し"},"押し合い":{"variants":"押し合い/押合い"},"押合い":{"variants":"押し合い/押合い"},"おしあげる":{"variants":"おしあげる/押し上げる"},"押し上げる":{"variants":"おしあげる/押し上げる"},"おしい":{"variants":"おしい/惜しい"},"惜しい":{"variants":"おしい/惜しい"},"おしいる":{"variants":"おしいる/押し入る/押入る"},"押し入る":{"variants":"おしいる/押し入る/押入る"},"押入る":{"variants":"おしいる/押し入る/押入る"},"押し入れ":{"variants":"押し入れ/押入"},"押入":{"variants":"押し入れ/押入"},"おしいれる":{"variants":"おしいれる/押し入れる"},"押し入れる":{"variants":"おしいれる/押し入れる"},"おしうつる":{"variants":"おしうつる/推し移る/推移る"},"推し移る":{"variants":"おしうつる/推し移る/推移る"},"推移る":{"variants":"おしうつる/推し移る/推移る"},"押し売り":{"variants":"押し売り/押売"},"押売":{"variants":"押し売り/押売"},"押し絵":{"variants":"押し絵/押絵"},"押絵":{"variants":"押し絵/押絵"},"おしえる":{"variants":"おしえる/教える"},"教える":{"variants":"おしえる/教える"},"おしおき":{"variants":"おしおき/お仕置/お仕置き"},"お仕置":{"variants":"おしおき/お仕置/お仕置き"},"お仕置き":{"variants":"おしおき/お仕置/お仕置き"},"おしかえす":{"variants":"おしかえす/押しかえす/押し返す/押返す"},"押しかえす":{"variants":"おしかえす/押しかえす/押し返す/押返す"},"押し返す":{"variants":"おしかえす/押しかえす/押し返す/押返す"},"押返す":{"variants":"おしかえす/押しかえす/押し返す/押返す"},"おしかえせる":{"variants":"おしかえせる/押し返せる"},"押し返せる":{"variants":"おしかえせる/押し返せる"},"おしかくす":{"variants":"おしかくす/押し隠す/押隠す"},"押し隠す":{"variants":"おしかくす/押し隠す/押隠す"},"押隠す":{"variants":"おしかくす/押し隠す/押隠す"},"おしかくせる":{"variants":"おしかくせる/押し隠せる"},"押し隠せる":{"variants":"おしかくせる/押し隠せる"},"おしかける":{"variants":"おしかける/押しかける/押し掛ける/押掛ける"},"押しかける":{"variants":"おしかける/押しかける/押し掛ける/押掛ける"},"押し掛ける":{"variants":"おしかける/押しかける/押し掛ける/押掛ける"},"押掛ける":{"variants":"おしかける/押しかける/押し掛ける/押掛ける"},"おしかぶさる":{"variants":"おしかぶさる/押しかぶさる"},"押しかぶさる":{"variants":"おしかぶさる/押しかぶさる"},"押し借り":{"variants":"押し借り/押借り"},"押借り":{"variants":"押し借り/押借り"},"押し切り":{"variants":"押し切り/押切り"},"押切り":{"variants":"押し切り/押切り"},"押し切り帳":{"variants":"押し切り帳/押切り帳"},"押切り帳":{"variants":"押し切り帳/押切り帳"},"おしきる":{"variants":"おしきる/押しきる/押し切る/押切る"},"押しきる":{"variants":"おしきる/押しきる/押し切る/押切る"},"押し切る":{"variants":"おしきる/押しきる/押し切る/押切る"},"押切る":{"variants":"おしきる/押しきる/押し切る/押切る"},"おしきれる":{"variants":"おしきれる/押し切れる"},"押し切れる":{"variants":"おしきれる/押し切れる"},"おしくも":{"variants":"おしくも/惜しくも"},"惜しくも":{"variants":"おしくも/惜しくも"},"押し込み":{"variants":"押し込み/押込み"},"押込み":{"variants":"押し込み/押込み"},"おしこむ":{"variants":"おしこむ/押し込む"},"押し込む":{"variants":"おしこむ/押し込む"},"おしこめる":{"variants":"おしこめる/押しこめる/押し込める/押込める"},"押しこめる":{"variants":"おしこめる/押しこめる/押し込める/押込める"},"押し込める":{"variants":"おしこめる/押しこめる/押し込める/押込める"},"押込める":{"variants":"おしこめる/押しこめる/押し込める/押込める"},"おしすすめる":{"variants":"おしすすめる/押し進める/押し薦める/推し進める"},"おしせまる":{"variants":"おしせまる/押し迫る"},"押し迫る":{"variants":"おしせまる/押し迫る"},"おしたおす":{"variants":"おしたおす/押し倒す"},"押し倒す":{"variants":"おしたおす/押し倒す"},"おしたおせる":{"variants":"おしたおせる/押し倒せる"},"押し倒せる":{"variants":"おしたおせる/押し倒せる"},"押し出し":{"variants":"押し出し/押出し"},"押出し":{"variants":"押し出し/押出し"},"おしだす":{"variants":"おしだす/押しだす/押し出す"},"押しだす":{"variants":"おしだす/押しだす/押し出す"},"押し出す":{"variants":"おしだす/押しだす/押し出す"},"おしだせる":{"variants":"おしだせる/押し出せる"},"押し出せる":{"variants":"おしだせる/押し出せる"},"おしだまる":{"variants":"おしだまる/おし黙る/押し黙る/押黙る"},"おし黙る":{"variants":"おしだまる/おし黙る/押し黙る/押黙る"},"押し黙る":{"variants":"おしだまる/おし黙る/押し黙る/押黙る"},"押黙る":{"variants":"おしだまる/おし黙る/押し黙る/押黙る"},"おしつけがましい":{"variants":"おしつけがましい/押しつけがましい/押し付けがましい/押付けがましい"},"押しつけがましい":{"variants":"おしつけがましい/押しつけがましい/押し付けがましい/押付けがましい"},"押し付けがましい":{"variants":"おしつけがましい/押しつけがましい/押し付けがましい/押付けがましい"},"押付けがましい":{"variants":"おしつけがましい/押しつけがましい/押し付けがましい/押付けがましい"},"おしつける":{"variants":"おしつける/押しつける/押し付ける/押付ける"},"押しつける":{"variants":"おしつける/押しつける/押し付ける/押付ける"},"押し付ける":{"variants":"おしつける/押しつける/押し付ける/押付ける"},"押付ける":{"variants":"おしつける/押しつける/押し付ける/押付ける"},"おしつぶす":{"variants":"おしつぶす/押しつぶす"},"押しつぶす":{"variants":"おしつぶす/押しつぶす"},"おしつぶせる":{"variants":"おしつぶせる/押しつぶせる"},"押しつぶせる":{"variants":"おしつぶせる/押しつぶせる"},"おしつまる":{"variants":"おしつまる/押しつまる/押し詰まる/押し詰る"},"押しつまる":{"variants":"おしつまる/押しつまる/押し詰まる/押し詰る"},"押し詰まる":{"variants":"おしつまる/押しつまる/押し詰まる/押し詰る"},"押し詰る":{"variants":"おしつまる/押しつまる/押し詰まる/押し詰る"},"おしつめる":{"variants":"おしつめる/押しつめる/押し詰める/押詰める"},"押しつめる":{"variants":"おしつめる/押しつめる/押し詰める/押詰める"},"押し詰める":{"variants":"おしつめる/押しつめる/押し詰める/押詰める"},"押詰める":{"variants":"おしつめる/押しつめる/押し詰める/押詰める"},"おして":{"variants":"おして/押して"},"押して":{"variants":"おして/押して"},"おしとおす":{"variants":"おしとおす/押し通す/押通す"},"押し通す":{"variants":"おしとおす/押し通す/押通す"},"押通す":{"variants":"おしとおす/押し通す/押通す"},"おしとおせる":{"variants":"おしとおせる/押し通せる"},"押し通せる":{"variants":"おしとおせる/押し通せる"},"オシドリ":{"variants":"オシドリ/鴛"},"鴛":{"variants":"オシドリ/鴛"},"おしどり夫婦":{"variants":"おしどり夫婦/鴛鴦夫婦"},"鴛鴦夫婦":{"variants":"おしどり夫婦/鴛鴦夫婦"},"おしながす":{"variants":"おしながす/押し流す"},"押し流す":{"variants":"おしながす/押し流す"},"おしながせる":{"variants":"おしながせる/押し流せる"},"押し流せる":{"variants":"おしながせる/押し流せる"},"おしなべて":{"variants":"おしなべて/押しなべて/押し並べて/押並べて"},"押しなべて":{"variants":"おしなべて/押しなべて/押し並べて/押並べて"},"押し並べて":{"variants":"おしなべて/押しなべて/押し並べて/押並べて"},"押並べて":{"variants":"おしなべて/押しなべて/押し並べて/押並べて"},"おしのける":{"variants":"おしのける/押しのける/押し退ける"},"押しのける":{"variants":"おしのける/押しのける/押し退ける"},"押し退ける":{"variants":"おしのける/押しのける/押し退ける"},"おしはかる":{"variants":"おしはかる/推し量る/推量る"},"推し量る":{"variants":"おしはかる/推し量る/推量る"},"推量る":{"variants":"おしはかる/推し量る/推量る"},"おしはかれる":{"variants":"おしはかれる/推し量れる"},"推し量れる":{"variants":"おしはかれる/推し量れる"},"押し葉":{"variants":"押し葉/押葉"},"押葉":{"variants":"押し葉/押葉"},"押し花":{"variants":"押し花/押花"},"押花":{"variants":"押し花/押花"},"おしひらく":{"variants":"おしひらく/押し開く"},"押し開く":{"variants":"おしひらく/押し開く"},"おしひろめる":{"variants":"おしひろめる/押し広める"},"押し広める":{"variants":"おしひろめる/押し広める"},"オシベ":{"variants":"オシベ/雄しべ/雄蕊"},"雄しべ":{"variants":"オシベ/雄しべ/雄蕊"},"雄蕊":{"variants":"オシベ/雄しべ/雄蕊"},"押し釦":{"variants":"押し釦/押釦"},"押釦":{"variants":"押し釦/押釦"},"おしまくる":{"variants":"おしまくる/押しまくる"},"押しまくる":{"variants":"おしまくる/押しまくる"},"おしみ":{"variants":"おしみ/惜しみ"},"惜しみ":{"variants":"おしみ/惜しみ"},"おしむ":{"variants":"おしむ/惜しむ"},"惜しむ":{"variants":"おしむ/惜しむ"},"押し麦":{"variants":"押し麦/押麦"},"押麦":{"variants":"押し麦/押麦"},"おしむらくは":{"variants":"おしむらくは/惜しむらくは"},"惜しむらくは":{"variants":"おしむらくは/惜しむらくは"},"おしめ":{"variants":"おしめ/押し目/押目"},"押し目":{"variants":"おしめ/押し目/押目"},"押目":{"variants":"おしめ/押し目/押目"},"おしもどす":{"variants":"おしもどす/押し戻す"},"押し戻す":{"variants":"おしもどす/押し戻す"},"お釈迦さま":{"variants":"お釈迦さま/お釈迦様"},"お釈迦様":{"variants":"お釈迦さま/お釈迦様"},"おしゃれ":{"variants":"おしゃれ/お洒落/オシャレ"},"お洒落":{"variants":"おしゃれ/お洒落/オシャレ"},"オシャレ":{"variants":"おしゃれ/お洒落/オシャレ"},"おしやる":{"variants":"おしやる/押しやる/押し遣る"},"押しやる":{"variants":"おしやる/押しやる/押し遣る"},"押し遣る":{"variants":"おしやる/押しやる/押し遣る"},"おしよせる":{"variants":"おしよせる/押し寄せる/押寄せる"},"押し寄せる":{"variants":"おしよせる/押し寄せる/押寄せる"},"押寄せる":{"variants":"おしよせる/押し寄せる/押寄せる"},"おしろい花":{"variants":"おしろい花/オシロイバナ/白粉花"},"オシロイバナ":{"variants":"おしろい花/オシロイバナ/白粉花"},"白粉花":{"variants":"おしろい花/オシロイバナ/白粉花"},"おしわける":{"variants":"おしわける/押しわける/押し分ける/押分ける"},"押しわける":{"variants":"おしわける/押しわける/押し分ける/押分ける"},"押し分ける":{"variants":"おしわける/押しわける/押し分ける/押分ける"},"押分ける":{"variants":"おしわける/押しわける/押し分ける/押分ける"},"押し割り":{"variants":"押し割り/押割り"},"押割り":{"variants":"押し割り/押割り"},"おじいさん":{"variants":"おじいさん/お祖父さん/お爺さん"},"おじぎ草":{"variants":"おじぎ草/オジギソウ/含羞草"},"オジギソウ":{"variants":"おじぎ草/オジギソウ/含羞草"},"含羞草":{"variants":"おじぎ草/オジギソウ/含羞草"},"おじけだつ":{"variants":"おじけだつ/怖じ気立つ/怖気立つ"},"怖じ気立つ":{"variants":"おじけだつ/怖じ気立つ/怖気立つ"},"怖気立つ":{"variants":"おじけだつ/怖じ気立つ/怖気立つ"},"おじけづく":{"variants":"おじけづく/怖じ気付く/怖気付く"},"怖じ気付く":{"variants":"おじけづく/怖じ気付く/怖気付く"},"怖気付く":{"variants":"おじけづく/怖じ気付く/怖気付く"},"おじける":{"variants":"おじける/怖じける"},"怖じける":{"variants":"おじける/怖じける"},"おじさん":{"variants":"おじさん/オジさん/オジサン/叔父さん"},"オジさん":{"variants":"おじさん/オジさん/オジサン/叔父さん"},"オジサン":{"variants":"おじさん/オジさん/オジサン/叔父さん"},"叔父さん":{"variants":"おじさん/オジさん/オジサン/叔父さん"},"おじょうさん":{"variants":"おじょうさん/お嬢さん"},"お嬢さん":{"variants":"おじょうさん/お嬢さん"},"おじる":{"variants":"おじる/怖じる"},"怖じる":{"variants":"おじる/怖じる"},"おす":{"variants":"おす/圧す/押す/推す/捺す"},"オス":{"variants":"オス/牡"},"牡":{"variants":"オス/牡"},"おすすめ":{"variants":"おすすめ/オススメ"},"オススメ":{"variants":"おすすめ/オススメ"},"おすそ分け":{"variants":"おすそ分け/お裾分け"},"お裾分け":{"variants":"おすそ分け/お裾分け"},"お墨付き":{"variants":"お墨付き/御墨付/御墨付き"},"御墨付":{"variants":"お墨付き/御墨付/御墨付き"},"御墨付き":{"variants":"お墨付き/御墨付/御墨付き"},"お歳暮":{"variants":"お歳暮/御歳暮"},"御歳暮":{"variants":"お歳暮/御歳暮"},"お節":{"variants":"お節/オセチ"},"オセチ":{"variants":"お節/オセチ"},"おせっかい":{"variants":"おせっかい/お節介"},"お節介":{"variants":"おせっかい/お節介"},"おせる":{"variants":"おせる/押せる/推せる"},"おぜん立て":{"variants":"おぜん立て/お膳立て/御膳立/御膳立て"},"お膳立て":{"variants":"おぜん立て/お膳立て/御膳立/御膳立て"},"御膳立":{"variants":"おぜん立て/お膳立て/御膳立/御膳立て"},"御膳立て":{"variants":"おぜん立て/お膳立て/御膳立/御膳立て"},"おそい":{"variants":"おそい/遅い"},"遅い":{"variants":"おそい/遅い"},"おそいかかる":{"variants":"おそいかかる/襲いかかる"},"襲いかかる":{"variants":"おそいかかる/襲いかかる"},"おそう":{"variants":"おそう/襲う"},"襲う":{"variants":"おそう/襲う"},"遅生まれ":{"variants":"遅生まれ/遅生れ"},"遅生れ":{"variants":"遅生まれ/遅生れ"},"おそくとも":{"variants":"おそくとも/遅くとも"},"遅くとも":{"variants":"おそくとも/遅くとも"},"おそなわる":{"variants":"おそなわる/遅なわる"},"遅なわる":{"variants":"おそなわる/遅なわる"},"遅まき":{"variants":"遅まき/遅蒔き"},"遅蒔き":{"variants":"遅まき/遅蒔き"},"おそらく":{"variants":"おそらく/恐らく"},"恐らく":{"variants":"おそらく/恐らく"},"おそらくは":{"variants":"おそらくは/恐らくは"},"恐らくは":{"variants":"おそらくは/恐らくは"},"おそるべき":{"variants":"おそるべき/恐るべき"},"恐るべき":{"variants":"おそるべき/恐るべき"},"おそれいる":{"variants":"おそれいる/畏れ入る/恐れ入る"},"おそれおおい":{"variants":"おそれおおい/畏れおおい/畏れ多い/畏多い/恐れおおい/恐れ多い/恐多い"},"恐多い":{"variants":"おそれおおい/恐れおおい/恐れ多い/恐多い"},"恐れ多い":{"variants":"おそれおおい/恐れおおい/恐れ多い/恐多い"},"畏多い":{"variants":"おそれおおい/畏れおおい/畏れ多い/畏多い"},"畏れ多い":{"variants":"おそれおおい/畏れおおい/畏れ多い/畏多い"},"恐れおおい":{"variants":"おそれおおい/恐れおおい/恐れ多い/恐多い"},"畏れおおい":{"variants":"おそれおおい/畏れおおい/畏れ多い/畏多い"},"おそれながら":{"variants":"おそれながら/恐れながら"},"恐れながら":{"variants":"おそれながら/恐れながら"},"おそれる":{"variants":"おそれる/畏れる/恐る/恐れる/慴れる"},"恐れる":{"variants":"おそれる/恐る/恐れる"},"恐る":{"variants":"おそれる/恐る/恐れる"},"おそろいで":{"variants":"おそろいで/お揃いで"},"お揃いで":{"variants":"おそろいで/お揃いで"},"おそろしい":{"variants":"おそろしい/恐ろしい"},"恐ろしい":{"variants":"おそろしい/恐ろしい"},"おそろしく":{"variants":"おそろしく/恐ろしく"},"恐ろしく":{"variants":"おそろしく/恐ろしく"},"おそわる":{"variants":"おそわる/教わる"},"教わる":{"variants":"おそわる/教わる"},"おそわれる":{"variants":"おそわれる/襲われる/魘われる"},"おたおた":{"variants":"おたおた/オタオタ"},"オタオタ":{"variants":"おたおた/オタオタ"},"おたかく":{"variants":"おたかく/お高く"},"お高く":{"variants":"おたかく/お高く"},"おたがいに":{"variants":"おたがいに/お互いに"},"お互いに":{"variants":"おたがいに/お互いに"},"お宅":{"variants":"お宅/オタク"},"オタク":{"variants":"お宅/オタク"},"雄たけび":{"variants":"雄たけび/雄叫び"},"雄叫び":{"variants":"雄たけび/雄叫び"},"おたずね者":{"variants":"おたずね者/お尋ね者/御尋ねもの/御尋ね者"},"お尋ね者":{"variants":"おたずね者/お尋ね者/御尋ねもの/御尋ね者"},"御尋ねもの":{"variants":"おたずね者/お尋ね者/御尋ねもの/御尋ね者"},"御尋ね者":{"variants":"おたずね者/お尋ね者/御尋ねもの/御尋ね者"},"おたふく":{"variants":"おたふく/お多福"},"お多福":{"variants":"おたふく/お多福"},"お多福豆":{"variants":"お多福豆/オタフクマメ"},"オタフクマメ":{"variants":"お多福豆/オタフクマメ"},"お玉じゃくし":{"variants":"お玉じゃくし/お玉杓子/オタマジャクシ"},"お玉杓子":{"variants":"お玉じゃくし/お玉杓子/オタマジャクシ"},"オタマジャクシ":{"variants":"お玉じゃくし/お玉杓子/オタマジャクシ"},"おためごかし":{"variants":"おためごかし/お為ごかし"},"お為ごかし":{"variants":"おためごかし/お為ごかし"},"お題目":{"variants":"お題目/御題目"},"御題目":{"variants":"お題目/御題目"},"おだてる":{"variants":"おだてる/煽てる"},"煽てる":{"variants":"おだてる/煽てる"},"オダマキ":{"variants":"オダマキ/小田巻/小田巻き/苧環"},"小田巻":{"variants":"オダマキ/小田巻/小田巻き"},"小田巻き":{"variants":"オダマキ/小田巻/小田巻き"},"小田巻き蒸し":{"variants":"小田巻き蒸し/小田巻蒸し"},"小田巻蒸し":{"variants":"小田巻き蒸し/小田巻蒸し"},"おだやか":{"variants":"おだやか/穏やか"},"穏やか":{"variants":"おだやか/穏やか"},"おちあう":{"variants":"おちあう/落ち合う/落合う"},"落ち合う":{"variants":"おちあう/落ち合う/落合う"},"落合う":{"variants":"おちあう/落ち合う/落合う"},"おちあえる":{"variants":"おちあえる/落ち合える"},"落ち合える":{"variants":"おちあえる/落ち合える"},"おちいる":{"variants":"おちいる/陥る"},"陥る":{"variants":"おちいる/陥る"},"おちこぼれる":{"variants":"おちこぼれる/落ちこぼれる"},"落ちこぼれる":{"variants":"おちこぼれる/落ちこぼれる"},"おちこむ":{"variants":"おちこむ/落ちこむ/落ち込む"},"落ちこむ":{"variants":"おちこむ/落ちこむ/落ち込む"},"落ち込む":{"variants":"おちこむ/落ちこむ/落ち込む"},"落ちつき":{"variants":"落ちつき/落ち着き/落着き"},"落ち着き":{"variants":"落ちつき/落ち着き/落着き"},"落着き":{"variants":"落ちつき/落ち着き/落着き"},"おちつきはらう":{"variants":"おちつきはらう/落ち着き払う/落着き払う"},"落ち着き払う":{"variants":"おちつきはらう/落ち着き払う/落着き払う"},"落着き払う":{"variants":"おちつきはらう/落ち着き払う/落着き払う"},"おちつく":{"variants":"おちつく/落ちつく/落ち着く"},"落ちつく":{"variants":"おちつく/落ちつく/落ち着く"},"落ち着く":{"variants":"おちつく/落ちつく/落ち着く"},"おちつける":{"variants":"おちつける/落ちつける/落ち着ける/落着ける"},"落ちつける":{"variants":"おちつける/落ちつける/落ち着ける/落着ける"},"落ち着ける":{"variants":"おちつける/落ちつける/落ち着ける/落着ける"},"落着ける":{"variants":"おちつける/落ちつける/落ち着ける/落着ける"},"落度":{"variants":"落ち度/落度"},"落ち度":{"variants":"落ち度/落度"},"おちのびる":{"variants":"おちのびる/落ちのびる/落ち延びる/落延びる"},"落ちのびる":{"variants":"おちのびる/落ちのびる/落ち延びる/落延びる"},"落ち延びる":{"variants":"おちのびる/落ちのびる/落ち延びる/落延びる"},"落延びる":{"variants":"おちのびる/落ちのびる/落ち延びる/落延びる"},"おちぶれる":{"variants":"おちぶれる/落ちぶれる/落魄れる/零落れる"},"落ちぶれる":{"variants":"おちぶれる/落ちぶれる/落魄れる"},"落魄れる":{"variants":"おちぶれる/落ちぶれる/落魄れる"},"落ち穂":{"variants":"落ち穂/落穂"},"落穂":{"variants":"落ち穂/落穂"},"落ち武者":{"variants":"落ち武者/落武者"},"落武者":{"variants":"落ち武者/落武者"},"落ちめ":{"variants":"落ちめ/落ち目"},"落ち目":{"variants":"落ちめ/落ち目"},"お茶ひき":{"variants":"お茶ひき/お茶挽"},"お茶挽":{"variants":"お茶ひき/お茶挽"},"お中元":{"variants":"お中元/御中元"},"御中元":{"variants":"お中元/御中元"},"おちゆく":{"variants":"おちゆく/落ち行く/落行く"},"落ち行く":{"variants":"おちゆく/落ち行く/落行く"},"落行く":{"variants":"おちゆく/落ち行く/落行く"},"おちる":{"variants":"おちる/堕ちる/墜ちる/落ちる"},"おっかける":{"variants":"おっかける/追っかける/追っ掛ける/追掛ける"},"追っかける":{"variants":"おっかける/追っかける/追っ掛ける/追掛ける"},"追っ掛ける":{"variants":"おっかける/追っかける/追っ掛ける/追掛ける"},"追掛ける":{"variants":"おっかける/追っかける/追っ掛ける/追掛ける"},"おっくう":{"variants":"おっくう/億劫"},"億劫":{"variants":"おっくう/億劫"},"おっこちる":{"variants":"おっこちる/落っこちる"},"落っこちる":{"variants":"おっこちる/落っこちる"},"おっさん":{"variants":"おっさん/オッサン"},"オッサン":{"variants":"おっさん/オッサン"},"おっしゃる":{"variants":"おっしゃる/仰る"},"仰る":{"variants":"おっしゃる/仰る"},"おっしゃれる":{"variants":"おっしゃれる/仰れる"},"仰れる":{"variants":"おっしゃれる/仰れる"},"おっつけ":{"variants":"おっつけ/追っ付け"},"追っ付け":{"variants":"おっつけ/追っ付け"},"おって":{"variants":"おって/追って"},"追って":{"variants":"おって/追って"},"追っ手":{"variants":"追っ手/追手"},"追手":{"variants":"追っ手/追手"},"オットセイ":{"variants":"オットセイ/膃肭臍"},"膃肭臍":{"variants":"オットセイ/膃肭臍"},"押取り刀":{"variants":"押取り刀/押取刀"},"押取刀":{"variants":"押取り刀/押取刀"},"おっぱい":{"variants":"おっぱい/オッパイ"},"オッパイ":{"variants":"おっぱい/オッパイ"},"おっぱらう":{"variants":"おっぱらう/追っぱらう/追っ払う"},"追っぱらう":{"variants":"おっぱらう/追っぱらう/追っ払う"},"追っ払う":{"variants":"おっぱらう/追っぱらう/追っ払う"},"おつかれ様":{"variants":"おつかれ様/お疲れさま"},"お疲れさま":{"variants":"おつかれ様/お疲れさま"},"お告げ":{"variants":"お告げ/御告"},"御告":{"variants":"お告げ/御告"},"お釣":{"variants":"お釣/お釣り"},"お釣り":{"variants":"お釣/お釣り"},"お手つき":{"variants":"お手つき/お手付き"},"お手付き":{"variants":"お手つき/お手付き"},"お手盛":{"variants":"お手盛/お手盛り"},"お手盛り":{"variants":"お手盛/お手盛り"},"お天道様":{"variants":"お天道様/御天道様"},"御天道様":{"variants":"お天道様/御天道様"},"お伽":{"variants":"お伽/御伽"},"御伽":{"variants":"お伽/御伽"},"お伽草子":{"variants":"お伽草子/御伽草子"},"御伽草子":{"variants":"お伽草子/御伽草子"},"オトギリソウ":{"variants":"オトギリソウ/小連翹/弟切草"},"オトコエシ":{"variants":"オトコエシ/男郎花"},"男郎花":{"variants":"オトコエシ/男郎花"},"男だて":{"variants":"男だて/男伊達"},"男伊達":{"variants":"男だて/男伊達"},"男っぷり":{"variants":"男っぷり/男っ振り"},"男っ振り":{"variants":"男っぷり/男っ振り"},"おとこの子":{"variants":"おとこの子/男の子"},"男の子":{"variants":"おとこの子/男の子"},"男もの":{"variants":"男もの/男物"},"男物":{"variants":"男もの/男物"},"男やもめ":{"variants":"男やもめ/男鰥"},"男鰥":{"variants":"男やもめ/男鰥"},"おとこらしい":{"variants":"おとこらしい/男らしい"},"男らしい":{"variants":"おとこらしい/男らしい"},"音さた":{"variants":"音さた/音沙汰"},"音沙汰":{"variants":"音さた/音沙汰"},"落とし":{"variants":"落し/落とし"},"落し":{"variants":"落し/落とし"},"落し穴":{"variants":"落し穴/落とし穴"},"落とし穴":{"variants":"落し穴/落とし穴"},"おとしいれる":{"variants":"おとしいれる/おとし入れる/陥れる/落し入れる"},"おとし入れる":{"variants":"おとしいれる/おとし入れる/落し入れる"},"落し入れる":{"variants":"おとしいれる/おとし入れる/落し入れる"},"落しだね":{"variants":"落しだね/落し胤"},"落し胤":{"variants":"落しだね/落し胤"},"落しばなし":{"variants":"落しばなし/落し噺"},"落し噺":{"variants":"落しばなし/落し噺"},"落しぶた":{"variants":"落しぶた/落し蓋/落としぶた"},"落し蓋":{"variants":"落しぶた/落し蓋/落としぶた"},"落としぶた":{"variants":"落しぶた/落し蓋/落としぶた"},"オトシブミ":{"variants":"オトシブミ/落し文"},"落し文":{"variants":"オトシブミ/落し文"},"落し前":{"variants":"落し前/落とし前"},"落とし前":{"variants":"落し前/落とし前"},"おとしめる":{"variants":"おとしめる/貶める"},"貶める":{"variants":"おとしめる/貶める"},"落しもの":{"variants":"落しもの/落とし物"},"落とし物":{"variants":"落しもの/落とし物"},"おとす":{"variants":"おとす/落す/落とす"},"落す":{"variants":"おとす/落す/落とす"},"落とす":{"variants":"おとす/落す/落とす"},"おとずれる":{"variants":"おとずれる/訪れる"},"訪れる":{"variants":"おとずれる/訪れる"},"おとせる":{"variants":"おとせる/落とせる"},"落とせる":{"variants":"おとせる/落とせる"},"おとっつぁん":{"variants":"おとっつぁん/お父つぁん"},"お父つぁん":{"variants":"おとっつぁん/お父つぁん"},"おとなげ":{"variants":"おとなげ/大人げ/大人気"},"大人げ":{"variants":"おとなげ/大人げ/大人気"},"大人気":{"variants":"おとなげ/大人げ/大人気"},"おとなしい":{"variants":"おとなしい/大人しい"},"大人しい":{"variants":"おとなしい/大人しい"},"おとなびる":{"variants":"おとなびる/大人びる"},"大人びる":{"variants":"おとなびる/大人びる"},"お酉さま":{"variants":"お酉さま/御酉様"},"御酉様":{"variants":"お酉さま/御酉様"},"おとる":{"variants":"おとる/劣る"},"劣る":{"variants":"おとる/劣る"},"おとろえる":{"variants":"おとろえる/衰える"},"衰える":{"variants":"おとろえる/衰える"},"おどおど":{"variants":"おどおど/オドオド"},"オドオド":{"variants":"おどおど/オドオド"},"おどかす":{"variants":"おどかす/威かす"},"威かす":{"variants":"おどかす/威かす"},"おどしつける":{"variants":"おどしつける/脅しつける/脅し付ける"},"脅しつける":{"variants":"おどしつける/脅しつける/脅し付ける"},"脅し付ける":{"variants":"おどしつける/脅しつける/脅し付ける"},"おどしとる":{"variants":"おどしとる/脅し取る"},"脅し取る":{"variants":"おどしとる/脅し取る"},"おどす":{"variants":"おどす/威す/脅す/縅す"},"踊":{"variants":"踊/踊り"},"踊り":{"variants":"踊/踊り"},"おどりあかす":{"variants":"おどりあかす/踊りあかす"},"踊りあかす":{"variants":"おどりあかす/踊りあかす"},"おどりあがる":{"variants":"おどりあがる/おどり上がる/躍り上がる"},"おどり上がる":{"variants":"おどりあがる/おどり上がる/躍り上がる"},"躍り上がる":{"variants":"おどりあがる/おどり上がる/躍り上がる"},"おどりかかる":{"variants":"おどりかかる/躍りかかる/躍り掛る"},"躍りかかる":{"variants":"おどりかかる/躍りかかる/躍り掛る"},"躍り掛る":{"variants":"おどりかかる/躍りかかる/躍り掛る"},"踊り子":{"variants":"踊り子/踊子"},"踊子":{"variants":"踊り子/踊子"},"オドリコソウ":{"variants":"オドリコソウ/踊り子草/踊子草"},"踊り子草":{"variants":"オドリコソウ/踊り子草/踊子草"},"踊子草":{"variants":"オドリコソウ/踊り子草/踊子草"},"おどりこむ":{"variants":"おどりこむ/躍り込む"},"躍り込む":{"variants":"おどりこむ/躍り込む"},"おどりでる":{"variants":"おどりでる/おどり出る/躍りでる/躍り出る"},"おどり出る":{"variants":"おどりでる/おどり出る/躍りでる/躍り出る"},"躍りでる":{"variants":"おどりでる/おどり出る/躍りでる/躍り出る"},"躍り出る":{"variants":"おどりでる/おどり出る/躍りでる/躍り出る"},"踊り念仏":{"variants":"踊り念仏/踊念仏"},"踊念仏":{"variants":"踊り念仏/踊念仏"},"踊り場":{"variants":"踊り場/踊場"},"踊場":{"variants":"踊り場/踊場"},"おどる":{"variants":"おどる/躍る/踊る"},"おどれる":{"variants":"おどれる/踊れる"},"踊れる":{"variants":"おどれる/踊れる"},"おどろかす":{"variants":"おどろかす/驚かす"},"驚かす":{"variants":"おどろかす/驚かす"},"おどろきいる":{"variants":"おどろきいる/驚き入る"},"驚き入る":{"variants":"おどろきいる/驚き入る"},"おどろく":{"variants":"おどろく/驚く"},"驚く":{"variants":"おどろく/驚く"},"同いどし":{"variants":"同いどし/同い年"},"同い年":{"variants":"同いどし/同い年"},"おなか":{"variants":"おなか/お腹"},"お腹":{"variants":"おなか/お腹"},"オナガ":{"variants":"オナガ/尾長"},"尾長":{"variants":"オナガ/尾長"},"オナガドリ":{"variants":"オナガドリ/尾長鶏"},"尾長鶏":{"variants":"オナガドリ/尾長鶏"},"おなじ":{"variants":"おなじ/同じ"},"同じ":{"variants":"おなじ/同じ"},"おなじく":{"variants":"おなじく/同じく"},"同じく":{"variants":"おなじく/同じく"},"おなら":{"variants":"おなら/オナラ"},"オナラ":{"variants":"おなら/オナラ"},"オニアザミ":{"variants":"オニアザミ/鬼あざみ/鬼薊"},"鬼あざみ":{"variants":"オニアザミ/鬼あざみ/鬼薊"},"鬼薊":{"variants":"オニアザミ/鬼あざみ/鬼薊"},"鬼がわら":{"variants":"鬼がわら/鬼瓦"},"鬼瓦":{"variants":"鬼がわら/鬼瓦"},"おにぎり":{"variants":"おにぎり/お握り"},"お握り":{"variants":"おにぎり/お握り"},"オニグモ":{"variants":"オニグモ/鬼蜘蛛"},"鬼蜘蛛":{"variants":"オニグモ/鬼蜘蛛"},"鬼ばば":{"variants":"鬼ばば/鬼婆"},"鬼婆":{"variants":"鬼ばば/鬼婆"},"オニユリ":{"variants":"オニユリ/鬼百合"},"鬼百合":{"variants":"オニユリ/鬼百合"},"おのおの":{"variants":"おのおの/各々"},"各々":{"variants":"おのおの/各々"},"おのがじし":{"variants":"おのがじし/己がじし"},"己がじし":{"variants":"おのがじし/己がじし"},"おのずから":{"variants":"おのずから/自ずから"},"自ずから":{"variants":"おのずから/自ずから"},"おのずと":{"variants":"おのずと/自ずと"},"自ずと":{"variants":"おのずと/自ずと"},"おののく":{"variants":"おののく/戦く"},"戦く":{"variants":"おののく/戦く"},"お上りさん":{"variants":"お上りさん/オノボリさん"},"オノボリさん":{"variants":"お上りさん/オノボリさん"},"おのれ":{"variants":"おのれ/己"},"己":{"variants":"おのれ/己"},"オハグロトンボ":{"variants":"オハグロトンボ/鉄漿蜻蛉"},"鉄漿蜻蛉":{"variants":"オハグロトンボ/鉄漿蜻蛉"},"お鉢めぐり":{"variants":"お鉢めぐり/御鉢巡り"},"御鉢巡り":{"variants":"お鉢めぐり/御鉢巡り"},"お話":{"variants":"お話/お話し"},"お話し":{"variants":"お話/お話し"},"おはよう":{"variants":"おはよう/お早う"},"お早う":{"variants":"おはよう/お早う"},"おはらい":{"variants":"おはらい/お祓い/御祓"},"お祓い":{"variants":"おはらい/お祓い/御祓"},"御祓":{"variants":"おはらい/お祓い/御祓"},"おはらい箱":{"variants":"おはらい箱/お払い箱"},"お払い箱":{"variants":"おはらい箱/お払い箱"},"おばあさん":{"variants":"おばあさん/お祖母さん/お婆さん"},"おばけ":{"variants":"おばけ/お化け/オバケ"},"お化け":{"variants":"おばけ/お化け/オバケ"},"オバケ":{"variants":"おばけ/お化け/オバケ"},"おばさん":{"variants":"おばさん/オバさん/オバサン/叔母さん"},"オバさん":{"variants":"おばさん/オバさん/オバサン/叔母さん"},"オバサン":{"variants":"おばさん/オバさん/オバサン/叔母さん"},"叔母さん":{"variants":"おばさん/オバさん/オバサン/叔母さん"},"オバナ":{"variants":"オバナ/尾花/雄花"},"お引き受け":{"variants":"お引き受け/お引受け"},"お引受け":{"variants":"お引き受け/お引受け"},"お人好し":{"variants":"お人好し/御人好し"},"御人好し":{"variants":"お人好し/御人好し"},"お姫さま":{"variants":"お姫さま/お姫様"},"お姫様":{"variants":"お姫さま/お姫様"},"お百度":{"variants":"お百度/御百度"},"御百度":{"variants":"お百度/御百度"},"尾ひれ":{"variants":"尾ひれ/尾ヒレ"},"尾ヒレ":{"variants":"尾ひれ/尾ヒレ"},"おびえる":{"variants":"おびえる/怯える/脅える"},"おびきだす":{"variants":"おびきだす/おびき出す/誘き出す"},"おびき出す":{"variants":"おびきだす/おびき出す/誘き出す"},"誘き出す":{"variants":"おびきだす/おびき出す/誘き出す"},"おびきだせる":{"variants":"おびきだせる/おびき出せる"},"おびき出せる":{"variants":"おびきだせる/おびき出せる"},"おびきよせる":{"variants":"おびきよせる/おびき寄せる/誘きよせる/誘き寄せる"},"おびき寄せる":{"variants":"おびきよせる/おびき寄せる/誘きよせる/誘き寄せる"},"誘きよせる":{"variants":"おびきよせる/おびき寄せる/誘きよせる/誘き寄せる"},"誘き寄せる":{"variants":"おびきよせる/おびき寄せる/誘きよせる/誘き寄せる"},"おびく":{"variants":"おびく/誘く"},"誘く":{"variants":"おびく/誘く"},"おびただしい":{"variants":"おびただしい/夥しい"},"夥しい":{"variants":"おびただしい/夥しい"},"帯留":{"variants":"帯留/帯留め"},"帯留め":{"variants":"帯留/帯留め"},"おびる":{"variants":"おびる/帯びる"},"帯びる":{"variants":"おびる/帯びる"},"尾びれ":{"variants":"尾びれ/尾ビレ/尾鰭"},"尾ビレ":{"variants":"尾びれ/尾ビレ/尾鰭"},"尾鰭":{"variants":"尾びれ/尾ビレ/尾鰭"},"おふくろ":{"variants":"おふくろ/お袋"},"お袋":{"variants":"おふくろ/お袋"},"お福わけ":{"variants":"お福わけ/お福分け"},"お福分け":{"variants":"お福わけ/お福分け"},"お布施":{"variants":"お布施/御布施"},"御布施":{"variants":"お布施/御布施"},"お触れ":{"variants":"お触れ/御触れ"},"御触れ":{"variants":"お触れ/御触れ"},"おぶさる":{"variants":"おぶさる/負ぶさる"},"負ぶさる":{"variants":"おぶさる/負ぶさる"},"覚え書き":{"variants":"覚え書き/覚書"},"覚書":{"variants":"覚え書き/覚書"},"おぼえこむ":{"variants":"おぼえこむ/覚え込む"},"覚え込む":{"variants":"おぼえこむ/覚え込む"},"おぼえず":{"variants":"おぼえず/覚えず"},"覚えず":{"variants":"おぼえず/覚えず"},"おぼえる":{"variants":"おぼえる/憶える/覚える"},"おぼしい":{"variants":"おぼしい/思しい"},"思しい":{"variants":"おぼしい/思しい"},"思し召し":{"variants":"思し召し/思召"},"思召":{"variants":"思し召し/思召"},"おぼしめす":{"variants":"おぼしめす/思し召す"},"思し召す":{"variants":"おぼしめす/思し召す"},"おぼす":{"variants":"おぼす/思す"},"思す":{"variants":"おぼす/思す"},"おぼつかない":{"variants":"おぼつかない/覚束無い"},"覚束無い":{"variants":"おぼつかない/覚束無い"},"おぼらす":{"variants":"おぼらす/溺らす"},"溺らす":{"variants":"おぼらす/溺らす"},"おぼれ谷":{"variants":"おぼれ谷/溺れ谷"},"溺れ谷":{"variants":"おぼれ谷/溺れ谷"},"おぼれる":{"variants":"おぼれる/溺れる"},"溺れる":{"variants":"おぼれる/溺れる"},"おぼろ":{"variants":"おぼろ/朧"},"朧":{"variants":"おぼろ/朧"},"おぼろ月":{"variants":"おぼろ月/朧月"},"朧月":{"variants":"おぼろ月/朧月"},"おぼろ月夜":{"variants":"おぼろ月夜/朧月夜"},"朧月夜":{"variants":"おぼろ月夜/朧月夜"},"お参り":{"variants":"お参り/御参り"},"御参り":{"variants":"お参り/御参り"},"おまえ":{"variants":"おまえ/お前"},"お前":{"variants":"おまえ/お前"},"おまじない":{"variants":"おまじない/オマジナイ"},"オマジナイ":{"variants":"おまじない/オマジナイ"},"お松":{"variants":"お松/オマツ/雄松"},"オマツ":{"variants":"お松/オマツ/雄松"},"雄松":{"variants":"お松/オマツ/雄松"},"お祭":{"variants":"お祭/お祭り"},"お祭り":{"variants":"お祭/お祭り"},"お祭り騒ぎ":{"variants":"お祭り騒ぎ/お祭騒ぎ"},"お祭騒ぎ":{"variants":"お祭り騒ぎ/お祭騒ぎ"},"お神酒":{"variants":"お神酒/御神酒"},"御神酒":{"variants":"お神酒/御神酒"},"おみこし":{"variants":"おみこし/お神輿/御神輿"},"お神輿":{"variants":"おみこし/お神輿/御神輿"},"御神輿":{"variants":"おみこし/お神輿/御神輿"},"オミナエシ":{"variants":"オミナエシ/女郎花"},"女郎花":{"variants":"オミナエシ/女郎花"},"お見舞":{"variants":"お見舞/御見舞/御見舞い"},"御見舞":{"variants":"お見舞/御見舞/御見舞い"},"御見舞い":{"variants":"お見舞/御見舞/御見舞い"},"お迎え":{"variants":"お迎え/御迎え"},"御迎え":{"variants":"お迎え/御迎え"},"お襁褓":{"variants":"お襁褓/オムツ"},"オムツ":{"variants":"お襁褓/オムツ"},"お召":{"variants":"お召/御召"},"御召":{"variants":"お召/御召"},"お召し物":{"variants":"お召し物/御召物"},"御召物":{"variants":"お召し物/御召物"},"おめにかかる":{"variants":"おめにかかる/お目にかかる"},"お目にかかる":{"variants":"おめにかかる/お目にかかる"},"お目見得":{"variants":"お目見得/御目見得"},"御目見得":{"variants":"お目見得/御目見得"},"おもい":{"variants":"おもい/重い"},"重い":{"variants":"おもい/重い"},"おもいあがる":{"variants":"おもいあがる/思い上がる"},"思い上がる":{"variants":"おもいあがる/思い上がる"},"おもいあたる":{"variants":"おもいあたる/思いあたる/思い当たる/思い当る"},"思いあたる":{"variants":"おもいあたる/思いあたる/思い当たる/思い当る"},"思い当たる":{"variants":"おもいあたる/思いあたる/思い当たる/思い当る"},"思い当る":{"variants":"おもいあたる/思いあたる/思い当たる/思い当る"},"おもいあまる":{"variants":"おもいあまる/思いあまる/思い余る"},"思いあまる":{"variants":"おもいあまる/思いあまる/思い余る"},"思い余る":{"variants":"おもいあまる/思いあまる/思い余る"},"おもいあわせる":{"variants":"おもいあわせる/思いあわせる/思い合せる/思い合わせる"},"思いあわせる":{"variants":"おもいあわせる/思いあわせる/思い合せる/思い合わせる"},"思い合せる":{"variants":"おもいあわせる/思いあわせる/思い合せる/思い合わせる"},"思い合わせる":{"variants":"おもいあわせる/思いあわせる/思い合せる/思い合わせる"},"おもいうかべる":{"variants":"おもいうかべる/思い浮かべる"},"思い浮かべる":{"variants":"おもいうかべる/思い浮かべる"},"おもいおこす":{"variants":"おもいおこす/思いおこす/思い起こす/思い起す"},"思いおこす":{"variants":"おもいおこす/思いおこす/思い起こす/思い起す"},"思い起こす":{"variants":"おもいおこす/思いおこす/思い起こす/思い起す"},"思い起す":{"variants":"おもいおこす/思いおこす/思い起こす/思い起す"},"おもいおこせる":{"variants":"おもいおこせる/思い起こせる"},"思い起こせる":{"variants":"おもいおこせる/思い起こせる"},"おもいおよぶ":{"variants":"おもいおよぶ/思い及ぶ"},"思い及ぶ":{"variants":"おもいおよぶ/思い及ぶ"},"おもいかえす":{"variants":"おもいかえす/思いかえす/思い返す"},"思いかえす":{"variants":"おもいかえす/思いかえす/思い返す"},"思い返す":{"variants":"おもいかえす/思いかえす/思い返す"},"おもいがけない":{"variants":"おもいがけない/思いがけない"},"思いがけない":{"variants":"おもいがけない/思いがけない"},"おもいがける":{"variants":"おもいがける/思いがける"},"思いがける":{"variants":"おもいがける/思いがける"},"おもいきり":{"variants":"おもいきり/思いきり/思い切り"},"思いきり":{"variants":"思いきり/思い切り"},"思い切り":{"variants":"思いきり/思い切り"},"おもいきる":{"variants":"おもいきる/思いきる/思い切る"},"思いきる":{"variants":"おもいきる/思いきる/思い切る"},"思い切る":{"variants":"おもいきる/思いきる/思い切る"},"おもいきれる":{"variants":"おもいきれる/思い切れる"},"思い切れる":{"variants":"おもいきれる/思い切れる"},"おもいこむ":{"variants":"おもいこむ/思いこむ/思い込む"},"思いこむ":{"variants":"おもいこむ/思いこむ/思い込む"},"思い込む":{"variants":"おもいこむ/思いこむ/思い込む"},"おもいしらせる":{"variants":"おもいしらせる/思い知らせる"},"思い知らせる":{"variants":"おもいしらせる/思い知らせる"},"おもいしる":{"variants":"おもいしる/思い知る"},"思い知る":{"variants":"おもいしる/思い知る"},"思いすごし":{"variants":"思いすごし/思い過し"},"思い過し":{"variants":"思いすごし/思い過し"},"おもいすごす":{"variants":"おもいすごす/思い過ごす"},"思い過ごす":{"variants":"おもいすごす/思い過ごす"},"おもいたつ":{"variants":"おもいたつ/思いたつ/思い立つ"},"思いたつ":{"variants":"おもいたつ/思いたつ/思い立つ"},"思い立つ":{"variants":"おもいたつ/思いたつ/思い立つ"},"おもいだす":{"variants":"おもいだす/思いだす/思い出す"},"思いだす":{"variants":"おもいだす/思いだす/思い出す"},"思い出す":{"variants":"おもいだす/思いだす/思い出す"},"おもいだせる":{"variants":"おもいだせる/思い出せる"},"思い出せる":{"variants":"おもいだせる/思い出せる"},"思いちがい":{"variants":"思いちがい/思い違い"},"思い違い":{"variants":"思いちがい/思い違い"},"思いっきり":{"variants":"思いっきり/思いっ切り"},"思いっ切り":{"variants":"思いっきり/思いっ切り"},"思いつき":{"variants":"思いつき/思い付き"},"思い付き":{"variants":"思いつき/思い付き"},"おもいつく":{"variants":"おもいつく/思いつく/思い付く"},"思いつく":{"variants":"おもいつく/思いつく/思い付く"},"思い付く":{"variants":"おもいつく/思いつく/思い付く"},"おもいつめる":{"variants":"おもいつめる/思いつめる/思い詰める"},"思いつめる":{"variants":"おもいつめる/思いつめる/思い詰める"},"思い詰める":{"variants":"おもいつめる/思いつめる/思い詰める"},"おもいで":{"variants":"おもいで/思い出/想い出"},"おもいとどまる":{"variants":"おもいとどまる/思いとどまる/思い止まる"},"思いとどまる":{"variants":"おもいとどまる/思いとどまる/思い止まる"},"思い止まる":{"variants":"おもいとどまる/思いとどまる/思い止まる"},"おもいとどまれる":{"variants":"おもいとどまれる/思いとどまれる"},"思いとどまれる":{"variants":"おもいとどまれる/思いとどまれる"},"おもいとまる":{"variants":"おもいとまる/思い止る"},"思い止る":{"variants":"おもいとまる/思い止る"},"おもいなおす":{"variants":"おもいなおす/思いなおす/思い直す"},"思いなおす":{"variants":"おもいなおす/思いなおす/思い直す"},"思い直す":{"variants":"おもいなおす/思いなおす/思い直す"},"おもいなおせる":{"variants":"おもいなおせる/思い直せる"},"思い直せる":{"variants":"おもいなおせる/思い直せる"},"おもいなし":{"variants":"おもいなし/思いなし"},"思いなし":{"variants":"おもいなし/思いなし"},"おもいなす":{"variants":"おもいなす/思いなす"},"思いなす":{"variants":"おもいなす/思いなす"},"おもいなやむ":{"variants":"おもいなやむ/思い悩む"},"思い悩む":{"variants":"おもいなやむ/思い悩む"},"おもいのこす":{"variants":"おもいのこす/思い残す"},"思い残す":{"variants":"おもいのこす/思い残す"},"思いのたけ":{"variants":"思いのたけ/思いの丈"},"思いの丈":{"variants":"思いのたけ/思いの丈"},"思いのほか":{"variants":"思いのほか/思いの外"},"思いの外":{"variants":"思いのほか/思いの外"},"おもいまどう":{"variants":"おもいまどう/思いまどう"},"思いまどう":{"variants":"おもいまどう/思いまどう"},"おもいまどえる":{"variants":"おもいまどえる/思いまどえる"},"思いまどえる":{"variants":"おもいまどえる/思いまどえる"},"おもいみだれる":{"variants":"おもいみだれる/思い乱れる"},"思い乱れる":{"variants":"おもいみだれる/思い乱れる"},"おもいめぐらす":{"variants":"おもいめぐらす/思いめぐらす"},"思いめぐらす":{"variants":"おもいめぐらす/思いめぐらす"},"おもいもうける":{"variants":"おもいもうける/思い設ける"},"思い設ける":{"variants":"おもいもうける/思い設ける"},"思いやり":{"variants":"思いやり/思い遣り"},"思い遣り":{"variants":"思いやり/思い遣り"},"おもいやる":{"variants":"おもいやる/思いやる"},"思いやる":{"variants":"おもいやる/思いやる"},"おもいわずらう":{"variants":"おもいわずらう/思いわずらう/思い煩う"},"思いわずらう":{"variants":"おもいわずらう/思いわずらう/思い煩う"},"思い煩う":{"variants":"おもいわずらう/思いわずらう/思い煩う"},"おもう":{"variants":"おもう/思う/想う"},"おもうさま":{"variants":"おもうさま/思うさま/思う様"},"思うさま":{"variants":"おもうさま/思うさま/思う様"},"思う様":{"variants":"おもうさま/思うさま/思う様"},"おもうぞんぶん":{"variants":"おもうぞんぶん/思う存分"},"思う存分":{"variants":"おもうぞんぶん/思う存分"},"思うつぼ":{"variants":"思うつぼ/思う壷"},"思う壷":{"variants":"思うつぼ/思う壷"},"おもえる":{"variants":"おもえる/思える/想える"},"おもおもしい":{"variants":"おもおもしい/重々しい/重重しい"},"重々しい":{"variants":"おもおもしい/重々しい/重重しい"},"重重しい":{"variants":"おもおもしい/重々しい/重重しい"},"おもかじ":{"variants":"おもかじ/面舵"},"面舵":{"variants":"おもかじ/面舵"},"おもくるしい":{"variants":"おもくるしい/重苦しい"},"重苦しい":{"variants":"おもくるしい/重苦しい"},"面差":{"variants":"面差/面差し"},"面差し":{"variants":"面差/面差し"},"おもし":{"variants":"おもし/重し/重石"},"重し":{"variants":"おもし/重し/重石"},"重石":{"variants":"おもし/重し/重石"},"おもしろい":{"variants":"おもしろい/面白い"},"面白い":{"variants":"おもしろい/面白い"},"面白み":{"variants":"面白み/面白味"},"面白味":{"variants":"面白み/面白味"},"おもたい":{"variants":"おもたい/重たい"},"重たい":{"variants":"おもたい/重たい"},"オモダカ":{"variants":"オモダカ/沢瀉"},"沢瀉":{"variants":"オモダカ/沢瀉"},"おもだつ":{"variants":"おもだつ/主立つ/重立つ"},"おもちゃ":{"variants":"おもちゃ/オモチャ"},"オモチャ":{"variants":"おもちゃ/オモチャ"},"表替":{"variants":"表替/表替え"},"表替え":{"variants":"表替/表替え"},"表ざた":{"variants":"表ざた/表沙汰"},"表沙汰":{"variants":"表ざた/表沙汰"},"おもてだつ":{"variants":"おもてだつ/表立つ"},"表立つ":{"variants":"おもてだつ/表立つ"},"おもて向き":{"variants":"おもて向き/表向き"},"表向き":{"variants":"おもて向き/表向き"},"オモト":{"variants":"オモト/御許/万年青"},"おもに":{"variants":"おもに/主に"},"主に":{"variants":"おもに/主に"},"おもねる":{"variants":"おもねる/阿る"},"阿る":{"variants":"おもねる/阿る"},"おもはゆい":{"variants":"おもはゆい/面映ゆい"},"面映ゆい":{"variants":"おもはゆい/面映ゆい"},"おもへらく":{"variants":"おもへらく/思へらく"},"思へらく":{"variants":"おもへらく/思へらく"},"おもほす":{"variants":"おもほす/思ほす"},"思ほす":{"variants":"おもほす/思ほす"},"趣":{"variants":"趣/趣き"},"趣き":{"variants":"趣/趣き"},"おもむく":{"variants":"おもむく/赴く"},"赴く":{"variants":"おもむく/赴く"},"おもむろに":{"variants":"おもむろに/徐に"},"徐に":{"variants":"おもむろに/徐に"},"面もち":{"variants":"面もち/面持/面持ち"},"面持":{"variants":"面もち/面持/面持ち"},"面持ち":{"variants":"面もち/面持/面持ち"},"おもり":{"variants":"おもり/オモリ/重り"},"オモリ":{"variants":"おもり/オモリ/重り"},"重り":{"variants":"おもり/オモリ/重り"},"おもる":{"variants":"おもる/重る"},"重る":{"variants":"おもる/重る"},"おもわしい":{"variants":"おもわしい/思わしい"},"思わしい":{"variants":"おもわしい/思わしい"},"思わせぶり":{"variants":"思わせぶり/思わせ振り"},"思わせ振り":{"variants":"思わせぶり/思わせ振り"},"おもんじる":{"variants":"おもんじる/重んじる"},"重んじる":{"variants":"おもんじる/重んじる"},"おもんずる":{"variants":"おもんずる/重んずる"},"重んずる":{"variants":"おもんずる/重んずる"},"おもんばかる":{"variants":"おもんばかる/慮る"},"慮る":{"variants":"おもんばかる/慮る"},"おもんみる":{"variants":"おもんみる/惟みる"},"惟みる":{"variants":"おもんみる/惟みる"},"親代り":{"variants":"親代り/親代わり"},"親代わり":{"variants":"親代り/親代わり"},"おや子":{"variants":"おや子/親子"},"親子":{"variants":"おや子/親子"},"親子づれ":{"variants":"親子づれ/親子連れ"},"親子連れ":{"variants":"親子づれ/親子連れ"},"親ごころ":{"variants":"親ごころ/親心"},"親心":{"variants":"親ごころ/親心"},"おやじ":{"variants":"おやじ/オヤジ/親仁/親爺"},"オヤジ":{"variants":"おやじ/オヤジ/親仁/親爺"},"おやすみ":{"variants":"おやすみ/オヤスミ"},"オヤスミ":{"variants":"おやすみ/オヤスミ"},"親ばか":{"variants":"親ばか/親馬鹿"},"親馬鹿":{"variants":"親ばか/親馬鹿"},"親もと":{"variants":"親もと/親許/親元"},"親ゆずり":{"variants":"親ゆずり/親譲り"},"親譲り":{"variants":"親ゆずり/親譲り"},"およぎつく":{"variants":"およぎつく/泳ぎ着く"},"泳ぎ着く":{"variants":"およぎつく/泳ぎ着く"},"およぎつける":{"variants":"およぎつける/泳ぎ着ける"},"泳ぎ着ける":{"variants":"およぎつける/泳ぎ着ける"},"およぐ":{"variants":"およぐ/泳ぐ/游ぐ"},"およげる":{"variants":"およげる/泳げる"},"泳げる":{"variants":"およげる/泳げる"},"および":{"variants":"および/及び"},"及び":{"variants":"および/及び"},"およぶ":{"variants":"およぶ/及ぶ"},"及ぶ":{"variants":"およぶ/及ぶ"},"およぼす":{"variants":"およぼす/及ぼす"},"及ぼす":{"variants":"およぼす/及ぼす"},"およぼせる":{"variants":"およぼせる/及ぼせる"},"及ぼせる":{"variants":"およぼせる/及ぼせる"},"おり":{"variants":"おり/折"},"オリ":{"variants":"おり/オリ/汚吏/折/檻"},"折":{"variants":"おり/折"},"折りあい":{"variants":"折りあい/折り合い/折合い"},"折り合い":{"variants":"折りあい/折り合い/折合い"},"折合い":{"variants":"折りあい/折り合い/折合い"},"おりあう":{"variants":"おりあう/折り合う/折合う"},"折り合う":{"variants":"おりあう/折り合う/折合う"},"折合う":{"variants":"おりあう/折り合う/折合う"},"おりあえる":{"variants":"おりあえる/折りあえる/折り合える"},"折りあえる":{"variants":"おりあえる/折りあえる/折り合える"},"折り合える":{"variants":"おりあえる/折りあえる/折り合える"},"おりあげる":{"variants":"おりあげる/織りあげる/織り上げる"},"織りあげる":{"variants":"おりあげる/織りあげる/織り上げる"},"織り上げる":{"variants":"おりあげる/織りあげる/織り上げる"},"折々":{"variants":"折々/折折"},"折折":{"variants":"折々/折折"},"折りかえし":{"variants":"折りかえし/折り返し/折返し"},"折り返し":{"variants":"折りかえし/折り返し/折返し"},"折返し":{"variants":"折りかえし/折り返し/折返し"},"おりかえす":{"variants":"おりかえす/折りかえす/折り返す/折返す"},"折りかえす":{"variants":"おりかえす/折りかえす/折り返す/折返す"},"折り返す":{"variants":"おりかえす/折りかえす/折り返す/折返す"},"折返す":{"variants":"おりかえす/折りかえす/折り返す/折返す"},"おりかえせる":{"variants":"おりかえせる/折り返せる"},"折り返せる":{"variants":"おりかえせる/折り返せる"},"おりかさなる":{"variants":"おりかさなる/折りかさなる/折り重なる/折重なる"},"折りかさなる":{"variants":"おりかさなる/折りかさなる/折り重なる/折重なる"},"折り重なる":{"variants":"おりかさなる/折りかさなる/折り重なる/折重なる"},"折重なる":{"variants":"おりかさなる/折りかさなる/折り重なる/折重なる"},"おりかさねる":{"variants":"おりかさねる/折りかさねる/折り重ねる/折重ねる"},"折りかさねる":{"variants":"おりかさねる/折りかさねる/折り重ねる/折重ねる"},"折り重ねる":{"variants":"おりかさねる/折りかさねる/折り重ねる/折重ねる"},"折重ねる":{"variants":"おりかさねる/折りかさねる/折り重ねる/折重ねる"},"おり紙":{"variants":"おり紙/折り紙"},"折り紙":{"variants":"おり紙/折り紙"},"折り紙付き":{"variants":"折り紙付き/折紙付"},"折紙付":{"variants":"折り紙付き/折紙付"},"折込":{"variants":"折り込み/折込/折込み"},"折り込み":{"variants":"折り込み/折込/折込み"},"折込み":{"variants":"折り込み/折込/折込み"},"おりこむ":{"variants":"おりこむ/織りこむ/織り込む/織込む/折りこむ/折り込む/折込む"},"折り込む":{"variants":"おりこむ/折りこむ/折り込む/折込む"},"折りこむ":{"variants":"おりこむ/折りこむ/折り込む/折込む"},"折込む":{"variants":"おりこむ/折りこむ/折り込む/折込む"},"織り込む":{"variants":"おりこむ/織りこむ/織り込む/織込む"},"織りこむ":{"variants":"おりこむ/織りこむ/織り込む/織込む"},"織込む":{"variants":"おりこむ/織りこむ/織り込む/織込む"},"おりこめる":{"variants":"おりこめる/織り込める/折り込める"},"おりしも":{"variants":"おりしも/折しも"},"折しも":{"variants":"おりしも/折しも"},"おりたたむ":{"variants":"おりたたむ/折りたたむ/折り畳む/折畳む"},"折りたたむ":{"variants":"おりたたむ/折りたたむ/折り畳む/折畳む"},"折り畳む":{"variants":"おりたたむ/折りたたむ/折り畳む/折畳む"},"折畳む":{"variants":"おりたたむ/折りたたむ/折り畳む/折畳む"},"おりたためる":{"variants":"おりたためる/折り畳める"},"折り畳める":{"variants":"おりたためる/折り畳める"},"おりたつ":{"variants":"おりたつ/下り立つ/下立つ/降り立つ"},"下り立つ":{"variants":"おりたつ/下り立つ/下立つ"},"下立つ":{"variants":"おりたつ/下り立つ/下立つ"},"折り詰め":{"variants":"折り詰め/折詰"},"折詰":{"variants":"折り詰め/折詰"},"折り鶴":{"variants":"折り鶴/折鶴"},"折鶴":{"variants":"折り鶴/折鶴"},"おりなす":{"variants":"おりなす/織りなす/織り成す/織成す"},"織りなす":{"variants":"おりなす/織りなす/織り成す/織成す"},"織り成す":{"variants":"おりなす/織りなす/織り成す/織成す"},"織成す":{"variants":"おりなす/織りなす/織り成す/織成す"},"折り箱":{"variants":"折り箱/折箱"},"折箱":{"variants":"折り箱/折箱"},"織り姫":{"variants":"織り姫/織姫"},"織姫":{"variants":"織り姫/織姫"},"折ふし":{"variants":"折ふし/折節"},"折節":{"variants":"折ふし/折節"},"おりまげる":{"variants":"おりまげる/折り曲げる"},"折り曲げる":{"variants":"おりまげる/折り曲げる"},"おりまぜる":{"variants":"おりまぜる/織りまぜる"},"織りまぜる":{"variants":"おりまぜる/織りまぜる"},"折り目":{"variants":"折り目/折目"},"折目":{"variants":"折り目/折目"},"織り目":{"variants":"織り目/織目"},"織目":{"variants":"織り目/織目"},"織り物":{"variants":"織り物/織物"},"織物":{"variants":"織り物/織物"},"おりる":{"variants":"おりる/下りる/降りる"},"おる":{"variants":"おる/居る/織る/折る"},"おれ":{"variants":"おれ/オレ/俺"},"オレ":{"variants":"おれ/オレ/俺"},"俺":{"variants":"おれ/オレ/俺"},"おれあう":{"variants":"おれあう/折れ合う"},"折れ合う":{"variants":"おれあう/折れ合う"},"おれあえる":{"variants":"おれあえる/折れ合える"},"折れ合える":{"variants":"おれあえる/折れ合える"},"お礼":{"variants":"お礼/御礼"},"御礼":{"variants":"お礼/御礼"},"お礼参り":{"variants":"お礼参り/御礼参り"},"御礼参り":{"variants":"お礼参り/御礼参り"},"お歴々":{"variants":"お歴々/お歴歴"},"お歴歴":{"variants":"お歴々/お歴歴"},"折れくぎ":{"variants":"折れくぎ/折れ釘"},"折れ釘":{"variants":"折れくぎ/折れ釘"},"折れくち":{"variants":"折れくち/折れ口"},"折れ口":{"variants":"折れくち/折れ口"},"おれこむ":{"variants":"おれこむ/折れ込む"},"折れ込む":{"variants":"おれこむ/折れ込む"},"折れ線":{"variants":"折れ線/折線"},"折線":{"variants":"折れ線/折線"},"おれまがる":{"variants":"おれまがる/折れ曲がる"},"折れ曲がる":{"variants":"おれまがる/折れ曲がる"},"おれる":{"variants":"おれる/織れる/折れる"},"おろおろ":{"variants":"おろおろ/オロオロ"},"オロオロ":{"variants":"おろおろ/オロオロ"},"おろか":{"variants":"おろか/愚か"},"愚か":{"variants":"オロカ/愚か"},"オロカ":{"variants":"オロカ/愚か"},"おろかしい":{"variants":"おろかしい/愚かしい"},"愚かしい":{"variants":"おろかしい/愚かしい"},"愚かもの":{"variants":"愚かもの/愚か者"},"愚か者":{"variants":"愚かもの/愚か者"},"卸売":{"variants":"卸売/卸売り"},"卸売り":{"variants":"卸売/卸売り"},"おろし金":{"variants":"おろし金/卸金/下し金/下ろし金"},"下し金":{"variants":"おろし金/下し金/下ろし金"},"下ろし金":{"variants":"おろし金/下し金/下ろし金"},"おろす":{"variants":"おろす/卸す/下ろす/降ろす"},"おろせる":{"variants":"おろせる/下ろせる/降ろせる"},"おわす":{"variants":"おわす/負わす"},"負わす":{"variants":"おわす/負わす"},"おわび":{"variants":"おわび/お詫び"},"お詫び":{"variants":"おわび/お詫び"},"おわらす":{"variants":"おわらす/終わらす"},"終わらす":{"variants":"おわらす/終わらす"},"おわらせる":{"variants":"おわらせる/終わらせる"},"終わらせる":{"variants":"おわらせる/終わらせる"},"終わり値":{"variants":"終わり値/終値"},"終値":{"variants":"終わり値/終値"},"おわる":{"variants":"おわる/終る/終わる"},"終る":{"variants":"おわる/終る/終わる"},"終わる":{"variants":"おわる/終る/終わる"},"Å":{"variants":"Å/オングストローム"},"オングストローム":{"variants":"Å/オングストローム"},"恩しゅう":{"variants":"恩しゅう/恩讎"},"恩讎":{"variants":"恩しゅう/恩讎"},"オンチ":{"variants":"オンチ/音痴/御地"},"音頭取":{"variants":"音頭取/音頭取り"},"音頭取り":{"variants":"音頭取/音頭取り"},"おんどり":{"variants":"おんどり/雄鶏/雄鳥"},"オンドル":{"variants":"オンドル/温突"},"温突":{"variants":"オンドル/温突"},"女ごころ":{"variants":"女ごころ/女心"},"女心":{"variants":"女ごころ/女心"},"女ずき":{"variants":"女ずき/女好き"},"女好き":{"variants":"女ずき/女好き"},"女たらし":{"variants":"女たらし/女誑し"},"女誑し":{"variants":"女たらし/女誑し"},"おんなの子":{"variants":"おんなの子/女のコ/女の子"},"女のコ":{"variants":"おんなの子/女のコ/女の子"},"女の子":{"variants":"おんなの子/女のコ/女の子"},"女もの":{"variants":"女もの/女物"},"女物":{"variants":"女もの/女物"},"おんならしい":{"variants":"おんならしい/女らしい"},"女らしい":{"variants":"おんならしい/女らしい"},"おん念":{"variants":"おん念/怨念"},"怨念":{"variants":"おん念/怨念"},"おんば":{"variants":"おんば/穏婆"},"穏婆":{"variants":"おんば/穏婆"},"かあさん":{"variants":"かあさん/母さん"},"母さん":{"variants":"かあさん/母さん"},"カイ":{"variants":"カイ/下位/下意/歌意/会/回/怪/皆/貝/峡/甲斐/買い/櫂/隗"},"かいあがる":{"variants":"かいあがる/買い上がる"},"買い上がる":{"variants":"かいあがる/買い上がる"},"買い上げ":{"variants":"買い上げ/買上/買上げ"},"買上":{"variants":"買い上げ/買上/買上げ"},"買上げ":{"variants":"買い上げ/買上/買上げ"},"かいあげる":{"variants":"かいあげる/買い上げる"},"買い上げる":{"variants":"かいあげる/買い上げる"},"かいあさる":{"variants":"かいあさる/買いあさる/買い漁る"},"買いあさる":{"variants":"かいあさる/買いあさる/買い漁る"},"買い漁る":{"variants":"かいあさる/買いあさる/買い漁る"},"かいあたえる":{"variants":"かいあたえる/買い与える"},"買い与える":{"variants":"かいあたえる/買い与える"},"貝あわせ":{"variants":"貝あわせ/貝合せ"},"貝合せ":{"variants":"貝あわせ/貝合せ"},"かいいれる":{"variants":"かいいれる/買い入れる/買入れる"},"買い入れる":{"variants":"かいいれる/買い入れる/買入れる"},"買入れる":{"variants":"かいいれる/買い入れる/買入れる"},"かいうける":{"variants":"かいうける/買い受ける/買受ける"},"買い受ける":{"variants":"かいうける/買い受ける/買受ける"},"買受ける":{"variants":"かいうける/買い受ける/買受ける"},"飼いおけ":{"variants":"飼いおけ/飼い桶"},"飼い桶":{"variants":"飼いおけ/飼い桶"},"かいかえる":{"variants":"かいかえる/買い換える/買い替える"},"買い掛け":{"variants":"買い掛け/買掛/買掛け"},"買掛":{"variants":"買い掛け/買掛/買掛け"},"買掛け":{"variants":"買い掛け/買掛/買掛け"},"かいかぶる":{"variants":"かいかぶる/買いかぶる/買い被る"},"買いかぶる":{"variants":"かいかぶる/買いかぶる/買い被る"},"買い被る":{"variants":"かいかぶる/買いかぶる/買い被る"},"かいがいしい":{"variants":"かいがいしい/甲斐甲斐しい"},"甲斐甲斐しい":{"variants":"かいがいしい/甲斐甲斐しい"},"カイガラ":{"variants":"カイガラ/貝がら/貝殻"},"貝がら":{"variants":"カイガラ/貝がら/貝殻"},"貝殻":{"variants":"カイガラ/貝がら/貝殻"},"カイガラボネ":{"variants":"カイガラボネ/貝殻骨"},"貝殻骨":{"variants":"カイガラボネ/貝殻骨"},"カイガラムシ":{"variants":"カイガラムシ/貝殻虫"},"貝殻虫":{"variants":"カイガラムシ/貝殻虫"},"買気":{"variants":"買い気/買気"},"買い気":{"variants":"買い気/買気"},"かいきる":{"variants":"かいきる/買い切る/買切る"},"買い切る":{"variants":"かいきる/買い切る/買切る"},"買切る":{"variants":"かいきる/買い切る/買切る"},"かいきれる":{"variants":"かいきれる/買い切れる"},"買い切れる":{"variants":"かいきれる/買い切れる"},"かいくぐる":{"variants":"かいくぐる/掻い潜る"},"掻い潜る":{"variants":"かいくぐる/掻い潜る"},"かいくる":{"variants":"かいくる/掻い繰る"},"掻い繰る":{"variants":"かいくる/掻い繰る"},"買いぐすり":{"variants":"買いぐすり/買い薬/買薬"},"買い薬":{"variants":"買いぐすり/買い薬/買薬"},"買薬":{"variants":"買いぐすり/買い薬/買薬"},"カイケイ":{"variants":"カイケイ/塊茎"},"塊茎":{"variants":"カイケイ/塊茎"},"かいこす":{"variants":"かいこす/買い越す"},"買い越す":{"variants":"かいこす/買い越す"},"買い言葉":{"variants":"買い言葉/買言葉"},"買言葉":{"variants":"買い言葉/買言葉"},"かいこむ":{"variants":"かいこむ/掻い込む/買いこむ/買い込む/買込む"},"買込む":{"variants":"かいこむ/買いこむ/買い込む/買込む"},"買い込む":{"variants":"かいこむ/買いこむ/買い込む/買込む"},"買いこむ":{"variants":"かいこむ/買いこむ/買い込む/買込む"},"かいこめる":{"variants":"かいこめる/買い込める"},"買い込める":{"variants":"かいこめる/買い込める"},"カイコン":{"variants":"カイコン/塊根/悔恨/皆婚"},"飼い殺し":{"variants":"飼い殺し/飼殺し"},"飼殺し":{"variants":"飼い殺し/飼殺し"},"快さい":{"variants":"快さい/快哉"},"快哉":{"variants":"快さい/快哉"},"改ざん":{"variants":"改ざん/改竄"},"改竄":{"variants":"改ざん/改竄"},"買い占め":{"variants":"買い占め/買占め"},"買占め":{"variants":"買い占め/買占め"},"かいしめる":{"variants":"かいしめる/買いしめる/買い占める/買占める"},"買いしめる":{"variants":"かいしめる/買いしめる/買い占める/買占める"},"買い占める":{"variants":"かいしめる/買いしめる/買い占める/買占める"},"買占める":{"variants":"かいしめる/買いしめる/買い占める/買占める"},"改悛":{"variants":"改しゅん/改悛"},"改しゅん":{"variants":"改しゅん/改悛"},"かいしゅん":{"variants":"かいしゅん/回春"},"回春":{"variants":"かいしゅん/回春"},"かい書":{"variants":"かい書/楷書"},"楷書":{"variants":"かい書/楷書"},"かい性":{"variants":"かい性/甲斐性"},"甲斐性":{"variants":"かい性/甲斐性"},"カイジュウ":{"variants":"カイジュウ/怪獣/晦渋/海獣"},"かい人":{"variants":"かい人/怪人"},"怪人":{"variants":"かい人/怪人"},"かいす":{"variants":"かいす/介す/会す"},"かいすすむ":{"variants":"かいすすむ/買い進む"},"買い進む":{"variants":"かいすすむ/買い進む"},"かいする":{"variants":"かいする/介する"},"介する":{"variants":"かいする/介する"},"カイゼルひげ":{"variants":"カイゼルひげ/カイゼル髭"},"カイゼル髭":{"variants":"カイゼルひげ/カイゼル髭"},"カイソウ":{"variants":"カイソウ/海草/海藻/階層"},"介添":{"variants":"介添/介添え"},"介添え":{"variants":"介添/介添え"},"かいたたく":{"variants":"かいたたく/買いたたく/買い叩く"},"買いたたく":{"variants":"かいたたく/買いたたく/買い叩く"},"買い叩く":{"variants":"かいたたく/買いたたく/買い叩く"},"かいたたける":{"variants":"かいたたける/買いたたける"},"買いたたける":{"variants":"かいたたける/買いたたける"},"買い出し":{"variants":"買い出し/買出し"},"買出し":{"variants":"買い出し/買出し"},"かいだす":{"variants":"かいだす/かい出す/掻い出す"},"かい出す":{"variants":"かいだす/かい出す/掻い出す"},"掻い出す":{"variants":"かいだす/かい出す/掻い出す"},"買いだめ":{"variants":"買いだめ/買い貯め"},"買い貯め":{"variants":"買いだめ/買い貯め"},"かいつくす":{"variants":"かいつくす/買い尽くす"},"買い尽くす":{"variants":"かいつくす/買い尽くす"},"かいつくろう":{"variants":"かいつくろう/掻い繕う"},"掻い繕う":{"variants":"かいつくろう/掻い繕う"},"買い付け":{"variants":"買い付け/買付け"},"買付け":{"variants":"買い付け/買付け"},"かいつける":{"variants":"かいつける/買いつける/買い付ける"},"買いつける":{"variants":"かいつける/買いつける/買い付ける"},"買い付ける":{"variants":"かいつける/買いつける/買い付ける"},"かいつまむ":{"variants":"かいつまむ/かい摘む/掻い摘む"},"かい摘む":{"variants":"かいつまむ/かい摘む/掻い摘む"},"掻い摘む":{"variants":"かいつまむ/かい摘む/掻い摘む"},"買い手":{"variants":"買い手/買手"},"買手":{"variants":"買い手/買手"},"買い取り":{"variants":"買い取り/買取"},"買取":{"variants":"買い取り/買取"},"かいとる":{"variants":"かいとる/買い取る/買取る"},"買い取る":{"variants":"かいとる/買い取る/買取る"},"買取る":{"variants":"かいとる/買い取る/買取る"},"かいとれる":{"variants":"かいとれる/買い取れる"},"買い取れる":{"variants":"かいとれる/買い取れる"},"カイドウ":{"variants":"カイドウ/会堂/怪童/海道/海棠/街道"},"買い得":{"variants":"買い得/買得"},"買得":{"variants":"買い得/買得"},"飼い鳥":{"variants":"飼い鳥/飼鳥"},"飼鳥":{"variants":"飼い鳥/飼鳥"},"かいならす":{"variants":"かいならす/飼い慣らす"},"飼い慣らす":{"variants":"かいならす/飼い慣らす"},"飼主":{"variants":"飼い主/飼主"},"買い主":{"variants":"買い主/買主"},"飼い主":{"variants":"飼い主/飼主"},"買主":{"variants":"買い主/買主"},"カイバ":{"variants":"カイバ/海馬/飼い葉/飼葉"},"飼葉":{"variants":"カイバ/飼い葉/飼葉"},"飼い葉":{"variants":"カイバ/飼い葉/飼葉"},"カイバシラ":{"variants":"カイバシラ/貝柱"},"貝柱":{"variants":"カイバシラ/貝柱"},"カイヒョウ":{"variants":"カイヒョウ/界標"},"界標":{"variants":"カイヒョウ/界標"},"開びゃく":{"variants":"開びゃく/開闢"},"開闢":{"variants":"開びゃく/開闢"},"かいまみる":{"variants":"かいまみる/かいま見る/垣間みる/垣間見る"},"かいま見る":{"variants":"かいまみる/かいま見る/垣間みる/垣間見る"},"垣間みる":{"variants":"かいまみる/かいま見る/垣間みる/垣間見る"},"垣間見る":{"variants":"かいまみる/かいま見る/垣間みる/垣間見る"},"カイメン":{"variants":"カイメン/海綿/海面/界面"},"カイメンドウブツ":{"variants":"カイメンドウブツ/海綿動物"},"海綿動物":{"variants":"カイメンドウブツ/海綿動物"},"かいもく":{"variants":"かいもく/皆目"},"皆目":{"variants":"かいもく/皆目"},"かいもとめる":{"variants":"かいもとめる/買い求める"},"買い求める":{"variants":"かいもとめる/買い求める"},"かいもどす":{"variants":"かいもどす/買い戻す/買戻す"},"買い戻す":{"variants":"かいもどす/買い戻す/買戻す"},"買戻す":{"variants":"かいもどす/買い戻す/買戻す"},"かいもどせる":{"variants":"かいもどせる/買い戻せる"},"買い戻せる":{"variants":"かいもどせる/買い戻せる"},"買いもの":{"variants":"買いもの/買い物/買物"},"買い物":{"variants":"買いもの/買い物/買物"},"買物":{"variants":"買いもの/買い物/買物"},"貝焼":{"variants":"貝焼/貝焼き"},"貝焼き":{"variants":"貝焼/貝焼き"},"かいよう":{"variants":"かいよう/海容/海洋/潰瘍"},"回覧":{"variants":"回らん/回覧"},"回らん":{"variants":"回らん/回覧"},"かい離":{"variants":"かい離/解離/乖離"},"カイリ":{"variants":"カイリ/海里/浬"},"カイロウドウケツ":{"variants":"カイロウドウケツ/偕老同穴"},"偕老同穴":{"variants":"カイロウドウケツ/偕老同穴"},"かいわい":{"variants":"かいわい/界わい/界隈"},"界わい":{"variants":"かいわい/界わい/界隈"},"界隈":{"variants":"かいわい/界わい/界隈"},"かう":{"variants":"かう/交う/支う/飼う/買う"},"替え歌":{"variants":"替え歌/替歌"},"替歌":{"variants":"替え歌/替歌"},"かえし縫い":{"variants":"かえし縫い/返し縫い"},"返し縫い":{"variants":"かえし縫い/返し縫い"},"かえす":{"variants":"かえす/還す/返す/孵す"},"かえすがえす":{"variants":"かえすがえす/返すがえす/返す返す"},"返すがえす":{"variants":"かえすがえす/返すがえす/返す返す"},"返す返す":{"variants":"かえすがえす/返すがえす/返す返す"},"かえせる":{"variants":"かえせる/帰せる/返せる"},"替え玉":{"variants":"替え玉/替玉"},"替玉":{"variants":"替え玉/替玉"},"替え地":{"variants":"替え地/替地"},"替地":{"variants":"替え地/替地"},"かえって":{"variants":"かえって/却って"},"却って":{"variants":"かえって/却って"},"カエデ":{"variants":"カエデ/楓"},"楓":{"variants":"カエデ/楓"},"返り討ち":{"variants":"返り討ち/返討"},"返討":{"variants":"返り討ち/返討"},"返り咲き":{"variants":"返り咲き/返咲き"},"返咲き":{"variants":"返り咲き/返咲き"},"かえりざく":{"variants":"かえりざく/返り咲く"},"返り咲く":{"variants":"かえりざく/返り咲く"},"かえりざける":{"variants":"かえりざける/返り咲ける"},"返り咲ける":{"variants":"かえりざける/返り咲ける"},"帰り支度":{"variants":"帰り支度/帰支度"},"帰支度":{"variants":"帰り支度/帰支度"},"かえりみる":{"variants":"かえりみる/顧みる/省みる"},"かえる":{"variants":"かえる/カエる/還る/帰る/返る/孵る"},"カエる":{"variants":"かえる/カエる/還る/帰る/返る/孵る"},"かえれる":{"variants":"かえれる/帰れる"},"帰れる":{"variants":"かえれる/帰れる"},"かお":{"variants":"かお/顔"},"顔":{"variants":"かお/顔"},"顔合せ":{"variants":"顔合せ/顔合わせ"},"顔合わせ":{"variants":"顔合せ/顔合わせ"},"顔かたち":{"variants":"顔かたち/顔貌"},"顔貌":{"variants":"顔かたち/顔貌"},"顔つき":{"variants":"顔つき/顔付き"},"顔付き":{"variants":"顔つき/顔付き"},"顔つなぎ":{"variants":"顔つなぎ/顔繋ぎ"},"顔繋ぎ":{"variants":"顔つなぎ/顔繋ぎ"},"顔なじみ":{"variants":"顔なじみ/顔馴染/顔馴染み"},"顔馴染":{"variants":"顔なじみ/顔馴染/顔馴染み"},"顔馴染み":{"variants":"顔なじみ/顔馴染/顔馴染み"},"顔ぶれ":{"variants":"顔ぶれ/顔触れ"},"顔触れ":{"variants":"顔ぶれ/顔触れ"},"かおる":{"variants":"かおる/馨る/薫る/香る"},"呵々":{"variants":"呵々/呵呵"},"呵呵":{"variants":"呵々/呵呵"},"かかあ天下":{"variants":"かかあ天下/嬶天下"},"嬶天下":{"variants":"かかあ天下/嬶天下"},"かかえこむ":{"variants":"かかえこむ/かかえ込む/抱えこむ/抱え込む"},"かかえ込む":{"variants":"かかえこむ/かかえ込む/抱えこむ/抱え込む"},"抱えこむ":{"variants":"かかえこむ/かかえ込む/抱えこむ/抱え込む"},"抱え込む":{"variants":"かかえこむ/かかえ込む/抱えこむ/抱え込む"},"かかえる":{"variants":"かかえる/抱える"},"抱える":{"variants":"かかえる/抱える"},"かかげる":{"variants":"かかげる/掲げる"},"掲げる":{"variants":"かかげる/掲げる"},"かかす":{"variants":"かかす/欠かす"},"欠かす":{"variants":"かかす/欠かす"},"係り":{"variants":"係/係り"},"係":{"variants":"がかり/係"},"かかりあう":{"variants":"かかりあう/かかり合う/掛かり合う/掛り合う"},"かかり合う":{"variants":"かかりあう/かかり合う/掛かり合う/掛り合う"},"掛かり合う":{"variants":"かかりあう/かかり合う/掛かり合う/掛り合う"},"掛り合う":{"variants":"かかりあう/かかり合う/掛かり合う/掛り合う"},"係りむすび":{"variants":"係りむすび/係り結び/係結び"},"係り結び":{"variants":"係りむすび/係り結び/係結び"},"係結び":{"variants":"係りむすび/係り結び/係結び"},"かかり湯":{"variants":"かかり湯/掛り湯"},"掛り湯":{"variants":"かかり湯/掛り湯"},"かかる":{"variants":"かかる/架かる/架る/掛かる/掛る/係る/繋る/懸かる/懸る/罹る"},"懸かる":{"variants":"かかる/懸かる/懸る"},"懸る":{"variants":"かかる/懸かる/懸る"},"架かる":{"variants":"かかる/架かる/架る"},"掛かる":{"variants":"かかる/掛かる/掛る"},"架る":{"variants":"かかる/架かる/架る"},"掛る":{"variants":"かかる/掛かる/掛る"},"かかれる":{"variants":"かかれる/掛かれる"},"掛かれる":{"variants":"かかれる/掛かれる"},"かかわり":{"variants":"かかわり/関わり"},"関わり":{"variants":"かかわり/関わり"},"かかわりあう":{"variants":"かかわりあう/かかわり合う"},"かかわり合う":{"variants":"かかわりあう/かかわり合う"},"かかわる":{"variants":"かかわる/関わる/係わる/拘る/拘わる"},"拘る":{"variants":"かかわる/拘る/拘わる"},"拘わる":{"variants":"かかわる/拘る/拘わる"},"カカン":{"variants":"カカン/果敢/花冠"},"鏡もち":{"variants":"鏡もち/鏡餅"},"鏡餅":{"variants":"鏡もち/鏡餅"},"かがむ":{"variants":"かがむ/屈む"},"屈む":{"variants":"かがむ/屈む"},"かがやかしい":{"variants":"かがやかしい/輝かしい/耀かしい"},"かがやかす":{"variants":"かがやかす/輝かす/耀かす"},"かがやく":{"variants":"かがやく/輝く/耀く"},"かがり火":{"variants":"かがり火/篝火"},"篝火":{"variants":"かがり火/篝火"},"かがる":{"variants":"かがる/縢る"},"縢る":{"variants":"かがる/縢る"},"カキ":{"variants":"カキ/牡蛎/下記/夏期/夏季/火器/火気/花き/花器/花期/花卉/垣/柿/蛎"},"花期":{"variants":"カキ/花き/花期"},"花き":{"variants":"カキ/花き/花器/花期/花卉"},"花器":{"variants":"カキ/花き/花器"},"花卉":{"variants":"カキ/花き/花卉"},"かき揚げ":{"variants":"かき揚げ/掻揚げ"},"掻揚げ":{"variants":"かき揚げ/掻揚げ"},"かきあげる":{"variants":"かきあげる/かき揚げる/書きあげる/書き上げる"},"書き上げる":{"variants":"かきあげる/書きあげる/書き上げる"},"書きあげる":{"variants":"かきあげる/書きあげる/書き上げる"},"かきあつめる":{"variants":"かきあつめる/かき集める/掻き集める"},"かき集める":{"variants":"かきあつめる/かき集める/掻き集める"},"掻き集める":{"variants":"かきあつめる/かき集める/掻き集める"},"かきあらわす":{"variants":"かきあらわす/書き表す"},"書き表す":{"variants":"かきあらわす/書き表す"},"かきあらわせる":{"variants":"かきあらわせる/書き表せる"},"書き表せる":{"variants":"かきあらわせる/書き表せる"},"かきあわせる":{"variants":"かきあわせる/かき合せる/掻き合せる"},"かき合せる":{"variants":"かきあわせる/かき合せる/掻き合せる"},"掻き合せる":{"variants":"かきあわせる/かき合せる/掻き合せる"},"書き入れ":{"variants":"書き入れ/書入れ"},"書入れ":{"variants":"書き入れ/書入れ"},"かきいれ時":{"variants":"かきいれ時/書き入れ時/書入れどき/書入れ時"},"書き入れ時":{"variants":"かきいれ時/書き入れ時/書入れどき/書入れ時"},"書入れどき":{"variants":"かきいれ時/書き入れ時/書入れどき/書入れ時"},"書入れ時":{"variants":"かきいれ時/書き入れ時/書入れどき/書入れ時"},"かきいれる":{"variants":"かきいれる/書きいれる/書き入れる/書入れる"},"書きいれる":{"variants":"かきいれる/書きいれる/書き入れる/書入れる"},"書き入れる":{"variants":"かきいれる/書きいれる/書き入れる/書入れる"},"書入れる":{"variants":"かきいれる/書きいれる/書き入れる/書入れる"},"書き置き":{"variants":"書き置き/書置"},"書置":{"variants":"書き置き/書置"},"かきおくる":{"variants":"かきおくる/書き送る/書送る"},"書き送る":{"variants":"かきおくる/書き送る/書送る"},"書送る":{"variants":"かきおくる/書き送る/書送る"},"かきおこす":{"variants":"かきおこす/書き起す/掻き起す"},"かきおとす":{"variants":"かきおとす/かき落とす/書き落す/書き落とす"},"かき落とす":{"variants":"かきおとす/かき落とす/書き落す/書き落とす"},"書き落す":{"variants":"かきおとす/かき落とす/書き落す/書き落とす"},"書き落とす":{"variants":"かきおとす/かき落とす/書き落す/書き落とす"},"書下し":{"variants":"書下し/書下ろし"},"書下ろし":{"variants":"書下し/書下ろし"},"かきおろす":{"variants":"かきおろす/書き下ろす"},"書き下ろす":{"variants":"かきおろす/書き下ろす"},"書き換え":{"variants":"書き換え/書換え"},"書換え":{"variants":"書き換え/書換え"},"かきかえる":{"variants":"かきかえる/書き換える/書換える"},"書き換える":{"variants":"かきかえる/書き換える/書換える"},"書換える":{"variants":"かきかえる/書き換える/書換える"},"書きかた":{"variants":"書きかた/書き方"},"書き方":{"variants":"書きかた/書き方"},"かききえる":{"variants":"かききえる/かき消える/掻き消える"},"かき消える":{"variants":"かききえる/かき消える/掻き消える"},"掻き消える":{"variants":"かききえる/かき消える/掻き消える"},"かきくだす":{"variants":"かきくだす/書き下す/書下す"},"書き下す":{"variants":"かきくだす/書き下す/書下す"},"書下す":{"variants":"かきくだす/書き下す/書下す"},"かきくどく":{"variants":"かきくどく/掻き口説く"},"掻き口説く":{"variants":"かきくどく/掻き口説く"},"かきくもる":{"variants":"かきくもる/かき曇る/掻き曇る"},"かき曇る":{"variants":"かきくもる/かき曇る/掻き曇る"},"掻き曇る":{"variants":"かきくもる/かき曇る/掻き曇る"},"かきくらす":{"variants":"かきくらす/かき暗す/掻き暗す"},"かき暗す":{"variants":"かきくらす/かき暗す/掻き暗す"},"掻き暗す":{"variants":"かきくらす/かき暗す/掻き暗す"},"かきくれる":{"variants":"かきくれる/かき暮れる/掻き暮れる"},"かき暮れる":{"variants":"かきくれる/かき暮れる/掻き暮れる"},"掻き暮れる":{"variants":"かきくれる/かき暮れる/掻き暮れる"},"かきけす":{"variants":"かきけす/かき消す"},"かき消す":{"variants":"かきけす/かき消す"},"かきけせる":{"variants":"かきけせる/かき消せる"},"かき消せる":{"variants":"かきけせる/かき消せる"},"書きことば":{"variants":"書きことば/書き言葉"},"書き言葉":{"variants":"書きことば/書き言葉"},"書き込み":{"variants":"書き込み/書込み"},"書込み":{"variants":"書き込み/書込み"},"かきこむ":{"variants":"かきこむ/かき込む/書き込む/掻き込む"},"かき込む":{"variants":"かきこむ/かき込む/書き込む/掻き込む"},"かきこめる":{"variants":"かきこめる/書き込める"},"書き込める":{"variants":"かきこめる/書き込める"},"かきさす":{"variants":"かきさす/書きさす"},"書きさす":{"variants":"かきさす/書きさす"},"かきしるす":{"variants":"かきしるす/書き記す/書記す"},"書き記す":{"variants":"かきしるす/書き記す/書記す"},"書記す":{"variants":"かきしるす/書き記す/書記す"},"かきしるせる":{"variants":"かきしるせる/書き記せる"},"書き記せる":{"variants":"かきしるせる/書き記せる"},"かきすてる":{"variants":"かきすてる/書き捨てる/書捨てる"},"書き捨てる":{"variants":"かきすてる/書き捨てる/書捨てる"},"書捨てる":{"variants":"かきすてる/書き捨てる/書捨てる"},"かきそえる":{"variants":"かきそえる/書き添える/書添える"},"書き添える":{"variants":"かきそえる/書き添える/書添える"},"書添える":{"variants":"かきそえる/書き添える/書添える"},"書き初め":{"variants":"書き初め/書初め"},"書初め":{"variants":"書き初め/書初め"},"かきたてる":{"variants":"かきたてる/かき立てる/書きたてる/書き立てる/書立てる/掻きたてる/掻き立てる"},"かき立てる":{"variants":"かきたてる/かき立てる/書きたてる/書き立てる/書立てる/掻きたてる/掻き立てる"},"掻き立てる":{"variants":"かきたてる/かき立てる/掻きたてる/掻き立てる"},"書きたてる":{"variants":"かきたてる/かき立てる/書きたてる/書き立てる/書立てる"},"掻きたてる":{"variants":"かきたてる/かき立てる/掻きたてる/掻き立てる"},"書立てる":{"variants":"かきたてる/かき立てる/書きたてる/書き立てる/書立てる"},"書き立てる":{"variants":"かきたてる/かき立てる/書きたてる/書き立てる/書立てる"},"書き出し":{"variants":"書き出し/書出し"},"書出し":{"variants":"書き出し/書出し"},"かきだす":{"variants":"かきだす/かき出す/書き出す/書出す/掻き出す"},"かき出す":{"variants":"かきだす/かき出す/書き出す/書出す/掻き出す"},"書出す":{"variants":"かきだす/かき出す/書き出す/書出す"},"書き出す":{"variants":"かきだす/かき出す/書き出す/書出す"},"かきだせる":{"variants":"かきだせる/書き出せる"},"書き出せる":{"variants":"かきだせる/書き出せる"},"かきちらす":{"variants":"かきちらす/書き散らす/書散らす"},"書き散らす":{"variants":"かきちらす/書き散らす/書散らす"},"書散らす":{"variants":"かきちらす/書き散らす/書散らす"},"書付":{"variants":"書付/書付け"},"書付け":{"variants":"書付/書付け"},"かきつける":{"variants":"かきつける/書きつける/書き付ける/書付ける"},"書きつける":{"variants":"かきつける/書きつける/書き付ける/書付ける"},"書き付ける":{"variants":"かきつける/書きつける/書き付ける/書付ける"},"書付ける":{"variants":"かきつける/書きつける/書き付ける/書付ける"},"カキツバタ":{"variants":"カキツバタ/燕子花/杜若"},"書き留め":{"variants":"書き留め/書留"},"書留":{"variants":"書き留め/書留"},"かきとめる":{"variants":"かきとめる/書きとめる/書き留める/書留める"},"書きとめる":{"variants":"かきとめる/書きとめる/書き留める/書留める"},"書き留める":{"variants":"かきとめる/書きとめる/書き留める/書留める"},"書留める":{"variants":"かきとめる/書きとめる/書き留める/書留める"},"かきとる":{"variants":"かきとる/書きとる/書き取る/書取る"},"書きとる":{"variants":"かきとる/書きとる/書き取る/書取る"},"書き取る":{"variants":"かきとる/書きとる/書き取る/書取る"},"書取る":{"variants":"かきとる/書きとる/書き取る/書取る"},"かきなおす":{"variants":"かきなおす/書き直す"},"書き直す":{"variants":"かきなおす/書き直す"},"かきなおせる":{"variants":"かきなおせる/書き直せる"},"書き直せる":{"variants":"かきなおせる/書き直せる"},"かきながす":{"variants":"かきながす/書き流す/書流す"},"書き流す":{"variants":"かきながす/書き流す/書流す"},"書流す":{"variants":"かきながす/書き流す/書流す"},"かきなぐる":{"variants":"かきなぐる/書きなぐる"},"書きなぐる":{"variants":"かきなぐる/書きなぐる"},"かきなす":{"variants":"かきなす/かき鳴す/書き成す/掻き鳴す"},"かき鳴す":{"variants":"かきなす/かき鳴す/掻き鳴す"},"掻き鳴す":{"variants":"かきなす/かき鳴す/掻き鳴す"},"かきならす":{"variants":"かきならす/かき鳴らす/掻き鳴らす"},"かき鳴らす":{"variants":"かきならす/かき鳴らす/掻き鳴らす"},"掻き鳴らす":{"variants":"かきならす/かき鳴らす/掻き鳴らす"},"かきぬく":{"variants":"かきぬく/書きぬく/書き抜く/書抜く"},"書きぬく":{"variants":"かきぬく/書きぬく/書き抜く/書抜く"},"書き抜く":{"variants":"かきぬく/書きぬく/書き抜く/書抜く"},"書抜く":{"variants":"かきぬく/書きぬく/書き抜く/書抜く"},"かきぬける":{"variants":"かきぬける/書き抜ける"},"書き抜ける":{"variants":"かきぬける/書き抜ける"},"垣ね":{"variants":"垣ね/垣根"},"垣根":{"variants":"垣ね/垣根"},"かきのこす":{"variants":"かきのこす/書き残す/書残す"},"書き残す":{"variants":"かきのこす/書き残す/書残す"},"書残す":{"variants":"かきのこす/書き残す/書残す"},"かきのこせる":{"variants":"かきのこせる/書き残せる"},"書き残せる":{"variants":"かきのこせる/書き残せる"},"書き判":{"variants":"書き判/書判"},"書判":{"variants":"書き判/書判"},"かきふるす":{"variants":"かきふるす/書き古す"},"書き古す":{"variants":"かきふるす/書き古す"},"かきまぜる":{"variants":"かきまぜる/かき混ぜる/掻きまぜる/掻き混ぜる"},"かき混ぜる":{"variants":"かきまぜる/かき混ぜる/掻きまぜる/掻き混ぜる"},"掻きまぜる":{"variants":"かきまぜる/かき混ぜる/掻きまぜる/掻き混ぜる"},"掻き混ぜる":{"variants":"かきまぜる/かき混ぜる/掻きまぜる/掻き混ぜる"},"かきまわす":{"variants":"かきまわす/かき回す/掻き回す"},"かき回す":{"variants":"かきまわす/かき回す/掻き回す"},"掻き回す":{"variants":"かきまわす/かき回す/掻き回す"},"かきみだす":{"variants":"かきみだす/かき乱す/掻き乱す"},"かき乱す":{"variants":"かきみだす/かき乱す/掻き乱す"},"掻き乱す":{"variants":"かきみだす/かき乱す/掻き乱す"},"かきむしる":{"variants":"かきむしる/掻きむしる/掻き毟る"},"掻きむしる":{"variants":"かきむしる/掻きむしる/掻き毟る"},"掻き毟る":{"variants":"かきむしる/掻きむしる/掻き毟る"},"かきゅうてき":{"variants":"かきゅうてき/可及的"},"可及的":{"variants":"かきゅうてき/可及的"},"かきよせる":{"variants":"かきよせる/かき寄せる"},"かき寄せる":{"variants":"かきよせる/かき寄せる"},"かきわける":{"variants":"かきわける/かき分ける/書き分ける/書分ける/掻き分ける"},"かき分ける":{"variants":"かきわける/かき分ける/書き分ける/書分ける/掻き分ける"},"書分ける":{"variants":"かきわける/かき分ける/書き分ける/書分ける"},"書き分ける":{"variants":"かきわける/かき分ける/書き分ける/書分ける"},"欠割り":{"variants":"欠き割り/欠割り"},"欠き割り":{"variants":"欠き割り/欠割り"},"かぎ":{"variants":"かぎ/カギ/科技/鈎/鍵/鉤"},"カギ":{"variants":"かぎ/カギ/科技/鈎/鍵/鉤"},"かぎあてる":{"variants":"かぎあてる/嗅ぎ当てる"},"嗅ぎ当てる":{"variants":"かぎあてる/嗅ぎ当てる"},"かぎ裂き":{"variants":"かぎ裂き/鉤裂き"},"鉤裂き":{"variants":"かぎ裂き/鉤裂き"},"嗅ぎたばこ":{"variants":"嗅ぎたばこ/嗅ぎ煙草/嗅煙草"},"嗅ぎ煙草":{"variants":"嗅ぎたばこ/嗅ぎ煙草/嗅煙草"},"嗅煙草":{"variants":"嗅ぎたばこ/嗅ぎ煙草/嗅煙草"},"かぎだす":{"variants":"かぎだす/かぎ出す/嗅ぎ出す"},"かぎ出す":{"variants":"かぎだす/かぎ出す/嗅ぎ出す"},"嗅ぎ出す":{"variants":"かぎだす/かぎ出す/嗅ぎ出す"},"かぎだせる":{"variants":"かぎだせる/かぎ出せる"},"かぎ出せる":{"variants":"かぎだせる/かぎ出せる"},"かぎっ子":{"variants":"かぎっ子/鍵っこ/鍵っ子"},"鍵っこ":{"variants":"かぎっ子/鍵っこ/鍵っ子"},"鍵っ子":{"variants":"かぎっ子/鍵っこ/鍵っ子"},"かぎつける":{"variants":"かぎつける/嗅ぎつける/嗅ぎ付ける"},"嗅ぎつける":{"variants":"かぎつける/嗅ぎつける/嗅ぎ付ける"},"嗅ぎ付ける":{"variants":"かぎつける/嗅ぎつける/嗅ぎ付ける"},"かぎ鼻":{"variants":"かぎ鼻/鉤鼻"},"鉤鼻":{"variants":"かぎ鼻/鉤鼻"},"かぎ針":{"variants":"かぎ針/鉤針"},"鉤針":{"variants":"かぎ針/鉤針"},"かぎゅう":{"variants":"かぎゅう/蝸牛"},"蝸牛":{"variants":"かぎゅう/蝸牛"},"かぎり":{"variants":"かぎり/限り"},"限り":{"variants":"かぎり/限り"},"かぎる":{"variants":"かぎる/限る"},"限る":{"variants":"かぎる/限る"},"かぎれる":{"variants":"かぎれる/限れる"},"限れる":{"variants":"かぎれる/限れる"},"かく":{"variants":"かく/斯く/斯ク"},"斯く":{"variants":"かく/斯く/斯ク"},"斯ク":{"variants":"かく/斯く/斯ク"},"カク":{"variants":"カク/格/核"},"かくい":{"variants":"かくい/角い"},"角い":{"variants":"かくい/角い"},"かくかく":{"variants":"かくかく/斯くかく/斯く斯く"},"斯くかく":{"variants":"かくかく/斯くかく/斯く斯く"},"斯く斯く":{"variants":"かくかく/斯くかく/斯く斯く"},"赫々":{"variants":"赫々/赫赫"},"赫赫":{"variants":"赫々/赫赫"},"かくしきばる":{"variants":"かくしきばる/格式張る"},"格式張る":{"variants":"かくしきばる/格式張る"},"隠しくぎ":{"variants":"隠しくぎ/隠し釘"},"隠し釘":{"variants":"隠しくぎ/隠し釘"},"かくし芸":{"variants":"かくし芸/隠し芸"},"隠し芸":{"variants":"かくし芸/隠し芸"},"かくし子":{"variants":"かくし子/隠し子"},"隠し子":{"variants":"かくし子/隠し子"},"隠しごと":{"variants":"隠しごと/隠し事"},"隠し事":{"variants":"隠しごと/隠し事"},"隠しだて":{"variants":"隠しだて/隠し立て"},"隠し立て":{"variants":"隠しだて/隠し立て"},"かくしもつ":{"variants":"かくしもつ/隠し持つ"},"隠し持つ":{"variants":"かくしもつ/隠し持つ"},"かくしもてる":{"variants":"かくしもてる/隠し持てる"},"隠し持てる":{"variants":"かくしもてる/隠し持てる"},"かくす":{"variants":"かくす/隠す/画す"},"かくする":{"variants":"かくする/画する/劃する"},"覚醒":{"variants":"覚せい/覚醒"},"覚せい":{"variants":"覚せい/覚醒"},"かくせる":{"variants":"かくせる/隠せる"},"隠せる":{"variants":"かくせる/隠せる"},"かくぜんと":{"variants":"かくぜんと/画然と"},"画然と":{"variants":"かくぜんと/画然と"},"角とう":{"variants":"角とう/角灯"},"角灯":{"variants":"角とう/角灯"},"かくばる":{"variants":"かくばる/角張る"},"角張る":{"variants":"かくばる/角張る"},"かくべつ":{"variants":"かくべつ/格別"},"格別":{"variants":"かくべつ/格別"},"かくまう":{"variants":"かくまう/匿う"},"匿う":{"variants":"かくまう/匿う"},"かく乱":{"variants":"かく乱/撹乱/攪乱"},"隔り":{"variants":"隔り/隔離"},"隔離":{"variants":"隔り/隔離"},"かくれミノ":{"variants":"かくれミノ/隠れみの/隠れ蓑"},"隠れみの":{"variants":"かくれミノ/隠れみの/隠れ蓑"},"隠れ蓑":{"variants":"かくれミノ/隠れみの/隠れ蓑"},"かくれる":{"variants":"かくれる/隠れる"},"隠れる":{"variants":"かくれる/隠れる"},"隠れんぼう":{"variants":"隠れんぼう/隠れん坊"},"隠れん坊":{"variants":"隠れんぼう/隠れん坊"},"かぐ":{"variants":"かぐ/嗅ぐ"},"嗅ぐ":{"variants":"かぐ/嗅ぐ"},"かぐろい":{"variants":"かぐろい/か黒い"},"か黒い":{"variants":"かぐろい/か黒い"},"かぐわしい":{"variants":"かぐわしい/馨しい/香しい"},"かけ":{"variants":"かけ/掛け/欠け/賭/賭け"},"賭":{"variants":"かけ/賭/賭け"},"賭け":{"variants":"かけ/賭/賭け"},"かけあい":{"variants":"かけあい/掛け合い/掛合/掛合い"},"掛け合い":{"variants":"かけあい/掛け合い/掛合/掛合い"},"掛合":{"variants":"かけあい/掛け合い/掛合/掛合い"},"掛合い":{"variants":"かけあい/掛け合い/掛合/掛合い"},"かけあう":{"variants":"かけあう/かけ合う/掛け合う/掛合う"},"かけ合う":{"variants":"かけあう/かけ合う/掛け合う/掛合う"},"掛け合う":{"variants":"かけあう/かけ合う/掛け合う/掛合う"},"掛合う":{"variants":"かけあう/かけ合う/掛け合う/掛合う"},"かけあえる":{"variants":"かけあえる/掛け合える"},"掛け合える":{"variants":"かけあえる/掛け合える"},"かけあわす":{"variants":"かけあわす/掛け合わす"},"掛け合わす":{"variants":"かけあわす/掛け合わす"},"かけあわせる":{"variants":"かけあわせる/かけ合せる/掛け合せる"},"かけ合せる":{"variants":"かけあわせる/かけ合せる/掛け合せる"},"掛け合せる":{"variants":"かけあわせる/かけ合せる/掛け合せる"},"カケイ":{"variants":"カケイ/佳景/家兄/家系/家計/火刑/花茎"},"掛け売り":{"variants":"掛け売り/掛売り"},"掛売り":{"variants":"掛け売り/掛売り"},"欠け落ち":{"variants":"欠け落ち/欠落ち"},"欠落ち":{"variants":"欠け落ち/欠落ち"},"かけがえ":{"variants":"かけがえ/掛け替え/掛替え"},"掛け替え":{"variants":"かけがえ/掛け替え/掛替え"},"掛替え":{"variants":"かけがえ/掛け替え/掛替え"},"掛け金":{"variants":"掛け金/掛金"},"掛金":{"variants":"掛け金/掛金"},"かけこむ":{"variants":"かけこむ/かけ込む/駆け込む/駆込む"},"かけ込む":{"variants":"かけこむ/かけ込む/駆け込む/駆込む"},"駆け込む":{"variants":"かけこむ/かけ込む/駆け込む/駆込む"},"駆込む":{"variants":"かけこむ/かけ込む/駆け込む/駆込む"},"かけこめる":{"variants":"かけこめる/駆け込める"},"駆け込める":{"variants":"かけこめる/駆け込める"},"かけ声":{"variants":"かけ声/掛け声/掛声"},"掛け声":{"variants":"かけ声/掛け声/掛声"},"掛声":{"variants":"かけ声/掛け声/掛声"},"賭け事":{"variants":"賭け事/賭事"},"賭事":{"variants":"賭け事/賭事"},"掛け算":{"variants":"掛け算/掛算"},"掛算":{"variants":"掛け算/掛算"},"掛字":{"variants":"掛け字/掛字"},"掛け字":{"variants":"掛け字/掛字"},"掛け軸":{"variants":"掛け軸/掛軸"},"掛軸":{"variants":"掛け軸/掛軸"},"掛け図":{"variants":"掛け図/掛図"},"掛図":{"variants":"掛け図/掛図"},"かけずりまわる":{"variants":"かけずりまわる/駆けずりまわる/駆けずり回る"},"駆けずりまわる":{"variants":"かけずりまわる/駆けずりまわる/駆けずり回る"},"駆けずり回る":{"variants":"かけずりまわる/駆けずりまわる/駆けずり回る"},"駆けだし":{"variants":"駆けだし/駆け出し/駆出し"},"駆け出し":{"variants":"駆けだし/駆け出し/駆出し"},"駆出し":{"variants":"駆けだし/駆け出し/駆出し"},"かけだす":{"variants":"かけだす/駆けだす/駆け出す"},"駆けだす":{"variants":"かけだす/駆けだす/駆け出す"},"駆け出す":{"variants":"かけだす/駆けだす/駆け出す"},"かけつける":{"variants":"かけつける/駆けつける/駆け付ける/駆付ける"},"駆けつける":{"variants":"かけつける/駆けつける/駆け付ける/駆付ける"},"駆け付ける":{"variants":"かけつける/駆けつける/駆け付ける/駆付ける"},"駆付ける":{"variants":"かけつける/駆けつける/駆け付ける/駆付ける"},"掛け取り":{"variants":"掛け取り/掛取り"},"掛取り":{"variants":"掛け取り/掛取り"},"掛け時計":{"variants":"掛け時計/掛時計"},"掛時計":{"variants":"掛け時計/掛時計"},"かけぬける":{"variants":"かけぬける/駆け抜ける"},"駆け抜ける":{"variants":"かけぬける/駆け抜ける"},"掛け値":{"variants":"掛け値/掛値"},"掛値":{"variants":"掛け値/掛値"},"かけ橋":{"variants":"かけ橋/架け橋/掛け橋/掛橋/懸け橋/懸橋"},"掛け橋":{"variants":"かけ橋/掛け橋/掛橋"},"懸け橋":{"variants":"かけ橋/懸け橋/懸橋"},"掛橋":{"variants":"かけ橋/掛け橋/掛橋"},"懸橋":{"variants":"かけ橋/懸け橋/懸橋"},"かけはなれる":{"variants":"かけはなれる/かけ離れる/掛け離れる/掛離れる/懸け離れる"},"かけ離れる":{"variants":"かけはなれる/かけ離れる/掛け離れる/掛離れる/懸け離れる"},"掛離れる":{"variants":"かけはなれる/かけ離れる/掛け離れる/掛離れる"},"掛け離れる":{"variants":"かけはなれる/かけ離れる/掛け離れる/掛離れる"},"駆け引き":{"variants":"駆け引き/駆引き"},"駆引き":{"variants":"駆け引き/駆引き"},"掛け布団":{"variants":"掛け布団/掛布団"},"掛布団":{"variants":"掛け布団/掛布団"},"かけへだたる":{"variants":"かけへだたる/かけ隔たる/懸け隔たる/懸隔たる"},"かけ隔たる":{"variants":"かけへだたる/かけ隔たる/懸け隔たる/懸隔たる"},"懸け隔たる":{"variants":"かけへだたる/かけ隔たる/懸け隔たる/懸隔たる"},"懸隔たる":{"variants":"かけへだたる/かけ隔たる/懸け隔たる/懸隔たる"},"かけへだてる":{"variants":"かけへだてる/かけ隔てる/懸け隔てる/懸隔てる"},"かけ隔てる":{"variants":"かけへだてる/かけ隔てる/懸け隔てる/懸隔てる"},"懸け隔てる":{"variants":"かけへだてる/かけ隔てる/懸け隔てる/懸隔てる"},"懸隔てる":{"variants":"かけへだてる/かけ隔てる/懸け隔てる/懸隔てる"},"かけまわる":{"variants":"かけまわる/駆け回る/駆回る"},"駆け回る":{"variants":"かけまわる/駆け回る/駆回る"},"駆回る":{"variants":"かけまわる/駆け回る/駆回る"},"かけまわれる":{"variants":"かけまわれる/駆け回れる"},"駆け回れる":{"variants":"かけまわれる/駆け回れる"},"欠目":{"variants":"欠け目/欠目"},"掛目":{"variants":"掛け目/掛目"},"欠け目":{"variants":"欠け目/欠目"},"掛け目":{"variants":"掛け目/掛目"},"かけ持ち":{"variants":"かけ持ち/掛持ち"},"掛持ち":{"variants":"かけ持ち/掛持ち"},"かけもつ":{"variants":"かけもつ/掛け持つ"},"掛け持つ":{"variants":"かけもつ/掛け持つ"},"掛け物":{"variants":"掛け物/掛物"},"掛物":{"variants":"掛け物/掛物"},"かけよる":{"variants":"かけよる/駆け寄る"},"駆け寄る":{"variants":"かけよる/駆け寄る"},"かけよれる":{"variants":"かけよれる/駆け寄れる"},"駆け寄れる":{"variants":"かけよれる/駆け寄れる"},"かける":{"variants":"かける/架ける/掛ける/駆ける/駈ける/欠ける/懸ける/書ける/掻ける/賭ける/翔ける"},"カゲ":{"variants":"カゲ/蔭/影/鹿毛/翳"},"か月":{"variants":"か月/カ月/ケ月/ヵ月/ヶ月/箇月/個月"},"カ月":{"variants":"か月/カ月/ケ月/ヵ月/ヶ月/箇月/個月"},"ケ月":{"variants":"か月/カ月/ケ月/ヵ月/ヶ月/箇月/個月"},"ヵ月":{"variants":"か月/カ月/ケ月/ヵ月/ヶ月/箇月/個月"},"ヶ月":{"variants":"か月/カ月/ケ月/ヵ月/ヶ月/箇月/個月"},"箇月":{"variants":"か月/カ月/ケ月/ヵ月/ヶ月/箇月/個月"},"個月":{"variants":"か月/カ月/ケ月/ヵ月/ヶ月/箇月/個月"},"かげながら":{"variants":"かげながら/陰ながら"},"陰ながら":{"variants":"かげながら/陰ながら"},"陰ひなた":{"variants":"陰ひなた/陰日向"},"陰日向":{"variants":"陰ひなた/陰日向"},"影ぼうし":{"variants":"影ぼうし/影法師"},"影法師":{"variants":"影ぼうし/影法師"},"かげり":{"variants":"かげり/陰り/翳り"},"かげる":{"variants":"かげる/陰る/翳る"},"カゲロウ":{"variants":"カゲロウ/陽炎/蜉蝣"},"かこう":{"variants":"かこう/囲う"},"囲う":{"variants":"かこう/囲う"},"カコウ":{"variants":"カコウ/化工/仮構/佳肴/嘉肴/歌稿/河口/河港/火口/花梗/華甲"},"かこう岩":{"variants":"かこう岩/花崗岩"},"花崗岩":{"variants":"かこう岩/花崗岩"},"かこえる":{"variants":"かこえる/囲える"},"囲える":{"variants":"かこえる/囲える"},"か国":{"variants":"か国/カ国/ケ国/ヵ国/ヶ国/箇国/個国"},"カ国":{"variants":"か国/カ国/ケ国/ヵ国/ヶ国/箇国/個国"},"ケ国":{"variants":"か国/カ国/ケ国/ヵ国/ヶ国/箇国/個国"},"ヵ国":{"variants":"か国/カ国/ケ国/ヵ国/ヶ国/箇国/個国"},"ヶ国":{"variants":"か国/カ国/ケ国/ヵ国/ヶ国/箇国/個国"},"箇国":{"variants":"か国/カ国/ケ国/ヵ国/ヶ国/箇国/個国"},"個国":{"variants":"か国/カ国/ケ国/ヵ国/ヶ国/箇国/個国"},"かこつ":{"variants":"かこつ/託つ"},"託つ":{"variants":"かこつ/託つ"},"かこむ":{"variants":"かこむ/囲む"},"囲む":{"variants":"かこむ/囲む"},"かこめる":{"variants":"かこめる/囲める"},"囲める":{"variants":"かこめる/囲める"},"かご":{"variants":"かご/過誤/駕篭/篭/籠/訛語"},"かごの鳥":{"variants":"かごの鳥/篭の鳥"},"篭の鳥":{"variants":"かごの鳥/篭の鳥"},"かさ":{"variants":"かさ/カサ/笠/傘/嵩/暈"},"カサ":{"variants":"かさ/カサ/笠/傘/嵩/暈"},"かさかさ":{"variants":"かさかさ/カサカサ"},"カサカサ":{"variants":"かさかさ/カサカサ"},"カサゴ":{"variants":"カサゴ/笠子"},"笠子":{"variants":"カサゴ/笠子"},"カササギ":{"variants":"カササギ/鵲"},"鵲":{"variants":"カササギ/鵲"},"かさなりあう":{"variants":"かさなりあう/重なり合う"},"重なり合う":{"variants":"かさなりあう/重なり合う"},"かさなる":{"variants":"かさなる/重なる"},"重なる":{"variants":"かさなる/重なる"},"重":{"variants":"重/重ね"},"重ね":{"variants":"重/重ね"},"かさねあわす":{"variants":"かさねあわす/重ね合わす"},"重ね合わす":{"variants":"かさねあわす/重ね合わす"},"かさねがさね":{"variants":"かさねがさね/重ねがさね/重ね重ね"},"重ねがさね":{"variants":"かさねがさね/重ねがさね/重ね重ね"},"重ね重ね":{"variants":"かさねがさね/重ねがさね/重ね重ね"},"かさねて":{"variants":"かさねて/重ねて"},"重ねて":{"variants":"かさねて/重ねて"},"かさねる":{"variants":"かさねる/重ねる"},"重ねる":{"variants":"かさねる/重ねる"},"かさばる":{"variants":"かさばる/かさ張る/嵩張る"},"かさ張る":{"variants":"かさばる/かさ張る/嵩張る"},"嵩張る":{"variants":"かさばる/かさ張る/嵩張る"},"かさぶた":{"variants":"かさぶた/痂/瘡蓋"},"かさむ":{"variants":"かさむ/嵩む"},"嵩む":{"variants":"かさむ/嵩む"},"かざす":{"variants":"かざす/挿頭す/翳す"},"かざり":{"variants":"かざり/飾/飾り"},"飾":{"variants":"かざり/飾/飾り"},"飾り":{"variants":"かざり/飾/飾り"},"飾りけ":{"variants":"飾りけ/飾り気"},"飾り気":{"variants":"飾りけ/飾り気"},"かざり職":{"variants":"かざり職/飾り職/錺職"},"かざりたてる":{"variants":"かざりたてる/飾りたてる/飾り立てる"},"飾りたてる":{"variants":"かざりたてる/飾りたてる/飾り立てる"},"飾り立てる":{"variants":"かざりたてる/飾りたてる/飾り立てる"},"かざりつける":{"variants":"かざりつける/飾りつける/飾り付ける"},"飾りつける":{"variants":"かざりつける/飾りつける/飾り付ける"},"飾り付ける":{"variants":"かざりつける/飾りつける/飾り付ける"},"飾りもの":{"variants":"飾りもの/飾り物"},"飾り物":{"variants":"飾りもの/飾り物"},"かざる":{"variants":"かざる/飾る"},"飾る":{"variants":"かざる/飾る"},"かざれる":{"variants":"かざれる/飾れる"},"飾れる":{"variants":"かざれる/飾れる"},"かし":{"variants":"かし/カシ/カ氏/下士/下肢/仮死/可視/歌詞/歌誌/華氏/菓子/樫/橿/貸し/瑕疵"},"カシ":{"variants":"かし/カシ/カ氏/下士/下肢/仮死/可視/歌詞/歌誌/華氏/菓子/樫/橿/貸し/瑕疵"},"貸し方":{"variants":"貸し方/貸方"},"貸方":{"variants":"貸し方/貸方"},"貸し切り":{"variants":"貸し切り/貸切/貸切り"},"貸切":{"variants":"貸し切り/貸切/貸切り"},"貸切り":{"variants":"貸し切り/貸切/貸切り"},"かしきる":{"variants":"かしきる/貸し切る/貸切る"},"貸し切る":{"variants":"かしきる/貸し切る/貸切る"},"貸切る":{"variants":"かしきる/貸し切る/貸切る"},"貸し金":{"variants":"貸し金/貸金"},"貸金":{"variants":"貸し金/貸金"},"かしぐ":{"variants":"かしぐ/傾ぐ/炊ぐ"},"かしこい":{"variants":"かしこい/カシコい/畏い/賢い"},"カシコい":{"variants":"かしこい/カシコい/畏い/賢い"},"かしこす":{"variants":"かしこす/貸し越す"},"貸し越す":{"variants":"かしこす/貸し越す"},"かしこまる":{"variants":"かしこまる/畏まる"},"畏まる":{"variants":"かしこまる/畏まる"},"貸し倒れ":{"variants":"貸し倒れ/貸倒れ"},"貸倒れ":{"variants":"貸し倒れ/貸倒れ"},"貸し出し":{"variants":"貸し出し/貸出"},"貸出":{"variants":"貸し出し/貸出"},"かしだす":{"variants":"かしだす/貸し出す/貸出す"},"貸し出す":{"variants":"かしだす/貸し出す/貸出す"},"貸出す":{"variants":"かしだす/貸し出す/貸出す"},"かしだせる":{"variants":"かしだせる/貸し出せる"},"貸し出せる":{"variants":"かしだせる/貸し出せる"},"貸し賃":{"variants":"貸し賃/貸賃"},"貸賃":{"variants":"貸し賃/貸賃"},"貸し付け":{"variants":"貸し付け/貸付"},"貸付":{"variants":"貸し付け/貸付"},"かしつける":{"variants":"かしつける/貸し付ける"},"貸し付ける":{"variants":"かしつける/貸し付ける"},"貸し手":{"variants":"貸し手/貸手"},"貸手":{"variants":"貸し手/貸手"},"カシドリ":{"variants":"カシドリ/樫鳥/橿鳥"},"貸し主":{"variants":"貸し主/貸主"},"貸主":{"variants":"貸し主/貸主"},"かしましい":{"variants":"かしましい/姦しい"},"姦しい":{"variants":"かしましい/姦しい"},"貸し元":{"variants":"貸し元/貸元"},"貸元":{"variants":"貸し元/貸元"},"カシュウ":{"variants":"カシュウ/何首烏/家集/歌集"},"か所":{"variants":"か所/カ所/ケ所/ヵ所/ヶ所/箇所"},"カ所":{"variants":"か所/カ所/ケ所/ヵ所/ヶ所/箇所"},"ケ所":{"variants":"か所/カ所/ケ所/ヵ所/ヶ所/箇所"},"ヵ所":{"variants":"か所/カ所/ケ所/ヵ所/ヶ所/箇所"},"ヶ所":{"variants":"か所/カ所/ケ所/ヵ所/ヶ所/箇所"},"箇所":{"variants":"か所/カ所/ケ所/ヵ所/ヶ所/箇所"},"かしら":{"variants":"かしら/カシラ"},"カシラ":{"variants":"かしら/カシラ"},"かしらだつ":{"variants":"かしらだつ/頭立つ"},"頭立つ":{"variants":"かしらだつ/頭立つ"},"かしわ":{"variants":"かしわ/カシワ/栢/柏/槲"},"カシワ":{"variants":"かしわ/カシワ/栢/柏/槲"},"柏もち":{"variants":"柏もち/柏餅"},"柏餅":{"variants":"柏もち/柏餅"},"かじ":{"variants":"かじ/カジ/家事/火じ/火事/梶/柁/舵/鍛冶/楫"},"カジ":{"variants":"かじ/カジ/家事/火じ/火事/梶/柁/舵/鍛冶/楫"},"火事":{"variants":"かじ/カジ/火じ/火事"},"火じ":{"variants":"かじ/カジ/火じ/火事"},"カジカ":{"variants":"カジカ/河鹿/鰍/鮖"},"カジカガエル":{"variants":"カジカガエル/河鹿蛙"},"河鹿蛙":{"variants":"カジカガエル/河鹿蛙"},"かじかむ":{"variants":"かじかむ/悴む"},"悴む":{"variants":"かじかむ/悴む"},"カジク":{"variants":"カジク/花軸"},"花軸":{"variants":"カジク/花軸"},"かじとり":{"variants":"かじとり/かじ取り/カジとり/舵取り"},"かじ取り":{"variants":"かじとり/かじ取り/カジとり/舵取り"},"カジとり":{"variants":"かじとり/かじ取り/カジとり/舵取り"},"舵取り":{"variants":"かじとり/かじ取り/カジとり/舵取り"},"カジノキ":{"variants":"カジノキ/梶の木"},"梶の木":{"variants":"カジノキ/梶の木"},"カジメ":{"variants":"カジメ/搗布"},"搗布":{"variants":"カジメ/搗布"},"カジョ":{"variants":"カジョ/花序"},"花序":{"variants":"カジョ/花序"},"か条":{"variants":"か条/カ条/ケ条/ヵ条/ヶ条/箇条/個条"},"カ条":{"variants":"か条/カ条/ケ条/ヵ条/ヶ条/箇条/個条"},"ケ条":{"variants":"か条/カ条/ケ条/ヵ条/ヶ条/箇条/個条"},"ヵ条":{"variants":"か条/カ条/ケ条/ヵ条/ヶ条/箇条/個条"},"ヶ条":{"variants":"か条/カ条/ケ条/ヵ条/ヶ条/箇条/個条"},"箇条":{"variants":"か条/カ条/ケ条/ヵ条/ヶ条/箇条/個条"},"個条":{"variants":"か条/カ条/ケ条/ヵ条/ヶ条/箇条/個条"},"個条書":{"variants":"個条書/個条書き"},"個条書き":{"variants":"個条書/個条書き"},"かじりつく":{"variants":"かじりつく/齧り付く"},"齧り付く":{"variants":"かじりつく/齧り付く"},"かじる":{"variants":"かじる/齧る"},"齧る":{"variants":"かじる/齧る"},"かす":{"variants":"かす/糟/粕/滓"},"カスイ":{"variants":"カスイ/加水/花穂"},"かすか":{"variants":"かすか/微か/幽か"},"かす汁":{"variants":"かす汁/粕汁"},"粕汁":{"variants":"かす汁/粕汁"},"粕漬":{"variants":"粕漬/粕漬け"},"粕漬け":{"variants":"粕漬/粕漬け"},"かすむ":{"variants":"かすむ/霞む"},"霞む":{"variants":"かすむ/霞む"},"かすめとる":{"variants":"かすめとる/かすめ取る"},"かすめ取る":{"variants":"かすめとる/かすめ取る"},"かすめる":{"variants":"かすめる/掠める"},"掠める":{"variants":"かすめる/掠める"},"かする":{"variants":"かする/掠る"},"掠る":{"variants":"かする/掠る"},"かすれる":{"variants":"かすれる/掠れる"},"掠れる":{"variants":"かすれる/掠れる"},"かずおおい":{"variants":"かずおおい/数多い"},"数多い":{"variants":"かずおおい/数多い"},"数々":{"variants":"数々/数数"},"数数":{"variants":"数々/数数"},"かずすくない":{"variants":"かずすくない/数少ない"},"数少ない":{"variants":"かずすくない/数少ない"},"数の子":{"variants":"かずの子/数の子"},"かずの子":{"variants":"かずの子/数の子"},"カセイ":{"variants":"カセイ/仮性/家政/歌聖/河清/火勢/火星/苛性/苛政"},"カセイカリ":{"variants":"カセイカリ/苛性カリ"},"苛性カリ":{"variants":"カセイカリ/苛性カリ"},"カセイソーダ":{"variants":"カセイソーダ/苛性ソーダ"},"苛性ソーダ":{"variants":"カセイソーダ/苛性ソーダ"},"かせぐ":{"variants":"かせぐ/稼ぐ"},"稼ぐ":{"variants":"かせぐ/稼ぐ"},"かせげる":{"variants":"かせげる/稼げる"},"稼げる":{"variants":"かせげる/稼げる"},"かせる":{"variants":"かせる/貸せる"},"貸せる":{"variants":"かせる/貸せる"},"かぜ":{"variants":"かぜ/カゼ/風/風邪"},"カゼ":{"variants":"かぜ/カゼ/風/風邪"},"風当たり":{"variants":"風当たり/風当り"},"風当り":{"variants":"風当たり/風当り"},"カゼクサ":{"variants":"カゼクサ/風草"},"風草":{"variants":"カゼクサ/風草"},"カゼシリグサ":{"variants":"カゼシリグサ/風知草"},"風知草":{"variants":"カゼシリグサ/風知草"},"風邪引き":{"variants":"風邪ひき/風邪引き"},"風邪ひき":{"variants":"風邪ひき/風邪引き"},"かぜん":{"variants":"かぜん/果然"},"果然":{"variants":"かぜん/果然"},"かそけい":{"variants":"かそけい/幽い"},"幽い":{"variants":"かそけい/幽い"},"か村":{"variants":"か村/カ村/ケ村/ヵ村/ヶ村"},"カ村":{"variants":"か村/カ村/ケ村/ヵ村/ヶ村"},"ケ村":{"variants":"か村/カ村/ケ村/ヵ村/ヶ村"},"ヵ村":{"variants":"か村/カ村/ケ村/ヵ村/ヶ村"},"ヶ村":{"variants":"か村/カ村/ケ村/ヵ村/ヶ村"},"かぞえあげる":{"variants":"かぞえあげる/数えあげる/数え上げる"},"数えあげる":{"variants":"かぞえあげる/数えあげる/数え上げる"},"数え上げる":{"variants":"かぞえあげる/数えあげる/数え上げる"},"数えうた":{"variants":"数えうた/数え歌"},"数え歌":{"variants":"数えうた/数え歌"},"かぞえたてる":{"variants":"かぞえたてる/数えたてる/数え立てる"},"数えたてる":{"variants":"かぞえたてる/数えたてる/数え立てる"},"数え立てる":{"variants":"かぞえたてる/数えたてる/数え立てる"},"かぞえる":{"variants":"かぞえる/数える"},"数える":{"variants":"かぞえる/数える"},"家族あわせ":{"variants":"家族あわせ/家族合せ"},"家族合せ":{"variants":"家族あわせ/家族合せ"},"家族づれ":{"variants":"家族づれ/家族連れ"},"家族連れ":{"variants":"家族づれ/家族連れ"},"かたい":{"variants":"かたい/堅い/固い/硬い/難い"},"下たい":{"variants":"下たい/下腿"},"下腿":{"variants":"下たい/下腿"},"肩掛":{"variants":"肩掛/肩掛け"},"肩掛け":{"variants":"肩掛/肩掛け"},"カタカナ":{"variants":"カタカナ/片かな/片仮名"},"片かな":{"variants":"カタカナ/片かな/片仮名"},"片仮名":{"variants":"カタカナ/片かな/片仮名"},"肩書":{"variants":"肩書/肩書き"},"肩書き":{"variants":"肩書/肩書き"},"かたがた":{"variants":"かたがた/方々/方方"},"方々":{"variants":"ほうぼう/方々/方方"},"方方":{"variants":"ほうぼう/方々/方方"},"肩代り":{"variants":"肩代り/肩代わり"},"肩代わり":{"variants":"肩代り/肩代わり"},"敵討":{"variants":"敵討/敵討ち"},"敵討ち":{"variants":"敵討/敵討ち"},"かたぎ":{"variants":"かたぎ/形木/堅気/模"},"カタクチイワシ":{"variants":"カタクチイワシ/片口鰯"},"片口鰯":{"variants":"カタクチイワシ/片口鰯"},"カタクリ":{"variants":"カタクリ/片栗"},"片栗":{"variants":"カタクリ/片栗"},"かたくり粉":{"variants":"かたくり粉/カタクリ粉/片栗粉"},"カタクリ粉":{"variants":"かたくり粉/カタクリ粉/片栗粉"},"片栗粉":{"variants":"かたくり粉/カタクリ粉/片栗粉"},"かたくるしい":{"variants":"かたくるしい/堅苦しい"},"堅苦しい":{"variants":"かたくるしい/堅苦しい"},"肩ぐるま":{"variants":"肩ぐるま/肩車"},"肩車":{"variants":"肩ぐるま/肩車"},"肩ごし":{"variants":"肩ごし/肩越し"},"肩越し":{"variants":"肩ごし/肩越し"},"かたじけない":{"variants":"かたじけない/忝ない"},"忝ない":{"variants":"かたじけない/忝ない"},"かたす":{"variants":"かたす/片す"},"片す":{"variants":"かたす/片す"},"片すみ":{"variants":"片すみ/片隅"},"片隅":{"variants":"片すみ/片隅"},"かたず":{"variants":"かたず/固唾"},"固唾":{"variants":"かたず/固唾"},"かた染め":{"variants":"かた染め/型染め"},"型染め":{"variants":"かた染め/型染め"},"かたちづくる":{"variants":"かたちづくる/形づくる/形作る"},"形づくる":{"variants":"かたちづくる/形づくる/形作る"},"形作る":{"variants":"かたちづくる/形づくる/形作る"},"かたちづくれる":{"variants":"かたちづくれる/形作れる"},"形作れる":{"variants":"かたちづくれる/形作れる"},"かたっぱし":{"variants":"かたっぱし/片っぱし/片っ端"},"片っぱし":{"variants":"かたっぱし/片っぱし/片っ端"},"片っ端":{"variants":"かたっぱし/片っぱし/片っ端"},"型付":{"variants":"型付/型付き"},"型付き":{"variants":"型付/型付き"},"かたつむり":{"variants":"かたつむり/カタツムリ"},"カタツムリ":{"variants":"かたつむり/カタツムリ"},"かたづく":{"variants":"かたづく/片づく/片付く"},"片づく":{"variants":"かたづく/片づく/片付く"},"片付く":{"variants":"かたづく/片づく/片付く"},"かたづける":{"variants":"かたづける/片づける/片付ける"},"片づける":{"variants":"かたづける/片づける/片付ける"},"片付ける":{"variants":"かたづける/片づける/片付ける"},"かたどる":{"variants":"かたどる/型どる/象る"},"かたどれる":{"variants":"かたどれる/型どれる/象れる"},"かたは":{"variants":"かたは/片刃"},"片刃":{"variants":"かたは/片刃"},"かたはらいたい":{"variants":"かたはらいたい/片腹痛い"},"片腹痛い":{"variants":"かたはらいたい/片腹痛い"},"カタバミ":{"variants":"カタバミ/酢漿"},"酢漿":{"variants":"カタバミ/酢漿"},"かたパン":{"variants":"かたパン/堅パン"},"堅パン":{"variants":"かたパン/堅パン"},"肩ひじ":{"variants":"肩ひじ/肩肘"},"肩肘":{"variants":"肩ひじ/肩肘"},"カタブツ":{"variants":"カタブツ/堅物"},"堅物":{"variants":"カタブツ/堅物"},"かたまりあう":{"variants":"かたまりあう/固まり合う"},"固まり合う":{"variants":"かたまりあう/固まり合う"},"かたまる":{"variants":"かたまる/固まる"},"固まる":{"variants":"かたまる/固まる"},"かたまれる":{"variants":"かたまれる/固まれる"},"固まれる":{"variants":"かたまれる/固まれる"},"かたみに":{"variants":"かたみに/互に"},"互に":{"variants":"かたみに/互に"},"固め":{"variants":"固め/固目"},"固目":{"variants":"固め/固目"},"かためる":{"variants":"かためる/固める"},"固める":{"variants":"かためる/固める"},"かたよせる":{"variants":"かたよせる/片寄せる"},"片寄せる":{"variants":"かたよせる/片寄せる"},"かたよる":{"variants":"かたよる/偏る/片寄る"},"かたらう":{"variants":"かたらう/語らう"},"語らう":{"variants":"かたらう/語らう"},"かたりあう":{"variants":"かたりあう/語りあう/語り合う"},"語りあう":{"variants":"かたりあう/語りあう/語り合う"},"語り合う":{"variants":"かたりあう/語りあう/語り合う"},"かたりあえる":{"variants":"かたりあえる/語り合える"},"語り合える":{"variants":"かたりあえる/語り合える"},"かたりあかす":{"variants":"かたりあかす/語り明かす"},"語り明かす":{"variants":"かたりあかす/語り明かす"},"かたりあかせる":{"variants":"かたりあかせる/語り明かせる"},"語り明かせる":{"variants":"かたりあかせる/語り明かせる"},"語りかける":{"variants":"語りかける/語り掛ける"},"語り掛ける":{"variants":"語りかける/語り掛ける"},"語り口":{"variants":"語り口/語口"},"語口":{"variants":"語り口/語口"},"語りぐさ":{"variants":"語りぐさ/語種/語草"},"かたりこむ":{"variants":"かたりこむ/語りこむ/語り込む"},"語りこむ":{"variants":"かたりこむ/語りこむ/語り込む"},"語り込む":{"variants":"かたりこむ/語りこむ/語り込む"},"かたりこめる":{"variants":"かたりこめる/語りこめる/語り込める"},"語りこめる":{"variants":"かたりこめる/語りこめる/語り込める"},"語り込める":{"variants":"かたりこめる/語りこめる/語り込める"},"かたりつぐ":{"variants":"かたりつぐ/語りつぐ/語り継ぐ"},"語りつぐ":{"variants":"かたりつぐ/語りつぐ/語り継ぐ"},"語り継ぐ":{"variants":"かたりつぐ/語りつぐ/語り継ぐ"},"語り手":{"variants":"語り手/語手"},"語手":{"variants":"語り手/語手"},"語りべ":{"variants":"語りべ/語部"},"語部":{"variants":"語りべ/語部"},"語り物":{"variants":"語り物/語物"},"語物":{"variants":"語り物/語物"},"かたる":{"variants":"かたる/語る/騙る"},"かたれる":{"variants":"かたれる/語れる"},"語れる":{"variants":"かたれる/語れる"},"かたわら":{"variants":"かたわら/傍ら"},"傍ら":{"variants":"かたわら/傍ら"},"片割れ月":{"variants":"片割れ月/片割月"},"片割月":{"variants":"片割れ月/片割月"},"かたん":{"variants":"かたん/加担/荷担"},"カタンいと":{"variants":"カタンいと/カタン糸"},"カタン糸":{"variants":"カタンいと/カタン糸"},"勝ち":{"variants":"勝/勝ち"},"勝":{"variants":"勝/勝ち"},"かちあう":{"variants":"かちあう/かち合う"},"かち合う":{"variants":"かちあう/かち合う"},"勝ちいくさ":{"variants":"勝ちいくさ/勝ち軍/勝ち戦"},"かちえる":{"variants":"かちえる/かち得る/勝ち得る/贏ち得える"},"かち得る":{"variants":"かちえる/かち得る/勝ち得る/贏ち得える"},"かちかち":{"variants":"かちかち/カチカチ"},"カチカチ":{"variants":"かちかち/カチカチ"},"勝ち気":{"variants":"勝ち気/勝気"},"勝気":{"variants":"勝ち気/勝気"},"かちこす":{"variants":"かちこす/勝ち越す/勝越す"},"勝ち越す":{"variants":"かちこす/勝ち越す/勝越す"},"勝越す":{"variants":"かちこす/勝ち越す/勝越す"},"かちこせる":{"variants":"かちこせる/勝ち越せる"},"勝ち越せる":{"variants":"かちこせる/勝ち越せる"},"かちすすむ":{"variants":"かちすすむ/勝ち進む"},"勝ち進む":{"variants":"かちすすむ/勝ち進む"},"かちすすめる":{"variants":"かちすすめる/勝ち進める"},"勝ち進める":{"variants":"かちすすめる/勝ち進める"},"かちとる":{"variants":"かちとる/かち取る/勝ち取る/勝取る"},"かち取る":{"variants":"かちとる/かち取る/勝ち取る/勝取る"},"勝ち取る":{"variants":"かちとる/かち取る/勝ち取る/勝取る"},"勝取る":{"variants":"かちとる/かち取る/勝ち取る/勝取る"},"かちとれる":{"variants":"かちとれる/かち取れる"},"かち取れる":{"variants":"かちとれる/かち取れる"},"勝ちどき":{"variants":"勝ちどき/勝ち鬨/勝鬨"},"勝ち鬨":{"variants":"勝ちどき/勝ち鬨/勝鬨"},"勝鬨":{"variants":"勝ちどき/勝ち鬨/勝鬨"},"勝ち名乗り":{"variants":"勝ち名乗り/勝名乗り"},"勝名乗り":{"variants":"勝ち名乗り/勝名乗り"},"勝ち抜き":{"variants":"勝ち抜き/勝抜き"},"勝抜き":{"variants":"勝ち抜き/勝抜き"},"かちぬく":{"variants":"かちぬく/勝ちぬく/勝ち抜く/勝抜く"},"勝ちぬく":{"variants":"かちぬく/勝ちぬく/勝ち抜く/勝抜く"},"勝ち抜く":{"variants":"かちぬく/勝ちぬく/勝ち抜く/勝抜く"},"勝抜く":{"variants":"かちぬく/勝ちぬく/勝ち抜く/勝抜く"},"かちほこる":{"variants":"かちほこる/勝ち誇る/勝誇る"},"勝ち誇る":{"variants":"かちほこる/勝ち誇る/勝誇る"},"勝誇る":{"variants":"かちほこる/勝ち誇る/勝誇る"},"勝ち星":{"variants":"勝ち星/勝星"},"勝星":{"variants":"勝ち星/勝星"},"勝ち負け":{"variants":"勝ち負け/勝負け"},"勝負け":{"variants":"勝ち負け/勝負け"},"勝ち味":{"variants":"勝ち味/勝味"},"勝味":{"variants":"勝ち味/勝味"},"勝ち目":{"variants":"勝ち目/勝目"},"勝目":{"variants":"勝ち目/勝目"},"かちん":{"variants":"かちん/カチン"},"カチン":{"variants":"かちん/カチン"},"カッカ":{"variants":"カッカ/各科/核果/閣下"},"かっきづく":{"variants":"かっきづく/活気づく"},"活気づく":{"variants":"かっきづく/活気づく"},"かっきる":{"variants":"かっきる/かっ切る/掻っ切る"},"かっ切る":{"variants":"かっきる/かっ切る/掻っ切る"},"掻っ切る":{"variants":"かっきる/かっ切る/掻っ切る"},"カッコ":{"variants":"カッコ/各個/各戸/確乎/確固/羯鼓"},"カッコイイ":{"variants":"かっこいい/カッコイイ"},"かっこいい":{"variants":"かっこいい/カッコイイ"},"かっこう":{"variants":"かっこう/カッコウ/格好/角行/郭公/恰好"},"カッコウ":{"variants":"かっこう/カッコウ/格好/角行/郭公/恰好"},"かっこむ":{"variants":"かっこむ/かっ込む/掻っ込む"},"かっ込む":{"variants":"かっこむ/かっ込む/掻っ込む"},"掻っ込む":{"variants":"かっこむ/かっ込む/掻っ込む"},"喝さい":{"variants":"喝さい/喝采"},"喝采":{"variants":"喝さい/喝采"},"かっする":{"variants":"かっする/渇する"},"渇する":{"variants":"かっする/渇する"},"カッソウ":{"variants":"カッソウ/褐藻"},"褐藻":{"variants":"カッソウ/褐藻"},"かっ達":{"variants":"かっ達/闊達"},"闊達":{"variants":"かっ達/闊達"},"かって":{"variants":"かって/勝手"},"勝手":{"variants":"かって/勝手"},"かっとう":{"variants":"かっとう/葛藤"},"葛藤":{"variants":"かっとう/葛藤"},"かっとばす":{"variants":"かっとばす/かっ飛ばす"},"かっ飛ばす":{"variants":"かっとばす/かっ飛ばす"},"カッパ":{"variants":"カッパ/河童/合羽"},"かっぱらう":{"variants":"かっぱらう/掻払う"},"掻払う":{"variants":"かっぱらう/掻払う"},"かっぽ":{"variants":"かっぽ/かっ歩/カッ歩/闊歩"},"かっ歩":{"variants":"かっぽ/かっ歩/カッ歩/闊歩"},"カッ歩":{"variants":"かっぽ/かっ歩/カッ歩/闊歩"},"闊歩":{"variants":"かっぽ/かっ歩/カッ歩/闊歩"},"かっぽう":{"variants":"かっぽう/割ぽう/割烹"},"割ぽう":{"variants":"かっぽう/割ぽう/割烹"},"割烹":{"variants":"かっぽう/割ぽう/割烹"},"かつ":{"variants":"かつ/且つ"},"且つ":{"variants":"かつ/且つ"},"カツ":{"variants":"カツ/喝/活"},"カツオ":{"variants":"カツオ/鰹"},"鰹":{"variants":"カツオ/鰹"},"かつお節":{"variants":"かつお節/カツオ節/鰹節"},"カツオ節":{"variants":"かつお節/カツオ節/鰹節"},"鰹節":{"variants":"かつお節/カツオ節/鰹節"},"かつぎあげる":{"variants":"かつぎあげる/かつぎ上げる"},"かつぎ上げる":{"variants":"かつぎあげる/かつぎ上げる"},"かつぎこむ":{"variants":"かつぎこむ/かつぎ込む"},"かつぎ込む":{"variants":"かつぎこむ/かつぎ込む"},"かつぎこめる":{"variants":"かつぎこめる/かつぎ込める"},"かつぎ込める":{"variants":"かつぎこめる/かつぎ込める"},"かつぐ":{"variants":"かつぐ/担ぐ"},"担ぐ":{"variants":"かつぐ/担ぐ"},"かつげる":{"variants":"かつげる/担げる"},"担げる":{"variants":"かつげる/担げる"},"カツヨウジュ":{"variants":"カツヨウジュ/闊葉樹"},"闊葉樹":{"variants":"カツヨウジュ/闊葉樹"},"かつら":{"variants":"かつら/カツラ/鬘"},"カツラ":{"variants":"かつら/カツラ/鬘"},"鬘":{"variants":"かつら/カツラ/鬘"},"かてる":{"variants":"かてる/勝てる"},"勝てる":{"variants":"かてる/勝てる"},"蚊取り線香":{"variants":"蚊取り線香/蚊取線香"},"蚊取線香":{"variants":"蚊取り線香/蚊取線香"},"カトンボ":{"variants":"カトンボ/蚊蜻蛉"},"蚊蜻蛉":{"variants":"カトンボ/蚊蜻蛉"},"カド":{"variants":"カド/過度/廉"},"か働":{"variants":"か働/稼働"},"稼働":{"variants":"か働/稼働"},"かどかどしい":{"variants":"かどかどしい/角々しい/角角しい"},"角々しい":{"variants":"かどかどしい/角々しい/角角しい"},"角角しい":{"variants":"かどかどしい/角々しい/角角しい"},"かどだつ":{"variants":"かどだつ/角立つ"},"角立つ":{"variants":"かどだつ/角立つ"},"かどだてる":{"variants":"かどだてる/角立てる"},"角立てる":{"variants":"かどだてる/角立てる"},"カド番":{"variants":"カド番/角番"},"角番":{"variants":"カド番/角番"},"かどわかす":{"variants":"かどわかす/拐かす"},"拐かす":{"variants":"かどわかす/拐かす"},"かな":{"variants":"かな/カナ"},"カナ":{"variants":"かな/カナ"},"かなう":{"variants":"かなう/叶う/適う"},"かなえる":{"variants":"かなえる/叶える/適える"},"かな漢字":{"variants":"かな漢字/仮名漢字"},"仮名漢字":{"variants":"かな漢字/仮名漢字"},"かな書き":{"variants":"かな書き/カナ書き/仮名書"},"カナ書き":{"variants":"かな書き/カナ書き/仮名書"},"仮名書":{"variants":"かな書き/カナ書き/仮名書"},"カナガシラ":{"variants":"カナガシラ/金頭"},"金頭":{"variants":"カナガシラ/金頭"},"金切り声":{"variants":"金切り声/金切声"},"金切声":{"variants":"金切り声/金切声"},"かなくさい":{"variants":"かなくさい/金臭い"},"金臭い":{"variants":"かなくさい/金臭い"},"かなぐりすてる":{"variants":"かなぐりすてる/かなぐり捨てる"},"かなぐり捨てる":{"variants":"かなぐりすてる/かなぐり捨てる"},"かなしい":{"variants":"かなしい/哀しい/悲しい"},"かなしみ":{"variants":"かなしみ/哀しみ/悲しみ"},"かなしむ":{"variants":"かなしむ/哀しむ/悲しむ"},"かな遣い":{"variants":"かな遣い/仮名遣/仮名遣い"},"仮名遣":{"variants":"かな遣い/仮名遣/仮名遣い"},"仮名遣い":{"variants":"かな遣い/仮名遣/仮名遣い"},"金づち":{"variants":"金づち/金槌"},"金槌":{"variants":"金づち/金槌"},"かなでる":{"variants":"かなでる/奏でる"},"奏でる":{"variants":"かなでる/奏でる"},"カナヘビ":{"variants":"カナヘビ/金蛇"},"金蛇":{"variants":"カナヘビ/金蛇"},"かなめ":{"variants":"かなめ/カナメ"},"カナメ":{"variants":"かなめ/カナメ"},"カナメモチ":{"variants":"カナメモチ/要黐"},"要黐":{"variants":"カナメモチ/要黐"},"かならずしも":{"variants":"かならずしも/必ずしも"},"必ずしも":{"variants":"かならずしも/必ずしも"},"かならずや":{"variants":"かならずや/必ずや"},"必ずや":{"variants":"かならずや/必ずや"},"かに":{"variants":"かに/カニ/蟹"},"カニ":{"variants":"かに/カニ/蟹"},"蟹":{"variants":"かに/カニ/蟹"},"かね":{"variants":"かね/カネ/鉦/鐘"},"カネ":{"variants":"かね/カネ/鉦/鐘"},"かね合い":{"variants":"かね合い/兼ね合い/兼合い"},"兼ね合い":{"variants":"かね合い/兼ね合い/兼合い"},"兼合い":{"variants":"かね合い/兼ね合い/兼合い"},"かねあう":{"variants":"かねあう/兼ね合う"},"兼ね合う":{"variants":"かねあう/兼ね合う"},"金貸":{"variants":"金貸/金貸し"},"金貸し":{"variants":"金貸/金貸し"},"かねそなえる":{"variants":"かねそなえる/兼ね備える"},"兼ね備える":{"variants":"かねそなえる/兼ね備える"},"カネタタキ":{"variants":"カネタタキ/鉦叩き"},"鉦叩き":{"variants":"カネタタキ/鉦叩き"},"金づる":{"variants":"金づる/金蔓"},"金蔓":{"variants":"金づる/金蔓"},"かねてから":{"variants":"かねてから/予てから"},"予てから":{"variants":"かねてから/予てから"},"金持":{"variants":"金持/金持ち"},"金持ち":{"variants":"金持/金持ち"},"かねる":{"variants":"かねる/兼ねる"},"兼ねる":{"variants":"かねる/兼ねる"},"か年":{"variants":"か年/カ年/ケ年/ヵ年/ヶ年/箇年/個年"},"カ年":{"variants":"か年/カ年/ケ年/ヵ年/ヶ年/箇年/個年"},"ケ年":{"variants":"か年/カ年/ケ年/ヵ年/ヶ年/箇年/個年"},"ヵ年":{"variants":"か年/カ年/ケ年/ヵ年/ヶ年/箇年/個年"},"ヶ年":{"variants":"か年/カ年/ケ年/ヵ年/ヶ年/箇年/個年"},"箇年":{"variants":"か年/カ年/ケ年/ヵ年/ヶ年/箇年/個年"},"個年":{"variants":"か年/カ年/ケ年/ヵ年/ヶ年/箇年/個年"},"化膿":{"variants":"化のう/化膿"},"化のう":{"variants":"化のう/化膿"},"鹿の子絞":{"variants":"鹿の子絞/鹿子絞り"},"鹿子絞り":{"variants":"鹿の子絞/鹿子絞り"},"鹿の子餅":{"variants":"鹿の子餅/鹿子餅"},"鹿子餅":{"variants":"鹿の子餅/鹿子餅"},"カバ":{"variants":"カバ/河馬/樺"},"かばう":{"variants":"かばう/庇う"},"庇う":{"variants":"かばう/庇う"},"カバノキ":{"variants":"カバノキ/樺の木"},"樺の木":{"variants":"カバノキ/樺の木"},"かば焼き":{"variants":"かば焼き/蒲焼/蒲焼き"},"蒲焼":{"variants":"かば焼き/蒲焼/蒲焼き"},"蒲焼き":{"variants":"かば焼き/蒲焼/蒲焼き"},"かばん":{"variants":"かばん/カバン/下番/鞄"},"カバン":{"variants":"かばん/カバン/下番/鞄"},"カヒ":{"variants":"カヒ/下婢/可否/果皮/歌碑"},"カビ":{"variants":"カビ/華美/黴"},"かびくさい":{"variants":"かびくさい/黴臭い"},"黴臭い":{"variants":"かびくさい/黴臭い"},"かびる":{"variants":"かびる/黴びる"},"黴びる":{"variants":"かびる/黴びる"},"カブ":{"variants":"カブ/下部/株"},"かぶさる":{"variants":"かぶさる/被さる"},"被さる":{"variants":"かぶさる/被さる"},"かぶせ蓋":{"variants":"かぶせ蓋/被せぶた/被せ蓋"},"被せぶた":{"variants":"かぶせ蓋/被せぶた/被せ蓋"},"被せ蓋":{"variants":"かぶせ蓋/被せぶた/被せ蓋"},"かぶせる":{"variants":"かぶせる/被せる"},"被せる":{"variants":"かぶせる/被せる"},"カブト":{"variants":"カブト/兜/甲/冑"},"かぶとむし":{"variants":"かぶとむし/かぶと虫/カブトムシ/カブト虫/甲虫"},"かぶと虫":{"variants":"かぶとむし/かぶと虫/カブトムシ/カブト虫/甲虫"},"カブトムシ":{"variants":"かぶとむし/かぶと虫/カブトムシ/カブト虫/甲虫"},"カブト虫":{"variants":"かぶとむし/かぶと虫/カブトムシ/カブト虫/甲虫"},"甲虫":{"variants":"かぶとむし/かぶと虫/カブトムシ/カブト虫/甲虫"},"カブラ":{"variants":"カブラ/鏑/蕪菁"},"被りもの":{"variants":"被りもの/被り物"},"被り物":{"variants":"被りもの/被り物"},"かぶれる":{"variants":"かぶれる/被れる"},"被れる":{"variants":"かぶれる/被れる"},"カベ":{"variants":"カベ/壁"},"壁":{"variants":"カベ/壁"},"かぼそい":{"variants":"かぼそい/か細い"},"か細い":{"variants":"かぼそい/か細い"},"カボチャ":{"variants":"カボチャ/南瓜"},"南瓜":{"variants":"カボチャ/南瓜"},"かま":{"variants":"かま/カマ/釜/鎌/窯/罐"},"カマ":{"variants":"かま/カマ/釜/鎌/窯/罐"},"かまう":{"variants":"かまう/構う"},"構う":{"variants":"かまう/構う"},"かまえる":{"variants":"かまえる/構える"},"構える":{"variants":"かまえる/構える"},"カマキリ":{"variants":"カマキリ/蟷螂"},"蟷螂":{"variants":"カマキリ/蟷螂"},"かま首":{"variants":"かま首/鎌首"},"鎌首":{"variants":"かま首/鎌首"},"カマス":{"variants":"カマス/叺"},"叺":{"variants":"カマス/叺"},"カマドウマ":{"variants":"カマドウマ/竃馬"},"竃馬":{"variants":"カマドウマ/竃馬"},"かまびすしい":{"variants":"かまびすしい/囂しい"},"囂しい":{"variants":"かまびすしい/囂しい"},"かまぼこ":{"variants":"かまぼこ/カマボコ/蒲鉾"},"カマボコ":{"variants":"かまぼこ/カマボコ/蒲鉾"},"蒲鉾":{"variants":"かまぼこ/カマボコ/蒲鉾"},"釜めし":{"variants":"釜めし/釜飯"},"釜飯":{"variants":"釜めし/釜飯"},"かまゆで":{"variants":"かまゆで/釜茹で"},"釜茹で":{"variants":"かまゆで/釜茹で"},"かみあう":{"variants":"かみあう/かみ合う/噛み合う"},"かみ合う":{"variants":"かみあう/かみ合う/噛み合う"},"噛み合う":{"variants":"かみあう/かみ合う/噛み合う"},"かみあわす":{"variants":"かみあわす/噛み合わす"},"噛み合わす":{"variants":"かみあわす/噛み合わす"},"かみあわせる":{"variants":"かみあわせる/噛み合せる"},"噛み合せる":{"variants":"かみあわせる/噛み合せる"},"神降し":{"variants":"神降し/神降ろし"},"神降ろし":{"variants":"神降し/神降ろし"},"神がかり":{"variants":"神がかり/神憑り"},"神憑り":{"variants":"神がかり/神憑り"},"かみきり虫":{"variants":"かみきり虫/カミキリムシ/髪切り虫/髪切虫"},"カミキリムシ":{"variants":"かみきり虫/カミキリムシ/髪切り虫/髪切虫"},"髪切り虫":{"variants":"かみきり虫/カミキリムシ/髪切り虫/髪切虫"},"髪切虫":{"variants":"かみきり虫/カミキリムシ/髪切り虫/髪切虫"},"紙きれ":{"variants":"紙きれ/紙切れ"},"紙切れ":{"variants":"紙きれ/紙切れ"},"紙くず":{"variants":"紙くず/紙屑"},"紙屑":{"variants":"紙くず/紙屑"},"かみくだく":{"variants":"かみくだく/噛みくだく/噛み砕く"},"噛みくだく":{"variants":"かみくだく/噛みくだく/噛み砕く"},"噛み砕く":{"variants":"かみくだく/噛みくだく/噛み砕く"},"かみくだける":{"variants":"かみくだける/噛み砕ける"},"噛み砕ける":{"variants":"かみくだける/噛み砕ける"},"かみころす":{"variants":"かみころす/かみ殺す/噛みころす/噛み殺す"},"かみ殺す":{"variants":"かみころす/かみ殺す/噛みころす/噛み殺す"},"噛みころす":{"variants":"かみころす/かみ殺す/噛みころす/噛み殺す"},"噛み殺す":{"variants":"かみころす/かみ殺す/噛みころす/噛み殺す"},"かみころせる":{"variants":"かみころせる/かみ殺せる"},"かみ殺せる":{"variants":"かみころせる/かみ殺せる"},"かみさびる":{"variants":"かみさびる/神さびる"},"神さびる":{"variants":"かみさびる/神さびる"},"神さま":{"variants":"神さま/神様"},"神様":{"variants":"神さま/神様"},"かみさん":{"variants":"かみさん/カミさん"},"カミさん":{"variants":"かみさん/カミさん"},"かみしだく":{"variants":"かみしだく/噛みしだく"},"噛みしだく":{"variants":"かみしだく/噛みしだく"},"かみしめる":{"variants":"かみしめる/かみ締める/噛みしめる/噛み締める"},"かみ締める":{"variants":"かみしめる/かみ締める/噛みしめる/噛み締める"},"噛みしめる":{"variants":"かみしめる/かみ締める/噛みしめる/噛み締める"},"噛み締める":{"variants":"かみしめる/かみ締める/噛みしめる/噛み締める"},"紙すき":{"variants":"紙すき/紙漉き"},"紙漉き":{"variants":"紙すき/紙漉き"},"カミソリ":{"variants":"カミソリ/剃刀"},"剃刀":{"variants":"カミソリ/剃刀"},"噛みたばこ":{"variants":"噛みたばこ/噛み煙草/噛煙草"},"噛み煙草":{"variants":"噛みたばこ/噛み煙草/噛煙草"},"噛煙草":{"variants":"噛みたばこ/噛み煙草/噛煙草"},"かみつく":{"variants":"かみつく/カミつく/噛みつく/噛み付く"},"カミつく":{"variants":"かみつく/カミつく/噛みつく/噛み付く"},"噛みつく":{"variants":"かみつく/カミつく/噛みつく/噛み付く"},"噛み付く":{"variants":"かみつく/カミつく/噛みつく/噛み付く"},"紙つぶて":{"variants":"紙つぶて/紙礫"},"紙礫":{"variants":"紙つぶて/紙礫"},"紙ばさみ":{"variants":"紙ばさみ/紙挟み"},"紙挟み":{"variants":"紙ばさみ/紙挟み"},"紙ふぶき":{"variants":"紙ふぶき/紙吹雪"},"紙吹雪":{"variants":"紙ふぶき/紙吹雪"},"紙巻":{"variants":"紙巻/紙巻き"},"紙巻き":{"variants":"紙巻/紙巻き"},"髪結":{"variants":"髪結/髪結い"},"髪結い":{"variants":"髪結/髪結い"},"かみわける":{"variants":"かみわける/噛みわける/噛み分ける"},"噛みわける":{"variants":"かみわける/噛みわける/噛み分ける"},"噛み分ける":{"variants":"かみわける/噛みわける/噛み分ける"},"かむ":{"variants":"かむ/噛む/咬む/嚼む"},"かめ":{"variants":"かめ/カメ/亀/龜"},"カメ":{"variants":"かめ/カメ/亀/龜"},"かめの子":{"variants":"かめの子/龜の子"},"龜の子":{"variants":"かめの子/龜の子"},"かめの甲":{"variants":"かめの甲/亀の甲/龜の甲"},"亀の子束子":{"variants":"亀の子だわし/亀の子束子"},"亀の子だわし":{"variants":"亀の子だわし/亀の子束子"},"カメムシ":{"variants":"カメムシ/龜虫"},"龜虫":{"variants":"カメムシ/龜虫"},"かめる":{"variants":"かめる/噛める/咬める"},"かも":{"variants":"かも/カモ/鴨"},"カモ":{"variants":"かも/カモ/鴨"},"鴨":{"variants":"かも/カモ/鴨"},"カモシカ":{"variants":"カモシカ/羚羊"},"羚羊":{"variants":"カモシカ/羚羊"},"かもしだす":{"variants":"かもしだす/かもし出す/醸し出す"},"かもし出す":{"variants":"かもしだす/かもし出す/醸し出す"},"醸し出す":{"variants":"かもしだす/かもし出す/醸し出す"},"かもしだせる":{"variants":"かもしだせる/醸し出せる"},"醸し出せる":{"variants":"かもしだせる/醸し出せる"},"かもす":{"variants":"かもす/醸す"},"醸す":{"variants":"かもす/醸す"},"かもせる":{"variants":"かもせる/醸せる"},"醸せる":{"variants":"かもせる/醸せる"},"カモノハシ":{"variants":"カモノハシ/鴨の嘴/鴨嘴"},"鴨の嘴":{"variants":"カモノハシ/鴨の嘴/鴨嘴"},"鴨嘴":{"variants":"カモノハシ/鴨の嘴/鴨嘴"},"カモメ":{"variants":"カモメ/鴎"},"鴎":{"variants":"カモメ/鴎"},"カヤ":{"variants":"カヤ/蚊屋/蚊帳/茅/萱/榧"},"カヤツリグサ":{"variants":"カヤツリグサ/蚊屋釣草"},"蚊屋釣草":{"variants":"カヤツリグサ/蚊屋釣草"},"カヤぶき":{"variants":"カヤぶき/茅ぶき/茅葺き"},"茅ぶき":{"variants":"カヤぶき/茅ぶき/茅葺き"},"茅葺き":{"variants":"カヤぶき/茅ぶき/茅葺き"},"かゆい":{"variants":"かゆい/痒い"},"痒い":{"variants":"かゆい/痒い"},"かよう":{"variants":"かよう/通う"},"通う":{"variants":"かよう/通う"},"かよえる":{"variants":"かよえる/通える"},"通える":{"variants":"かよえる/通える"},"かよわい":{"variants":"かよわい/か弱い"},"か弱い":{"variants":"かよわい/か弱い"},"かよわす":{"variants":"かよわす/通わす"},"通わす":{"variants":"かよわす/通わす"},"カラ":{"variants":"カラ/殻"},"殻":{"variants":"カラ/殻"},"空くじ":{"variants":"空くじ/空籤"},"空籤":{"variants":"空くじ/空籤"},"から口":{"variants":"から口/辛口"},"辛口":{"variants":"から口/辛口"},"からくり":{"variants":"からくり/カラクリ"},"カラクリ":{"variants":"からくり/カラクリ"},"からげる":{"variants":"からげる/絡げる"},"絡げる":{"variants":"からげる/絡げる"},"から元気":{"variants":"から元気/空元気"},"空元気":{"variants":"から元気/空元気"},"カラシナ":{"variants":"カラシナ/芥子菜"},"芥子菜":{"variants":"カラシナ/芥子菜"},"からす":{"variants":"からす/枯らす/嗄らす/涸らす"},"カラス":{"variants":"カラス/烏/鴉"},"からす瓜":{"variants":"からす瓜/カラスウリ/烏瓜"},"カラスウリ":{"variants":"からす瓜/カラスウリ/烏瓜"},"烏瓜":{"variants":"からす瓜/カラスウリ/烏瓜"},"カラスガイ":{"variants":"カラスガイ/烏貝"},"烏貝":{"variants":"カラスガイ/烏貝"},"カラスヘビ":{"variants":"カラスヘビ/烏蛇"},"烏蛇":{"variants":"カラスヘビ/烏蛇"},"カラスムギ":{"variants":"カラスムギ/烏麦"},"烏麦":{"variants":"カラスムギ/烏麦"},"カラタケ":{"variants":"カラタケ/幹竹/唐竹"},"カラタチ":{"variants":"カラタチ/枳殻"},"枳殻":{"variants":"カラタチ/枳殻"},"カラタチバナ":{"variants":"カラタチバナ/唐橘"},"唐橘":{"variants":"カラタチバナ/唐橘"},"からだ":{"variants":"からだ/躰"},"躰":{"variants":"からだ/躰"},"からっ風":{"variants":"からっ風/空っ風"},"空っ風":{"variants":"からっ風/空っ風"},"からっと":{"variants":"からっと/カラッと"},"カラッと":{"variants":"からっと/カラッと"},"からっ下手":{"variants":"からっ下手/空っ下手"},"空っ下手":{"variants":"からっ下手/空っ下手"},"からっぽ":{"variants":"からっぽ/空っぽ"},"空っぽ":{"variants":"からっぽ/空っぽ"},"唐びつ":{"variants":"唐びつ/唐櫃"},"唐櫃":{"variants":"唐びつ/唐櫃"},"からびる":{"variants":"からびる/乾びる"},"乾びる":{"variants":"からびる/乾びる"},"からます":{"variants":"からます/絡ます"},"絡ます":{"variants":"からます/絡ます"},"からませる":{"variants":"からませる/絡ませる"},"絡ませる":{"variants":"からませる/絡ませる"},"カラマツ":{"variants":"カラマツ/唐松/落葉松"},"からまる":{"variants":"からまる/絡まる"},"絡まる":{"variants":"からまる/絡まる"},"辛味":{"variants":"辛み/辛味"},"辛み":{"variants":"辛み/辛味"},"からみあう":{"variants":"からみあう/絡み合う"},"絡み合う":{"variants":"からみあう/絡み合う"},"辛みそ":{"variants":"辛みそ/辛味噌"},"辛味噌":{"variants":"辛みそ/辛味噌"},"からみつく":{"variants":"からみつく/絡みつく/絡み付く"},"絡みつく":{"variants":"からみつく/絡みつく/絡み付く"},"絡み付く":{"variants":"からみつく/絡みつく/絡み付く"},"からむ":{"variants":"からむ/絡む"},"絡む":{"variants":"からむ/絡む"},"辛め":{"variants":"辛め/辛目"},"辛目":{"variants":"辛め/辛目"},"からめ手":{"variants":"からめ手/搦手"},"搦手":{"variants":"からめ手/搦手"},"からめる":{"variants":"からめる/絡める/搦める"},"カリ":{"variants":"カリ/仮/仮り/加里/刈/苅/借り/狩/狩り"},"仮":{"variants":"カリ/仮/仮り"},"狩り":{"variants":"カリ/狩/狩り"},"狩":{"variants":"カリ/狩/狩り"},"仮り":{"variants":"カリ/仮/仮り"},"借り上げ":{"variants":"借り上げ/借上げ"},"刈り上げ":{"variants":"刈り上げ/刈上げ"},"借上げ":{"variants":"借り上げ/借上げ"},"刈上げ":{"variants":"刈り上げ/刈上げ"},"かりあげる":{"variants":"かりあげる/刈り上げる/借り上げる"},"かりあつめる":{"variants":"かりあつめる/かり集める/駆り集める/駆集める/借り集める"},"かり集める":{"variants":"かりあつめる/かり集める/駆り集める/駆集める/借り集める"},"駆り集める":{"variants":"かりあつめる/かり集める/駆り集める/駆集める"},"駆集める":{"variants":"かりあつめる/かり集める/駆り集める/駆集める"},"借入":{"variants":"借入/借入れ"},"借入れ":{"variants":"借入/借入れ"},"かりいれる":{"variants":"かりいれる/刈り入れる/刈入れる/借り入れる/借入れる"},"借り入れる":{"variants":"かりいれる/借り入れる/借入れる"},"刈り入れる":{"variants":"かりいれる/刈り入れる/刈入れる"},"借入れる":{"variants":"かりいれる/借り入れる/借入れる"},"刈入れる":{"variants":"かりいれる/刈り入れる/刈入れる"},"かりうける":{"variants":"かりうける/借り受ける/借受ける"},"借り受ける":{"variants":"かりうける/借り受ける/借受ける"},"借受ける":{"variants":"かりうける/借り受ける/借受ける"},"かりかえる":{"variants":"かりかえる/借り換える/借換える"},"借り換える":{"variants":"かりかえる/借り換える/借換える"},"借換える":{"variants":"かりかえる/借り換える/借換える"},"借り方":{"variants":"借り方/借方"},"借方":{"variants":"借り方/借方"},"かりきる":{"variants":"かりきる/借り切る/借切る"},"借り切る":{"variants":"かりきる/借り切る/借切る"},"借切る":{"variants":"かりきる/借り切る/借切る"},"借り着":{"variants":"借り着/借着"},"借着":{"variants":"借り着/借着"},"かりこす":{"variants":"かりこす/借り越す"},"借り越す":{"variants":"かりこす/借り越す"},"狩り込み":{"variants":"狩り込み/狩込み"},"狩込み":{"variants":"狩り込み/狩込み"},"かりこむ":{"variants":"かりこむ/刈り込む/刈込む"},"刈り込む":{"variants":"かりこむ/刈り込む/刈込む"},"刈込む":{"variants":"かりこむ/刈り込む/刈込む"},"仮住い":{"variants":"仮住い/仮住まい"},"仮住まい":{"variants":"仮住い/仮住まい"},"仮りそめ":{"variants":"仮りそめ/仮初"},"仮初":{"variants":"仮りそめ/仮初"},"かりたおす":{"variants":"かりたおす/借り倒す/借倒す"},"借り倒す":{"variants":"かりたおす/借り倒す/借倒す"},"借倒す":{"variants":"かりたおす/借り倒す/借倒す"},"かりたてる":{"variants":"かりたてる/駆りたてる/駆り立てる/駆立てる"},"駆りたてる":{"variants":"かりたてる/駆りたてる/駆り立てる/駆立てる"},"駆り立てる":{"variants":"かりたてる/駆りたてる/駆り立てる/駆立てる"},"駆立てる":{"variants":"かりたてる/駆りたてる/駆り立てる/駆立てる"},"かりだす":{"variants":"かりだす/かり出す/駆り出す/借り出す/狩り出す/狩出す"},"かり出す":{"variants":"かりだす/かり出す/駆り出す/借り出す/狩り出す/狩出す"},"狩り出す":{"variants":"かりだす/かり出す/狩り出す/狩出す"},"狩出す":{"variants":"かりだす/かり出す/狩り出す/狩出す"},"借り手":{"variants":"借り手/借手"},"借手":{"variants":"借り手/借手"},"かりとる":{"variants":"かりとる/刈りとる/刈り取る/刈取る"},"刈りとる":{"variants":"かりとる/刈りとる/刈り取る/刈取る"},"刈り取る":{"variants":"かりとる/刈りとる/刈り取る/刈取る"},"刈取る":{"variants":"かりとる/刈りとる/刈り取る/刈取る"},"かりとれる":{"variants":"かりとれる/刈り取れる"},"刈り取れる":{"variants":"かりとれる/刈り取れる"},"かりに":{"variants":"かりに/仮に"},"仮に":{"variants":"かりに/仮に"},"借り主":{"variants":"借り主/借主"},"借主":{"variants":"借り主/借主"},"狩り場":{"variants":"狩り場/狩場"},"狩場":{"variants":"狩り場/狩場"},"刈り穂":{"variants":"刈り穂/刈穂"},"刈穂":{"variants":"刈り穂/刈穂"},"借り物":{"variants":"借り物/借物"},"借物":{"variants":"借り物/借物"},"かりもよおす":{"variants":"かりもよおす/駆り催す/駆催す"},"駆り催す":{"variants":"かりもよおす/駆り催す/駆催す"},"駆催す":{"variants":"かりもよおす/駆り催す/駆催す"},"かりる":{"variants":"かりる/借りる"},"借りる":{"variants":"かりる/借りる"},"カリン":{"variants":"カリン/花梨"},"花梨":{"variants":"カリン/花梨"},"かりん糖":{"variants":"かりん糖/花林糖"},"花林糖":{"variants":"かりん糖/花林糖"},"かる":{"variants":"かる/穫る/刈る/苅る/駆る/駈る/借る/狩る"},"かるい":{"variants":"かるい/軽い"},"軽い":{"variants":"かるい/軽い"},"カルカヤ":{"variants":"カルカヤ/刈萱"},"刈萱":{"variants":"カルカヤ/刈萱"},"かるがる":{"variants":"かるがる/軽々/軽軽"},"軽々":{"variants":"軽々/軽軽"},"軽軽":{"variants":"軽々/軽軽"},"かるがるしい":{"variants":"かるがるしい/軽々しい/軽軽しい"},"軽々しい":{"variants":"かるがるしい/軽々しい/軽軽しい"},"軽軽しい":{"variants":"かるがるしい/軽々しい/軽軽しい"},"かるがると":{"variants":"かるがると/軽々と/軽軽と"},"軽々と":{"variants":"かるがると/軽々と/軽軽と"},"軽軽と":{"variants":"かるがると/軽々と/軽軽と"},"カルメやき":{"variants":"カルメやき/カルメ焼/カルメ焼き"},"カルメ焼":{"variants":"カルメやき/カルメ焼/カルメ焼き"},"カルメ焼き":{"variants":"カルメやき/カルメ焼/カルメ焼き"},"軽焼":{"variants":"軽焼/軽焼きせんべい"},"軽焼きせんべい":{"variants":"軽焼/軽焼きせんべい"},"カレイ":{"variants":"カレイ/佳麗/嘉例/家令/家例/華麗/鰔/鰈"},"枯れ枝":{"variants":"枯れ枝/枯枝"},"枯枝":{"variants":"枯れ枝/枯枝"},"枯れ尾花":{"variants":"枯れ尾花/枯尾花"},"枯尾花":{"variants":"枯れ尾花/枯尾花"},"枯れ木":{"variants":"枯れ木/枯木"},"枯木":{"variants":"枯れ木/枯木"},"カレシ":{"variants":"カレシ/彼氏"},"彼氏":{"variants":"カレシ/彼氏"},"枯れすすき":{"variants":"枯れすすき/枯れ薄"},"枯れ薄":{"variants":"枯れすすき/枯れ薄"},"枯れ葉":{"variants":"枯れ葉/枯葉"},"枯葉":{"variants":"枯れ葉/枯葉"},"かればむ":{"variants":"かればむ/枯ればむ"},"枯ればむ":{"variants":"かればむ/枯ればむ"},"彼ら":{"variants":"彼ら/彼等"},"彼等":{"variants":"彼ら/彼等"},"かれる":{"variants":"かれる/渇れる/枯れる/借れる/涸れる"},"可れん":{"variants":"可れん/可憐"},"可憐":{"variants":"可れん/可憐"},"かろうじて":{"variants":"かろうじて/辛うじて"},"辛うじて":{"variants":"かろうじて/辛うじて"},"かろしめる":{"variants":"かろしめる/軽しめる"},"軽しめる":{"variants":"かろしめる/軽しめる"},"ｃａｌ":{"variants":"ｃａｌ/カロリー"},"カロリー":{"variants":"ｃａｌ/カロリー"},"かろんずる":{"variants":"かろんずる/軽んずる"},"軽んずる":{"variants":"かろんずる/軽んずる"},"かわいい":{"variants":"かわいい/可愛い"},"可愛い":{"variants":"かわいい/可愛い"},"かわいがる":{"variants":"かわいがる/可愛がる"},"可愛がる":{"variants":"かわいがる/可愛がる"},"かわいがれる":{"variants":"かわいがれる/可愛がれる"},"可愛がれる":{"variants":"かわいがれる/可愛がれる"},"かわいそう":{"variants":"かわいそう/可哀想/可哀相"},"かわいらしい":{"variants":"かわいらしい/可愛らしい"},"可愛らしい":{"variants":"かわいらしい/可愛らしい"},"カワウソ":{"variants":"カワウソ/川獺"},"川獺":{"variants":"カワウソ/川獺"},"かわかす":{"variants":"かわかす/渇かす/乾かす"},"かわく":{"variants":"かわく/渇く/乾く"},"かわす":{"variants":"かわす/交す/交わす/買わす/躱す"},"交す":{"variants":"かわす/交す/交わす"},"交わす":{"variants":"かわす/交す/交わす"},"川すじ":{"variants":"川すじ/川筋"},"川筋":{"variants":"川すじ/川筋"},"カワセミ":{"variants":"カワセミ/川蝉"},"川蝉":{"variants":"カワセミ/川蝉"},"かわせる":{"variants":"かわせる/交わせる"},"交わせる":{"variants":"かわせる/交わせる"},"カワハギ":{"variants":"カワハギ/皮剥"},"皮剥":{"variants":"カワハギ/皮剥"},"カワホネ":{"variants":"カワホネ/河骨"},"河骨":{"variants":"カワホネ/河骨"},"カワホリ":{"variants":"カワホリ/蝙蝠"},"蝙蝠":{"variants":"カワホリ/蝙蝠"},"カワヤナギ":{"variants":"カワヤナギ/水楊/楊柳"},"瓦せんべい":{"variants":"瓦せんべい/瓦煎餅"},"瓦煎餅":{"variants":"瓦せんべい/瓦煎餅"},"カワラナデシコ":{"variants":"カワラナデシコ/河原撫子/川原撫子"},"かわら版":{"variants":"かわら版/瓦版"},"瓦版":{"variants":"かわら版/瓦版"},"かわり":{"variants":"かわり/替り/代り/代わり/変り"},"代り":{"variants":"かわり/代り/代わり"},"代わり":{"variants":"かわり/代り/代わり"},"変りだね":{"variants":"変りだね/変り種/変わり種"},"変り種":{"variants":"変りだね/変り種/変わり種"},"変わり種":{"variants":"変りだね/変り種/変わり種"},"かわりはてる":{"variants":"かわりはてる/変りはてる/変り果てる/変わり果てる"},"変りはてる":{"variants":"かわりはてる/変りはてる/変り果てる/変わり果てる"},"変り果てる":{"variants":"かわりはてる/変りはてる/変り果てる/変わり果てる"},"変わり果てる":{"variants":"かわりはてる/変りはてる/変り果てる/変わり果てる"},"代りばえ":{"variants":"代りばえ/代り映え/代わり映え"},"代り映え":{"variants":"代りばえ/代り映え/代わり映え"},"代わり映え":{"variants":"代りばえ/代り映え/代わり映え"},"変り目":{"variants":"変り目/変わり目"},"変わり目":{"variants":"変り目/変わり目"},"変りもの":{"variants":"変りもの/変り者/変わり者"},"変り者":{"variants":"変りもの/変り者/変わり者"},"変わり者":{"variants":"変りもの/変り者/変わり者"},"かわる":{"variants":"かわる/換わる/替る/替わる/代る/代わる/変る/変わる"},"代る":{"variants":"かわる/代る/代わる"},"代わる":{"variants":"かわる/代る/代わる"},"替る":{"variants":"かわる/替る/替わる"},"変る":{"variants":"かわる/変る/変わる"},"替わる":{"variants":"かわる/替る/替わる"},"変わる":{"variants":"かわる/変る/変わる"},"かわるがわる":{"variants":"かわるがわる/代るがわる/代る代る"},"代るがわる":{"variants":"かわるがわる/代るがわる/代る代る"},"代る代る":{"variants":"かわるがわる/代るがわる/代る代る"},"かわれる":{"variants":"かわれる/替われる/代われる"},"かん":{"variants":"かん/カン/寒/勘/完/感/缶/艦/観/鑑/燗/疳/癇/鐶"},"カン":{"variants":"かん/カン/寒/勘/完/感/缶/艦/観/鑑/燗/疳/癇/鐶"},"かんあい":{"variants":"かんあい/寒靄"},"寒靄":{"variants":"かんあい/寒靄"},"かんおけ":{"variants":"かんおけ/棺おけ/棺桶"},"棺おけ":{"variants":"かんおけ/棺おけ/棺桶"},"棺桶":{"variants":"かんおけ/棺おけ/棺桶"},"閑々":{"variants":"閑々/閑閑"},"閑閑":{"variants":"閑々/閑閑"},"侃々諤々":{"variants":"侃々諤々/侃侃諤諤"},"侃侃諤諤":{"variants":"侃々諤々/侃侃諤諤"},"かんがい":{"variants":"かんがい/寒害/干害/感慨/管外/旱害"},"かんがえこむ":{"variants":"かんがえこむ/考え込む"},"考え込む":{"variants":"かんがえこむ/考え込む"},"考えごと":{"variants":"考えごと/考え事"},"考え事":{"variants":"考えごと/考え事"},"かんがえだす":{"variants":"かんがえだす/考え出す"},"考え出す":{"variants":"かんがえだす/考え出す"},"かんがえだせる":{"variants":"かんがえだせる/考え出せる"},"考え出せる":{"variants":"かんがえだせる/考え出せる"},"かんがえつく":{"variants":"かんがえつく/考えつく/考え付く"},"考えつく":{"variants":"かんがえつく/考えつく/考え付く"},"考え付く":{"variants":"かんがえつく/考えつく/考え付く"},"かんがえなおす":{"variants":"かんがえなおす/考え直す"},"考え直す":{"variants":"かんがえなおす/考え直す"},"かんがえぬく":{"variants":"かんがえぬく/考え抜く"},"考え抜く":{"variants":"かんがえぬく/考え抜く"},"考えもの":{"variants":"考えもの/考え物"},"考え物":{"variants":"考えもの/考え物"},"かんがえる":{"variants":"かんがえる/考える"},"考える":{"variants":"かんがえる/考える"},"かんがみる":{"variants":"かんがみる/鑑みる"},"鑑みる":{"variants":"かんがみる/鑑みる"},"かんきつ類":{"variants":"かんきつ類/カンキツルイ/カンキツ類/柑橘類"},"カンキツルイ":{"variants":"かんきつ類/カンキツルイ/カンキツ類/柑橘類"},"カンキツ類":{"variants":"かんきつ類/カンキツルイ/カンキツ類/柑橘類"},"柑橘類":{"variants":"かんきつ類/カンキツルイ/カンキツ類/柑橘類"},"カンギク":{"variants":"カンギク/寒菊/観菊"},"かんぐる":{"variants":"かんぐる/勘ぐる/勘繰る"},"勘ぐる":{"variants":"かんぐる/勘ぐる/勘繰る"},"勘繰る":{"variants":"かんぐる/勘ぐる/勘繰る"},"かんけいづける":{"variants":"かんけいづける/関係付ける"},"関係付ける":{"variants":"かんけいづける/関係付ける"},"寒げいこ":{"variants":"寒げいこ/寒稽古"},"寒稽古":{"variants":"寒げいこ/寒稽古"},"間げき":{"variants":"間げき/間隙"},"間隙":{"variants":"間げき/間隙"},"かん口令":{"variants":"かん口令/箝口令"},"箝口令":{"variants":"かん口令/箝口令"},"カンコドリ":{"variants":"カンコドリ/閑古鳥"},"閑古鳥":{"variants":"カンコドリ/閑古鳥"},"かんさんと":{"variants":"かんさんと/閑散と"},"閑散と":{"variants":"かんさんと/閑散と"},"かん子":{"variants":"かん子/鉗子"},"鉗子":{"variants":"かん子/鉗子"},"感しゃ":{"variants":"感しゃ/感謝"},"感謝":{"variants":"感しゃ/感謝"},"カンシャ":{"variants":"カンシャ/官舎"},"官舎":{"variants":"カンシャ/官舎"},"カンショ":{"variants":"カンショ/官署/漢書/甘薯"},"かんじいる":{"variants":"かんじいる/感じ入る"},"感じ入る":{"variants":"かんじいる/感じ入る"},"かんじとる":{"variants":"かんじとる/感じとる/感じ取る"},"感じとる":{"variants":"かんじとる/感じとる/感じ取る"},"感じ取る":{"variants":"かんじとる/感じとる/感じ取る"},"かんじとれる":{"variants":"かんじとれる/感じとれる/感じ取れる"},"感じとれる":{"variants":"かんじとれる/感じとれる/感じ取れる"},"感じ取れる":{"variants":"かんじとれる/感じとれる/感じ取れる"},"かんじょうだかい":{"variants":"かんじょうだかい/勘定高い"},"勘定高い":{"variants":"かんじょうだかい/勘定高い"},"かんじる":{"variants":"かんじる/感じる"},"感じる":{"variants":"かんじる/感じる"},"かん水":{"variants":"かん水/冠水/潅水"},"潅水":{"variants":"かん水/潅水"},"冠水":{"variants":"かん水/冠水"},"かんする":{"variants":"かんする/冠する/観する/関する/緘する"},"かんずる":{"variants":"かんずる/感ずる/観ずる"},"乾癬":{"variants":"乾せん/乾癬"},"汗腺":{"variants":"汗せん/汗腺"},"汗せん":{"variants":"汗せん/汗腺"},"乾せん":{"variants":"乾せん/乾癬"},"かんぜん":{"variants":"かんぜん/敢然"},"敢然":{"variants":"かんぜん/敢然"},"かんぜんと":{"variants":"かんぜんと/敢然と"},"敢然と":{"variants":"かんぜんと/敢然と"},"カンゾウ":{"variants":"カンゾウ/萱草/甘草/肝臓"},"カンタン":{"variants":"カンタン/簡単/肝胆/邯鄲"},"カンタンシ":{"variants":"カンタンシ/邯鄲師"},"邯鄲師":{"variants":"カンタンシ/邯鄲師"},"かんだかい":{"variants":"かんだかい/かん高い/甲高い/疳高い"},"かん高い":{"variants":"かんだかい/かん高い/甲高い/疳高い"},"カンチク":{"variants":"カンチク/寒竹"},"寒竹":{"variants":"カンチク/寒竹"},"かん腸":{"variants":"かん腸/浣腸"},"浣腸":{"variants":"かん腸/浣腸"},"かん通":{"variants":"かん通/姦通/貫通"},"カンツバキ":{"variants":"カンツバキ/寒椿"},"寒椿":{"variants":"カンツバキ/寒椿"},"かんづく":{"variants":"かんづく/勘づく/感づく"},"缶詰":{"variants":"缶詰/缶詰め"},"缶詰め":{"variants":"缶詰/缶詰め"},"勘どころ":{"variants":"勘どころ/勘所"},"勘所":{"variants":"勘どころ/勘所"},"かんな":{"variants":"かんな/カンナ/鉋"},"カンナ":{"variants":"かんな/カンナ/鉋"},"鉋":{"variants":"かんな/カンナ/鉋"},"かんにん":{"variants":"かんにん/堪忍"},"堪忍":{"variants":"かんにん/堪忍"},"かんぬき":{"variants":"かんぬき/閂"},"閂":{"variants":"かんぬき/閂"},"かんの虫":{"variants":"かんの虫/疳のむし/疳の虫/癇のむし/癇の虫"},"疳のむし":{"variants":"かんの虫/疳のむし/疳の虫"},"癇のむし":{"variants":"かんの虫/癇のむし/癇の虫"},"疳の虫":{"variants":"かんの虫/疳のむし/疳の虫"},"癇の虫":{"variants":"かんの虫/癇のむし/癇の虫"},"カンバ":{"variants":"カンバ/汗馬/悍馬/駻馬"},"かんばしる":{"variants":"かんばしる/甲走る"},"甲走る":{"variants":"かんばしる/甲走る"},"カンパ":{"variants":"カンパ/看破"},"看破":{"variants":"カンパ/看破"},"かん発":{"variants":"かん発/渙発/煥発"},"カンパン":{"variants":"カンパン/乾パン/乾板/官版/甲板"},"乾板":{"variants":"カンパン/乾パン/乾板"},"乾パン":{"variants":"カンパン/乾パン/乾板"},"カンピョウ":{"variants":"カンピョウ/乾瓢/干ぴょう/干瓢"},"干ぴょう":{"variants":"カンピョウ/干ぴょう/干瓢"},"干瓢":{"variants":"カンピョウ/干ぴょう/干瓢"},"かんべん":{"variants":"かんべん/勘弁"},"勘弁":{"variants":"かんべん/勘弁"},"完ぺき":{"variants":"完ぺき/完璧"},"完璧":{"variants":"完ぺき/完璧"},"カンボク":{"variants":"かん木/カンボク/潅木/翰墨"},"かん木":{"variants":"かん木/カンボク/潅木"},"潅木":{"variants":"かん木/カンボク/潅木"},"かんぽ":{"variants":"かんぽ/簡保"},"簡保":{"variants":"かんぽ/簡保"},"乾めん":{"variants":"乾めん/乾麺"},"乾麺":{"variants":"乾めん/乾麺"},"涵養":{"variants":"かん養/涵養"},"かん養":{"variants":"かん養/涵養"},"カンラン":{"variants":"カンラン/寒蘭/甘藍/橄欖"},"かんれんづける":{"variants":"かんれんづける/関連づける/関連付ける"},"関連づける":{"variants":"かんれんづける/関連づける/関連付ける"},"関連付ける":{"variants":"かんれんづける/関連づける/関連付ける"},"ガ":{"variants":"ガ/臥/蛾/賀/駕"},"がい":{"variants":"がい/外/街"},"皚々":{"variants":"皚々/皚皚"},"皚皚":{"variants":"皚々/皚皚"},"外こく":{"variants":"外こく/外国"},"外国":{"variants":"外こく/外国"},"がいして":{"variants":"がいして/概して"},"概して":{"variants":"がいして/概して"},"がいす":{"variants":"がいす/害す"},"害す":{"variants":"がいす/害す"},"がいする":{"variants":"がいする/害する/慨する"},"がい旋":{"variants":"がい旋/凱旋"},"凱旋":{"variants":"がい旋/凱旋"},"がい然性":{"variants":"がい然性/蓋然性"},"蓋然性":{"variants":"がい然性/蓋然性"},"ガイチョウ":{"variants":"ガイチョウ/害鳥"},"害鳥":{"variants":"ガイチョウ/害鳥"},"外とう":{"variants":"外とう/外套/外灯"},"外灯":{"variants":"外とう/外灯"},"外套":{"variants":"外とう/外套"},"がえんずる":{"variants":"がえんずる/肯んずる"},"肯んずる":{"variants":"がえんずる/肯んずる"},"がかり":{"variants":"がかり/係"},"峨々":{"variants":"峨々/峨峨"},"峨峨":{"variants":"峨々/峨峨"},"がき":{"variants":"がき/ガキ/餓鬼"},"ガキ":{"variants":"がき/ガキ/餓鬼"},"餓鬼":{"variants":"がき/ガキ/餓鬼"},"がぎゅう":{"variants":"がぎゅう/臥牛"},"臥牛":{"variants":"がぎゅう/臥牛"},"ガク":{"variants":"ガク/学/萼"},"諤々":{"variants":"諤々/諤諤"},"諤諤":{"variants":"諤々/諤諤"},"がく然":{"variants":"がく然/愕然"},"愕然":{"variants":"がく然/愕然"},"額ぶち":{"variants":"額ぶち/額縁"},"額縁":{"variants":"額ぶち/額縁"},"がけ":{"variants":"がけ/崖"},"崖":{"variants":"がけ/崖"},"がけっぷち":{"variants":"がけっぷち/ガケっぷち/崖っぷち"},"ガケっぷち":{"variants":"がけっぷち/ガケっぷち/崖っぷち"},"崖っぷち":{"variants":"がけっぷち/ガケっぷち/崖っぷち"},"がさがさ":{"variants":"がさがさ/ガサガサ"},"ガサガサ":{"variants":"がさがさ/ガサガサ"},"ガス":{"variants":"ガス/瓦斯"},"瓦斯":{"variants":"ガス/瓦斯"},"がする":{"variants":"がする/賀する"},"賀する":{"variants":"がする/賀する"},"がぜん":{"variants":"がぜん/俄然"},"俄然":{"variants":"がぜん/俄然"},"がたい":{"variants":"がたい/難い"},"難い":{"variants":"がたい/難い"},"がたがた":{"variants":"がたがた/ガタガタ"},"ガタガタ":{"variants":"がたがた/ガタガタ"},"がちがち":{"variants":"がちがち/ガチガチ"},"ガチガチ":{"variants":"がちがち/ガチガチ"},"ガチョウ":{"variants":"ガチョウ/画帳/鵞鳥"},"がっかり":{"variants":"がっかり/ガッカリ"},"ガッカリ":{"variants":"がっかり/ガッカリ"},"がっくり":{"variants":"がっくり/ガックリ"},"ガックリ":{"variants":"がっくり/ガックリ"},"がに股":{"variants":"がに股/蟹股"},"蟹股":{"variants":"がに股/蟹股"},"画びょう":{"variants":"画びょう/画鋲"},"画鋲":{"variants":"画びょう/画鋲"},"ガホウ":{"variants":"ガホウ/芽胞"},"芽胞":{"variants":"ガホウ/芽胞"},"がま":{"variants":"がま/ガマ/蝦蟇"},"ガマ":{"variants":"がま/ガマ/蝦蟇"},"蝦蟇":{"variants":"がま/ガマ/蝦蟇"},"がま口":{"variants":"がま口/蝦蟇口"},"蝦蟇口":{"variants":"がま口/蝦蟇口"},"がまん":{"variants":"がまん/ガマン/我慢"},"ガマン":{"variants":"がまん/ガマン/我慢"},"我慢":{"variants":"がまん/ガマン/我慢"},"がまんづよい":{"variants":"がまんづよい/がまん強い/我慢強い"},"がまん強い":{"variants":"がまんづよい/がまん強い/我慢強い"},"我慢強い":{"variants":"がまんづよい/がまん強い/我慢強い"},"がみがみ":{"variants":"がみがみ/ガミガミ"},"ガミガミ":{"variants":"がみがみ/ガミガミ"},"がら":{"variants":"がら/柄"},"柄":{"variants":"がら/柄"},"がらがら":{"variants":"がらがら/ガラガラ"},"ガラガラ":{"variants":"がらがら/ガラガラ"},"がらがら蛇":{"variants":"がらがら蛇/ガラガラヘビ"},"ガラガラヘビ":{"variants":"がらがら蛇/ガラガラヘビ"},"ガラス":{"variants":"ガラス/硝子"},"硝子":{"variants":"ガラス/硝子"},"ガラス張り":{"variants":"ガラス張り/硝子張り"},"硝子張り":{"variants":"ガラス張り/硝子張り"},"がらみ":{"variants":"がらみ/絡み"},"絡み":{"variants":"がらみ/絡み"},"柄もの":{"variants":"柄もの/柄物"},"柄物":{"variants":"柄もの/柄物"},"がらり":{"variants":"がらり/ガラリ"},"ガラリ":{"variants":"がらり/ガラリ"},"がらん":{"variants":"がらん/伽藍"},"伽藍":{"variants":"がらん/伽藍"},"がり版":{"variants":"がり版/ガリ版"},"ガリ版":{"variants":"がり版/ガリ版"},"がれき":{"variants":"がれき/ガレキ/瓦礫"},"ガレキ":{"variants":"がれき/ガレキ/瓦礫"},"瓦礫":{"variants":"がれき/ガレキ/瓦礫"},"がわり":{"variants":"がわり/換わり/替わり/変わり"},"がん":{"variants":"がん/ガン/癌/龕"},"ガン":{"variants":"がん/ガン/癌/龕"},"願かけ":{"variants":"願かけ/願掛け"},"願掛け":{"variants":"願かけ/願掛け"},"がん作":{"variants":"がん作/贋作"},"贋作":{"variants":"がん作/贋作"},"がんじがらめ":{"variants":"がんじがらめ/雁字搦め"},"雁字搦め":{"variants":"がんじがらめ/雁字搦め"},"がんぜない":{"variants":"がんぜない/頑是無い"},"頑是無い":{"variants":"がんぜない/頑是無い"},"がんとして":{"variants":"がんとして/頑として"},"頑として":{"variants":"がんとして/頑として"},"がんばる":{"variants":"がんばる/ガンバる/頑張る"},"ガンバる":{"variants":"がんばる/ガンバる/頑張る"},"頑張る":{"variants":"がんばる/ガンバる/頑張る"},"がんばれる":{"variants":"がんばれる/頑張れる"},"頑張れる":{"variants":"がんばれる/頑張れる"},"ガンピ":{"variants":"ガンピ/雁皮"},"雁皮":{"variants":"ガンピ/雁皮"},"ガンピシ":{"variants":"ガンピシ/雁皮紙"},"雁皮紙":{"variants":"ガンピシ/雁皮紙"},"ガンマ線":{"variants":"ガンマ線/γ線"},"γ線":{"variants":"ガンマ線/γ線"},"がんらい":{"variants":"がんらい/元来"},"元来":{"variants":"がんらい/元来"},"ガンライコウ":{"variants":"ガンライコウ/雁来紅"},"雁来紅":{"variants":"ガンライコウ/雁来紅"},"Ｋｅｙ":{"variants":"Ｋｅｙ/キー"},"キー":{"variants":"Ｋｅｙ/キー"},"気合":{"variants":"気合/気合い"},"気合い":{"variants":"気合/気合い"},"きあわす":{"variants":"きあわす/来あわす"},"来あわす":{"variants":"きあわす/来あわす"},"きあわせる":{"variants":"きあわせる/来あわせる/来合せる"},"来あわせる":{"variants":"きあわせる/来あわせる/来合せる"},"来合せる":{"variants":"きあわせる/来あわせる/来合せる"},"キイチゴ":{"variants":"キイチゴ/木いちご/木苺"},"木いちご":{"variants":"キイチゴ/木いちご/木苺"},"木苺":{"variants":"キイチゴ/木いちご/木苺"},"黄いろ":{"variants":"黄いろ/黄色"},"黄色":{"variants":"黄いろ/黄色"},"きいろい":{"variants":"きいろい/黄いろい/黄色い"},"黄いろい":{"variants":"きいろい/黄いろい/黄色い"},"黄色い":{"variants":"きいろい/黄いろい/黄色い"},"きえいる":{"variants":"きえいる/消え入る"},"消え入る":{"variants":"きえいる/消え入る"},"きえうせる":{"variants":"きえうせる/消えうせる/消え失せる"},"消えうせる":{"variants":"きえうせる/消えうせる/消え失せる"},"消え失せる":{"variants":"きえうせる/消えうせる/消え失せる"},"きえさる":{"variants":"きえさる/消え去る"},"消え去る":{"variants":"きえさる/消え去る"},"きえのこる":{"variants":"きえのこる/消え残る"},"消え残る":{"variants":"きえのこる/消え残る"},"きえはてる":{"variants":"きえはてる/消えはてる/消え果てる"},"消えはてる":{"variants":"きえはてる/消えはてる/消え果てる"},"消え果てる":{"variants":"きえはてる/消えはてる/消え果てる"},"きえる":{"variants":"きえる/消える"},"消える":{"variants":"きえる/消える"},"きおいたつ":{"variants":"きおいたつ/気負い立つ/競い立つ"},"競いはだ":{"variants":"競いはだ/競い肌"},"競い肌":{"variants":"競いはだ/競い肌"},"きおう":{"variants":"きおう/気負う"},"気負う":{"variants":"きおう/気負う"},"きかざる":{"variants":"きかざる/着飾る"},"着飾る":{"variants":"きかざる/着飾る"},"きかざれる":{"variants":"きかざれる/着飾れる"},"着飾れる":{"variants":"きかざれる/着飾れる"},"きかす":{"variants":"きかす/聞かす/利かす"},"きかん坊":{"variants":"きかん坊/利かんぼう/利かん坊"},"利かんぼう":{"variants":"きかん坊/利かんぼう/利かん坊"},"利かん坊":{"variants":"きかん坊/利かんぼう/利かん坊"},"きがえる":{"variants":"きがえる/着替える"},"着替える":{"variants":"きがえる/着替える"},"気がかり":{"variants":"気がかり/気掛かり/気掛り"},"気掛り":{"variants":"気がかり/気掛かり/気掛り"},"気掛かり":{"variants":"気がかり/気掛かり/気掛り"},"気がつく":{"variants":"気がつく/気が付く"},"気が付く":{"variants":"気がつく/気が付く"},"気がね":{"variants":"気がね/気兼ね"},"気兼ね":{"variants":"気がね/気兼ね"},"きがまえる":{"variants":"きがまえる/気構える"},"気構える":{"variants":"きがまえる/気構える"},"きがるい":{"variants":"きがるい/気軽い"},"気軽い":{"variants":"きがるい/気軽い"},"きき":{"variants":"きき/危き/危機/器機/嬉々/嬉嬉/既記/機器/鬼気/毀棄"},"嬉々":{"variants":"きき/嬉々/嬉嬉"},"危き":{"variants":"きき/危き/危機"},"危機":{"variants":"きき/危き/危機"},"嬉嬉":{"variants":"きき/嬉々/嬉嬉"},"ききあきる":{"variants":"ききあきる/聞きあきる"},"聞きあきる":{"variants":"ききあきる/聞きあきる"},"ききあわす":{"variants":"ききあわす/聞き合わす"},"聞き合わす":{"variants":"ききあわす/聞き合わす"},"ききあわせる":{"variants":"ききあわせる/聞きあわせる/聞き合せる/聞き合わせる"},"聞きあわせる":{"variants":"ききあわせる/聞きあわせる/聞き合せる/聞き合わせる"},"聞き合せる":{"variants":"ききあわせる/聞きあわせる/聞き合せる/聞き合わせる"},"聞き合わせる":{"variants":"ききあわせる/聞きあわせる/聞き合せる/聞き合わせる"},"ききいる":{"variants":"ききいる/聴き入る/聞き入る"},"ききいれる":{"variants":"ききいれる/聞きいれる/聞き入れる/聞入れる"},"聞きいれる":{"variants":"ききいれる/聞きいれる/聞き入れる/聞入れる"},"聞き入れる":{"variants":"ききいれる/聞きいれる/聞き入れる/聞入れる"},"聞入れる":{"variants":"ききいれる/聞きいれる/聞き入れる/聞入れる"},"利き腕":{"variants":"利き腕/利腕"},"利腕":{"variants":"利き腕/利腕"},"ききおく":{"variants":"ききおく/聞き置く/聞置く"},"聞き置く":{"variants":"ききおく/聞き置く/聞置く"},"聞置く":{"variants":"ききおく/聞き置く/聞置く"},"ききおとす":{"variants":"ききおとす/聞き落す"},"聞き落す":{"variants":"ききおとす/聞き落す"},"聞き覚え":{"variants":"聞き覚え/聞覚え"},"聞覚え":{"variants":"聞き覚え/聞覚え"},"ききおよぶ":{"variants":"ききおよぶ/聞きおよぶ/聞き及ぶ/聞及ぶ"},"聞きおよぶ":{"variants":"ききおよぶ/聞きおよぶ/聞き及ぶ/聞及ぶ"},"聞き及ぶ":{"variants":"ききおよぶ/聞きおよぶ/聞き及ぶ/聞及ぶ"},"聞及ぶ":{"variants":"ききおよぶ/聞きおよぶ/聞き及ぶ/聞及ぶ"},"奇々怪々":{"variants":"奇々怪々/奇奇怪怪"},"奇奇怪怪":{"variants":"奇々怪々/奇奇怪怪"},"ききかえす":{"variants":"ききかえす/聞きかえす/聞き返す/聞返す"},"聞きかえす":{"variants":"ききかえす/聞きかえす/聞き返す/聞返す"},"聞き返す":{"variants":"ききかえす/聞きかえす/聞き返す/聞返す"},"聞返す":{"variants":"ききかえす/聞きかえす/聞き返す/聞返す"},"ききかえせる":{"variants":"ききかえせる/聞き返せる"},"聞き返せる":{"variants":"ききかえせる/聞き返せる"},"ききかじる":{"variants":"ききかじる/聞きかじる/聞き齧る"},"聞きかじる":{"variants":"ききかじる/聞きかじる/聞き齧る"},"聞き齧る":{"variants":"ききかじる/聞きかじる/聞き齧る"},"聞き書き":{"variants":"聞き書き/聞書"},"聞書":{"variants":"聞き書き/聞書"},"ききぐるしい":{"variants":"ききぐるしい/聞き苦しい/聞苦しい"},"聞き苦しい":{"variants":"ききぐるしい/聞き苦しい/聞苦しい"},"聞苦しい":{"variants":"ききぐるしい/聞き苦しい/聞苦しい"},"ききこむ":{"variants":"ききこむ/聴き込む/聞き込む/聞込む"},"聞込む":{"variants":"ききこむ/聞き込む/聞込む"},"聞き込む":{"variants":"ききこむ/聞き込む/聞込む"},"ききこめる":{"variants":"ききこめる/聞き込める"},"聞き込める":{"variants":"ききこめる/聞き込める"},"きき酒":{"variants":"きき酒/聞酒/利酒"},"聞き上手":{"variants":"聞き上手/聞上手"},"聞上手":{"variants":"聞き上手/聞上手"},"ききすごす":{"variants":"ききすごす/聞きすごす/聞き過す/聞過す"},"聞きすごす":{"variants":"ききすごす/聞きすごす/聞き過す/聞過す"},"聞き過す":{"variants":"ききすごす/聞きすごす/聞き過す/聞過す"},"聞過す":{"variants":"ききすごす/聞きすごす/聞き過す/聞過す"},"ききすます":{"variants":"ききすます/聞きすます/聞き澄ます/聞澄ます"},"聞きすます":{"variants":"ききすます/聞きすます/聞き澄ます/聞澄ます"},"聞き澄ます":{"variants":"ききすます/聞きすます/聞き澄ます/聞澄ます"},"聞澄ます":{"variants":"ききすます/聞きすます/聞き澄ます/聞澄ます"},"ききそこなう":{"variants":"ききそこなう/聞きそこなう/聞き損なう/聞損なう"},"聞きそこなう":{"variants":"ききそこなう/聞きそこなう/聞き損なう/聞損なう"},"聞き損なう":{"variants":"ききそこなう/聞きそこなう/聞き損なう/聞損なう"},"聞損なう":{"variants":"ききそこなう/聞きそこなう/聞き損なう/聞損なう"},"ききただす":{"variants":"ききただす/聞きただす/聞き糺す"},"聞きただす":{"variants":"ききただす/聞きただす/聞き糺す"},"聞き糺す":{"variants":"ききただす/聞きただす/聞き糺す"},"ききただせる":{"variants":"ききただせる/聞きただせる"},"聞きただせる":{"variants":"ききただせる/聞きただせる"},"ききだす":{"variants":"ききだす/聞きだす/聞き出す/聞出す"},"聞きだす":{"variants":"ききだす/聞きだす/聞き出す/聞出す"},"聞き出す":{"variants":"ききだす/聞きだす/聞き出す/聞出す"},"聞出す":{"variants":"ききだす/聞きだす/聞き出す/聞出す"},"ききだせる":{"variants":"ききだせる/聞き出せる"},"聞き出せる":{"variants":"ききだせる/聞き出せる"},"ききつける":{"variants":"ききつける/聞きつける/聞き付ける/聞付ける"},"聞きつける":{"variants":"ききつける/聞きつける/聞き付ける/聞付ける"},"聞き付ける":{"variants":"ききつける/聞きつける/聞き付ける/聞付ける"},"聞付ける":{"variants":"ききつける/聞きつける/聞き付ける/聞付ける"},"ききづらい":{"variants":"ききづらい/聞きづらい/聞き辛い/聞辛い"},"聞きづらい":{"variants":"ききづらい/聞きづらい/聞き辛い/聞辛い"},"聞き辛い":{"variants":"ききづらい/聞きづらい/聞き辛い/聞辛い"},"聞辛い":{"variants":"ききづらい/聞きづらい/聞き辛い/聞辛い"},"聞手":{"variants":"聞き手/聞手"},"聞き手":{"variants":"聞き手/聞手"},"利手":{"variants":"利き手/利手"},"利き手":{"variants":"利き手/利手"},"ききとがめる":{"variants":"ききとがめる/聞きとがめる/聞き咎める"},"聞きとがめる":{"variants":"ききとがめる/聞きとがめる/聞き咎める"},"聞き咎める":{"variants":"ききとがめる/聞きとがめる/聞き咎める"},"ききとどける":{"variants":"ききとどける/聞きとどける/聞き届ける/聞届ける"},"聞きとどける":{"variants":"ききとどける/聞きとどける/聞き届ける/聞届ける"},"聞き届ける":{"variants":"ききとどける/聞きとどける/聞き届ける/聞届ける"},"聞届ける":{"variants":"ききとどける/聞きとどける/聞き届ける/聞届ける"},"ききとる":{"variants":"ききとる/聞き取る/聞取る"},"聞き取る":{"variants":"ききとる/聞き取る/聞取る"},"聞取る":{"variants":"ききとる/聞き取る/聞取る"},"ききとれる":{"variants":"ききとれる/聞き取れる"},"聞き取れる":{"variants":"ききとれる/聞き取れる"},"ききながす":{"variants":"ききながす/聞き流す/聞流す"},"聞き流す":{"variants":"ききながす/聞き流す/聞流す"},"聞流す":{"variants":"ききながす/聞き流す/聞流す"},"ききながせる":{"variants":"ききながせる/聞き流せる"},"聞き流せる":{"variants":"ききながせる/聞き流せる"},"ききにくい":{"variants":"ききにくい/聞きにくい"},"聞きにくい":{"variants":"ききにくい/聞きにくい"},"ききはずす":{"variants":"ききはずす/聞きはずす/聞き外す/聞外す"},"聞きはずす":{"variants":"ききはずす/聞きはずす/聞き外す/聞外す"},"聞き外す":{"variants":"ききはずす/聞きはずす/聞き外す/聞外す"},"聞外す":{"variants":"ききはずす/聞きはずす/聞き外す/聞外す"},"ききほれる":{"variants":"ききほれる/聞きほれる/聞き惚れる"},"聞きほれる":{"variants":"ききほれる/聞きほれる/聞き惚れる"},"聞き惚れる":{"variants":"ききほれる/聞きほれる/聞き惚れる"},"聞き耳":{"variants":"聞き耳/聞耳"},"聞耳":{"variants":"聞き耳/聞耳"},"奇々妙々":{"variants":"奇々妙々/奇奇妙妙"},"奇奇妙妙":{"variants":"奇々妙々/奇奇妙妙"},"効きめ":{"variants":"効きめ/効き目/効目"},"効目":{"variants":"効きめ/効き目/効目"},"効き目":{"variants":"効きめ/効き目/効目"},"聞き物":{"variants":"聞き物/聞物"},"聞物":{"variants":"聞き物/聞物"},"ききもらす":{"variants":"ききもらす/聞きもらす/聞き漏らす/聞漏らす"},"聞きもらす":{"variants":"ききもらす/聞きもらす/聞き漏らす/聞漏らす"},"聞き漏らす":{"variants":"ききもらす/聞きもらす/聞き漏らす/聞漏らす"},"聞漏らす":{"variants":"ききもらす/聞きもらす/聞き漏らす/聞漏らす"},"聞き役":{"variants":"聞き役/聞役"},"聞役":{"variants":"聞き役/聞役"},"キキョウ":{"variants":"キキョウ/奇矯/気胸/桔梗"},"聞き分け":{"variants":"聞き分け/聞分け"},"聞分け":{"variants":"聞き分け/聞分け"},"ききわける":{"variants":"ききわける/聞きわける/聞き分ける/聞分ける"},"聞きわける":{"variants":"ききわける/聞きわける/聞き分ける/聞分ける"},"聞き分ける":{"variants":"ききわける/聞きわける/聞き分ける/聞分ける"},"聞分ける":{"variants":"ききわける/聞きわける/聞き分ける/聞分ける"},"飢饉":{"variants":"飢きん/飢饉"},"飢きん":{"variants":"飢きん/飢饉"},"きく":{"variants":"きく/キク/規矩/起句/菊"},"キク":{"variants":"きく/キク/規矩/起句/菊"},"キクイタダキ":{"variants":"キクイタダキ/菊戴"},"菊戴":{"variants":"キクイタダキ/菊戴"},"キクイモ":{"variants":"キクイモ/菊芋"},"菊芋":{"variants":"キクイモ/菊芋"},"きくする":{"variants":"きくする/掬する"},"掬する":{"variants":"きくする/掬する"},"木くず":{"variants":"木くず/木屑"},"木屑":{"variants":"木くず/木屑"},"キクナ":{"variants":"キクナ/菊菜"},"菊菜":{"variants":"キクナ/菊菜"},"きくならく":{"variants":"きくならく/聞くならく/聞説/聞道"},"聞くならく":{"variants":"きくならく/聞くならく/聞説/聞道"},"気くばり":{"variants":"気くばり/気配り"},"気配り":{"variants":"気くばり/気配り"},"キクラゲ":{"variants":"キクラゲ/木耳"},"木耳":{"variants":"キクラゲ/木耳"},"危ぐ":{"variants":"危ぐ/危惧"},"危惧":{"variants":"危ぐ/危惧"},"きぐす":{"variants":"きぐす/危惧す"},"危惧す":{"variants":"きぐす/危惧す"},"きける":{"variants":"きける/聴ける/聞ける"},"キケン":{"variants":"キケン/危険"},"危険":{"variants":"キケン/危険"},"キコウ":{"variants":"キコウ/奇功/奇効/奇行/機工/機巧/機構/機甲/帰航/気候/気功/気孔/季候/稀覯/紀綱/紀行/貴公/貴校"},"きこえる":{"variants":"きこえる/聴こえる/聞える/聞こえる"},"聞こえる":{"variants":"きこえる/聞える/聞こえる"},"聞える":{"variants":"きこえる/聞える/聞こえる"},"きこしめす":{"variants":"きこしめす/聞し召す"},"聞し召す":{"variants":"きこしめす/聞し召す"},"きこす":{"variants":"きこす/聞す"},"聞す":{"variants":"きこす/聞す"},"きこなす":{"variants":"きこなす/着こなす"},"着こなす":{"variants":"きこなす/着こなす"},"きこなせる":{"variants":"きこなせる/着こなせる"},"着こなせる":{"variants":"きこなせる/着こなせる"},"きこむ":{"variants":"きこむ/着込む"},"着込む":{"variants":"きこむ/着込む"},"キコリ":{"variants":"キコリ/樵/木こり"},"キコン":{"variants":"キコン/基根/既婚/機根/気根"},"揮ごう":{"variants":"揮ごう/揮毫"},"揮毫":{"variants":"揮ごう/揮毫"},"きさく":{"variants":"きさく/奇策"},"奇策":{"variants":"きさく/奇策"},"キササゲ":{"variants":"キササゲ/木ささげ"},"木ささげ":{"variants":"キササゲ/木ささげ"},"きざす":{"variants":"きざす/兆す/萌す"},"きざっぽい":{"variants":"きざっぽい/気障っぽい"},"気障っぽい":{"variants":"きざっぽい/気障っぽい"},"きざみこむ":{"variants":"きざみこむ/刻み込む"},"刻み込む":{"variants":"きざみこむ/刻み込む"},"刻みたばこ":{"variants":"刻みたばこ/刻み煙草/刻煙草"},"刻み煙草":{"variants":"刻みたばこ/刻み煙草/刻煙草"},"刻煙草":{"variants":"刻みたばこ/刻み煙草/刻煙草"},"きざみつける":{"variants":"きざみつける/刻みつける/刻み付ける"},"刻みつける":{"variants":"きざみつける/刻みつける/刻み付ける"},"刻み付ける":{"variants":"きざみつける/刻みつける/刻み付ける"},"きざむ":{"variants":"きざむ/刻む"},"刻む":{"variants":"きざむ/刻む"},"きざめる":{"variants":"きざめる/刻める"},"刻める":{"variants":"きざめる/刻める"},"きしむ":{"variants":"きしむ/軋む"},"軋む":{"variants":"きしむ/軋む"},"きしめく":{"variants":"きしめく/軋めく"},"軋めく":{"variants":"きしめく/軋めく"},"きしょい":{"variants":"きしょい/キショい"},"キショい":{"variants":"きしょい/キショい"},"きしる":{"variants":"きしる/軋る"},"軋る":{"variants":"きしる/軋る"},"キジ":{"variants":"キジ/記事/木地/雉/雉子"},"キジバト":{"variants":"キジバト/雉鳩"},"雉鳩":{"variants":"キジバト/雉鳩"},"キじるし":{"variants":"キじるし/キ印"},"キ印":{"variants":"キじるし/キ印"},"帰すう":{"variants":"帰すう/帰趨"},"帰趨":{"variants":"帰すう/帰趨"},"きする":{"variants":"きする/期する"},"期する":{"variants":"きする/期する"},"キズ":{"variants":"キズ/傷/生酢/瑕/疵"},"傷跡":{"variants":"きず跡/傷あと/傷跡"},"傷痕":{"variants":"傷あと/傷痕"},"きず跡":{"variants":"きず跡/傷あと/傷跡"},"傷あと":{"variants":"きず跡/傷あと/傷痕/傷跡"},"きずきあげる":{"variants":"きずきあげる/築き上げる"},"築き上げる":{"variants":"きずきあげる/築き上げる"},"きずく":{"variants":"きずく/築く"},"築く":{"variants":"きずく/築く"},"きずつく":{"variants":"きずつく/傷つく"},"傷つく":{"variants":"きずつく/傷つく"},"きずつける":{"variants":"きずつける/傷つける/傷付ける/疵付ける"},"傷つける":{"variants":"きずつける/傷つける/傷付ける"},"傷付ける":{"variants":"きずつける/傷つける/傷付ける"},"きずな":{"variants":"きずな/紲"},"紲":{"variants":"きずな/紲"},"傷もの":{"variants":"傷もの/傷物"},"傷物":{"variants":"傷もの/傷物"},"季節はずれ":{"variants":"季節はずれ/季節外れ"},"季節外れ":{"variants":"季節はずれ/季節外れ"},"きせる":{"variants":"きせる/着せる"},"着せる":{"variants":"きせる/着せる"},"きせん":{"variants":"きせん/基線/棋戦/機先/汽船/貴せん/貴賎/輝線"},"貴せん":{"variants":"きせん/貴せん/貴賎"},"貴賎":{"variants":"きせん/貴せん/貴賎"},"きぜわしい":{"variants":"きぜわしい/気ぜわしい/気忙しい"},"気ぜわしい":{"variants":"きぜわしい/気ぜわしい/気忙しい"},"気忙しい":{"variants":"きぜわしい/気ぜわしい/気忙しい"},"き然":{"variants":"き然/毅然"},"毅然":{"variants":"き然/毅然"},"きぜんと":{"variants":"きぜんと/毅然と"},"毅然と":{"variants":"きぜんと/毅然と"},"きそう":{"variants":"きそう/競う"},"競う":{"variants":"きそう/競う"},"きそえる":{"variants":"きそえる/競える"},"競える":{"variants":"きそえる/競える"},"気息奄々":{"variants":"気息奄々/気息奄奄"},"気息奄奄":{"variants":"気息奄々/気息奄奄"},"きそくただしい":{"variants":"きそくただしい/規則正しい"},"規則正しい":{"variants":"きそくただしい/規則正しい"},"きそくだつ":{"variants":"きそくだつ/規則立つ"},"規則立つ":{"variants":"きそくだつ/規則立つ"},"毀損":{"variants":"き損/毀損"},"き損":{"variants":"き損/毀損"},"きた":{"variants":"きた/北"},"北":{"variants":"きた/北"},"きたえあげる":{"variants":"きたえあげる/鍛え上げる"},"鍛え上げる":{"variants":"きたえあげる/鍛え上げる"},"きたえる":{"variants":"きたえる/鍛える"},"鍛える":{"variants":"きたえる/鍛える"},"着たきり":{"variants":"着たきり/着た切り"},"着た切り":{"variants":"着たきり/着た切り"},"きたきり雀":{"variants":"きたきり雀/着たきりすずめ/着た切り雀"},"着たきりすずめ":{"variants":"きたきり雀/着たきりすずめ/着た切り雀"},"着た切り雀":{"variants":"きたきり雀/着たきりすずめ/着た切り雀"},"きたす":{"variants":"きたす/来す/来たす"},"来す":{"variants":"きたす/来す/来たす"},"来たす":{"variants":"きたす/来す/来たす"},"きたない":{"variants":"きたない/汚い/穢い"},"きたならしい":{"variants":"きたならしい/汚らしい/穢らしい"},"きたる":{"variants":"きたる/来る"},"来る":{"variants":"きたる/来る"},"きたん":{"variants":"きたん/忌憚"},"忌憚":{"variants":"きたん/忌憚"},"気だて":{"variants":"気だて/気立て"},"気立て":{"variants":"気だて/気立て"},"気違沙汰":{"variants":"気違い沙汰/気違沙汰"},"気狂い沙汰":{"variants":"気狂い沙汰/気狂沙汰"},"気違い沙汰":{"variants":"気違い沙汰/気違沙汰"},"気狂沙汰":{"variants":"気狂い沙汰/気狂沙汰"},"気違水":{"variants":"気違い水/気違水"},"気狂い水":{"variants":"気狂い水/気狂水"},"気違い水":{"variants":"気違い水/気違水"},"気狂水":{"variants":"気狂い水/気狂水"},"きちょうめん":{"variants":"きちょうめん/きちょう面/几帳面"},"きちょう面":{"variants":"きちょう面/几帳面"},"几帳面":{"variants":"きちょう面/几帳面"},"きちん":{"variants":"きちん/キチン"},"キチン":{"variants":"キチン/木賃"},"木賃":{"variants":"キチン/木賃"},"きっかい":{"variants":"きっかい/奇っ怪"},"奇っ怪":{"variants":"きっかい/奇っ怪"},"きっかけ":{"variants":"きっかけ/切っ掛け"},"切っ掛け":{"variants":"きっかけ/切っ掛け"},"きっ抗":{"variants":"きっ抗/拮抗"},"拮抗":{"variants":"きっ抗/拮抗"},"きっこう":{"variants":"きっこう/亀甲/龜甲"},"切っさき":{"variants":"切っさき/切っ先/切先"},"切っ先":{"variants":"切っさき/切っ先/切先"},"切先":{"variants":"切っさき/切っ先/切先"},"きっする":{"variants":"きっする/喫する"},"喫する":{"variants":"きっする/喫する"},"きっぱり":{"variants":"きっぱり/キッパリ"},"キッパリ":{"variants":"きっぱり/キッパリ"},"きっぷ":{"variants":"きっぷ/キップ/気っぷ/気っ風/切符"},"キップ":{"variants":"きっぷ/キップ/気っぷ/気っ風/切符"},"気っ風":{"variants":"きっぷ/キップ/気っぷ/気っ風"},"気っぷ":{"variants":"きっぷ/キップ/気っぷ/気っ風"},"気付":{"variants":"気付/気付け"},"気付け":{"variants":"気付/気付け"},"きつける":{"variants":"きつける/着付ける"},"着付ける":{"variants":"きつける/着付ける"},"きつね":{"variants":"きつね/キツネ/狐"},"キツネ":{"variants":"きつね/キツネ/狐"},"狐":{"variants":"きつね/キツネ/狐"},"きつねの嫁入り":{"variants":"きつねの嫁入り/狐の嫁入り"},"狐の嫁入り":{"variants":"きつねの嫁入り/狐の嫁入り"},"きづかう":{"variants":"きづかう/気づかう/気遣う"},"気づかう":{"variants":"きづかう/気づかう/気遣う"},"気遣う":{"variants":"きづかう/気づかう/気遣う"},"きづかわしい":{"variants":"きづかわしい/気遣わしい"},"気遣わしい":{"variants":"きづかわしい/気遣わしい"},"きづく":{"variants":"きづく/気づく/気付く"},"気づく":{"variants":"きづく/気づく/気付く"},"気付く":{"variants":"きづく/気づく/気付く"},"キヅタ":{"variants":"キヅタ/木蔦"},"木蔦":{"variants":"キヅタ/木蔦"},"気詰まり":{"variants":"気詰まり/気詰り"},"気詰り":{"variants":"気詰まり/気詰り"},"きづよい":{"variants":"きづよい/気強い"},"気強い":{"variants":"きづよい/気強い"},"祈とう":{"variants":"祈とう/祈祷"},"祈祷":{"variants":"祈とう/祈祷"},"危とく":{"variants":"危とく/危篤"},"危篤":{"variants":"危とく/危篤"},"きどる":{"variants":"きどる/気どる"},"気どる":{"variants":"きどる/気どる"},"キナ":{"variants":"キナ/規那"},"規那":{"variants":"キナ/規那"},"きなくさい":{"variants":"きなくさい/きな臭い"},"きな臭い":{"variants":"きなくさい/きな臭い"},"きなこ":{"variants":"きなこ/きな粉/黄粉"},"きな粉":{"variants":"きなこ/きな粉/黄粉"},"黄粉":{"variants":"きなこ/きな粉/黄粉"},"きなさる":{"variants":"きなさる/来なさる"},"来なさる":{"variants":"きなさる/来なさる"},"気にいる":{"variants":"気にいる/気に入る"},"気に入る":{"variants":"気にいる/気に入る"},"きぬがさ":{"variants":"きぬがさ/衣笠/絹傘"},"絹ごし":{"variants":"絹ごし/絹漉"},"絹漉":{"variants":"絹ごし/絹漉"},"絹もの":{"variants":"絹もの/絹物"},"絹物":{"variants":"絹もの/絹物"},"キネズミ":{"variants":"キネズミ/木鼠"},"木鼠":{"variants":"キネズミ/木鼠"},"きねづか":{"variants":"きねづか/杵柄"},"杵柄":{"variants":"きねづか/杵柄"},"きのう":{"variants":"きのう/昨日"},"昨日":{"variants":"きのう/昨日"},"気のくすり":{"variants":"気のくすり/気の薬"},"気の薬":{"variants":"気のくすり/気の薬"},"着のみ着のまま":{"variants":"着のみ着のまま/着の身着のまま/着の身着の侭"},"着の身着のまま":{"variants":"着のみ着のまま/着の身着のまま/着の身着の侭"},"着の身着の侭":{"variants":"着のみ着のまま/着の身着のまま/着の身着の侭"},"木の芽":{"variants":"木の芽/木芽"},"木芽":{"variants":"木の芽/木芽"},"気のやまい":{"variants":"気のやまい/気の病"},"気の病":{"variants":"気のやまい/気の病"},"きはじめる":{"variants":"きはじめる/来はじめる"},"来はじめる":{"variants":"きはじめる/来はじめる"},"きはずかしい":{"variants":"きはずかしい/気恥しい"},"気恥しい":{"variants":"きはずかしい/気恥しい"},"キハダ":{"variants":"キハダ/木肌"},"木肌":{"variants":"キハダ/木肌"},"きば":{"variants":"きば/牙/騎馬/木場"},"気ばたらき":{"variants":"気ばたらき/気働き"},"気働き":{"variants":"気ばたらき/気働き"},"きばむ":{"variants":"きばむ/黄ばむ"},"黄ばむ":{"variants":"きばむ/黄ばむ"},"気晴し":{"variants":"気晴し/気晴らし"},"気晴らし":{"variants":"気晴し/気晴らし"},"きばる":{"variants":"きばる/気張る"},"気張る":{"variants":"きばる/気張る"},"きばれる":{"variants":"きばれる/気張れる"},"気張れる":{"variants":"きばれる/気張れる"},"キビ":{"variants":"キビ/機微/黍/稷/驥尾"},"忌引":{"variants":"忌引/忌引き"},"忌引き":{"variants":"忌引/忌引き"},"きびきび":{"variants":"きびきび/キビキビ"},"キビキビ":{"variants":"きびきび/キビキビ"},"きびしい":{"variants":"きびしい/酷しい"},"酷しい":{"variants":"きびしい/酷しい"},"キビタキ":{"variants":"キビタキ/黄鶲"},"黄鶲":{"variants":"キビタキ/黄鶲"},"着ぶくれ":{"variants":"着ぶくれ/着脹れ/着膨れ"},"きぶくれる":{"variants":"きぶくれる/着膨れる"},"着膨れる":{"variants":"きぶくれる/着膨れる"},"気ぶん":{"variants":"気ぶん/気分"},"気分":{"variants":"気ぶん/気分"},"キホウ":{"variants":"キホウ/既報/機鋒/気泡/気胞/記法/貴報"},"木彫":{"variants":"木彫/木彫り"},"木彫り":{"variants":"木彫/木彫り"},"気まぐれ":{"variants":"気まぐれ/気紛れ"},"気紛れ":{"variants":"気まぐれ/気紛れ"},"きまじめ":{"variants":"きまじめ/生真面目"},"生真面目":{"variants":"きまじめ/生真面目"},"きまずい":{"variants":"きまずい/気まずい"},"気まずい":{"variants":"きまずい/気まずい"},"きまって":{"variants":"きまって/決まって"},"決まって":{"variants":"きまって/決まって"},"気まま":{"variants":"気まま/気侭"},"気侭":{"variants":"気まま/気侭"},"きまり":{"variants":"きまり/極り/決まり/決り"},"決り":{"variants":"きまり/決まり/決り"},"決まり":{"variants":"きまり/決まり/決り"},"きまる":{"variants":"きまる/決まる/決る"},"決まる":{"variants":"きまる/決まる/決る"},"決る":{"variants":"きまる/決まる/決る"},"黄み":{"variants":"黄み/黄身"},"黄身":{"variants":"黄み/黄身"},"きみ":{"variants":"きみ/キミ/君"},"キミ":{"variants":"きみ/キミ/君"},"君":{"variants":"くん/クン/君"},"きみがわるい":{"variants":"きみがわるい/気味が悪い"},"気味が悪い":{"variants":"きみがわるい/気味が悪い"},"きみわるい":{"variants":"きみわるい/気味悪い"},"気味悪い":{"variants":"きみわるい/気味悪い"},"きむずかしい":{"variants":"きむずかしい/気むずかしい/気難しい"},"気むずかしい":{"variants":"きむずかしい/気むずかしい/気難しい"},"気難しい":{"variants":"きむずかしい/気むずかしい/気難しい"},"きめこまかい":{"variants":"きめこまかい/きめ細かい/キメ細かい"},"きめ細かい":{"variants":"きめこまかい/きめ細かい/キメ細かい"},"キメ細かい":{"variants":"きめこまかい/きめ細かい/キメ細かい"},"木目込":{"variants":"木目込/木目込み"},"木目込み":{"variants":"木目込/木目込み"},"きめこむ":{"variants":"きめこむ/極め込む/決めこむ/決め込む/決込む"},"決込む":{"variants":"きめこむ/決めこむ/決め込む/決込む"},"決め込む":{"variants":"きめこむ/決めこむ/決め込む/決込む"},"決めこむ":{"variants":"きめこむ/決めこむ/決め込む/決込む"},"きめつける":{"variants":"きめつける/極め付ける/決めつける"},"きめ手":{"variants":"きめ手/キメ手/極め手/決め手"},"キメ手":{"variants":"きめ手/キメ手/極め手/決め手"},"決めどころ":{"variants":"決めどころ/決め所"},"決め所":{"variants":"決めどころ/決め所"},"極めどころ":{"variants":"極めどころ/極め所"},"極め所":{"variants":"極めどころ/極め所"},"きめる":{"variants":"きめる/キメる/決める"},"キメる":{"variants":"きめる/キメる/決める"},"決める":{"variants":"きめる/キメる/決める"},"きも煎り":{"variants":"きも煎り/肝いり/肝煎/肝煎り"},"肝いり":{"variants":"きも煎り/肝いり/肝煎/肝煎り"},"肝煎":{"variants":"きも煎り/肝いり/肝煎/肝煎り"},"肝煎り":{"variants":"きも煎り/肝いり/肝煎/肝煎り"},"気もち":{"variants":"気もち/気持/気持ち"},"気持":{"variants":"気もち/気持/気持ち"},"気持ち":{"variants":"気もち/気持/気持ち"},"気持ちよい":{"variants":"気持ちよい/気持ち良い"},"気持ち良い":{"variants":"気持ちよい/気持ち良い"},"きもっ玉":{"variants":"きもっ玉/肝ったま/肝っ玉"},"肝ったま":{"variants":"きもっ玉/肝ったま/肝っ玉"},"肝っ玉":{"variants":"きもっ玉/肝ったま/肝っ玉"},"きもの":{"variants":"きもの/着物"},"着物":{"variants":"きもの/着物"},"きゃー":{"variants":"きゃー/キャー"},"キャー":{"variants":"きゃー/キャー"},"客せん":{"variants":"客せん/客船"},"客船":{"variants":"客せん/客船"},"きゃしゃ":{"variants":"きゃしゃ/花車/華奢"},"キャラボク":{"variants":"キャラボク/伽羅木"},"伽羅木":{"variants":"キャラボク/伽羅木"},"キャリア・ウーマン":{"variants":"キャリア・ウーマン/キャリアウーマン"},"キャリアウーマン":{"variants":"キャリア・ウーマン/キャリアウーマン"},"きやすい":{"variants":"きやすい/気安い"},"気安い":{"variants":"きやすい/気安い"},"木やり":{"variants":"木やり/木遣/木遣り"},"木遣":{"variants":"木やり/木遣/木遣り"},"木遣り":{"variants":"木やり/木遣/木遣り"},"きゅう":{"variants":"きゅう/休/急/灸/級/旧"},"９":{"variants":"９/九"},"九":{"variants":"９/九"},"きゅう覚":{"variants":"きゅう覚/嗅覚"},"嗅覚":{"variants":"きゅう覚/嗅覚"},"キュウカンチョウ":{"variants":"キュウカンチョウ/九官鳥"},"九官鳥":{"variants":"キュウカンチョウ/九官鳥"},"汲々":{"variants":"汲々/汲汲"},"汲汲":{"variants":"汲々/汲汲"},"きゅうきょ":{"variants":"きゅうきょ/急遽"},"急遽":{"variants":"きゅうきょ/急遽"},"キュウコン":{"variants":"キュウコン/球根"},"球根":{"variants":"キュウコン/球根"},"急ごしらえ":{"variants":"急ごしらえ/急拵え"},"急拵え":{"variants":"急ごしらえ/急拵え"},"窮死":{"variants":"窮し/窮死"},"窮し":{"variants":"窮し/窮死"},"厩舎":{"variants":"きゅう舎/厩舎"},"鳩舎":{"variants":"きゅう舎/鳩舎"},"きゅう舎":{"variants":"きゅう舎/厩舎/鳩舎"},"急しゅん":{"variants":"急しゅん/急峻"},"急峻":{"variants":"急しゅん/急峻"},"きゅうじ":{"variants":"きゅうじ/灸治/球児/給餌"},"きゅうす":{"variants":"きゅうす/急須"},"急須":{"variants":"きゅうす/急須"},"きゅうする":{"variants":"きゅうする/休する/窮する/給する"},"急先ぽう":{"variants":"急先ぽう/急先鋒"},"急先鋒":{"variants":"急先ぽう/急先鋒"},"キュウリ":{"variants":"キュウリ/久離/究理/窮理/旧離/胡瓜"},"きょう":{"variants":"きょう/今日"},"今日":{"variants":"きょう/今日"},"京おんな":{"variants":"京おんな/京女"},"京女":{"variants":"京おんな/京女"},"驚がく":{"variants":"驚がく/驚愕"},"驚愕":{"variants":"驚がく/驚愕"},"キョウガノコ":{"variants":"キョウガノコ/京鹿子"},"京鹿子":{"variants":"キョウガノコ/京鹿子"},"きょうがる":{"variants":"きょうがる/興がる"},"興がる":{"variants":"きょうがる/興がる"},"恟々":{"variants":"恟々/恟恟"},"恐恐":{"variants":"恐々/恐恐"},"恐々":{"variants":"恐々/恐恐"},"兢々":{"variants":"兢々/兢兢"},"恟恟":{"variants":"恟々/恟恟"},"兢兢":{"variants":"兢々/兢兢"},"狂言まわし":{"variants":"狂言まわし/狂言回し"},"狂言回し":{"variants":"狂言まわし/狂言回し"},"きょうこう":{"variants":"きょうこう/向後/嚮後"},"狭さく":{"variants":"狭さく/狭窄"},"狭窄":{"variants":"狭さく/狭窄"},"きょうざめる":{"variants":"きょうざめる/興ざめる/興醒める"},"興ざめる":{"variants":"きょうざめる/興ざめる/興醒める"},"興醒める":{"variants":"きょうざめる/興ざめる/興醒める"},"きょうじる":{"variants":"きょうじる/興じる"},"興じる":{"variants":"きょうじる/興じる"},"強じん":{"variants":"強じん/強靭/強靱"},"強靱":{"variants":"強じん/強靱"},"きょうする":{"variants":"きょうする/供する/狂する/饗する"},"きょうずる":{"variants":"きょうずる/興ずる"},"興ずる":{"variants":"きょうずる/興ずる"},"強請":{"variants":"強せい/強請"},"強せい":{"variants":"強せい/強制/強請"},"強制":{"variants":"強せい/強制"},"胸せん":{"variants":"胸せん/胸腺"},"胸腺":{"variants":"胸せん/胸腺"},"京染":{"variants":"京染/京染め"},"京染め":{"variants":"京染/京染め"},"キョウチクトウ":{"variants":"キョウチクトウ/夾竹桃"},"夾竹桃":{"variants":"キョウチクトウ/夾竹桃"},"キョウナ":{"variants":"キョウナ/京菜"},"京菜":{"variants":"キョウナ/京菜"},"キョウニン":{"variants":"キョウニン/杏仁"},"杏仁":{"variants":"キョウニン/杏仁"},"教べん":{"variants":"教べん/教鞭"},"教鞭":{"variants":"教べん/教鞭"},"キョウボク":{"variants":"キョウボク/喬木/梟木"},"興味しんしん":{"variants":"興味しんしん/興味津々"},"興味津々":{"variants":"興味しんしん/興味津々"},"きょうみぶかい":{"variants":"きょうみぶかい/興味深い"},"興味深い":{"variants":"きょうみぶかい/興味深い"},"キョウリュウ":{"variants":"キョウリュウ/恐竜"},"恐竜":{"variants":"キョウリュウ/恐竜"},"橋梁":{"variants":"橋りょう/橋梁"},"橋りょう":{"variants":"橋りょう/橋梁"},"京わらべ":{"variants":"京わらべ/京童"},"京童":{"variants":"京わらべ/京童"},"虚々実々":{"variants":"虚々実々/虚虚実実"},"虚虚実実":{"variants":"虚々実々/虚虚実実"},"きょくひ動物":{"variants":"きょくひ動物/棘皮動物"},"棘皮動物":{"variants":"きょくひ動物/棘皮動物"},"きょとん":{"variants":"きょとん/キョトン"},"キョトン":{"variants":"きょとん/キョトン"},"きょろきょろ":{"variants":"きょろきょろ/キョロキョロ"},"キョロキョロ":{"variants":"きょろきょろ/キョロキョロ"},"きよい":{"variants":"きよい/清い"},"清い":{"variants":"きよい/清い"},"きよまる":{"variants":"きよまる/清まる"},"清まる":{"variants":"きよまる/清まる"},"きよめる":{"variants":"きよめる/清める"},"清める":{"variants":"きよめる/清める"},"きらい":{"variants":"きらい/嫌い"},"嫌い":{"variants":"きらい/嫌い"},"きらう":{"variants":"きらう/嫌う"},"嫌う":{"variants":"きらう/嫌う"},"きらす":{"variants":"きらす/切らす"},"切らす":{"variants":"きらす/切らす"},"きらめく":{"variants":"きらめく/煌めく"},"煌めく":{"variants":"きらめく/煌めく"},"きらめむ":{"variants":"きらめむ/燐む/煌む"},"きらり":{"variants":"きらり/キラリ"},"キラリ":{"variants":"きらり/キラリ"},"きらわれる":{"variants":"きらわれる/嫌われる"},"嫌われる":{"variants":"きらわれる/嫌われる"},"きり":{"variants":"きり/キリ/奇利/桐/限/錐/切り/雰/霧"},"キリ":{"variants":"きり/キリ/奇利/桐/限/錐/切り/雰/霧"},"きりあう":{"variants":"きりあう/切り合う/切合う"},"切り合う":{"variants":"きりあう/切り合う/切合う"},"切合う":{"variants":"きりあう/切り合う/切合う"},"切り上げ":{"variants":"切り上げ/切上げ"},"切上げ":{"variants":"切り上げ/切上げ"},"きりあげる":{"variants":"きりあげる/切りあげる/切り上げる/切上げる"},"切りあげる":{"variants":"きりあげる/切りあげる/切り上げる/切上げる"},"切り上げる":{"variants":"きりあげる/切りあげる/切り上げる/切上げる"},"切上げる":{"variants":"きりあげる/切りあげる/切り上げる/切上げる"},"切り石":{"variants":"切り石/切石"},"切石":{"variants":"切り石/切石"},"切り売り":{"variants":"切り売り/切売"},"切売":{"variants":"切り売り/切売"},"きりおとす":{"variants":"きりおとす/切り落す/切り落とす"},"切り落す":{"variants":"きりおとす/切り落す/切り落とす"},"切り落とす":{"variants":"きりおとす/切り落す/切り落とす"},"きりおとせる":{"variants":"きりおとせる/切り落とせる"},"切り落とせる":{"variants":"きりおとせる/切り落とせる"},"切り換え":{"variants":"切り換え/切換え"},"切換え":{"variants":"切り換え/切換え"},"切替":{"variants":"切り替え/切替"},"切り替え":{"variants":"切り替え/切替"},"切り返し":{"variants":"切り返し/切返し"},"切返し":{"variants":"切り返し/切返し"},"きりかえす":{"variants":"きりかえす/切り返す/切返す"},"切り返す":{"variants":"きりかえす/切り返す/切返す"},"切返す":{"variants":"きりかえす/切り返す/切返す"},"きりかえる":{"variants":"きりかえる/切りかえる/切り換える/切り替える/切換える/切替える"},"切りかえる":{"variants":"きりかえる/切りかえる/切り換える/切り替える/切換える/切替える"},"切り換える":{"variants":"きりかえる/切りかえる/切り換える/切換える"},"切換える":{"variants":"きりかえる/切りかえる/切り換える/切換える"},"切り替える":{"variants":"きりかえる/切りかえる/切り替える/切替える"},"切替える":{"variants":"きりかえる/切りかえる/切り替える/切替える"},"きりかかる":{"variants":"きりかかる/切りかかる/切り掛る"},"切りかかる":{"variants":"きりかかる/切りかかる/切り掛る"},"切り掛る":{"variants":"きりかかる/切りかかる/切り掛る"},"きりかける":{"variants":"きりかける/切りかける/切り掛ける/切掛ける"},"切りかける":{"variants":"きりかける/切りかける/切り掛ける/切掛ける"},"切り掛ける":{"variants":"きりかける/切りかける/切り掛ける/切掛ける"},"切掛ける":{"variants":"きりかける/切りかける/切り掛ける/切掛ける"},"切り株":{"variants":"切り株/切株"},"切株":{"variants":"切り株/切株"},"きりかわる":{"variants":"きりかわる/切り替る/切り替わる"},"切り替る":{"variants":"きりかわる/切り替る/切り替わる"},"切り替わる":{"variants":"きりかわる/切り替る/切り替わる"},"きりきざむ":{"variants":"きりきざむ/切り刻む"},"切り刻む":{"variants":"きりきざむ/切り刻む"},"切りきず":{"variants":"切りきず/切り傷/切傷/切疵"},"切り傷":{"variants":"切りきず/切り傷/切傷"},"切傷":{"variants":"切りきず/切り傷/切傷"},"切り狂言":{"variants":"切り狂言/切狂言"},"切狂言":{"variants":"切り狂言/切狂言"},"きりきり":{"variants":"きりきり/キリキリ"},"キリキリ":{"variants":"きりきり/キリキリ"},"きりきり舞い":{"variants":"きりきり舞い/キリキリ舞い"},"キリキリ舞い":{"variants":"きりきり舞い/キリキリ舞い"},"キリギリス":{"variants":"キリギリス/螽斯"},"螽斯":{"variants":"キリギリス/螽斯"},"きりくずす":{"variants":"きりくずす/切りくずす/切り崩す/切崩す"},"切りくずす":{"variants":"きりくずす/切りくずす/切り崩す/切崩す"},"切り崩す":{"variants":"きりくずす/切りくずす/切り崩す/切崩す"},"切崩す":{"variants":"きりくずす/切りくずす/切り崩す/切崩す"},"きりくずせる":{"variants":"きりくずせる/切り崩せる"},"切り崩せる":{"variants":"きりくずせる/切り崩せる"},"切り口":{"variants":"切り口/切口"},"切口":{"variants":"切り口/切口"},"きりくむ":{"variants":"きりくむ/切り組む/切組む"},"切り組む":{"variants":"きりくむ/切り組む/切組む"},"切組む":{"variants":"きりくむ/切り組む/切組む"},"切り子":{"variants":"切り子/切子"},"切子":{"variants":"切り子/切子"},"きりこガラス":{"variants":"きりこガラス/切子ガラス/切篭ガラス"},"きりこまざく":{"variants":"きりこまざく/切りこまざく"},"切りこまざく":{"variants":"きりこまざく/切りこまざく"},"切りこみ":{"variants":"切りこみ/切込み"},"切込み":{"variants":"切りこみ/切込み"},"きりこむ":{"variants":"きりこむ/切り込む/切込む"},"切り込む":{"variants":"きりこむ/切り込む/切込む"},"切込む":{"variants":"きりこむ/切り込む/切込む"},"きりこめる":{"variants":"きりこめる/切り込める"},"切り込める":{"variants":"きりこめる/切り込める"},"切りごたつ":{"variants":"切りごたつ/切炬燵"},"切炬燵":{"variants":"切りごたつ/切炬燵"},"きりさいなむ":{"variants":"きりさいなむ/切りさいなむ/切り苛む"},"切りさいなむ":{"variants":"きりさいなむ/切りさいなむ/切り苛む"},"切り苛む":{"variants":"きりさいなむ/切りさいなむ/切り苛む"},"きりさく":{"variants":"きりさく/切り裂く/切裂く"},"切り裂く":{"variants":"きりさく/切り裂く/切裂く"},"切裂く":{"variants":"きりさく/切り裂く/切裂く"},"切り下げ":{"variants":"切り下げ/切下げ"},"切下げ":{"variants":"切り下げ/切下げ"},"きりさげる":{"variants":"きりさげる/切り下げる/切下げる"},"切り下げる":{"variants":"きりさげる/切り下げる/切下げる"},"切下げる":{"variants":"きりさげる/切り下げる/切下げる"},"キリシタン":{"variants":"キリシタン/吉利支丹/切支丹"},"切りすて":{"variants":"切りすて/切り捨て/切捨て"},"切り捨て":{"variants":"切りすて/切り捨て/切捨て"},"切捨て":{"variants":"切りすて/切り捨て/切捨て"},"斬り捨て御免":{"variants":"斬り捨て御免/斬捨て御免/斬捨御免"},"斬捨て御免":{"variants":"斬り捨て御免/斬捨て御免/斬捨御免"},"斬捨御免":{"variants":"斬り捨て御免/斬捨て御免/斬捨御免"},"きりすてる":{"variants":"きりすてる/切り捨てる/切捨てる"},"切り捨てる":{"variants":"きりすてる/切り捨てる/切捨てる"},"切捨てる":{"variants":"きりすてる/切り捨てる/切捨てる"},"キリスト教":{"variants":"キリスト教/基督教"},"基督教":{"variants":"キリスト教/基督教"},"きりそろえる":{"variants":"きりそろえる/切りそろえる"},"切りそろえる":{"variants":"きりそろえる/切りそろえる"},"きりたおす":{"variants":"きりたおす/切り倒す"},"切り倒す":{"variants":"きりたおす/切り倒す"},"きりたおせる":{"variants":"きりたおせる/切り倒せる"},"切り倒せる":{"variants":"きりたおせる/切り倒せる"},"きりたつ":{"variants":"きりたつ/切り立つ/切立つ"},"切り立つ":{"variants":"きりたつ/切り立つ/切立つ"},"切立つ":{"variants":"きりたつ/切り立つ/切立つ"},"きりたてる":{"variants":"きりたてる/切り立てる"},"切り立てる":{"variants":"きりたてる/切り立てる"},"切り出し":{"variants":"切り出し/切出し"},"切出し":{"variants":"切り出し/切出し"},"きりだす":{"variants":"きりだす/切り出す/切出す"},"切り出す":{"variants":"きりだす/切り出す/切出す"},"切出す":{"variants":"きりだす/切り出す/切出す"},"きりだせる":{"variants":"きりだせる/切り出せる"},"切り出せる":{"variants":"きりだせる/切り出せる"},"きりつける":{"variants":"きりつける/切りつける/切り付ける/切付ける"},"切りつける":{"variants":"きりつける/切りつける/切り付ける/切付ける"},"切り付ける":{"variants":"きりつける/切りつける/切り付ける/切付ける"},"切付ける":{"variants":"きりつける/切りつける/切り付ける/切付ける"},"きりつめる":{"variants":"きりつめる/切りつめる/切り詰める/切詰める"},"切りつめる":{"variants":"きりつめる/切りつめる/切り詰める/切詰める"},"切り詰める":{"variants":"きりつめる/切りつめる/切り詰める/切詰める"},"切詰める":{"variants":"きりつめる/切りつめる/切り詰める/切詰める"},"切り取り":{"variants":"切り取り/切取り"},"切取り":{"variants":"切り取り/切取り"},"きりとる":{"variants":"きりとる/切りとる/切り取る/切取る"},"切りとる":{"variants":"きりとる/切りとる/切り取る/切取る"},"切り取る":{"variants":"きりとる/切りとる/切り取る/切取る"},"切取る":{"variants":"きりとる/切りとる/切り取る/切取る"},"きりとれる":{"variants":"きりとれる/切りとれる/切り取れる"},"切りとれる":{"variants":"きりとれる/切りとれる/切り取れる"},"切り取れる":{"variants":"きりとれる/切りとれる/切り取れる"},"切り通し":{"variants":"切り通し/切通し"},"切通し":{"variants":"切り通し/切通し"},"切り抜き":{"variants":"切り抜き/切抜"},"切抜":{"variants":"切り抜き/切抜"},"きりぬく":{"variants":"きりぬく/切りぬく/切り抜く"},"切りぬく":{"variants":"きりぬく/切りぬく/切り抜く"},"切り抜く":{"variants":"きりぬく/切りぬく/切り抜く"},"きりぬける":{"variants":"きりぬける/切り抜ける/切抜ける"},"切り抜ける":{"variants":"きりぬける/切り抜ける/切抜ける"},"切抜ける":{"variants":"きりぬける/切り抜ける/切抜ける"},"きりはずす":{"variants":"きりはずす/切りはずす"},"切りはずす":{"variants":"きりはずす/切りはずす"},"きりはずせる":{"variants":"きりはずせる/切りはずせる"},"切りはずせる":{"variants":"きりはずせる/切りはずせる"},"切り離し":{"variants":"切り離し/切離し"},"切離し":{"variants":"切り離し/切離し"},"きりはなす":{"variants":"きりはなす/切り放す/切り離す/切放す/切離す"},"切り離す":{"variants":"きりはなす/切り離す/切離す"},"切離す":{"variants":"きりはなす/切り離す/切離す"},"切り放す":{"variants":"きりはなす/切り放す/切放す"},"切放す":{"variants":"きりはなす/切り放す/切放す"},"きりはなせる":{"variants":"きりはなせる/切り放せる/切り離せる"},"きりはらう":{"variants":"きりはらう/切り払う/切払う"},"切り払う":{"variants":"きりはらう/切り払う/切払う"},"切払う":{"variants":"きりはらう/切り払う/切払う"},"きりはらえる":{"variants":"きりはらえる/切り払える"},"切り払える":{"variants":"きりはらえる/切り払える"},"切り花":{"variants":"切り花/切花"},"切花":{"variants":"切り花/切花"},"きりひらく":{"variants":"きりひらく/切り開く/切開く"},"切り開く":{"variants":"きりひらく/切り開く/切開く"},"切開く":{"variants":"きりひらく/切り開く/切開く"},"きりひらける":{"variants":"きりひらける/切り開ける"},"切り開ける":{"variants":"きりひらける/切り開ける"},"切り火":{"variants":"切り火/切火"},"切火":{"variants":"切り火/切火"},"霧吹":{"variants":"霧吹/霧吹き"},"霧吹き":{"variants":"霧吹/霧吹き"},"きりふせる":{"variants":"きりふせる/切り伏せる/切伏せる"},"切り伏せる":{"variants":"きりふせる/切り伏せる/切伏せる"},"切伏せる":{"variants":"きりふせる/切り伏せる/切伏せる"},"切り札":{"variants":"切り札/切札"},"切札":{"variants":"切り札/切札"},"切り干し":{"variants":"切り干し/切干"},"切干":{"variants":"切り干し/切干"},"きりまくる":{"variants":"きりまくる/切り捲る"},"切り捲る":{"variants":"きりまくる/切り捲る"},"きりまわす":{"variants":"きりまわす/切り回す/切り廻す/切回す/切廻す"},"切り回す":{"variants":"きりまわす/切り回す/切回す"},"切回す":{"variants":"きりまわす/切り回す/切回す"},"切り廻す":{"variants":"きりまわす/切り廻す/切廻す"},"切廻す":{"variants":"きりまわす/切り廻す/切廻す"},"きりまわせる":{"variants":"きりまわせる/切り回せる"},"切り回せる":{"variants":"きりまわせる/切り回せる"},"切り身":{"variants":"切り身/切身"},"切身":{"variants":"切り身/切身"},"きりむすぶ":{"variants":"きりむすぶ/切り結ぶ/切結ぶ"},"切り結ぶ":{"variants":"きりむすぶ/切り結ぶ/切結ぶ"},"切結ぶ":{"variants":"きりむすぶ/切り結ぶ/切結ぶ"},"切り目":{"variants":"切り目/切目"},"切目":{"variants":"切り目/切目"},"切り餅":{"variants":"切り餅/切餅"},"切餅":{"variants":"切り餅/切餅"},"切り盛り":{"variants":"切り盛り/切盛り"},"切盛り":{"variants":"切り盛り/切盛り"},"きりわすれる":{"variants":"きりわすれる/切り忘れる"},"切り忘れる":{"variants":"きりわすれる/切り忘れる"},"切り割り":{"variants":"切り割り/切割り"},"切割り":{"variants":"切り割り/切割り"},"キリン":{"variants":"キリン/騏りん/麒麟"},"きる":{"variants":"きる/切る"},"着る":{"variants":"きる/着る"},"切る":{"variants":"きる/切る"},"キレ":{"variants":"キレ/切れ"},"切れ":{"variants":"キレ/切れ"},"きれあがる":{"variants":"きれあがる/切れ上がる"},"切れ上がる":{"variants":"きれあがる/切れ上がる"},"切れあじ":{"variants":"切れあじ/切れ味"},"切れ味":{"variants":"切れあじ/切れ味"},"きれい":{"variants":"きれい/キレイ/奇麗/綺麗"},"キレイ":{"variants":"きれい/キレイ/奇麗/綺麗"},"きれい事":{"variants":"きれい事/奇麗事/綺麗事"},"切れぎれ":{"variants":"切れぎれ/切れ切れ"},"切れ切れ":{"variants":"切れぎれ/切れ切れ"},"切れくち":{"variants":"切れくち/切れ口"},"切れ口":{"variants":"切れくち/切れ口"},"切れこみ":{"variants":"切れこみ/切れ込み"},"切れ込み":{"variants":"切れこみ/切れ込み"},"きれこむ":{"variants":"きれこむ/切れ込む"},"切れ込む":{"variants":"きれこむ/切れ込む"},"切地":{"variants":"切れ地/切地"},"切れ地":{"variants":"切れ地/切地"},"切れはし":{"variants":"切れはし/切れ端"},"切れ端":{"variants":"切れはし/切れ端"},"切れめ":{"variants":"切れめ/切れ目"},"切れ目":{"variants":"切れめ/切れ目"},"切れもの":{"variants":"切れもの/切れ者/切れ物"},"きれる":{"variants":"きれる/切れる"},"切れる":{"variants":"きれる/切れる"},"キロ":{"variants":"キロ/岐路"},"岐路":{"variants":"キロ/岐路"},"ｋｇ":{"variants":"ｋｇ/ｋグラム/キログラム"},"ｋグラム":{"variants":"ｋｇ/ｋグラム/キログラム"},"キログラム":{"variants":"ｋｇ/ｋグラム/キログラム"},"ｋｔ":{"variants":"ｋｔ/キロトン"},"キロトン":{"variants":"ｋｔ/キロトン"},"ｋｂ":{"variants":"ｋｂ/ｋバイト/キロバイト"},"ｋバイト":{"variants":"ｋｂ/ｋバイト/キロバイト"},"キロバイト":{"variants":"ｋｂ/ｋバイト/キロバイト"},"ｋｈｚ":{"variants":"ｋｈｚ/ｋヘルツ/キロヘルツ"},"ｋヘルツ":{"variants":"ｋｈｚ/ｋヘルツ/キロヘルツ"},"キロヘルツ":{"variants":"ｋｈｚ/ｋヘルツ/キロヘルツ"},"ｋｍ":{"variants":"ｋｍ/ｋメートル/キロメートル/粁"},"ｋメートル":{"variants":"ｋｍ/ｋメートル/キロメートル/粁"},"キロメートル":{"variants":"ｋｍ/ｋメートル/キロメートル/粁"},"粁":{"variants":"ｋｍ/ｋメートル/キロメートル/粁"},"ｋｌ":{"variants":"ｋｌ/ｋリットル/キロリットル"},"ｋリットル":{"variants":"ｋｌ/ｋリットル/キロリットル"},"キロリットル":{"variants":"ｋｌ/ｋリットル/キロリットル"},"ｋｗ":{"variants":"ｋｗ/ｋワット/キロワット"},"ｋワット":{"variants":"ｋｗ/ｋワット/キロワット"},"キロワット":{"variants":"ｋｗ/ｋワット/キロワット"},"きわだつ":{"variants":"きわだつ/きわ立つ/際だつ/際立つ"},"きわ立つ":{"variants":"きわだつ/きわ立つ/際だつ/際立つ"},"際だつ":{"variants":"きわだつ/きわ立つ/際だつ/際立つ"},"際立つ":{"variants":"きわだつ/きわ立つ/際だつ/際立つ"},"きわまる":{"variants":"きわまる/窮まる/極まる/谷まる"},"きわみ":{"variants":"きわみ/極み"},"極み":{"variants":"きわみ/極み"},"極め付き":{"variants":"極め付き/極付"},"極付":{"variants":"極め付き/極付"},"きわめつくす":{"variants":"きわめつくす/窮め尽くす"},"窮め尽くす":{"variants":"きわめつくす/窮め尽くす"},"きわめて":{"variants":"きわめて/極めて"},"極めて":{"variants":"きわめて/極めて"},"きわめる":{"variants":"きわめる/究める/窮める/極める"},"キン":{"variants":"キン/斤/禁"},"きんか":{"variants":"きんか/キンカ/近火/金貨/槿花"},"キンカ":{"variants":"きんか/キンカ/近火/金貨/槿花"},"キンカン":{"variants":"キンカン/近刊/金冠/金柑/金環/金管"},"きんきん":{"variants":"きんきん/キンキン/僅僅"},"キンキン":{"variants":"きんきん/キンキン/僅僅"},"僅僅":{"variants":"きんきん/キンキン/僅僅"},"欣々":{"variants":"欣々/欣欣"},"欣欣":{"variants":"欣々/欣欣"},"欣々然":{"variants":"欣々然/欣欣然"},"欣欣然":{"variants":"欣々然/欣欣然"},"キンギョ":{"variants":"キンギョ/禁漁/金魚"},"キンケイ":{"variants":"キンケイ/錦鶏/謹啓/近景"},"キンコ":{"variants":"キンコ/近古/金海鼠/金庫/光参"},"きんしゅ":{"variants":"きんしゅ/筋しゅ/筋腫/菌株/金主"},"筋しゅ":{"variants":"きんしゅ/筋しゅ/筋腫"},"筋腫":{"variants":"きんしゅ/筋しゅ/筋腫"},"きんじる":{"variants":"きんじる/禁じる"},"禁じる":{"variants":"きんじる/禁じる"},"きんずる":{"variants":"きんずる/禁ずる"},"禁ずる":{"variants":"きんずる/禁ずる"},"きんせん花":{"variants":"きんせん花/キンセンカ/金盞花"},"キンセンカ":{"variants":"きんせん花/キンセンカ/金盞花"},"金盞花":{"variants":"きんせん花/キンセンカ/金盞花"},"きんぜん":{"variants":"きんぜん/欣然"},"欣然":{"variants":"きんぜん/欣然"},"金太郎あめ":{"variants":"金太郎あめ/金太郎飴"},"金太郎飴":{"variants":"金太郎あめ/金太郎飴"},"金つば":{"variants":"金つば/金鍔"},"金鍔":{"variants":"金つば/金鍔"},"きんとき":{"variants":"きんとき/金時"},"金時":{"variants":"きんとき/金時"},"キンバエ":{"variants":"キンバエ/金蝿"},"金蝿":{"variants":"キンバエ/金蝿"},"金ぱく":{"variants":"金ぱく/金箔"},"金箔":{"variants":"金ぱく/金箔"},"金ぴか":{"variants":"金ぴか/金ピカ"},"金ピカ":{"variants":"金ぴか/金ピカ"},"キンピラ":{"variants":"キンピラ/金平"},"金平":{"variants":"キンピラ/金平"},"キンポウゲ":{"variants":"キンポウゲ/金鳳花"},"金鳳花":{"variants":"キンポウゲ/金鳳花"},"キンモクセイ":{"variants":"キンモクセイ/金木犀"},"金木犀":{"variants":"キンモクセイ/金木犀"},"金らんどんす":{"variants":"金らんどんす/金襴緞子"},"金襴緞子":{"variants":"金らんどんす/金襴緞子"},"キンルイ":{"variants":"キンルイ/キン類/菌類"},"キン類":{"variants":"キンルイ/キン類/菌類"},"菌類":{"variants":"キンルイ/キン類/菌類"},"ぎえん金":{"variants":"ぎえん金/義援金"},"義援金":{"variants":"ぎえん金/義援金"},"ギガ":{"variants":"Ｇ/ギガ"},"戯画":{"variants":"ギガ/戯画"},"Ｇ":{"variants":"Ｇ/ギガ"},"ＧＢ":{"variants":"ＧＢ/Ｇバイト/ギガバイト"},"Ｇバイト":{"variants":"ＧＢ/Ｇバイト/ギガバイト"},"ギガバイト":{"variants":"ＧＢ/Ｇバイト/ギガバイト"},"巍巍":{"variants":"巍々/巍巍"},"巍々":{"variants":"巍々/巍巍"},"ぎくしゃく":{"variants":"ぎくしゃく/ギクシャク"},"ギクシャク":{"variants":"ぎくしゃく/ギクシャク"},"ぎしきばる":{"variants":"ぎしきばる/儀式張る"},"儀式張る":{"variants":"ぎしきばる/儀式張る"},"ギシギシ":{"variants":"ギシギシ/羊蹄"},"羊蹄":{"variants":"ギシギシ/羊蹄"},"ぎす":{"variants":"ぎす/擬す/議す"},"ぎする":{"variants":"ぎする/擬する/議する"},"ギブ・アンド・テーク":{"variants":"ギブ・アンド・テーク/ギブアンドテーク"},"ギブアンドテーク":{"variants":"ギブ・アンド・テーク/ギブアンドテーク"},"欺まん":{"variants":"欺まん/欺瞞"},"欺瞞":{"variants":"欺まん/欺瞞"},"ぎみ":{"variants":"ぎみ/気味"},"気味":{"variants":"ぎみ/気味"},"ぎむづける":{"variants":"ぎむづける/義務づける/義務付ける"},"義務づける":{"variants":"ぎむづける/義務づける/義務付ける"},"義務付ける":{"variants":"ぎむづける/義務づける/義務付ける"},"ぎゃくに":{"variants":"ぎゃくに/逆に"},"逆に":{"variants":"ぎゃくに/逆に"},"逆もどり":{"variants":"逆もどり/逆戻り"},"逆戻り":{"variants":"逆もどり/逆戻り"},"ぎゅうぎゅう":{"variants":"ぎゅうぎゅう/ギュウギュウ"},"ギュウギュウ":{"variants":"ぎゅうぎゅう/ギュウギュウ"},"ぎゅうじる":{"variants":"ぎゅうじる/牛耳る"},"牛耳る":{"variants":"ぎゅうじる/牛耳る"},"牛なべ":{"variants":"牛なべ/牛鍋"},"牛鍋":{"variants":"牛なべ/牛鍋"},"ぎゅうひ":{"variants":"ぎゅうひ/求肥/牛皮"},"牛ふん":{"variants":"牛ふん/牛フン/牛糞"},"牛フン":{"variants":"牛ふん/牛フン/牛糞"},"牛糞":{"variants":"牛ふん/牛フン/牛糞"},"ぎょい":{"variants":"ぎょい/御意"},"御意":{"variants":"ぎょい/御意"},"ギョウギョウシ":{"variants":"ギョウギョウシ/行々子/行行子"},"行々子":{"variants":"ギョウギョウシ/行々子/行行子"},"行行子":{"variants":"ギョウギョウシ/行々子/行行子"},"ぎょうぎょうしい":{"variants":"ぎょうぎょうしい/仰々しい/仰仰しい"},"仰々しい":{"variants":"ぎょうぎょうしい/仰々しい/仰仰しい"},"仰仰しい":{"variants":"ぎょうぎょうしい/仰々しい/仰仰しい"},"ぎょうさん":{"variants":"ぎょうさん/仰山"},"仰山":{"variants":"ぎょうさん/仰山"},"ギョウザ":{"variants":"ギョウザ/餃子"},"餃子":{"variants":"ギョウザ/餃子"},"ぎょうずる":{"variants":"ぎょうずる/行ずる"},"行ずる":{"variants":"ぎょうずる/行ずる"},"ぎょしゃ":{"variants":"ぎょしゃ/御者/馭者"},"ぎょする":{"variants":"ぎょする/御する"},"御する":{"variants":"ぎょする/御する"},"ギョリュウ":{"variants":"ギョリュウ/御柳"},"御柳":{"variants":"ギョリュウ/御柳"},"ぎりがたい":{"variants":"ぎりがたい/義理堅い"},"義理堅い":{"variants":"ぎりがたい/義理堅い"},"ぎりぎり":{"variants":"ぎりぎり/ギリギリ"},"ギリギリ":{"variants":"ぎりぎり/ギリギリ"},"ぎんじる":{"variants":"ぎんじる/吟じる"},"吟じる":{"variants":"ぎんじる/吟じる"},"ぎんずる":{"variants":"ぎんずる/吟ずる"},"吟ずる":{"variants":"ぎんずる/吟ずる"},"銀ぱく":{"variants":"銀ぱく/銀箔"},"銀箔":{"variants":"銀ぱく/銀箔"},"銀ぶち":{"variants":"銀ぶち/銀縁"},"銀縁":{"variants":"銀ぶち/銀縁"},"ギンポ":{"variants":"ギンポ/銀宝"},"銀宝":{"variants":"ギンポ/銀宝"},"銀りん":{"variants":"銀りん/銀輪/銀鱗"},"ク":{"variants":"ク/句/区/苦"},"くいあう":{"variants":"くいあう/食い合う/食合う"},"食い合う":{"variants":"くいあう/食い合う/食合う"},"食合う":{"variants":"くいあう/食い合う/食合う"},"食い上げ":{"variants":"食い上げ/食上げ"},"食上げ":{"variants":"食い上げ/食上げ"},"くいあらす":{"variants":"くいあらす/食い荒らす/食荒らす"},"食い荒らす":{"variants":"くいあらす/食い荒らす/食荒らす"},"食荒らす":{"variants":"くいあらす/食い荒らす/食荒らす"},"くいあらためる":{"variants":"くいあらためる/悔い改める/悔改める"},"悔い改める":{"variants":"くいあらためる/悔い改める/悔改める"},"悔改める":{"variants":"くいあらためる/悔い改める/悔改める"},"食い意地":{"variants":"食い意地/食意地"},"食意地":{"variants":"食い意地/食意地"},"くいいる":{"variants":"くいいる/食い入る/食入る"},"食い入る":{"variants":"くいいる/食い入る/食入る"},"食入る":{"variants":"くいいる/食い入る/食入る"},"食いかけ":{"variants":"食いかけ/食い掛け"},"食い掛け":{"variants":"食いかけ/食い掛け"},"くいきる":{"variants":"くいきる/食い切る/食切る"},"食い切る":{"variants":"くいきる/食い切る/食切る"},"食切る":{"variants":"くいきる/食い切る/食切る"},"くいこむ":{"variants":"くいこむ/くい込む/食い込む/食込む"},"くい込む":{"variants":"くいこむ/くい込む/食い込む/食込む"},"食い込む":{"variants":"くいこむ/くい込む/食い込む/食込む"},"食込む":{"variants":"くいこむ/くい込む/食い込む/食込む"},"くいこめる":{"variants":"くいこめる/食い込める"},"食い込める":{"variants":"くいこめる/食い込める"},"くいさがる":{"variants":"くいさがる/食い下がる/食下がる"},"食い下がる":{"variants":"くいさがる/食い下がる/食下がる"},"食下がる":{"variants":"くいさがる/食い下がる/食下がる"},"くいさがれる":{"variants":"くいさがれる/食い下がれる"},"食い下がれる":{"variants":"くいさがれる/食い下がれる"},"くいしばる":{"variants":"くいしばる/食いしばる"},"食いしばる":{"variants":"くいしばる/食いしばる"},"食いしろ":{"variants":"食いしろ/食い代"},"食い代":{"variants":"食いしろ/食い代"},"くいしん坊":{"variants":"くいしん坊/食いしんぼう/食いしん坊"},"食いしんぼう":{"variants":"食いしんぼう/食いしん坊"},"食いしん坊":{"variants":"食いしんぼう/食いしん坊"},"食い初め":{"variants":"食い初め/食初め"},"食初め":{"variants":"食い初め/食初め"},"くいたおす":{"variants":"くいたおす/食い倒す/食倒す"},"食い倒す":{"variants":"くいたおす/食い倒す/食倒す"},"食倒す":{"variants":"くいたおす/食い倒す/食倒す"},"食い倒れ":{"variants":"食い倒れ/食倒れ"},"食倒れ":{"variants":"食い倒れ/食倒れ"},"食いだめ":{"variants":"食いだめ/食い溜め"},"食い溜め":{"variants":"食いだめ/食い溜め"},"くいちがう":{"variants":"くいちがう/食い違う/食違う"},"食い違う":{"variants":"くいちがう/食い違う/食違う"},"食違う":{"variants":"くいちがう/食い違う/食違う"},"くいちらす":{"variants":"くいちらす/食い散らす/食散らす"},"食い散らす":{"variants":"くいちらす/食い散らす/食散らす"},"食散らす":{"variants":"くいちらす/食い散らす/食散らす"},"くいつく":{"variants":"くいつく/食いつく"},"食いつく":{"variants":"くいつく/食いつく"},"くいつなぐ":{"variants":"くいつなぐ/食いつなぐ"},"食いつなぐ":{"variants":"くいつなぐ/食いつなぐ"},"くいつぶす":{"variants":"くいつぶす/食いつぶす/食い潰す"},"食いつぶす":{"variants":"くいつぶす/食いつぶす/食い潰す"},"食い潰す":{"variants":"くいつぶす/食いつぶす/食い潰す"},"くいつめる":{"variants":"くいつめる/食い詰める/食詰める"},"食い詰める":{"variants":"くいつめる/食い詰める/食詰める"},"食詰める":{"variants":"くいつめる/食い詰める/食詰める"},"くいとめる":{"variants":"くいとめる/くい止める/食い止める/食止める"},"くい止める":{"variants":"くいとめる/くい止める/食い止める/食止める"},"食い止める":{"variants":"くいとめる/くい止める/食い止める/食止める"},"食止める":{"variants":"くいとめる/くい止める/食い止める/食止める"},"食い道楽":{"variants":"食い道楽/食道楽"},"食道楽":{"variants":"食い道楽/食道楽"},"クイナ":{"variants":"クイナ/水鶏"},"水鶏":{"variants":"クイナ/水鶏"},"食い逃げ":{"variants":"食い逃げ/食逃げ"},"食逃げ":{"variants":"食い逃げ/食逃げ"},"くいのばす":{"variants":"くいのばす/食い延す/食延す"},"食い延す":{"variants":"くいのばす/食い延す/食延す"},"食延す":{"variants":"くいのばす/食い延す/食延す"},"食い扶持":{"variants":"食い扶持/食扶持"},"食扶持":{"variants":"食い扶持/食扶持"},"食いぶん":{"variants":"食いぶん/食い分"},"食い分":{"variants":"食いぶん/食い分"},"食いもの":{"variants":"食いもの/食い物"},"食い物":{"variants":"食いもの/食い物"},"くいる":{"variants":"くいる/悔いる"},"悔いる":{"variants":"くいる/悔いる"},"くう":{"variants":"くう/喰う/食う"},"空々":{"variants":"空々/空空"},"空空":{"variants":"空々/空空"},"空せき":{"variants":"空せき/空席"},"空席":{"variants":"空せき/空席"},"空てい":{"variants":"空てい/空挺"},"空挺":{"variants":"空てい/空挺"},"くえる":{"variants":"くえる/喰える/食える"},"９月":{"variants":"９月/九月"},"九月":{"variants":"９月/九月"},"くぎ":{"variants":"くぎ/クギ/釘"},"クギ":{"variants":"くぎ/クギ/釘"},"釘":{"variants":"くぎ/クギ/釘"},"くぎかくし":{"variants":"くぎかくし/釘隠/釘隠し"},"釘隠":{"variants":"くぎかくし/釘隠/釘隠し"},"釘隠し":{"variants":"くぎかくし/釘隠/釘隠し"},"くぎづけ":{"variants":"くぎづけ/くぎ付け"},"くぎ付け":{"variants":"くぎづけ/くぎ付け"},"釘抜":{"variants":"釘抜/釘抜き"},"釘抜き":{"variants":"釘抜/釘抜き"},"区切り":{"variants":"区切/区切り"},"区切":{"variants":"区切/区切り"},"くぎる":{"variants":"くぎる/句切る/区切る"},"くぎれる":{"variants":"くぎれる/区切れる"},"区切れる":{"variants":"くぎれる/区切れる"},"九々":{"variants":"九々/九九"},"九九":{"variants":"九々/九九"},"区々":{"variants":"区々/区区"},"区区":{"variants":"区々/区区"},"くくめる":{"variants":"くくめる/銜める"},"銜める":{"variants":"くくめる/銜める"},"くくる":{"variants":"くくる/括る"},"括る":{"variants":"くくる/括る"},"クグイ":{"variants":"クグイ/鵠"},"鵠":{"variants":"クグイ/鵠"},"くぐまる":{"variants":"くぐまる/屈まる"},"屈まる":{"variants":"くぐまる/屈まる"},"潜り戸":{"variants":"潜り戸/潜戸"},"潜戸":{"variants":"潜り戸/潜戸"},"くぐりぬける":{"variants":"くぐりぬける/くぐり抜ける"},"くぐり抜ける":{"variants":"くぐりぬける/くぐり抜ける"},"くける":{"variants":"くける/絎ける"},"絎ける":{"variants":"くける/絎ける"},"クコ":{"variants":"クコ/枸杞"},"枸杞":{"variants":"クコ/枸杞"},"くさい":{"variants":"くさい/臭い"},"臭い":{"variants":"におい/臭/臭い"},"クサカゲロウ":{"variants":"クサカゲロウ/草蜉蝣"},"草蜉蝣":{"variants":"クサカゲロウ/草蜉蝣"},"草刈":{"variants":"草刈/草刈り"},"草刈り":{"variants":"草刈/草刈り"},"草かんむり":{"variants":"草かんむり/草冠"},"草冠":{"variants":"草かんむり/草冠"},"クサガメ":{"variants":"クサガメ/草龜"},"草龜":{"variants":"クサガメ/草龜"},"くさす":{"variants":"くさす/腐す"},"腐す":{"variants":"くさす/腐す"},"草とり":{"variants":"草とり/草取/草取り"},"草取":{"variants":"草とり/草取/草取り"},"草取り":{"variants":"草とり/草取/草取り"},"クサヒバリ":{"variants":"クサヒバリ/草雲雀"},"草雲雀":{"variants":"クサヒバリ/草雲雀"},"くさび":{"variants":"くさび/クサビ/楔"},"クサビ":{"variants":"くさび/クサビ/楔"},"楔":{"variants":"くさび/クサビ/楔"},"くさぶかい":{"variants":"くさぶかい/草深い"},"草深い":{"variants":"くさぶかい/草深い"},"草葺":{"variants":"草葺/草葺き"},"草葺き":{"variants":"草葺/草葺き"},"クサボケ":{"variants":"クサボケ/草木瓜"},"草木瓜":{"variants":"クサボケ/草木瓜"},"くさむす":{"variants":"くさむす/草生す"},"草生す":{"variants":"くさむす/草生す"},"草もち":{"variants":"草もち/草餅"},"草餅":{"variants":"草もち/草餅"},"草やぶ":{"variants":"草やぶ/草薮"},"草薮":{"variants":"草やぶ/草薮"},"くさらす":{"variants":"くさらす/腐らす"},"腐らす":{"variants":"くさらす/腐らす"},"くさる":{"variants":"くさる/腐る"},"腐る":{"variants":"くさる/腐る"},"くされ縁":{"variants":"くされ縁/腐れ縁"},"腐れ縁":{"variants":"くされ縁/腐れ縁"},"くされる":{"variants":"くされる/腐れる"},"腐れる":{"variants":"くされる/腐れる"},"草わけ":{"variants":"草わけ/草分/草分け"},"草分":{"variants":"草わけ/草分/草分け"},"草分け":{"variants":"草わけ/草分/草分け"},"くし":{"variants":"くし/クシ/区史/串/櫛"},"クシ":{"variants":"くし/クシ/区史/串/櫛"},"串かつ":{"variants":"串かつ/串カツ"},"串カツ":{"variants":"串かつ/串カツ"},"くしくも":{"variants":"くしくも/奇しくも"},"奇しくも":{"variants":"くしくも/奇しくも"},"串刺":{"variants":"串刺/串刺し"},"串刺し":{"variants":"串刺/串刺し"},"くしゃみ":{"variants":"くしゃみ/クシャミ"},"クシャミ":{"variants":"くしゃみ/クシャミ"},"くし焼き":{"variants":"くし焼き/串焼/串焼き"},"串焼":{"variants":"くし焼き/串焼/串焼き"},"串焼き":{"variants":"くし焼き/串焼/串焼き"},"くじ":{"variants":"くじ/九字/九時/籤/鬮"},"くじ運":{"variants":"くじ運/籤運"},"籤運":{"variants":"くじ運/籤運"},"くじける":{"variants":"くじける/挫ける"},"挫ける":{"variants":"くじける/挫ける"},"クジャク":{"variants":"クジャク/孔雀"},"孔雀":{"variants":"クジャク/孔雀"},"クジャクセキ":{"variants":"クジャクセキ/孔雀石"},"孔雀石":{"variants":"クジャクセキ/孔雀石"},"くじら":{"variants":"くじら/クジラ/鯨/鯀"},"クジラ":{"variants":"くじら/クジラ/鯨/鯀"},"くすぐったい":{"variants":"くすぐったい/擽ったい"},"擽ったい":{"variants":"くすぐったい/擽ったい"},"くすぐる":{"variants":"くすぐる/擽る"},"擽る":{"variants":"くすぐる/擽る"},"くす玉":{"variants":"くす玉/薬玉"},"薬玉":{"variants":"くす玉/薬玉"},"くず":{"variants":"くず/クズ/屑"},"クズ":{"variants":"くず/クズ/屑"},"屑":{"variants":"くず/クズ/屑"},"くずかご":{"variants":"くずかご/屑篭"},"屑篭":{"variants":"くずかご/屑篭"},"くず粉":{"variants":"くず粉/葛粉"},"葛粉":{"variants":"くず粉/葛粉"},"くずし書き":{"variants":"くずし書き/崩し書き"},"崩し書き":{"variants":"くずし書き/崩し書き"},"くずす":{"variants":"くずす/崩す"},"崩す":{"variants":"くずす/崩す"},"くずせる":{"variants":"くずせる/崩せる"},"崩せる":{"variants":"くずせる/崩せる"},"くず鉄":{"variants":"くず鉄/屑鉄"},"屑鉄":{"variants":"くず鉄/屑鉄"},"くず米":{"variants":"くず米/屑米"},"屑米":{"variants":"くず米/屑米"},"くず餅":{"variants":"くず餅/葛餅"},"葛餅":{"variants":"くず餅/葛餅"},"くずれおちる":{"variants":"くずれおちる/崩れ落ちる"},"崩れ落ちる":{"variants":"くずれおちる/崩れ落ちる"},"くずれさる":{"variants":"くずれさる/崩れさる"},"崩れさる":{"variants":"くずれさる/崩れさる"},"くずれる":{"variants":"くずれる/崩れる"},"崩れる":{"variants":"くずれる/崩れる"},"くせ":{"variants":"くせ/癖"},"クセ":{"variants":"くせ/クセ/癖"},"癖":{"variants":"くせ/癖"},"くせ者":{"variants":"くせ者/曲者"},"曲者":{"variants":"くせ者/曲者"},"くそ力":{"variants":"くそ力/糞力"},"糞力":{"variants":"くそ力/糞力"},"くそ度胸":{"variants":"くそ度胸/糞度胸"},"糞度胸":{"variants":"くそ度胸/糞度胸"},"クソバエ":{"variants":"クソバエ/糞蝿"},"糞蝿":{"variants":"クソバエ/糞蝿"},"クソムシ":{"variants":"クソムシ/糞虫"},"糞虫":{"variants":"クソムシ/糞虫"},"くたくた":{"variants":"くたくた/クタクタ"},"クタクタ":{"variants":"くたくた/クタクタ"},"くたびれる":{"variants":"くたびれる/草臥れる"},"草臥れる":{"variants":"くたびれる/草臥れる"},"くだく":{"variants":"くだく/砕く/碎く"},"くだける":{"variants":"くだける/砕ける/碎ける"},"くださる":{"variants":"くださる/下さる"},"下さる":{"variants":"くださる/下さる"},"下しぐすり":{"variants":"下しぐすり/下し薬"},"下し薬":{"variants":"下しぐすり/下し薬"},"くだす":{"variants":"くだす/下す/降す"},"くだせる":{"variants":"くだせる/下せる"},"下せる":{"variants":"くだせる/下せる"},"くだらない":{"variants":"くだらない/下らない"},"下らない":{"variants":"くだらない/下らない"},"くだり":{"variants":"くだり/下り"},"下り":{"variants":"くだり/下り"},"下りあゆ":{"variants":"下りあゆ/下り鮎"},"下り鮎":{"variants":"下りあゆ/下り鮎"},"くだる":{"variants":"くだる/下る"},"下る":{"variants":"くだる/下る"},"口当たり":{"variants":"口当たり/口当り"},"口当り":{"variants":"口当たり/口当り"},"くちうるさい":{"variants":"くちうるさい/口うるさい/口煩い"},"口うるさい":{"variants":"くちうるさい/口うるさい/口煩い"},"口煩い":{"variants":"くちうるさい/口うるさい/口煩い"},"くちがたい":{"variants":"くちがたい/口堅い"},"口堅い":{"variants":"くちがたい/口堅い"},"朽ち木":{"variants":"朽ち木/朽木"},"朽木":{"variants":"朽ち木/朽木"},"くちぎたない":{"variants":"くちぎたない/口汚い"},"口汚い":{"variants":"くちぎたない/口汚い"},"口ぐせ":{"variants":"口ぐせ/口癖"},"口癖":{"variants":"口ぐせ/口癖"},"口々":{"variants":"口々/口口"},"口口":{"variants":"口々/口口"},"口げんか":{"variants":"口げんか/口喧嘩"},"口喧嘩":{"variants":"口げんか/口喧嘩"},"口こみ":{"variants":"口こみ/口コミ"},"口コミ":{"variants":"口こみ/口コミ"},"くちごもる":{"variants":"くちごもる/口ごもる/口篭る"},"口ごもる":{"variants":"くちごもる/口ごもる/口篭る"},"口篭る":{"variants":"くちごもる/口ごもる/口篭る"},"くちさがない":{"variants":"くちさがない/口さがない"},"口さがない":{"variants":"くちさがない/口さがない"},"くちずから":{"variants":"くちずから/口ずから"},"口ずから":{"variants":"くちずから/口ずから"},"くちずさむ":{"variants":"くちずさむ/口ずさむ"},"口ずさむ":{"variants":"くちずさむ/口ずさむ"},"口づけ":{"variants":"口づけ/口付け"},"口付け":{"variants":"口づけ/口付け"},"口づて":{"variants":"口づて/口伝て"},"口伝て":{"variants":"口づて/口伝て"},"口取":{"variants":"口取/口取り"},"口取り":{"variants":"口取/口取り"},"クチナシ":{"variants":"クチナシ/山梔子/梔"},"くちはてる":{"variants":"くちはてる/朽ち果てる/朽果てる"},"朽ち果てる":{"variants":"くちはてる/朽ち果てる/朽果てる"},"朽果てる":{"variants":"くちはてる/朽ち果てる/朽果てる"},"くちはばったい":{"variants":"くちはばったい/口幅ったい"},"口幅ったい":{"variants":"くちはばったい/口幅ったい"},"くちばしる":{"variants":"くちばしる/口走る"},"口走る":{"variants":"くちばしる/口走る"},"口ひげ":{"variants":"口ひげ/口髭"},"口髭":{"variants":"口ひげ/口髭"},"くちびる":{"variants":"くちびる/唇"},"唇":{"variants":"くちびる/唇"},"口ぶり":{"variants":"口ぶり/口振り"},"口振り":{"variants":"口ぶり/口振り"},"口べた":{"variants":"口べた/口下手"},"口下手":{"variants":"口べた/口下手"},"口まね":{"variants":"口まね/口真似"},"口真似":{"variants":"口まね/口真似"},"口もと":{"variants":"口もと/口許/口元"},"くちやかましい":{"variants":"くちやかましい/口喧しい"},"口喧しい":{"variants":"くちやかましい/口喧しい"},"口よせ":{"variants":"口よせ/口寄せ"},"口寄せ":{"variants":"口よせ/口寄せ"},"くちる":{"variants":"くちる/朽ちる"},"朽ちる":{"variants":"くちる/朽ちる"},"屈し":{"variants":"屈し/屈指"},"屈指":{"variants":"屈し/屈指"},"くっする":{"variants":"くっする/屈する"},"屈する":{"variants":"くっする/屈する"},"くったく":{"variants":"くったく/屈託"},"屈託":{"variants":"くったく/屈託"},"くつがえす":{"variants":"くつがえす/覆す"},"覆す":{"variants":"くつがえす/覆す"},"くつがえせる":{"variants":"くつがえせる/覆せる"},"覆せる":{"variants":"くつがえせる/覆せる"},"くつがえる":{"variants":"くつがえる/覆る"},"覆る":{"variants":"くつがえる/覆る"},"くつ下":{"variants":"くつ下/靴下"},"靴下":{"variants":"くつ下/靴下"},"靴ずれ":{"variants":"靴ずれ/靴擦れ"},"靴擦れ":{"variants":"靴ずれ/靴擦れ"},"靴べら":{"variants":"靴べら/靴篦"},"靴篦":{"variants":"靴べら/靴篦"},"くつろぐ":{"variants":"くつろぐ/寛ぐ"},"寛ぐ":{"variants":"くつろぐ/寛ぐ"},"くつろげる":{"variants":"くつろげる/寛げる"},"寛げる":{"variants":"くつろげる/寛げる"},"クツワムシ":{"variants":"クツワムシ/轡虫"},"轡虫":{"variants":"クツワムシ/轡虫"},"くどきおとす":{"variants":"くどきおとす/口説き落とす"},"口説き落とす":{"variants":"くどきおとす/口説き落とす"},"くどく":{"variants":"くどく/口説く"},"口説く":{"variants":"くどく/口説く"},"くどける":{"variants":"くどける/口説ける"},"口説ける":{"variants":"くどける/口説ける"},"くに":{"variants":"くに/クニ/国/國"},"クニ":{"variants":"くに/クニ/国/國"},"国替":{"variants":"国替/国替え"},"国替え":{"variants":"国替/国替え"},"国なまり":{"variants":"国なまり/国訛/国訛り"},"国訛":{"variants":"国なまり/国訛/国訛り"},"国訛り":{"variants":"国なまり/国訛/国訛り"},"クヌギ":{"variants":"クヌギ/椚"},"椚":{"variants":"クヌギ/椚"},"クネンボ":{"variants":"クネンボ/九年母"},"九年母":{"variants":"クネンボ/九年母"},"くばりあるく":{"variants":"くばりあるく/配り歩く"},"配り歩く":{"variants":"くばりあるく/配り歩く"},"くばりあるける":{"variants":"くばりあるける/配り歩ける"},"配り歩ける":{"variants":"くばりあるける/配り歩ける"},"くばる":{"variants":"くばる/配る"},"配る":{"variants":"くばる/配る"},"くばれる":{"variants":"くばれる/配れる"},"配れる":{"variants":"くばれる/配れる"},"クビ":{"variants":"クビ/首"},"首":{"variants":"クビ/首"},"首枷":{"variants":"首かせ/首枷"},"首かせ":{"variants":"首かせ/首枷"},"首くくり":{"variants":"首くくり/首縊り"},"首縊り":{"variants":"首くくり/首縊り"},"首すじ":{"variants":"首すじ/首筋"},"首筋":{"variants":"首すじ/首筋"},"首ったま":{"variants":"首ったま/首っ玉"},"首っ玉":{"variants":"首ったま/首っ玉"},"くびっぴき":{"variants":"くびっぴき/首っぴき/首っ引き"},"首っぴき":{"variants":"くびっぴき/首っぴき/首っ引き"},"首っ引き":{"variants":"くびっぴき/首っぴき/首っ引き"},"首つり":{"variants":"首つり/首吊り"},"首吊り":{"variants":"首つり/首吊り"},"くびれる":{"variants":"くびれる/括れる/縊れる"},"くぼち":{"variants":"くぼち/窪地"},"窪地":{"variants":"くぼち/窪地"},"くぼまる":{"variants":"くぼまる/窪まる"},"窪まる":{"variants":"くぼまる/窪まる"},"くぼむ":{"variants":"くぼむ/窪む"},"窪む":{"variants":"くぼむ/窪む"},"くぼめる":{"variants":"くぼめる/窪める"},"窪める":{"variants":"くぼめる/窪める"},"くま":{"variants":"くま/クマ/熊/隈"},"クマ":{"variants":"くま/クマ/熊/隈"},"隈々":{"variants":"隈々/隈隈"},"隈隈":{"variants":"隈々/隈隈"},"クマザサ":{"variants":"クマザサ/熊ざさ/熊笹/隈笹"},"熊ざさ":{"variants":"クマザサ/熊ざさ/熊笹"},"熊笹":{"variants":"クマザサ/熊ざさ/熊笹"},"クマタカ":{"variants":"クマタカ/熊鷹"},"熊鷹":{"variants":"クマタカ/熊鷹"},"クマどり":{"variants":"クマどり/隈取/隈取り"},"隈取":{"variants":"クマどり/隈取/隈取り"},"隈取り":{"variants":"クマどり/隈取/隈取り"},"くまの胆":{"variants":"くまの胆/熊のい/熊の胆"},"熊のい":{"variants":"くまの胆/熊のい/熊の胆"},"熊の胆":{"variants":"くまの胆/熊のい/熊の胆"},"クマバチ":{"variants":"クマバチ/熊蜂"},"熊蜂":{"variants":"クマバチ/熊蜂"},"クマンバチ":{"variants":"クマンバチ/熊んばち/熊ん蜂"},"熊んばち":{"variants":"クマンバチ/熊んばち/熊ん蜂"},"熊ん蜂":{"variants":"クマンバチ/熊んばち/熊ん蜂"},"組":{"variants":"組/組み"},"組み":{"variants":"組/組み"},"組み合い":{"variants":"組み合い/組合"},"組合":{"variants":"組み合い/組合"},"くみあう":{"variants":"くみあう/組みあう/組み合う/組合う"},"組みあう":{"variants":"くみあう/組みあう/組み合う/組合う"},"組み合う":{"variants":"くみあう/組みあう/組み合う/組合う"},"組合う":{"variants":"くみあう/組みあう/組み合う/組合う"},"くみあげる":{"variants":"くみあげる/くみ上げる/汲みあげる/汲み上げる/組みあげる/組み上げる/組上げる"},"くみ上げる":{"variants":"くみあげる/くみ上げる/汲みあげる/汲み上げる/組みあげる/組み上げる/組上げる"},"組上げる":{"variants":"くみあげる/くみ上げる/組みあげる/組み上げる/組上げる"},"汲み上げる":{"variants":"くみあげる/くみ上げる/汲みあげる/汲み上げる"},"組み上げる":{"variants":"くみあげる/くみ上げる/組みあげる/組み上げる/組上げる"},"汲みあげる":{"variants":"くみあげる/くみ上げる/汲みあげる/汲み上げる"},"組みあげる":{"variants":"くみあげる/くみ上げる/組みあげる/組み上げる/組上げる"},"くみあわす":{"variants":"くみあわす/組みあわす/組み合す/組み合わす/組合す"},"組みあわす":{"variants":"くみあわす/組みあわす/組み合す/組み合わす/組合す"},"組み合す":{"variants":"くみあわす/組みあわす/組み合す/組み合わす/組合す"},"組み合わす":{"variants":"くみあわす/組みあわす/組み合す/組み合わす/組合す"},"組合す":{"variants":"くみあわす/組みあわす/組み合す/組み合わす/組合す"},"組み合わせ":{"variants":"組み合わせ/組合せ"},"組合せ":{"variants":"組み合わせ/組合せ"},"くみあわせる":{"variants":"くみあわせる/組みあわせる/組み合せる/組み合わせる/組合せる"},"組みあわせる":{"variants":"くみあわせる/組みあわせる/組み合せる/組み合わせる/組合せる"},"組み合せる":{"variants":"くみあわせる/組みあわせる/組み合せる/組み合わせる/組合せる"},"組み合わせる":{"variants":"くみあわせる/組みあわせる/組み合せる/組み合わせる/組合せる"},"組合せる":{"variants":"くみあわせる/組みあわせる/組み合せる/組み合わせる/組合せる"},"くみいれる":{"variants":"くみいれる/組みいれる/組み入れる/組入れる"},"組みいれる":{"variants":"くみいれる/組みいれる/組み入れる/組入れる"},"組み入れる":{"variants":"くみいれる/組みいれる/組み入れる/組入れる"},"組入れる":{"variants":"くみいれる/組みいれる/組み入れる/組入れる"},"組歌":{"variants":"組み歌/組歌"},"組み歌":{"variants":"組み歌/組歌"},"組打":{"variants":"組打/組打ち"},"組打ち":{"variants":"組打/組打ち"},"くみかえる":{"variants":"くみかえる/組みかえる/組み替える/組替える"},"組みかえる":{"variants":"くみかえる/組みかえる/組み替える/組替える"},"組み替える":{"variants":"くみかえる/組みかえる/組み替える/組替える"},"組替える":{"variants":"くみかえる/組みかえる/組み替える/組替える"},"くみかわす":{"variants":"くみかわす/酌み交す/酌み交わす"},"酌み交す":{"variants":"くみかわす/酌み交す/酌み交わす"},"酌み交わす":{"variants":"くみかわす/酌み交す/酌み交わす"},"組み曲":{"variants":"組み曲/組曲"},"組曲":{"variants":"組み曲/組曲"},"組み込み":{"variants":"組み込み/組込み"},"組込み":{"variants":"組み込み/組込み"},"くみこむ":{"variants":"くみこむ/汲み込む/組みこむ/組み込む/組込む"},"組込む":{"variants":"くみこむ/組みこむ/組み込む/組込む"},"組み込む":{"variants":"くみこむ/組みこむ/組み込む/組込む"},"組みこむ":{"variants":"くみこむ/組みこむ/組み込む/組込む"},"くみこめる":{"variants":"くみこめる/組みこめる/組み込める/組込める"},"組みこめる":{"variants":"くみこめる/組みこめる/組み込める/組込める"},"組み込める":{"variants":"くみこめる/組みこめる/組み込める/組込める"},"組込める":{"variants":"くみこめる/組みこめる/組み込める/組込める"},"くみしく":{"variants":"くみしく/組み敷く/組敷く"},"組み敷く":{"variants":"くみしく/組み敷く/組敷く"},"組敷く":{"variants":"くみしく/組み敷く/組敷く"},"くみする":{"variants":"くみする/与する"},"与する":{"variants":"くみする/与する"},"組立":{"variants":"組み立て/組立/組立て"},"汲みたて":{"variants":"汲みたて/汲み立て"},"組立て":{"variants":"組み立て/組立/組立て"},"汲み立て":{"variants":"汲みたて/汲み立て"},"組み立て":{"variants":"組み立て/組立/組立て"},"くみたてる":{"variants":"くみたてる/組みたてる/組み立てる/組み立る/組立てる"},"組みたてる":{"variants":"くみたてる/組みたてる/組み立てる/組み立る/組立てる"},"組み立てる":{"variants":"くみたてる/組みたてる/組み立てる/組み立る/組立てる"},"組み立る":{"variants":"くみたてる/組みたてる/組み立てる/組み立る/組立てる"},"組立てる":{"variants":"くみたてる/組みたてる/組み立てる/組み立る/組立てる"},"くみだす":{"variants":"くみだす/くみ出す/汲みだす/汲み出す"},"くみ出す":{"variants":"くみだす/くみ出す/汲みだす/汲み出す"},"汲みだす":{"variants":"くみだす/くみ出す/汲みだす/汲み出す"},"汲み出す":{"variants":"くみだす/くみ出す/汲みだす/汲み出す"},"くみだせる":{"variants":"くみだせる/くみ出せる"},"くみ出せる":{"variants":"くみだせる/くみ出せる"},"くみつく":{"variants":"くみつく/組みつく/組み付く/組付く"},"組みつく":{"variants":"くみつく/組みつく/組み付く/組付く"},"組み付く":{"variants":"くみつく/組みつく/組み付く/組付く"},"組付く":{"variants":"くみつく/組みつく/組み付く/組付く"},"くみつける":{"variants":"くみつける/組みつける/組み付ける/組付ける"},"組みつける":{"variants":"くみつける/組みつける/組み付ける/組付ける"},"組み付ける":{"variants":"くみつける/組みつける/組み付ける/組付ける"},"組付ける":{"variants":"くみつける/組みつける/組み付ける/組付ける"},"くみとる":{"variants":"くみとる/くみ取る/汲み取る"},"くみ取る":{"variants":"くみとる/くみ取る/汲み取る"},"汲み取る":{"variants":"くみとる/くみ取る/汲み取る"},"くみとれる":{"variants":"くみとれる/くみ取れる/汲み取れる"},"くみ取れる":{"variants":"くみとれる/くみ取れる/汲み取れる"},"汲み取れる":{"variants":"くみとれる/くみ取れる/汲み取れる"},"くみなおす":{"variants":"くみなおす/組みなおす/組み直す"},"組みなおす":{"variants":"くみなおす/組みなおす/組み直す"},"組み直す":{"variants":"くみなおす/組みなおす/組み直す"},"くみなおせる":{"variants":"くみなおせる/組みなおせる/組み直せる"},"組みなおせる":{"variants":"くみなおせる/組みなおせる/組み直せる"},"組み直せる":{"variants":"くみなおせる/組みなおせる/組み直せる"},"組み紐":{"variants":"組み紐/組紐"},"組紐":{"variants":"組み紐/組紐"},"くみふせる":{"variants":"くみふせる/組み伏せる/組伏せる"},"組み伏せる":{"variants":"くみふせる/組み伏せる/組伏せる"},"組伏せる":{"variants":"くみふせる/組み伏せる/組伏せる"},"くみほす":{"variants":"くみほす/汲み乾す/汲み干す"},"くむ":{"variants":"くむ/汲む/酌む/組む"},"くめる":{"variants":"くめる/汲める/酌める/組める"},"くも":{"variants":"くも/クモ/蜘蛛"},"クモ":{"variants":"くも/クモ/蜘蛛"},"蜘蛛":{"variants":"くも/クモ/蜘蛛"},"クモザル":{"variants":"クモザル/蜘蛛猿"},"蜘蛛猿":{"variants":"クモザル/蜘蛛猿"},"くも膜":{"variants":"くも膜/蜘蛛膜"},"蜘蛛膜":{"variants":"くも膜/蜘蛛膜"},"くもらす":{"variants":"くもらす/曇らす"},"曇らす":{"variants":"くもらす/曇らす"},"くもらせる":{"variants":"くもらせる/曇らせる"},"曇らせる":{"variants":"くもらせる/曇らせる"},"くもりガラス":{"variants":"くもりガラス/曇ガラス"},"曇ガラス":{"variants":"くもりガラス/曇ガラス"},"くもる":{"variants":"くもる/曇る"},"曇る":{"variants":"くもる/曇る"},"くやしい":{"variants":"くやしい/悔しい"},"悔しい":{"variants":"くやしい/悔しい"},"くやしさ":{"variants":"くやしさ/悔しさ"},"悔しさ":{"variants":"くやしさ/悔しさ"},"くやし泣き":{"variants":"くやし泣き/悔し泣き"},"悔し泣き":{"variants":"くやし泣き/悔し泣き"},"くやし涙":{"variants":"くやし涙/悔しなみだ/悔し涙/悔涙"},"悔しなみだ":{"variants":"くやし涙/悔しなみだ/悔し涙/悔涙"},"悔し涙":{"variants":"くやし涙/悔しなみだ/悔し涙/悔涙"},"悔涙":{"variants":"くやし涙/悔しなみだ/悔し涙/悔涙"},"くやし紛れ":{"variants":"くやし紛れ/悔しまぎれ/悔し紛れ"},"悔しまぎれ":{"variants":"くやし紛れ/悔しまぎれ/悔し紛れ"},"悔し紛れ":{"variants":"くやし紛れ/悔しまぎれ/悔し紛れ"},"悔み":{"variants":"悔み/悔やみ"},"悔やみ":{"variants":"悔み/悔やみ"},"くやむ":{"variants":"くやむ/悔やむ"},"悔やむ":{"variants":"くやむ/悔やむ"},"くゆらす":{"variants":"くゆらす/燻らす"},"燻らす":{"variants":"くゆらす/燻らす"},"くよくよ":{"variants":"くよくよ/クヨクヨ"},"クヨクヨ":{"variants":"くよくよ/クヨクヨ"},"くらい":{"variants":"くらい/クラい/暗い"},"クラい":{"variants":"くらい/クラい/暗い"},"暗い":{"variants":"くらい/クラい/暗い"},"くらいする":{"variants":"くらいする/位する"},"位する":{"variants":"くらいする/位する"},"くらいつく":{"variants":"くらいつく/食らいつく"},"食らいつく":{"variants":"くらいつく/食らいつく"},"くらう":{"variants":"くらう/喰らう/食らう"},"くらえる":{"variants":"くらえる/食らえる"},"食らえる":{"variants":"くらえる/食らえる"},"くらくら":{"variants":"くらくら/クラクラ"},"クラクラ":{"variants":"くらくら/クラクラ"},"クラゲ":{"variants":"クラゲ/海月/水母"},"くらし":{"variants":"くらし/暮し/暮らし"},"暮し":{"variants":"くらし/暮し/暮らし"},"暮らし":{"variants":"ぐらし/暮らし"},"くらす":{"variants":"くらす/暮す/暮らす"},"暮す":{"variants":"くらす/暮す/暮らす"},"暮らす":{"variants":"くらす/暮す/暮らす"},"くらせる":{"variants":"くらせる/暮らせる"},"暮らせる":{"variants":"くらせる/暮らせる"},"比べもの":{"variants":"比べもの/比べ物"},"比べ物":{"variants":"比べもの/比べ物"},"くらべる":{"variants":"くらべる/較べる/競べる/比べる"},"くらます":{"variants":"くらます/暗ます/晦ます"},"くらむ":{"variants":"くらむ/暗む/眩む"},"暗やみ":{"variants":"暗やみ/暗闇"},"暗闇":{"variants":"暗やみ/暗闇"},"くらわす":{"variants":"くらわす/食らわす"},"食らわす":{"variants":"くらわす/食らわす"},"くらわせる":{"variants":"くらわせる/食らわせる"},"食らわせる":{"variants":"くらわせる/食らわせる"},"クリ":{"variants":"クリ/栗/庫裏/庫裡"},"くりあげる":{"variants":"くりあげる/くり上げる/繰りあげる/繰り上げる/繰上げる"},"くり上げる":{"variants":"くりあげる/くり上げる/繰りあげる/繰り上げる/繰上げる"},"繰りあげる":{"variants":"くりあげる/くり上げる/繰りあげる/繰り上げる/繰上げる"},"繰り上げる":{"variants":"くりあげる/くり上げる/繰りあげる/繰り上げる/繰上げる"},"繰上げる":{"variants":"くりあげる/くり上げる/繰りあげる/繰り上げる/繰上げる"},"くりあわせる":{"variants":"くりあわせる/繰りあわせる/繰り合せる/繰合せる"},"繰りあわせる":{"variants":"くりあわせる/繰りあわせる/繰り合せる/繰合せる"},"繰り合せる":{"variants":"くりあわせる/繰りあわせる/繰り合せる/繰合せる"},"繰合せる":{"variants":"くりあわせる/繰りあわせる/繰り合せる/繰合せる"},"くりいれる":{"variants":"くりいれる/繰り入れる/繰入れる"},"繰り入れる":{"variants":"くりいれる/繰り入れる/繰入れる"},"繰入れる":{"variants":"くりいれる/繰り入れる/繰入れる"},"繰りかえし":{"variants":"繰りかえし/繰り返し/繰返し"},"繰り返し":{"variants":"繰りかえし/繰り返し/繰返し"},"繰返し":{"variants":"繰りかえし/繰り返し/繰返し"},"くりかえす":{"variants":"くりかえす/繰りかえす/繰り返す/繰返す"},"繰りかえす":{"variants":"くりかえす/繰りかえす/繰り返す/繰返す"},"繰り返す":{"variants":"くりかえす/繰りかえす/繰り返す/繰返す"},"繰返す":{"variants":"くりかえす/繰りかえす/繰り返す/繰返す"},"くりかえせる":{"variants":"くりかえせる/繰り返せる"},"繰り返せる":{"variants":"くりかえせる/繰り返せる"},"くりかえる":{"variants":"くりかえる/繰りかえる/繰り替える/繰替える"},"繰りかえる":{"variants":"くりかえる/繰りかえる/繰り替える/繰替える"},"繰り替える":{"variants":"くりかえる/繰りかえる/繰り替える/繰替える"},"繰替える":{"variants":"くりかえる/繰りかえる/繰り替える/繰替える"},"繰り越し":{"variants":"繰り越し/繰越"},"繰越":{"variants":"繰り越し/繰越"},"くりこす":{"variants":"くりこす/繰り越す/繰越す"},"繰り越す":{"variants":"くりこす/繰り越す/繰越す"},"繰越す":{"variants":"くりこす/繰り越す/繰越す"},"くりこせる":{"variants":"くりこせる/繰り越せる"},"繰り越せる":{"variants":"くりこせる/繰り越せる"},"くりこむ":{"variants":"くりこむ/繰り込む"},"繰り込む":{"variants":"くりこむ/繰り込む"},"くりこめる":{"variants":"くりこめる/繰り込める"},"繰り込める":{"variants":"くりこめる/繰り込める"},"くりさげる":{"variants":"くりさげる/繰り下げる/繰下げる"},"繰り下げる":{"variants":"くりさげる/繰り下げる/繰下げる"},"繰下げる":{"variants":"くりさげる/繰り下げる/繰下げる"},"Ｘｍａｓ":{"variants":"Ｘｍａｓ/クリスマス"},"クリスマス":{"variants":"Ｘｍａｓ/クリスマス"},"繰り出し":{"variants":"繰り出し/繰出し"},"繰出し":{"variants":"繰り出し/繰出し"},"くりだす":{"variants":"くりだす/くり出す/繰り出す"},"くり出す":{"variants":"くりだす/くり出す/繰り出す"},"繰り出す":{"variants":"くりだす/くり出す/繰り出す"},"くりだせる":{"variants":"くりだせる/繰り出せる"},"繰り出せる":{"variants":"くりだせる/繰り出せる"},"繰り戸":{"variants":"繰り戸/繰戸"},"繰戸":{"variants":"繰り戸/繰戸"},"くりぬく":{"variants":"くりぬく/くり貫く/くり抜く/刳り貫く"},"刳り貫く":{"variants":"くりぬく/くり貫く/刳り貫く"},"くり貫く":{"variants":"くりぬく/くり貫く/刳り貫く"},"くりぬける":{"variants":"くりぬける/くり貫ける"},"くり貫ける":{"variants":"くりぬける/くり貫ける"},"繰り延べ":{"variants":"繰り延べ/繰延"},"繰延":{"variants":"繰り延べ/繰延"},"くりのべる":{"variants":"くりのべる/繰り延べる/繰延べる"},"繰り延べる":{"variants":"くりのべる/繰り延べる/繰延べる"},"繰延べる":{"variants":"くりのべる/繰り延べる/繰延べる"},"くりひろげる":{"variants":"くりひろげる/くり広げる/繰り広げる/繰広げる"},"くり広げる":{"variants":"くりひろげる/くり広げる/繰り広げる/繰広げる"},"繰り広げる":{"variants":"くりひろげる/くり広げる/繰り広げる/繰広げる"},"繰広げる":{"variants":"くりひろげる/くり広げる/繰り広げる/繰広げる"},"くりまわす":{"variants":"くりまわす/繰りまわす/繰り回す/繰回す"},"繰りまわす":{"variants":"くりまわす/繰りまわす/繰り回す/繰回す"},"繰り回す":{"variants":"くりまわす/繰りまわす/繰り回す/繰回す"},"繰回す":{"variants":"くりまわす/繰りまわす/繰り回す/繰回す"},"栗まんじゅう":{"variants":"栗まんじゅう/栗饅頭"},"栗饅頭":{"variants":"栗まんじゅう/栗饅頭"},"くりよせる":{"variants":"くりよせる/繰り寄せる/繰寄せる"},"繰り寄せる":{"variants":"くりよせる/繰り寄せる/繰寄せる"},"繰寄せる":{"variants":"くりよせる/繰り寄せる/繰寄せる"},"くる":{"variants":"くる/繰る/刳る"},"くるう":{"variants":"くるう/狂う"},"狂う":{"variants":"くるう/狂う"},"くるおしい":{"variants":"くるおしい/狂おしい"},"狂おしい":{"variants":"くるおしい/狂おしい"},"くるくる":{"variants":"くるくる/クルクル"},"クルクル":{"variants":"くるくる/クルクル"},"くるしい":{"variants":"くるしい/苦しい"},"苦しい":{"variants":"くるしい/苦しい"},"苦しまぎれ":{"variants":"苦しまぎれ/苦し紛れ"},"苦し紛れ":{"variants":"苦しまぎれ/苦し紛れ"},"くるしむ":{"variants":"くるしむ/苦しむ"},"苦しむ":{"variants":"くるしむ/苦しむ"},"くるしめる":{"variants":"くるしめる/苦しめる"},"苦しめる":{"variants":"くるしめる/苦しめる"},"くるぶし":{"variants":"くるぶし/踝"},"踝":{"variants":"くるぶし/踝"},"車いす":{"variants":"車いす/車椅子"},"車椅子":{"variants":"車いす/車椅子"},"クルマエビ":{"variants":"クルマエビ/車蝦/車海老"},"車止":{"variants":"車止/車止め"},"車止め":{"variants":"車止/車止め"},"車寄":{"variants":"車寄/車寄せ"},"車寄せ":{"variants":"車寄/車寄せ"},"くるみ":{"variants":"くるみ/クルミ/胡桃"},"クルミ":{"variants":"くるみ/クルミ/胡桃"},"胡桃":{"variants":"くるみ/クルミ/胡桃"},"久留米がすり":{"variants":"久留米がすり/久留米絣"},"久留米絣":{"variants":"久留米がすり/久留米絣"},"くるめく":{"variants":"くるめく/眩く"},"眩く":{"variants":"くるめく/眩く"},"くるわしい":{"variants":"くるわしい/狂わしい"},"狂わしい":{"variants":"くるわしい/狂わしい"},"くるわす":{"variants":"くるわす/狂わす"},"狂わす":{"variants":"くるわす/狂わす"},"暮":{"variants":"暮/暮れ"},"暮れ":{"variants":"暮/暮れ"},"くれぐれ":{"variants":"くれぐれ/呉呉"},"呉呉":{"variants":"くれぐれ/呉呉"},"クレタケ":{"variants":"クレタケ/呉竹"},"呉竹":{"variants":"クレタケ/呉竹"},"くれのこる":{"variants":"くれのこる/暮れ残る"},"暮れ残る":{"variants":"くれのこる/暮れ残る"},"くれる":{"variants":"くれる/呉れる"},"呉れる":{"variants":"くれる/呉れる"},"クロ":{"variants":"クロ/黒"},"黒":{"variants":"クロ/黒"},"くろい":{"variants":"くろい/黒い"},"黒い":{"variants":"くろい/黒い"},"クロカビ":{"variants":"クロカビ/黒カビ/黒黴"},"黒カビ":{"variants":"クロカビ/黒カビ/黒黴"},"黒黴":{"variants":"クロカビ/黒カビ/黒黴"},"クロガキ":{"variants":"クロガキ/黒柿"},"黒柿":{"variants":"クロガキ/黒柿"},"クロキ":{"variants":"クロキ/黒酒"},"黒酒":{"variants":"クロキ/黒酒"},"クロクマ":{"variants":"クロクマ/黒熊"},"黒熊":{"variants":"クロクマ/黒熊"},"黒こげ":{"variants":"黒こげ/黒焦げ"},"黒焦げ":{"variants":"黒こげ/黒焦げ"},"くろずむ":{"variants":"くろずむ/黒ずむ"},"黒ずむ":{"variants":"くろずむ/黒ずむ"},"クロダイ":{"variants":"クロダイ/黒鯛"},"黒鯛":{"variants":"クロダイ/黒鯛"},"くろダイヤ":{"variants":"くろダイヤ/黒ダイヤ"},"黒ダイヤ":{"variants":"くろダイヤ/黒ダイヤ"},"クロチク":{"variants":"クロチク/黒竹"},"黒竹":{"variants":"クロチク/黒竹"},"くろっぽい":{"variants":"くろっぽい/黒っぽい"},"黒っぽい":{"variants":"くろっぽい/黒っぽい"},"クロテン":{"variants":"クロテン/黒貂"},"黒貂":{"variants":"クロテン/黒貂"},"くろパン":{"variants":"くろパン/黒パン"},"黒パン":{"variants":"くろパン/黒パン"},"くろビール":{"variants":"くろビール/黒ビール"},"黒ビール":{"variants":"くろビール/黒ビール"},"黒光":{"variants":"黒光/黒光り"},"黒光り":{"variants":"黒光/黒光り"},"クロマツ":{"variants":"クロマツ/黒松"},"黒松":{"variants":"クロマツ/黒松"},"クロマメ":{"variants":"クロマメ/黒豆"},"黒豆":{"variants":"クロマメ/黒豆"},"くろみがかる":{"variants":"くろみがかる/黒みがかる"},"黒みがかる":{"variants":"くろみがかる/黒みがかる"},"くろめる":{"variants":"くろめる/黒める"},"黒める":{"variants":"くろめる/黒める"},"クロモジ":{"variants":"クロモジ/黒文字"},"黒文字":{"variants":"クロモジ/黒文字"},"黒焼":{"variants":"黒焼/黒焼き"},"黒焼き":{"variants":"黒焼/黒焼き"},"クロユリ":{"variants":"クロユリ/黒百合"},"黒百合":{"variants":"クロユリ/黒百合"},"黒んぼう":{"variants":"黒んぼう/黒ん坊"},"黒ん坊":{"variants":"黒んぼう/黒ん坊"},"クワ":{"variants":"クワ/桑/鍬"},"クワイ":{"variants":"クワイ/慈姑"},"慈姑":{"variants":"クワイ/慈姑"},"クワイアタマ":{"variants":"クワイアタマ/慈姑頭"},"慈姑頭":{"variants":"クワイアタマ/慈姑頭"},"くわえもつ":{"variants":"くわえもつ/加え持つ"},"加え持つ":{"variants":"くわえもつ/加え持つ"},"くわえる":{"variants":"くわえる/加える/銜える"},"クワガタ":{"variants":"クワガタ/鍬形"},"鍬形":{"variants":"クワガタ/鍬形"},"くわがた虫":{"variants":"くわがた虫/クワガタムシ/鍬形虫"},"クワガタムシ":{"variants":"くわがた虫/クワガタムシ/鍬形虫"},"鍬形虫":{"variants":"くわがた虫/クワガタムシ/鍬形虫"},"クワゴ":{"variants":"クワゴ/桑蚕/桑子/野蚕"},"くわしい":{"variants":"くわしい/委しい/詳しい/精しい"},"くわす":{"variants":"くわす/食わす"},"食わす":{"variants":"くわす/食わす"},"食わずぎらい":{"variants":"食わずぎらい/食わず嫌い"},"食わず嫌い":{"variants":"食わずぎらい/食わず嫌い"},"食わせもの":{"variants":"食わせもの/食わせ物"},"食わせ物":{"variants":"食わせもの/食わせ物"},"くわせる":{"variants":"くわせる/食わせる"},"食わせる":{"variants":"くわせる/食わせる"},"くわだてる":{"variants":"くわだてる/企てる"},"企てる":{"variants":"くわだてる/企てる"},"くわわる":{"variants":"くわわる/加わる"},"加わる":{"variants":"くわわる/加わる"},"くん":{"variants":"くん/クン/君"},"クン":{"variants":"くん/クン/君"},"クンシ":{"variants":"クンシ/君子"},"君子":{"variants":"クンシ/君子"},"クンシジン":{"variants":"クンシジン/君子人"},"君子人":{"variants":"クンシジン/君子人"},"クンシラン":{"variants":"クンシラン/君子蘭"},"君子蘭":{"variants":"クンシラン/君子蘭"},"くん蒸":{"variants":"くん蒸/燻蒸"},"燻蒸":{"variants":"くん蒸/燻蒸"},"くんずる":{"variants":"くんずる/薫ずる/訓ずる"},"くん製":{"variants":"くん製/薫製/燻製"},"ぐーんと":{"variants":"ぐーんと/グーンと"},"グーンと":{"variants":"ぐーんと/グーンと"},"具合":{"variants":"具合/具合い"},"具合い":{"variants":"具合/具合い"},"ぐいぐい":{"variants":"ぐいぐい/グイグイ"},"グイグイ":{"variants":"ぐいぐい/グイグイ"},"ぐうする":{"variants":"ぐうする/遇する"},"遇する":{"variants":"ぐうする/遇する"},"ぐうぜん":{"variants":"ぐうぜん/偶然"},"偶然":{"variants":"ぐうぜん/偶然"},"ぐしょぬれ":{"variants":"ぐしょぬれ/ぐしょ濡れ"},"ぐしょ濡れ":{"variants":"ぐしょぬれ/ぐしょ濡れ"},"ぐする":{"variants":"ぐする/具する"},"具する":{"variants":"ぐする/具する"},"ぐずぐず":{"variants":"ぐずぐず/グズグズ"},"グズグズ":{"variants":"ぐずぐず/グズグズ"},"ぐずる":{"variants":"ぐずる/愚図る"},"愚図る":{"variants":"ぐずる/愚図る"},"グチ":{"variants":"グチ/愚痴"},"愚痴":{"variants":"グチ/愚痴"},"ぐちゃぐちゃ":{"variants":"ぐちゃぐちゃ/グチャグチャ"},"グチャグチャ":{"variants":"ぐちゃぐちゃ/グチャグチャ"},"ぐちる":{"variants":"ぐちる/愚痴る"},"愚痴る":{"variants":"ぐちる/愚痴る"},"ぐつぐつ":{"variants":"ぐつぐつ/グツグツ"},"グツグツ":{"variants":"ぐつぐつ/グツグツ"},"グビジンソウ":{"variants":"グビジンソウ/虞美人草"},"虞美人草":{"variants":"グビジンソウ/虞美人草"},"グミ":{"variants":"グミ/胡頽子/茱萸"},"ぐらぐら":{"variants":"ぐらぐら/グラグラ"},"グラグラ":{"variants":"ぐらぐら/グラグラ"},"ぐらし":{"variants":"ぐらし/暮らし"},"ｇ":{"variants":"ｇ/グラム"},"グラム":{"variants":"ｇ/グラム"},"ぐりぐり":{"variants":"ぐりぐり/グリグリ"},"グリグリ":{"variants":"ぐりぐり/グリグリ"},"ぐるぐる":{"variants":"ぐるぐる/グルグル"},"グルグル":{"variants":"ぐるぐる/グルグル"},"ぐれる":{"variants":"ぐれる/グレる"},"グレる":{"variants":"ぐれる/グレる"},"ぐろう":{"variants":"ぐろう/愚ろう/愚弄"},"愚ろう":{"variants":"ぐろう/愚ろう/愚弄"},"愚弄":{"variants":"ぐろう/愚ろう/愚弄"},"ぐんぐん":{"variants":"ぐんぐん/グングン"},"グングン":{"variants":"ぐんぐん/グングン"},"けあげる":{"variants":"けあげる/蹴上げる"},"蹴上げる":{"variants":"けあげる/蹴上げる"},"けい":{"variants":"けい/ケイ/刑/景/系/経/罫/計/軽/頚"},"ケイ":{"variants":"けい/ケイ/刑/景/系/経/罫/計/軽/頚"},"形がい":{"variants":"形がい/形骸"},"形骸":{"variants":"形がい/形骸"},"炯々":{"variants":"炯々/炯炯"},"炯炯":{"variants":"炯々/炯炯"},"けいけん":{"variants":"けいけん/敬虔"},"敬虔":{"variants":"敬けん/敬虔"},"敬けん":{"variants":"敬けん/敬虔"},"けいこ":{"variants":"けいこ/稽古"},"稽古":{"variants":"けいこ/稽古"},"けい骨":{"variants":"けい骨/頚骨/脛骨"},"けいざい":{"variants":"けいざい/経済"},"経済":{"variants":"けいざい/経済"},"けいする":{"variants":"けいする/刑する/啓する/慶する/敬する"},"頚腺":{"variants":"頚せん/頚腺"},"頚せん":{"variants":"頚せん/頚腺"},"硅素":{"variants":"ケイ素/硅素"},"ケイ素":{"variants":"ケイ素/珪素/硅素"},"珪素":{"variants":"ケイ素/珪素"},"ケイソウ":{"variants":"ケイソウ/珪藻/継走/軽躁/硅藻"},"けい椎":{"variants":"けい椎/頚椎"},"頚椎":{"variants":"けい椎/頚椎"},"ケイトウ":{"variants":"ケイトウ/敬答/系統/継投/鶏頭"},"けい動脈":{"variants":"けい動脈/頚動脈"},"頚動脈":{"variants":"けい動脈/頚動脈"},"ケイヒ":{"variants":"ケイヒ/桂皮/経費"},"鶏ふん":{"variants":"鶏ふん/鶏糞"},"鶏糞":{"variants":"鶏ふん/鶏糞"},"軽べつ":{"variants":"軽べつ/軽蔑"},"軽蔑":{"variants":"軽べつ/軽蔑"},"啓もう":{"variants":"啓もう/啓蒙"},"啓蒙":{"variants":"啓もう/啓蒙"},"警ら":{"variants":"警ら/警邏"},"警邏":{"variants":"警ら/警邏"},"けいれん":{"variants":"けいれん/痙攣"},"痙攣":{"variants":"けいれん/痙攣"},"けう":{"variants":"けう/希有/稀有"},"けうとい":{"variants":"けうとい/気疎い"},"気疎い":{"variants":"けうとい/気疎い"},"けおされる":{"variants":"けおされる/気圧される"},"気圧される":{"variants":"けおされる/気圧される"},"けおとす":{"variants":"けおとす/け落とす/蹴落す"},"け落とす":{"variants":"けおとす/け落とす/蹴落す"},"蹴落す":{"variants":"けおとす/け落とす/蹴落す"},"けおとせる":{"variants":"けおとせる/け落とせる"},"け落とせる":{"variants":"けおとせる/け落とせる"},"毛織":{"variants":"毛織/毛織り"},"毛織り":{"variants":"毛織/毛織り"},"けかえす":{"variants":"けかえす/蹴返す"},"蹴返す":{"variants":"けかえす/蹴返す"},"ケカビ":{"variants":"ケカビ/毛カビ/毛黴"},"毛カビ":{"variants":"ケカビ/毛カビ/毛黴"},"毛黴":{"variants":"ケカビ/毛カビ/毛黴"},"けが":{"variants":"けが/ケガ"},"ケガ":{"variants":"けが/ケガ"},"けがす":{"variants":"けがす/穢す"},"穢す":{"variants":"けがす/穢す"},"ケガニ":{"variants":"ケガニ/毛ガニ/毛蟹"},"毛ガニ":{"variants":"ケガニ/毛ガニ/毛蟹"},"毛蟹":{"variants":"ケガニ/毛ガニ/毛蟹"},"けがらわしい":{"variants":"けがらわしい/汚らわしい/穢らわしい"},"けがれ":{"variants":"けがれ/穢/穢れ"},"穢":{"variants":"けがれ/穢/穢れ"},"穢れ":{"variants":"けがれ/穢/穢れ"},"けがれる":{"variants":"けがれる/穢れる"},"穢れる":{"variants":"けがれる/穢れる"},"けげん":{"variants":"けげん/怪訝"},"怪訝":{"variants":"けげん/怪訝"},"ケゴ":{"variants":"ケゴ/毛蚕"},"毛蚕":{"variants":"ケゴ/毛蚕"},"袈裟がけ":{"variants":"袈裟がけ/袈裟懸け"},"袈裟懸け":{"variants":"袈裟がけ/袈裟懸け"},"ケシ":{"variants":"ケシ/消し/罌粟"},"けしきばむ":{"variants":"けしきばむ/気色ばむ"},"気色ばむ":{"variants":"けしきばむ/気色ばむ"},"けしゴム":{"variants":"けしゴム/ケシゴム/消しゴム/消ゴム"},"ケシゴム":{"variants":"けしゴム/ケシゴム/消しゴム/消ゴム"},"消しゴム":{"variants":"けしゴム/ケシゴム/消しゴム/消ゴム"},"消ゴム":{"variants":"けしゴム/ケシゴム/消しゴム/消ゴム"},"消し炭":{"variants":"消し炭/消炭"},"消炭":{"variants":"消し炭/消炭"},"けしとぶ":{"variants":"けしとぶ/けし飛ぶ/消し飛ぶ"},"けし飛ぶ":{"variants":"けしとぶ/けし飛ぶ/消し飛ぶ"},"消し飛ぶ":{"variants":"けしとぶ/けし飛ぶ/消し飛ぶ"},"けしとめる":{"variants":"けしとめる/消し止める"},"消し止める":{"variants":"けしとめる/消し止める"},"けじめ":{"variants":"けじめ/ケジメ"},"ケジメ":{"variants":"けじめ/ケジメ"},"ケジラミ":{"variants":"ケジラミ/毛じらみ/毛ジラミ/毛虱"},"毛じらみ":{"variants":"ケジラミ/毛じらみ/毛ジラミ/毛虱"},"毛ジラミ":{"variants":"ケジラミ/毛じらみ/毛ジラミ/毛虱"},"毛虱":{"variants":"ケジラミ/毛じらみ/毛ジラミ/毛虱"},"けす":{"variants":"けす/消す"},"消す":{"variants":"けす/消す"},"けずりたおす":{"variants":"けずりたおす/削り倒す"},"削り倒す":{"variants":"けずりたおす/削り倒す"},"けずりたおせる":{"variants":"けずりたおせる/削り倒せる"},"削り倒せる":{"variants":"けずりたおせる/削り倒せる"},"けずりとる":{"variants":"けずりとる/削り取る"},"削り取る":{"variants":"けずりとる/削り取る"},"けずりとれる":{"variants":"けずりとれる/削り取れる"},"削り取れる":{"variants":"けずりとれる/削り取れる"},"削りぶし":{"variants":"削りぶし/削り節/削節"},"削り節":{"variants":"削りぶし/削り節/削節"},"削節":{"variants":"削りぶし/削り節/削節"},"けずる":{"variants":"けずる/削る"},"削る":{"variants":"けずる/削る"},"けずれる":{"variants":"けずれる/削れる"},"削れる":{"variants":"けずれる/削れる"},"けせる":{"variants":"けせる/消せる"},"消せる":{"variants":"けせる/消せる"},"ケタ":{"variants":"けた/ケタ/桁"},"桁":{"variants":"けた/ケタ/桁"},"けた":{"variants":"けた/ケタ/桁"},"けたおす":{"variants":"けたおす/蹴倒す"},"蹴倒す":{"variants":"けたおす/蹴倒す"},"けたてる":{"variants":"けたてる/蹴立てる"},"蹴立てる":{"variants":"けたてる/蹴立てる"},"けだかい":{"variants":"けだかい/気高い"},"気高い":{"variants":"けだかい/気高い"},"けだし":{"variants":"けだし/蓋し"},"蓋し":{"variants":"けだし/蓋し"},"けだす":{"variants":"けだす/蹴出す"},"蹴出す":{"variants":"けだす/蹴出す"},"けち":{"variants":"けち/ケチ"},"ケチ":{"variants":"けち/ケチ"},"けちがえる":{"variants":"けちがえる/蹴違える"},"蹴違える":{"variants":"けちがえる/蹴違える"},"けぢかい":{"variants":"けぢかい/気近い"},"気近い":{"variants":"けぢかい/気近い"},"けっく":{"variants":"けっく/結句"},"結句":{"variants":"けっく/結句"},"けっこう":{"variants":"けっこう/結構"},"結構":{"variants":"けっこう/結構"},"けっして":{"variants":"けっして/決して"},"決して":{"variants":"けっして/決して"},"血しゅ":{"variants":"血しゅ/血腫"},"血腫":{"variants":"血しゅ/血腫"},"血しょう":{"variants":"血しょう/血漿"},"血漿":{"variants":"血しょう/血漿"},"けっする":{"variants":"けっする/決する"},"決する":{"variants":"けっする/決する"},"血栓":{"variants":"血せん/血栓"},"血せん":{"variants":"血せん/血栓"},"血たん":{"variants":"血たん/血痰"},"血痰":{"variants":"血たん/血痰"},"けっていづける":{"variants":"けっていづける/決定づける"},"決定づける":{"variants":"けっていづける/決定づける"},"血統書つき":{"variants":"血統書つき/血統書付き"},"血統書付き":{"variants":"血統書つき/血統書付き"},"けっとばす":{"variants":"けっとばす/蹴っとばす/蹴っ飛ばす"},"蹴っとばす":{"variants":"けっとばす/蹴っとばす/蹴っ飛ばす"},"蹴っ飛ばす":{"variants":"けっとばす/蹴っとばす/蹴っ飛ばす"},"けつ岩":{"variants":"けつ岩/頁岩"},"頁岩":{"variants":"けつ岩/頁岩"},"けつぜん":{"variants":"けつぜん/決然/蹶然"},"けつまずく":{"variants":"けつまずく/蹴躓く"},"蹴躓く":{"variants":"けつまずく/蹴躓く"},"けとばす":{"variants":"けとばす/け飛ばす/蹴飛ばす"},"け飛ばす":{"variants":"けとばす/け飛ばす/蹴飛ばす"},"蹴飛ばす":{"variants":"けとばす/け飛ばす/蹴飛ばす"},"けなす":{"variants":"けなす/貶す"},"貶す":{"variants":"けなす/貶す"},"毛並":{"variants":"毛並/毛並み"},"毛並み":{"variants":"毛並/毛並み"},"毛抜":{"variants":"毛抜/毛抜き"},"毛抜き":{"variants":"毛抜/毛抜き"},"けばけば":{"variants":"けばけば/ケバケバ"},"ケバケバ":{"variants":"けばけば/ケバケバ"},"けばだつ":{"variants":"けばだつ/毛羽立つ/毳立つ"},"けぶかい":{"variants":"けぶかい/毛深い"},"毛深い":{"variants":"けぶかい/毛深い"},"けぶる":{"variants":"けぶる/烟る"},"烟る":{"variants":"けぶる/烟る"},"けまり":{"variants":"けまり/蹴まり/蹴鞠"},"蹴まり":{"variants":"けまり/蹴まり/蹴鞠"},"蹴鞠":{"variants":"けまり/蹴まり/蹴鞠"},"けむい":{"variants":"けむい/煙い"},"煙い":{"variants":"けむい/煙い"},"ケムシ":{"variants":"ケムシ/毛虫"},"毛虫":{"variants":"ケムシ/毛虫"},"けむたい":{"variants":"けむたい/煙たい"},"煙たい":{"variants":"けむたい/煙たい"},"けむたがる":{"variants":"けむたがる/煙たがる"},"煙たがる":{"variants":"けむたがる/煙たがる"},"けむる":{"variants":"けむる/煙る"},"煙る":{"variants":"けむる/煙る"},"ケヤキ":{"variants":"ケヤキ/欅"},"欅":{"variants":"ケヤキ/欅"},"けやぶる":{"variants":"けやぶる/蹴破る"},"蹴破る":{"variants":"けやぶる/蹴破る"},"けら":{"variants":"けら/ケラ"},"ケラ":{"variants":"けら/ケラ"},"ケリ":{"variants":"ケリ/鳧"},"鳧":{"variants":"ケリ/鳧"},"ける":{"variants":"ける/蹴る/蹶る"},"けわしい":{"variants":"けわしい/険しい"},"険しい":{"variants":"けわしい/険しい"},"牽引":{"variants":"けん引/牽引"},"けん引":{"variants":"けん引/牽引"},"ケンカ":{"variants":"ケンカ/喧嘩/献花/鹸化"},"けんか":{"variants":"けんか/懸架/県下/県花"},"けんか腰":{"variants":"けんか腰/喧嘩腰"},"喧嘩腰":{"variants":"けんか腰/喧嘩腰"},"ケンギュウ":{"variants":"ケンギュウ/牽牛"},"牽牛":{"variants":"ケンギュウ/牽牛"},"ケンギュウカ":{"variants":"ケンギュウカ/牽牛花"},"牽牛花":{"variants":"ケンギュウカ/牽牛花"},"喧々":{"variants":"喧々/喧喧"},"拳拳":{"variants":"拳々/拳拳"},"喧喧":{"variants":"喧々/喧喧"},"拳々":{"variants":"拳々/拳拳"},"喧々囂々":{"variants":"喧々囂々/喧喧囂囂"},"喧喧囂囂":{"variants":"喧々囂々/喧喧囂囂"},"けんけんふくよう":{"variants":"けんけんふくよう/拳々服膺"},"拳々服膺":{"variants":"けんけんふくよう/拳々服膺"},"剣先":{"variants":"剣先/剣先き"},"剣先き":{"variants":"剣先/剣先き"},"研さん":{"variants":"研さん/研鑽"},"研鑽":{"variants":"研さん/研鑽"},"けんしきばる":{"variants":"けんしきばる/見識張る"},"見識張る":{"variants":"けんしきばる/見識張る"},"けん銃":{"variants":"けん銃/拳銃"},"拳銃":{"variants":"けん銃/拳銃"},"けんじる":{"variants":"けんじる/献じる"},"献じる":{"variants":"けんじる/献じる"},"けんする":{"variants":"けんする/検する/験する"},"けんずる":{"variants":"けんずる/献ずる"},"献ずる":{"variants":"けんずる/献ずる"},"けん制":{"variants":"けん制/牽制"},"牽制":{"variants":"けん制/牽制"},"けん責":{"variants":"けん責/譴責"},"譴責":{"variants":"けん責/譴責"},"けん騒":{"variants":"けん騒/喧騒"},"喧騒":{"variants":"けん騒/喧騒"},"謙そん":{"variants":"謙そん/謙遜"},"謙遜":{"variants":"けんそん/謙遜"},"けんそん":{"variants":"けんそん/謙遜"},"けん怠":{"variants":"けん怠/倦怠"},"倦怠":{"variants":"けん怠/倦怠"},"けん怠期":{"variants":"けん怠期/倦怠期"},"倦怠期":{"variants":"けん怠期/倦怠期"},"けん玉":{"variants":"けん玉/剣玉/拳玉"},"けんちん汁":{"variants":"けんちん汁/巻繊汁"},"巻繊汁":{"variants":"けんちん汁/巻繊汁"},"けん伝":{"variants":"けん伝/喧伝"},"喧伝":{"variants":"けん伝/喧伝"},"けん土重来":{"variants":"けん土重来/捲土重来"},"捲土重来":{"variants":"けん土重来/捲土重来"},"鍵盤":{"variants":"けん盤/鍵盤"},"けん盤":{"variants":"けん盤/鍵盤"},"けんび鏡":{"variants":"けんび鏡/顕微鏡"},"顕微鏡":{"variants":"けんび鏡/顕微鏡"},"建ぺい率":{"variants":"建ぺい率/建蔽率"},"建蔽率":{"variants":"建ぺい率/建蔽率"},"けんぽう":{"variants":"けんぽう/剣法/憲法/拳法"},"けんまく":{"variants":"けんまく/剣幕/権幕/見幕"},"けんめい":{"variants":"けんめい/懸命/賢明"},"けんらん":{"variants":"けんらん/絢爛"},"絢爛":{"variants":"けんらん/絢爛"},"ゲイ":{"variants":"ゲイ/芸/藝"},"ゲキ":{"variants":"ゲキ/劇/檄"},"げきする":{"variants":"げきする/檄する"},"檄する":{"variants":"げきする/檄する"},"げすばる":{"variants":"げすばる/下種張る"},"下種張る":{"variants":"げすばる/下種張る"},"ゲタ":{"variants":"ゲタ/下駄"},"下駄":{"variants":"ゲタ/下駄"},"ゲッカ":{"variants":"ゲッカ/月下"},"月下":{"variants":"ゲッカ/月下"},"ゲッカヒョウジン":{"variants":"ゲッカヒョウジン/月下氷人"},"月下氷人":{"variants":"ゲッカヒョウジン/月下氷人"},"ゲッカビジン":{"variants":"ゲッカビジン/月下美人"},"月下美人":{"variants":"ゲッカビジン/月下美人"},"ゲッケイ":{"variants":"ゲッケイ/月桂/月経"},"ゲッケイカン":{"variants":"ゲッケイカン/月桂冠"},"月桂冠":{"variants":"ゲッケイカン/月桂冠"},"ゲッケイジュ":{"variants":"ゲッケイジュ/月桂樹"},"月桂樹":{"variants":"ゲッケイジュ/月桂樹"},"げっぺい":{"variants":"げっぺい/月餅"},"月餅":{"variants":"げっぺい/月餅"},"げびる":{"variants":"げびる/下卑びる"},"下卑びる":{"variants":"げびる/下卑びる"},"ゲン":{"variants":"ゲン/厳/減/玄/言/儼"},"げん気":{"variants":"げんき/げん気/元気"},"衒気":{"variants":"げん気/衒気"},"げんき":{"variants":"げんき/げん気/元気"},"元気":{"variants":"げんき/げん気/元気"},"言々":{"variants":"言々/言言"},"言言":{"variants":"言々/言言"},"げんこつ":{"variants":"げんこつ/ゲンコツ/拳骨"},"ゲンコツ":{"variants":"げんこつ/ゲンコツ/拳骨"},"拳骨":{"variants":"げんこつ/ゲンコツ/拳骨"},"ゲンゴロウ":{"variants":"ゲンゴロウ/源五郎"},"源五郎":{"variants":"ゲンゴロウ/源五郎"},"ゲンゴロウブナ":{"variants":"ゲンゴロウブナ/源五郎鮒"},"源五郎鮒":{"variants":"ゲンゴロウブナ/源五郎鮒"},"ゲンジボタル":{"variants":"ゲンジボタル/源氏蛍"},"源氏蛍":{"variants":"ゲンジボタル/源氏蛍"},"げんじる":{"variants":"げんじる/減じる"},"減じる":{"variants":"げんじる/減じる"},"げんずる":{"variants":"げんずる/減ずる/現ずる"},"ゲンセイ":{"variants":"ゲンセイ/原生/厳正/現制/現勢"},"ゲンチュウ":{"variants":"ゲンチュウ/原注/原虫/原註"},"げんに":{"variants":"げんに/厳に/現に"},"コーヒー":{"variants":"コーヒー/珈琲"},"珈琲":{"variants":"コーヒー/珈琲"},"こい":{"variants":"こい/濃い"},"濃い":{"variants":"こい/濃い"},"コイ":{"variants":"コイ/故意/乞い/鯉/請い/恋"},"濃い口":{"variants":"濃い口/濃口"},"濃口":{"variants":"濃い口/濃口"},"こいこがれる":{"variants":"こいこがれる/恋いこがれる/恋い焦がれる/恋こがれる/恋焦がれる"},"恋いこがれる":{"variants":"こいこがれる/恋いこがれる/恋い焦がれる/恋こがれる/恋焦がれる"},"恋い焦がれる":{"variants":"こいこがれる/恋いこがれる/恋い焦がれる/恋こがれる/恋焦がれる"},"恋こがれる":{"variants":"こいこがれる/恋いこがれる/恋い焦がれる/恋こがれる/恋焦がれる"},"恋焦がれる":{"variants":"こいこがれる/恋いこがれる/恋い焦がれる/恋こがれる/恋焦がれる"},"こいしい":{"variants":"こいしい/恋しい"},"恋しい":{"variants":"こいしい/恋しい"},"こいしたう":{"variants":"こいしたう/恋い慕う"},"恋い慕う":{"variants":"こいしたう/恋い慕う"},"こいする":{"variants":"こいする/恋する"},"恋する":{"variants":"こいする/恋する"},"こいねがう":{"variants":"こいねがう/希う/庶幾う/冀う"},"こいねがわくは":{"variants":"こいねがわくは/希くは/庶幾は/冀くは"},"コイのぼり":{"variants":"コイのぼり/鯉のぼり/鯉幟"},"鯉のぼり":{"variants":"コイのぼり/鯉のぼり/鯉幟"},"鯉幟":{"variants":"コイのぼり/鯉のぼり/鯉幟"},"恋びと":{"variants":"恋びと/恋人"},"恋人":{"variants":"恋びと/恋人"},"コイン":{"variants":"コイン/雇員"},"雇員":{"variants":"コイン/雇員"},"こう":{"variants":"こう/請う"},"請う":{"variants":"こう/請う"},"コウ":{"variants":"コウ/候/功/効/孝/工/幸/校/稿/耕/考/鉱/項/香/高/劫"},"こうかつ":{"variants":"こうかつ/広闊/狡猾"},"こう丸":{"variants":"こう丸/睾丸"},"睾丸":{"variants":"こう丸/睾丸"},"コウギョ":{"variants":"コウギョ/香魚"},"香魚":{"variants":"コウギョ/香魚"},"コウギョク":{"variants":"コウギョク/硬玉/紅玉/綱玉/鋼玉"},"こうくう":{"variants":"こうくう/航空/高空"},"煌煌":{"variants":"煌々/煌煌"},"煌々":{"variants":"煌々/煌煌"},"皓々":{"variants":"皓々/皓皓"},"皓皓":{"variants":"皓々/皓皓"},"好々爺":{"variants":"好々爺/好好爺"},"好好爺":{"variants":"好々爺/好好爺"},"コウコツ":{"variants":"コウコツ/甲骨/硬骨/恍惚"},"コウコツギョ":{"variants":"コウコツギョ/硬骨魚"},"硬骨魚":{"variants":"コウコツギョ/硬骨魚"},"こうごうしい":{"variants":"こうごうしい/神々しい/神神しい"},"神々しい":{"variants":"こうごうしい/神々しい/神神しい"},"神神しい":{"variants":"こうごうしい/神々しい/神神しい"},"鉱さい":{"variants":"鉱さい/鉱滓"},"鉱滓":{"variants":"鉱さい/鉱滓"},"格子じま":{"variants":"格子じま/格子縞"},"格子縞":{"variants":"格子じま/格子縞"},"コウショッキ":{"variants":"コウショッキ/紅蜀葵"},"紅蜀葵":{"variants":"コウショッキ/紅蜀葵"},"コウシン":{"variants":"コウシン/後身/功臣/口唇/孝心/庚申/恒心/紅唇/香辛"},"コウシンヅカ":{"variants":"コウシンヅカ/庚申塚"},"庚申塚":{"variants":"コウシンヅカ/庚申塚"},"コウシンバラ":{"variants":"コウシンバラ/庚申薔薇"},"庚申薔薇":{"variants":"コウシンバラ/庚申薔薇"},"コウシンマチ":{"variants":"コウシンマチ/庚申待"},"庚申待":{"variants":"コウシンマチ/庚申待"},"コウジ":{"variants":"コウジ/柑子/後事/公事/好餌/好字/高次/麹/小路/糀"},"コウジ菌":{"variants":"コウジ菌/麹菌"},"麹菌":{"variants":"コウジ菌/麹菌"},"甲状せん":{"variants":"甲状せん/甲状腺"},"甲状腺":{"variants":"甲状せん/甲状腺"},"こうじる":{"variants":"こうじる/講じる/高じる/困じる/嵩じる"},"後じん":{"variants":"後じん/後人/後塵"},"後人":{"variants":"後じん/後人"},"後塵":{"variants":"後じん/後塵"},"こうずる":{"variants":"こうずる/講ずる/貢ずる/高ずる/嵩ずる/薨ずる"},"コウソン":{"variants":"コウソン/公孫/皇孫"},"コウゾ":{"variants":"コウゾ/楮"},"楮":{"variants":"コウゾ/楮"},"コウチセイ":{"variants":"コウチセイ/向地性"},"向地性":{"variants":"コウチセイ/向地性"},"こう着":{"variants":"こう着/降着/膠着"},"コウチョウ":{"variants":"コウチョウ/黄鳥/候鳥/公聴/好調/校長/硬調/高潮"},"交通まひ":{"variants":"交通まひ/交通マヒ"},"交通マヒ":{"variants":"交通まひ/交通マヒ"},"こう頭":{"variants":"こう頭/叩頭"},"叩頭":{"variants":"こう頭/叩頭"},"荒唐無けい":{"variants":"荒唐無けい/荒唐無稽"},"荒唐無稽":{"variants":"荒唐無けい/荒唐無稽"},"コウノトリ":{"variants":"コウノトリ/鸛"},"鸛":{"variants":"コウノトリ/鸛"},"香の物":{"variants":"香の物/香物"},"香物":{"variants":"香の物/香物"},"コウバイ":{"variants":"こう配/コウバイ/勾配/紅梅"},"こう配":{"variants":"こう配/コウバイ/勾配"},"勾配":{"variants":"こう配/コウバイ/勾配"},"こうばしい":{"variants":"こうばしい/香ばしい/芳ばしい"},"降雹":{"variants":"降ひょう/降雹"},"降ひょう":{"variants":"降ひょう/降雹"},"コウボ":{"variants":"コウボ/酵母"},"酵母":{"variants":"コウボ/酵母"},"高まい":{"variants":"高まい/高邁"},"高邁":{"variants":"高まい/高邁"},"こうむる":{"variants":"こうむる/蒙る"},"蒙る":{"variants":"こうむる/蒙る"},"コウメ":{"variants":"コウメ/小梅"},"小梅":{"variants":"コウメ/小梅"},"こうもり傘":{"variants":"こうもり傘/蝙蝠傘"},"蝙蝠傘":{"variants":"こうもり傘/蝙蝠傘"},"こう門":{"variants":"こう門/黄門/校門/肛門/閘門"},"コウヤマキ":{"variants":"コウヤマキ/高野槙"},"高野槙":{"variants":"コウヤマキ/高野槙"},"コウライシバ":{"variants":"コウライシバ/高麗芝"},"高麗芝":{"variants":"コウライシバ/高麗芝"},"小売":{"variants":"小売/小売り"},"小売り":{"variants":"小売/小売り"},"コウリャン":{"variants":"コウリャン/高粱"},"高粱":{"variants":"コウリャン/高粱"},"こうりょうと":{"variants":"こうりょうと/荒涼と"},"荒涼と":{"variants":"こうりょうと/荒涼と"},"こうるさい":{"variants":"こうるさい/小うるさい/小煩い"},"小うるさい":{"variants":"こうるさい/小うるさい/小煩い"},"小煩い":{"variants":"こうるさい/小うるさい/小煩い"},"声変り":{"variants":"声変り/声変わり"},"声変わり":{"variants":"声変り/声変わり"},"声々":{"variants":"声々/声声"},"声声":{"variants":"声々/声声"},"こえる":{"variants":"こえる/越える/超える/肥える"},"こおどり":{"variants":"こおどり/小躍り"},"小躍り":{"variants":"こおどり/小躍り"},"こおりつく":{"variants":"こおりつく/凍りつく/凍り付く"},"凍りつく":{"variants":"こおりつく/凍りつく/凍り付く"},"凍り付く":{"variants":"こおりつく/凍りつく/凍り付く"},"凍りどうふ":{"variants":"凍りどうふ/凍り豆腐/凍豆腐"},"凍り豆腐":{"variants":"凍りどうふ/凍り豆腐/凍豆腐"},"凍豆腐":{"variants":"凍りどうふ/凍り豆腐/凍豆腐"},"氷まくら":{"variants":"氷まくら/氷枕"},"氷枕":{"variants":"氷まくら/氷枕"},"こおる":{"variants":"こおる/凍る/氷る"},"コオロギ":{"variants":"コオロギ/蟋蟀"},"蟋蟀":{"variants":"コオロギ/蟋蟀"},"木蔭":{"variants":"木かげ/木蔭"},"木陰":{"variants":"木かげ/木陰"},"木かげ":{"variants":"木かげ/木蔭/木陰"},"こ関節":{"variants":"こ関節/股関節"},"股関節":{"variants":"こ関節/股関節"},"こがす":{"variants":"こがす/焦がす"},"焦がす":{"variants":"こがす/焦がす"},"コガネ":{"variants":"コガネ/小金"},"小金":{"variants":"コガネ/小金"},"コガネムシ":{"variants":"コガネムシ/黄金虫"},"黄金虫":{"variants":"コガネムシ/黄金虫"},"コガモ":{"variants":"コガモ/小鴨"},"小鴨":{"variants":"コガモ/小鴨"},"木枯らし":{"variants":"木枯し/木枯らし"},"木枯し":{"variants":"木枯し/木枯らし"},"こがれる":{"variants":"こがれる/焦がれる"},"焦がれる":{"variants":"こがれる/焦がれる"},"こきおろす":{"variants":"こきおろす/こき下ろす/扱きおろす/扱き下ろす"},"こき下ろす":{"variants":"こきおろす/こき下ろす/扱きおろす/扱き下ろす"},"扱きおろす":{"variants":"こきおろす/こき下ろす/扱きおろす/扱き下ろす"},"扱き下ろす":{"variants":"こきおろす/こき下ろす/扱きおろす/扱き下ろす"},"小きざみ":{"variants":"小きざみ/小刻み"},"小刻み":{"variants":"小きざみ/小刻み"},"こきつかう":{"variants":"こきつかう/こき使う/扱き使う"},"こき使う":{"variants":"こきつかう/こき使う/扱き使う"},"扱き使う":{"variants":"こきつかう/こき使う/扱き使う"},"こきつかえる":{"variants":"こきつかえる/こき使える"},"こき使える":{"variants":"こきつかえる/こき使える"},"こきまぜる":{"variants":"こきまぜる/扱き雑ぜる"},"扱き雑ぜる":{"variants":"こきまぜる/扱き雑ぜる"},"こぎたない":{"variants":"こぎたない/小汚い"},"小汚い":{"variants":"こぎたない/小汚い"},"こぎつく":{"variants":"こぎつく/こぎ着く"},"こぎ着く":{"variants":"こぎつく/こぎ着く"},"こぎつける":{"variants":"こぎつける/こぎ着ける/漕ぎつける/漕ぎ着ける"},"こぎ着ける":{"variants":"こぎつける/こぎ着ける/漕ぎつける/漕ぎ着ける"},"漕ぎつける":{"variants":"こぎつける/こぎ着ける/漕ぎつける/漕ぎ着ける"},"漕ぎ着ける":{"variants":"こぎつける/こぎ着ける/漕ぎつける/漕ぎ着ける"},"こギャル":{"variants":"こギャル/コギャル"},"コギャル":{"variants":"こギャル/コギャル"},"こぎる":{"variants":"こぎる/小切る"},"小切る":{"variants":"こぎる/小切る"},"小ぎれい":{"variants":"小ぎれい/小奇麗/小綺麗"},"こく":{"variants":"こく/放く"},"放く":{"variants":"こく/放く"},"コク":{"variants":"コク/酷"},"酷":{"variants":"コク/酷"},"コクガ":{"variants":"コクガ/国衙/穀蛾"},"こくこく":{"variants":"こくこく/刻刻"},"刻刻":{"variants":"こくこく/刻刻"},"こくする":{"variants":"こくする/刻する/哭する"},"コクゾウムシ":{"variants":"コクゾウムシ/穀象虫"},"穀象虫":{"variants":"コクゾウムシ/穀象虫"},"コクタン":{"variants":"コクタン/黒炭/黒檀"},"こぐ":{"variants":"こぐ/扱ぐ/漕ぐ"},"コケ":{"variants":"コケ/虚仮/苔"},"こけむす":{"variants":"こけむす/苔むす"},"苔むす":{"variants":"こけむす/苔むす"},"コケモモ":{"variants":"コケモモ/苔桃"},"苔桃":{"variants":"コケモモ/苔桃"},"こけら落し":{"variants":"こけら落し/こけら落とし/柿落し"},"こけら落とし":{"variants":"こけら落し/こけら落とし/柿落し"},"柿落し":{"variants":"こけら落し/こけら落とし/柿落し"},"こける":{"variants":"こける/コケる/痩ける/転ける"},"コケる":{"variants":"こける/コケる/痩ける/転ける"},"こげくさい":{"variants":"こげくさい/焦げくさい/焦げ臭い/焦臭い"},"焦げくさい":{"variants":"こげくさい/焦げくさい/焦げ臭い/焦臭い"},"焦げ臭い":{"variants":"こげくさい/焦げくさい/焦げ臭い/焦臭い"},"焦臭い":{"variants":"こげくさい/焦げくさい/焦げ臭い/焦臭い"},"焦げ茶":{"variants":"焦げ茶/焦茶"},"焦茶":{"variants":"焦げ茶/焦茶"},"こげつかす":{"variants":"こげつかす/焦げつかす"},"焦げつかす":{"variants":"こげつかす/焦げつかす"},"こげつく":{"variants":"こげつく/焦げつく/焦げ付く"},"焦げつく":{"variants":"こげつく/焦げつく/焦げ付く"},"焦げ付く":{"variants":"こげつく/焦げつく/焦げ付く"},"焦げめ":{"variants":"焦げめ/焦げ目"},"焦げ目":{"variants":"焦げめ/焦げ目"},"こげる":{"variants":"こげる/焦げる/漕げる"},"箇々":{"variants":"箇々/箇箇"},"個々":{"variants":"個々/個個"},"個個":{"variants":"個々/個個"},"呱々":{"variants":"呱々/呱呱"},"呱呱":{"variants":"呱々/呱呱"},"箇箇":{"variants":"箇々/箇箇"},"個々人":{"variants":"個々人/個個人"},"個個人":{"variants":"個々人/個個人"},"箇箇人":{"variants":"箇々人/箇箇人"},"箇々人":{"variants":"箇々人/箇箇人"},"ここちよい":{"variants":"ここちよい/心地よい/心地好い"},"心地よい":{"variants":"ここちよい/心地よい/心地好い"},"心地好い":{"variants":"ここちよい/心地よい/心地好い"},"９つ":{"variants":"９つ/九つ"},"九つ":{"variants":"９つ/九つ"},"ココやし":{"variants":"ココやし/ココヤシ/ココ椰子"},"ココヤシ":{"variants":"ココやし/ココヤシ/ココ椰子"},"ココ椰子":{"variants":"ココやし/ココヤシ/ココ椰子"},"心当たり":{"variants":"心当たり/心当り"},"心当り":{"variants":"心当たり/心当り"},"こころうい":{"variants":"こころうい/心憂い"},"心憂い":{"variants":"こころうい/心憂い"},"心得ちがい":{"variants":"心得ちがい/心得違い"},"心得違い":{"variants":"心得ちがい/心得違い"},"心得る":{"variants":"こころえる/心得る"},"こころえる":{"variants":"こころえる/心得る"},"心がけ":{"variants":"心がけ/心掛け"},"心掛け":{"variants":"心がけ/心掛け"},"こころがける":{"variants":"こころがける/心がける/心掛ける"},"心がける":{"variants":"こころがける/心がける/心掛ける"},"心掛ける":{"variants":"こころがける/心がける/心掛ける"},"心がまえ":{"variants":"心がまえ/心構え"},"心構え":{"variants":"心がまえ/心構え"},"心変り":{"variants":"心変り/心変わり"},"心変わり":{"variants":"心変り/心変わり"},"こころぐるしい":{"variants":"こころぐるしい/心苦しい"},"心苦しい":{"variants":"こころぐるしい/心苦しい"},"心々":{"variants":"心々/心心"},"心心":{"variants":"心々/心心"},"こころざす":{"variants":"こころざす/志ざす/志す"},"志ざす":{"variants":"こころざす/志ざす/志す"},"志す":{"variants":"こころざす/志ざす/志す"},"こころする":{"variants":"こころする/心する"},"心する":{"variants":"こころする/心する"},"心づかい":{"variants":"心づかい/心遣い"},"心遣い":{"variants":"心づかい/心遣い"},"こころづく":{"variants":"こころづく/心づく/心付く"},"心づく":{"variants":"こころづく/心づく/心付く"},"心付く":{"variants":"こころづく/心づく/心付く"},"心尽くし":{"variants":"心尽くし/心尽し"},"心尽し":{"variants":"心尽くし/心尽し"},"心付":{"variants":"心付/心付け"},"心付け":{"variants":"心付/心付け"},"心づもり":{"variants":"心づもり/心積り"},"心積り":{"variants":"心づもり/心積り"},"こころづよい":{"variants":"こころづよい/心づよい/心強い"},"心づよい":{"variants":"こころづよい/心づよい/心強い"},"心強い":{"variants":"こころづよい/心づよい/心強い"},"こころない":{"variants":"こころない/心無い"},"心無い":{"variants":"こころない/心無い"},"こころにくい":{"variants":"こころにくい/心憎い"},"心憎い":{"variants":"こころにくい/心憎い"},"心ばせ":{"variants":"心ばせ/心馳せ"},"心馳せ":{"variants":"心ばせ/心馳せ"},"こころぼそい":{"variants":"こころぼそい/心細い"},"心細い":{"variants":"こころぼそい/心細い"},"こころみる":{"variants":"こころみる/試みる"},"試みる":{"variants":"こころみる/試みる"},"心もち":{"variants":"心もち/心持/心持ち"},"心持":{"variants":"心もち/心持/心持ち"},"心持ち":{"variants":"心もち/心持/心持ち"},"こころもとない":{"variants":"こころもとない/心もとない/心許ない/心許無い"},"心もとない":{"variants":"こころもとない/心もとない/心許ない/心許無い"},"心許ない":{"variants":"こころもとない/心もとない/心許ない/心許無い"},"心許無い":{"variants":"こころもとない/心もとない/心許ない/心許無い"},"こころやすい":{"variants":"こころやすい/心安い"},"心安い":{"variants":"こころやすい/心安い"},"心やり":{"variants":"心やり/心遣り"},"心遣り":{"variants":"心やり/心遣り"},"こころゆく":{"variants":"こころゆく/心ゆく/心行く"},"心ゆく":{"variants":"こころゆく/心ゆく/心行く"},"心行く":{"variants":"こころゆく/心ゆく/心行く"},"こころよい":{"variants":"こころよい/快い"},"快い":{"variants":"こころよい/快い"},"こころよわい":{"variants":"こころよわい/心弱い"},"心弱い":{"variants":"こころよわい/心弱い"},"こごえる":{"variants":"こごえる/凍える"},"凍える":{"variants":"こごえる/凍える"},"コゴメ":{"variants":"コゴメ/小米/粉米"},"コゴメバナ":{"variants":"コゴメバナ/小米花"},"小米花":{"variants":"コゴメバナ/小米花"},"こざかしい":{"variants":"こざかしい/小賢しい"},"小賢しい":{"variants":"こざかしい/小賢しい"},"こざっぱり":{"variants":"こざっぱり/小ざっぱり"},"小ざっぱり":{"variants":"こざっぱり/小ざっぱり"},"こし餡":{"variants":"こし餡/漉し餡"},"漉し餡":{"variants":"こし餡/漉し餡"},"腰かけ":{"variants":"腰かけ/腰掛/腰掛け"},"腰掛":{"variants":"腰かけ/腰掛/腰掛け"},"腰掛け":{"variants":"腰かけ/腰掛/腰掛け"},"こしかける":{"variants":"こしかける/腰かける/腰掛ける"},"腰かける":{"variants":"こしかける/腰かける/腰掛ける"},"腰掛ける":{"variants":"こしかける/腰かける/腰掛ける"},"腰ぎんちゃく":{"variants":"腰ぎんちゃく/腰巾着"},"腰巾着":{"variants":"腰ぎんちゃく/腰巾着"},"虎視たんたん":{"variants":"虎視たんたん/虎視眈々"},"虎視眈々":{"variants":"虎視たんたん/虎視眈々"},"腰っぽね":{"variants":"腰っぽね/腰っ骨"},"腰っ骨":{"variants":"腰っぽね/腰っ骨"},"腰ひも":{"variants":"腰ひも/腰紐"},"腰紐":{"variants":"腰ひも/腰紐"},"腰巻":{"variants":"腰巻/腰巻き"},"腰巻き":{"variants":"腰巻/腰巻き"},"腰みの":{"variants":"腰みの/腰蓑"},"腰蓑":{"variants":"腰みの/腰蓑"},"こしょう":{"variants":"こしょう/コショウ/妓生/古称/湖沼/胡椒/小姓"},"コショウ":{"variants":"こしょう/コショウ/妓生/古称/湖沼/胡椒/小姓"},"こしらえ事":{"variants":"こしらえ事/拵えごと/拵え事/拵事"},"拵えごと":{"variants":"こしらえ事/拵えごと/拵え事/拵事"},"拵え事":{"variants":"こしらえ事/拵えごと/拵え事/拵事"},"拵事":{"variants":"こしらえ事/拵えごと/拵え事/拵事"},"こしらえる":{"variants":"こしらえる/拵える"},"拵える":{"variants":"こしらえる/拵える"},"こじあける":{"variants":"こじあける/こじ開ける"},"こじ開ける":{"variants":"こじあける/こじ開ける"},"コジュケイ":{"variants":"コジュケイ/小綬鶏"},"小綬鶏":{"variants":"コジュケイ/小綬鶏"},"こじらす":{"variants":"こじらす/拗らす"},"拗らす":{"variants":"こじらす/拗らす"},"こじれる":{"variants":"こじれる/拗れる"},"拗れる":{"variants":"こじれる/拗れる"},"小じわ":{"variants":"小じわ/小皺"},"小皺":{"variants":"小じわ/小皺"},"こす":{"variants":"こす/越す/漉す/超す/濾す"},"こすっからい":{"variants":"こすっからい/こすっ辛い/狡っからい/狡っ辛い/狡辛い"},"こすっ辛い":{"variants":"こすっからい/こすっ辛い/狡っからい/狡っ辛い/狡辛い"},"狡っからい":{"variants":"こすっからい/こすっ辛い/狡っからい/狡っ辛い/狡辛い"},"狡っ辛い":{"variants":"こすっからい/こすっ辛い/狡っからい/狡っ辛い/狡辛い"},"狡辛い":{"variants":"こすっからい/こすっ辛い/狡っからい/狡っ辛い/狡辛い"},"こする":{"variants":"こする/鼓する"},"鼓する":{"variants":"こする/鼓する"},"こせる":{"variants":"こせる/越せる/漉せる/超せる/濾せる"},"こぜり合い":{"variants":"こぜり合い/小競り合い/小競合い"},"小競り合い":{"variants":"こぜり合い/小競り合い/小競合い"},"小競合い":{"variants":"こぜり合い/小競り合い/小競合い"},"こそこそ":{"variants":"こそこそ/コソコソ"},"コソコソ":{"variants":"こそこそ/コソコソ"},"小そで":{"variants":"小そで/小袖"},"小袖":{"variants":"小そで/小袖"},"こぞう":{"variants":"こぞう/小僧"},"小僧":{"variants":"こぞう/小僧"},"小僧っこ":{"variants":"小僧っこ/小僧っ子"},"小僧っ子":{"variants":"小僧っこ/小僧っ子"},"答":{"variants":"答/答え"},"答え":{"variants":"答/答え"},"こたえる":{"variants":"こたえる/応える/答える"},"こたつ":{"variants":"こたつ/コタツ/火燵/炬燵"},"コタツ":{"variants":"こたつ/コタツ/火燵/炬燵"},"こだかい":{"variants":"こだかい/小高い"},"小高い":{"variants":"こだかい/小高い"},"子だくさん":{"variants":"子だくさん/子沢山"},"子沢山":{"variants":"子だくさん/子沢山"},"こだま":{"variants":"こだま/小玉/木霊/谺"},"コチ":{"variants":"コチ/故知/故智/胡地/東風/鯒"},"こちこち":{"variants":"こちこち/コチコチ"},"コチコチ":{"variants":"こちこち/コチコチ"},"こぢんまり":{"variants":"こぢんまり/小ぢんまり"},"小ぢんまり":{"variants":"こぢんまり/小ぢんまり"},"こっとう":{"variants":"こっとう/骨とう/骨董"},"骨とう":{"variants":"こっとう/骨とう/骨董"},"骨董":{"variants":"こっとう/骨とう/骨董"},"木っ端みじん":{"variants":"木っ端みじん/木っ端微塵/木端微塵"},"木っ端微塵":{"variants":"木っ端みじん/木っ端微塵/木端微塵"},"木端微塵":{"variants":"木っ端みじん/木っ端微塵/木端微塵"},"こっぴどい":{"variants":"こっぴどい/こっ酷い"},"こっ酷い":{"variants":"こっぴどい/こっ酷い"},"こつえん":{"variants":"こつえん/忽焉"},"忽焉":{"variants":"こつえん/忽焉"},"こつぜんと":{"variants":"こつぜんと/こつ然と/忽然と"},"こつ然と":{"variants":"こつぜんと/こつ然と/忽然と"},"忽然と":{"variants":"こつぜんと/こつ然と/忽然と"},"骨つぼ":{"variants":"骨つぼ/骨壷"},"骨壷":{"variants":"骨つぼ/骨壷"},"骨ずい":{"variants":"骨ずい/骨髄"},"骨髄":{"variants":"骨ずい/骨髄"},"骨髄しゅ":{"variants":"骨髄しゅ/骨髄腫"},"骨髄腫":{"variants":"骨髄しゅ/骨髄腫"},"小つづみ":{"variants":"小つづみ/小鼓"},"小鼓":{"variants":"小つづみ/小鼓"},"こづかい":{"variants":"こづかい/小遣/小遣い/小使"},"小遣":{"variants":"こづかい/小遣/小遣い"},"小遣い":{"variants":"こづかい/小遣/小遣い"},"こづきまわす":{"variants":"こづきまわす/小突き回す"},"小突き回す":{"variants":"こづきまわす/小突き回す"},"こづく":{"variants":"こづく/小突く"},"小突く":{"variants":"こづく/小突く"},"小づくり":{"variants":"小づくり/小作り"},"小作り":{"variants":"小づくり/小作り"},"小づち":{"variants":"小づち/小槌"},"小槌":{"variants":"小づち/小槌"},"こづらにくい":{"variants":"こづらにくい/小面憎い"},"小面憎い":{"variants":"こづらにくい/小面憎い"},"こてこて":{"variants":"こてこて/コテコテ"},"コテコテ":{"variants":"こてこて/コテコテ"},"コデマリ":{"variants":"コデマリ/小手毬"},"小手毬":{"variants":"コデマリ/小手毬"},"こと":{"variants":"こと/コト"},"コト":{"variants":"こと/コト"},"ことあたらしい":{"variants":"ことあたらしい/事新しい"},"事新しい":{"variants":"ことあたらしい/事新しい"},"ことかく":{"variants":"ことかく/事欠く"},"事欠く":{"variants":"ことかく/事欠く"},"こときれる":{"variants":"こときれる/こと切れる/事切れる"},"こと切れる":{"variants":"こときれる/こと切れる/事切れる"},"事切れる":{"variants":"こときれる/こと切れる/事切れる"},"事事":{"variants":"事々/事事"},"事々":{"variants":"事々/事事"},"ことごとく":{"variants":"ことごとく/悉く/尽く/毎々"},"ことごとしい":{"variants":"ことごとしい/事々しい/事事しい"},"事々しい":{"variants":"ことごとしい/事々しい/事事しい"},"事事しい":{"variants":"ことごとしい/事々しい/事事しい"},"ことさら":{"variants":"ことさら/殊更"},"殊更":{"variants":"ことさら/殊更"},"ことし":{"variants":"ことし/今年"},"今年":{"variants":"ことし/今年"},"ことたりる":{"variants":"ことたりる/こと足りる/事足りる"},"こと足りる":{"variants":"ことたりる/こと足りる/事足りる"},"事足りる":{"variants":"ことたりる/こと足りる/事足りる"},"ことたる":{"variants":"ことたる/こと足る/事足る"},"こと足る":{"variants":"ことたる/こと足る/事足る"},"事足る":{"variants":"ことたる/こと足る/事足る"},"ことづかる":{"variants":"ことづかる/言付かる"},"言付かる":{"variants":"ことづかる/言付かる"},"ことなかれ主義":{"variants":"ことなかれ主義/事勿れ主義/事勿主義"},"事勿れ主義":{"variants":"ことなかれ主義/事勿れ主義/事勿主義"},"事勿主義":{"variants":"ことなかれ主義/事勿れ主義/事勿主義"},"ことなる":{"variants":"ことなる/異なる"},"異なる":{"variants":"ことなる/異なる"},"ことに":{"variants":"ことに/異に/殊に"},"事始":{"variants":"事始/事始め"},"事始め":{"variants":"事始/事始め"},"ことば":{"variants":"ことば/コトバ/言葉"},"コトバ":{"variants":"ことば/コトバ/言葉"},"言葉":{"variants":"ことば/コトバ/言葉"},"言葉じり":{"variants":"言葉じり/言葉尻"},"言葉尻":{"variants":"言葉じり/言葉尻"},"言葉づかい":{"variants":"言葉づかい/言葉遣い"},"言葉遣い":{"variants":"言葉づかい/言葉遣い"},"ことほぐ":{"variants":"ことほぐ/言祝ぐ/寿ぐ"},"ことも無げ":{"variants":"ことも無げ/事もなげ/事も無げ"},"事もなげ":{"variants":"ことも無げ/事もなげ/事も無げ"},"事も無げ":{"variants":"ことも無げ/事もなげ/事も無げ"},"ことよせる":{"variants":"ことよせる/事寄せる"},"事寄せる":{"variants":"ことよせる/事寄せる"},"ことわざ":{"variants":"ことわざ/諺"},"諺":{"variants":"ことわざ/諺"},"ことわり":{"variants":"ことわり/断り"},"断り":{"variants":"ことわり/断り"},"ことわる":{"variants":"ことわる/断る/断わる/理る"},"断る":{"variants":"ことわる/断る/断わる"},"断わる":{"variants":"ことわる/断る/断わる"},"ことわれる":{"variants":"ことわれる/断れる"},"断れる":{"variants":"ことわれる/断れる"},"こども":{"variants":"こども/子ども/子供/小人"},"子ども":{"variants":"こども/子ども/子供"},"子供":{"variants":"こども/子ども/子供"},"子供だまし":{"variants":"子供だまし/子供騙し"},"子供騙し":{"variants":"子供だまし/子供騙し"},"粉々":{"variants":"こなごな/粉々"},"粉粉":{"variants":"粉々/粉粉"},"こなごな":{"variants":"こなごな/粉々"},"粉みじん":{"variants":"粉みじん/粉微塵"},"粉微塵":{"variants":"粉みじん/粉微塵"},"こなミルク":{"variants":"こなミルク/粉ミルク"},"粉ミルク":{"variants":"こなミルク/粉ミルク"},"こにくらしい":{"variants":"こにくらしい/小憎らしい"},"小憎らしい":{"variants":"こにくらしい/小憎らしい"},"こぬか雨":{"variants":"こぬか雨/小糠雨/粉糠雨"},"こねかえす":{"variants":"こねかえす/こね返す/捏ねかえす/捏ね返す"},"こね返す":{"variants":"こねかえす/こね返す/捏ねかえす/捏ね返す"},"捏ねかえす":{"variants":"こねかえす/こね返す/捏ねかえす/捏ね返す"},"捏ね返す":{"variants":"こねかえす/こね返す/捏ねかえす/捏ね返す"},"こねくる":{"variants":"こねくる/捏ねくる"},"捏ねくる":{"variants":"こねくる/捏ねくる"},"こねこ":{"variants":"こねこ/子猫"},"子猫":{"variants":"こねこ/子猫"},"この内":{"variants":"この内/此の内"},"此の内":{"variants":"この内/此の内"},"この方":{"variants":"この方/此の方"},"此の方":{"variants":"この方/此の方"},"このごろ":{"variants":"このごろ/この頃"},"この頃":{"variants":"このごろ/この頃"},"この際":{"variants":"この際/此の際"},"此の際":{"variants":"この際/此の際"},"この先":{"variants":"この先/此の先"},"此の先":{"variants":"この先/此の先"},"この節":{"variants":"この節/此の節"},"此の節":{"variants":"この節/此の節"},"この度":{"variants":"この度/此の度"},"此の度":{"variants":"この度/此の度"},"コノハズク":{"variants":"コノハズク/木の葉木菟"},"木の葉木菟":{"variants":"コノハズク/木の葉木菟"},"コノハチョウ":{"variants":"コノハチョウ/木の葉蝶"},"木の葉蝶":{"variants":"コノハチョウ/木の葉蝶"},"このほど":{"variants":"このほど/この程/此の程"},"この程":{"variants":"このほど/この程/此の程"},"此の程":{"variants":"このほど/この程/此の程"},"この前":{"variants":"この前/此の前"},"此の前":{"variants":"この前/此の前"},"このましい":{"variants":"このましい/好ましい"},"好ましい":{"variants":"このましい/好ましい"},"このむ":{"variants":"このむ/好む"},"好む":{"variants":"このむ/好む"},"このもしい":{"variants":"このもしい/好もしい"},"好もしい":{"variants":"このもしい/好もしい"},"この世":{"variants":"この世/此の世"},"此の世":{"variants":"この世/此の世"},"このんで":{"variants":"このんで/好んで"},"好んで":{"variants":"このんで/好んで"},"こばか":{"variants":"こばか/小馬鹿"},"小馬鹿":{"variants":"こばか/小馬鹿"},"こばむ":{"variants":"こばむ/拒む"},"拒む":{"variants":"こばむ/拒む"},"こばめる":{"variants":"こばめる/拒める"},"拒める":{"variants":"こばめる/拒める"},"コバンイタダキ":{"variants":"コバンイタダキ/小判戴"},"小判戴":{"variants":"コバンイタダキ/小判戴"},"コバンザメ":{"variants":"コバンザメ/小判鮫"},"小判鮫":{"variants":"コバンザメ/小判鮫"},"木挽":{"variants":"木挽/木挽き"},"木挽き":{"variants":"木挽/木挽き"},"こびりつく":{"variants":"こびりつく/こびり着く/こびり付く"},"こびる":{"variants":"こびる/媚びる"},"媚びる":{"variants":"こびる/媚びる"},"小びん":{"variants":"小びん/小瓶/小鬢"},"コブ":{"variants":"コブ/瘤"},"瘤":{"variants":"コブ/瘤"},"こぶかい":{"variants":"こぶかい/木深い"},"木深い":{"variants":"こぶかい/木深い"},"こぶし":{"variants":"こぶし/コブシ/古武士/辛夷"},"コブシ":{"variants":"こぶし/コブシ/古武士/辛夷"},"小ぶり":{"variants":"小ぶり/小降り/小振り"},"こぼす":{"variants":"こぼす/零す"},"零す":{"variants":"こぼす/零す"},"こぼつ":{"variants":"こぼつ/毀つ"},"毀つ":{"variants":"こぼつ/毀つ"},"こぼれおちる":{"variants":"こぼれおちる/こぼれ落ちる"},"こぼれ落ちる":{"variants":"こぼれおちる/こぼれ落ちる"},"こぼれ種":{"variants":"こぼれ種/零れ種"},"零れ種":{"variants":"こぼれ種/零れ種"},"こぼれ話":{"variants":"こぼれ話/零れ話"},"零れ話":{"variants":"こぼれ話/零れ話"},"こぼれる":{"variants":"こぼれる/零れる"},"零れる":{"variants":"こぼれる/零れる"},"子ぼんのう":{"variants":"子ぼんのう/子煩悩"},"子煩悩":{"variants":"子ぼんのう/子煩悩"},"こま":{"variants":"こま/コマ/駒/小間/独楽/齣"},"コマ":{"variants":"こま/コマ/駒/小間/独楽/齣"},"こま犬":{"variants":"こま犬/狛犬"},"狛犬":{"variants":"こま犬/狛犬"},"こまかい":{"variants":"こまかい/細かい"},"細かい":{"variants":"こまかい/細かい"},"こまかしい":{"variants":"こまかしい/細かしい"},"細かしい":{"variants":"こまかしい/細かしい"},"こまかな":{"variants":"こまかな/細かな"},"細かな":{"variants":"こまかな/細かな"},"こまごましい":{"variants":"こまごましい/細々しい/細細しい"},"細々しい":{"variants":"こまごましい/細々しい/細細しい"},"細細しい":{"variants":"こまごましい/細々しい/細細しい"},"小また":{"variants":"小また/小股"},"小股":{"variants":"小また/小股"},"コマツナ":{"variants":"コマツナ/小松菜"},"小松菜":{"variants":"コマツナ/小松菜"},"コマドリ":{"variants":"コマドリ/駒鳥"},"駒鳥":{"variants":"コマドリ/駒鳥"},"コマネズミ":{"variants":"コマネズミ/高麗鼠/独楽鼠"},"こまやか":{"variants":"こまやか/細やか/濃やか"},"こまりきる":{"variants":"こまりきる/困りきる"},"困りきる":{"variants":"こまりきる/困りきる"},"こまりぬく":{"variants":"こまりぬく/困り抜く"},"困り抜く":{"variants":"こまりぬく/困り抜く"},"こまりはてる":{"variants":"こまりはてる/困り果てる"},"困り果てる":{"variants":"こまりはてる/困り果てる"},"こまる":{"variants":"こまる/困る"},"困る":{"variants":"こまる/困る"},"込":{"variants":"込/込み"},"込み":{"variants":"込/込み"},"こみあう":{"variants":"こみあう/込み合う/込合う"},"込み合う":{"variants":"こみあう/込み合う/込合う"},"込合う":{"variants":"こみあう/込み合う/込合う"},"こみあげる":{"variants":"こみあげる/こみ上げる/込み上げる/込上げる"},"こみ上げる":{"variants":"こみあげる/こみ上げる/込み上げる/込上げる"},"込み上げる":{"variants":"こみあげる/こみ上げる/込み上げる/込上げる"},"込上げる":{"variants":"こみあげる/こみ上げる/込み上げる/込上げる"},"こみいる":{"variants":"こみいる/込み入る/込入る"},"込み入る":{"variants":"こみいる/込み入る/込入る"},"込入る":{"variants":"こみいる/込み入る/込入る"},"コミ出し":{"variants":"コミ出し/小見出し"},"小見出し":{"variants":"コミ出し/小見出し"},"こむ":{"variants":"こむ/込む"},"込む":{"variants":"こむ/込む"},"コムギ":{"variants":"コムギ/小麦"},"小麦":{"variants":"コムギ/小麦"},"こむずかしい":{"variants":"こむずかしい/こ難しい"},"こ難しい":{"variants":"こむずかしい/こ難しい"},"こむら返り":{"variants":"こむら返り/腓返り"},"腓返り":{"variants":"こむら返り/腓返り"},"こめかみ":{"variants":"こめかみ/顳かみ"},"顳かみ":{"variants":"こめかみ/顳かみ"},"こめくい虫":{"variants":"こめくい虫/コメクイムシ/米食い虫"},"コメクイムシ":{"variants":"こめくい虫/コメクイムシ/米食い虫"},"米食い虫":{"variants":"こめくい虫/コメクイムシ/米食い虫"},"コメツキ":{"variants":"コメツキ/米つき/米搗き"},"米つき":{"variants":"コメツキ/米つき/米搗き"},"米搗き":{"variants":"コメツキ/米つき/米搗き"},"コメツキバッタ":{"variants":"コメツキバッタ/米搗きばった/米搗き飛蝗"},"米搗きばった":{"variants":"コメツキバッタ/米搗きばった/米搗き飛蝗"},"米搗き飛蝗":{"variants":"コメツキバッタ/米搗きばった/米搗き飛蝗"},"こめつき虫":{"variants":"こめつき虫/コメツキムシ/米搗き虫"},"コメツキムシ":{"variants":"こめつき虫/コメツキムシ/米搗き虫"},"米搗き虫":{"variants":"こめつき虫/コメツキムシ/米搗き虫"},"米どころ":{"variants":"米どころ/米所"},"米所":{"variants":"米どころ/米所"},"米ぬか":{"variants":"米ぬか/米糠"},"米糠":{"variants":"米ぬか/米糠"},"米びつ":{"variants":"米びつ/米櫃"},"米櫃":{"variants":"米びつ/米櫃"},"こめる":{"variants":"こめる/込める/篭める"},"コモ":{"variants":"コモ/菰/薦"},"こもごも":{"variants":"こもごも/交交"},"交交":{"variants":"こもごも/交交"},"子持":{"variants":"子持/子持ち"},"子持ち":{"variants":"子持/子持ち"},"こもどす":{"variants":"こもどす/小戻す"},"小戻す":{"variants":"こもどす/小戻す"},"こもる":{"variants":"こもる/隠る/篭もる/篭る/籠る"},"篭る":{"variants":"こもる/篭もる/篭る"},"篭もる":{"variants":"こもる/篭もる/篭る"},"こもれる":{"variants":"こもれる/篭もれる"},"篭もれる":{"variants":"こもれる/篭もれる"},"小屋がけ":{"variants":"小屋がけ/小屋掛け"},"小屋掛け":{"variants":"小屋がけ/小屋掛け"},"肥し":{"variants":"肥し/肥やし"},"肥やし":{"variants":"肥し/肥やし"},"こやす":{"variants":"こやす/肥す/肥やす"},"肥す":{"variants":"こやす/肥す/肥やす"},"肥やす":{"variants":"こやす/肥す/肥やす"},"小やみ":{"variants":"小やみ/小止み"},"小止み":{"variants":"小やみ/小止み"},"こらい":{"variants":"こらい/古来"},"古来":{"variants":"こらい/古来"},"こらえ性":{"variants":"こらえ性/堪え性"},"堪え性":{"variants":"こらえ性/堪え性"},"こらしめる":{"variants":"こらしめる/懲らしめる"},"懲らしめる":{"variants":"こらしめる/懲らしめる"},"こらす":{"variants":"こらす/凝らす/懲らす"},"こりかたまる":{"variants":"こりかたまる/凝り固まる/凝固まる"},"凝り固まる":{"variants":"こりかたまる/凝り固まる/凝固まる"},"凝固まる":{"variants":"こりかたまる/凝り固まる/凝固まる"},"懲りごり":{"variants":"懲りごり/懲り懲り"},"懲り懲り":{"variants":"懲りごり/懲り懲り"},"こり性":{"variants":"こり性/凝り性"},"凝り性":{"variants":"こり性/凝り性"},"こりる":{"variants":"こりる/懲りる"},"懲りる":{"variants":"こりる/懲りる"},"こる":{"variants":"こる/樵る"},"樵る":{"variants":"こる/樵る"},"これ":{"variants":"これ/之"},"之":{"variants":"の/ノ/之"},"ころ":{"variants":"ころ/頃"},"頃":{"variants":"ころ/頃"},"ころがす":{"variants":"ころがす/転がす"},"転がす":{"variants":"ころがす/転がす"},"ころがせる":{"variants":"ころがせる/転がせる"},"転がせる":{"variants":"ころがせる/転がせる"},"ころがりこむ":{"variants":"ころがりこむ/転がりこむ/転がり込む"},"転がりこむ":{"variants":"ころがりこむ/転がりこむ/転がり込む"},"転がり込む":{"variants":"ころがりこむ/転がりこむ/転がり込む"},"ころがる":{"variants":"ころがる/転がる"},"転がる":{"variants":"ころがる/転がる"},"ころがれる":{"variants":"ころがれる/転がれる"},"転がれる":{"variants":"ころがれる/転がれる"},"ころげおちる":{"variants":"ころげおちる/転げ落ちる"},"転げ落ちる":{"variants":"ころげおちる/転げ落ちる"},"ころげこむ":{"variants":"ころげこむ/転げ込む"},"転げ込む":{"variants":"ころげこむ/転げ込む"},"ころげでる":{"variants":"ころげでる/転げでる"},"転げでる":{"variants":"ころげでる/転げでる"},"ころげる":{"variants":"ころげる/転げる"},"転げる":{"variants":"ころげる/転げる"},"ころころ":{"variants":"ころころ/コロコロ"},"コロコロ":{"variants":"ころころ/コロコロ"},"ころし文句":{"variants":"ころし文句/殺し文句/殺文句"},"殺し文句":{"variants":"ころし文句/殺し文句/殺文句"},"殺文句":{"variants":"ころし文句/殺し文句/殺文句"},"ころす":{"variants":"ころす/殺す"},"殺す":{"variants":"ころす/殺す"},"ころせる":{"variants":"ころせる/殺せる"},"殺せる":{"variants":"ころせる/殺せる"},"ころばす":{"variants":"ころばす/転ばす"},"転ばす":{"variants":"ころばす/転ばす"},"ころぶ":{"variants":"ころぶ/転ぶ"},"転ぶ":{"variants":"ころぶ/転ぶ"},"ころべる":{"variants":"ころべる/転べる"},"転べる":{"variants":"ころべる/転べる"},"こわい":{"variants":"こわい/コワい/恐い/怖い"},"コワい":{"variants":"こわい/コワい/恐い/怖い"},"こわがる":{"variants":"こわがる/恐がる/怖がる"},"小わき":{"variants":"小わき/小脇"},"小脇":{"variants":"小わき/小脇"},"こわす":{"variants":"こわす/壊す/毀す"},"こわせる":{"variants":"こわせる/壊せる"},"壊せる":{"variants":"こわせる/壊せる"},"こわ談判":{"variants":"こわ談判/強談判"},"強談判":{"variants":"こわ談判/強談判"},"こわばる":{"variants":"こわばる/強ばる"},"強ばる":{"variants":"こわばる/強ばる"},"こわもて":{"variants":"こわもて/強もて/強持て"},"強もて":{"variants":"こわもて/強もて/強持て"},"強持て":{"variants":"こわもて/強もて/強持て"},"こわれ物":{"variants":"こわれ物/壊れもの/壊れ物/毀れもの/毀れ物"},"毀れ物":{"variants":"こわれ物/毀れもの/毀れ物"},"毀れもの":{"variants":"こわれ物/毀れもの/毀れ物"},"壊れ物":{"variants":"こわれ物/壊れもの/壊れ物"},"壊れもの":{"variants":"こわれ物/壊れもの/壊れ物"},"こわれる":{"variants":"こわれる/壊れる"},"壊れる":{"variants":"こわれる/壊れる"},"コン":{"variants":"コン/婚/懇/紺"},"紺がすり":{"variants":"紺がすり/紺飛白/紺絣"},"こんこんと":{"variants":"こんこんと/懇懇と/昏昏と/滾滾と"},"金剛づえ":{"variants":"金剛づえ/金剛杖"},"金剛杖":{"variants":"金剛づえ/金剛杖"},"こんしん":{"variants":"こんしん/こん身/懇親/渾身"},"こん身":{"variants":"こんしん/こん身/渾身"},"渾身":{"variants":"こんしん/こん身/渾身"},"こんじる":{"variants":"こんじる/混じる"},"混じる":{"variants":"こんじる/混じる"},"こん睡":{"variants":"こん睡/昏睡"},"昏睡":{"variants":"こん睡/昏睡"},"こんずる":{"variants":"こんずる/混ずる"},"混ずる":{"variants":"こんずる/混ずる"},"こん然":{"variants":"こん然/渾然"},"渾然":{"variants":"こん然/渾然"},"こん然一体":{"variants":"こん然一体/渾然一体"},"渾然一体":{"variants":"こん然一体/渾然一体"},"コンチュウ":{"variants":"コンチュウ/昆虫"},"昆虫":{"variants":"コンチュウ/昆虫"},"こんとん":{"variants":"こんとん/混とん/混沌/渾沌"},"混沌":{"variants":"こんとん/混とん/混沌"},"混とん":{"variants":"こんとん/混とん/混沌"},"こんど":{"variants":"こんど/こん度/今度"},"こん度":{"variants":"こんど/こん度/今度"},"今度":{"variants":"こんど/こん度/今度"},"こんにちわ":{"variants":"こんにちわ/コンニチワ"},"コンニチワ":{"variants":"こんにちわ/コンニチワ"},"こんにゃく":{"variants":"こんにゃく/コンニャク/菎蒻/蒟蒻"},"コンニャク":{"variants":"こんにゃく/コンニャク/菎蒻/蒟蒻"},"こんにゃく版":{"variants":"こんにゃく版/菎蒻版/蒟蒻版"},"こんぱい":{"variants":"こんぱい/困ぱい/困憊"},"困ぱい":{"variants":"こんぱい/困ぱい/困憊"},"困憊":{"variants":"こんぱい/困ぱい/困憊"},"こんぺいとう":{"variants":"こんぺいとう/金平糖/金米糖"},"紺ぺき":{"variants":"紺ぺき/紺碧"},"紺碧":{"variants":"紺ぺき/紺碧"},"こん棒":{"variants":"こん棒/棍棒"},"棍棒":{"variants":"こん棒/棍棒"},"こん包":{"variants":"こん包/梱包"},"梱包":{"variants":"こん包/梱包"},"こんりんざい":{"variants":"こんりんざい/金輪際"},"金輪際":{"variants":"こんりんざい/金輪際"},"コンロ":{"variants":"コンロ/焜炉"},"焜炉":{"variants":"コンロ/焜炉"},"５":{"variants":"５/五"},"五":{"variants":"５/五"},"ＧＷ":{"variants":"ＧＷ/ゴールデンウィーク"},"ゴールデンウィーク":{"variants":"ＧＷ/ゴールデンウィーク"},"語い":{"variants":"語い/語意/語彙"},"ごい":{"variants":"ごい/乞い"},"乞い":{"variants":"ごい/乞い"},"ゴイサギ":{"variants":"ゴイサギ/五位鷺"},"五位鷺":{"variants":"ゴイサギ/五位鷺"},"ごう音":{"variants":"ごう音/号音/轟音"},"囂囂":{"variants":"囂々/囂囂"},"轟轟":{"variants":"轟々/轟轟"},"囂々":{"variants":"囂々/囂囂"},"轟々":{"variants":"轟々/轟轟"},"ごうごうたる":{"variants":"ごうごうたる/轟々たる"},"轟々たる":{"variants":"ごうごうたる/轟々たる"},"ごうごうと":{"variants":"ごうごうと/轟々と"},"轟々と":{"variants":"ごうごうと/轟々と"},"ごうする":{"variants":"ごうする/号する"},"号する":{"variants":"ごうする/号する"},"ごうほう":{"variants":"ごうほう/合法/豪放"},"ごうまん":{"variants":"ごうまん/ごう慢/傲慢"},"ごう慢":{"variants":"ごう慢/傲慢"},"傲慢":{"variants":"ごう慢/傲慢"},"ごうも":{"variants":"ごうも/毫も"},"毫も":{"variants":"ごうも/毫も"},"合目的々":{"variants":"合目的々/合目的的"},"合目的的":{"variants":"合目的々/合目的的"},"ごう問":{"variants":"ごう問/拷問"},"拷問":{"variants":"ごう問/拷問"},"ゴカイ":{"variants":"ゴカイ/五戒/沙蚕"},"５月":{"variants":"５月/五月"},"五月":{"variants":"５月/五月"},"ご機嫌":{"variants":"ご機嫌/御機嫌"},"御機嫌":{"variants":"ご機嫌/御機嫌"},"ゴギョウ":{"variants":"ゴギョウ/五行/御形"},"ごく":{"variants":"ごく/極"},"極":{"variants":"ごく/極"},"ごくごく":{"variants":"ごくごく/極々/極極"},"極々":{"variants":"ごくごく/極々/極極"},"極極":{"variants":"ごくごく/極々/極極"},"ゴクラクチョウ":{"variants":"ゴクラクチョウ/極楽鳥"},"極楽鳥":{"variants":"ゴクラクチョウ/極楽鳥"},"極楽とんぼ":{"variants":"極楽とんぼ/極楽蜻蛉"},"極楽蜻蛉":{"variants":"極楽とんぼ/極楽蜻蛉"},"ご苦労":{"variants":"ご苦労/御苦労"},"御苦労":{"variants":"ご苦労/御苦労"},"五穀豊じょう":{"variants":"五穀豊じょう/五穀豊穣"},"五穀豊穣":{"variants":"五穀豊じょう/五穀豊穣"},"ごこち":{"variants":"ごこち/心地"},"心地":{"variants":"ごこち/心地"},"ご懇切":{"variants":"ご懇切/御懇切"},"御懇切":{"variants":"ご懇切/御懇切"},"午餐":{"variants":"午さん/午餐"},"午さん":{"variants":"午さん/午餐"},"ご三家":{"variants":"ご三家/御三家"},"御三家":{"variants":"ご三家/御三家"},"ござる":{"variants":"ござる/御座る"},"御座る":{"variants":"ござる/御座る"},"ごしごし":{"variants":"ごしごし/ゴシゴシ"},"ゴシゴシ":{"variants":"ごしごし/ゴシゴシ"},"ご愁傷さま":{"variants":"ご愁傷さま/御愁傷様"},"御愁傷様":{"variants":"ご愁傷さま/御愁傷様"},"五重の塔":{"variants":"五重の塔/五重塔"},"五重塔":{"variants":"五重の塔/五重塔"},"ごする":{"variants":"ごする/伍する"},"伍する":{"variants":"ごする/伍する"},"五寸くぎ":{"variants":"五寸くぎ/五寸釘"},"五寸釘":{"variants":"五寸くぎ/五寸釘"},"ゴセイ":{"variants":"ゴセイ/悟性/碁聖/語勢"},"ご盛大":{"variants":"ご盛大/御盛大"},"御盛大":{"variants":"ご盛大/御盛大"},"午前さま":{"variants":"午前さま/午前様"},"午前様":{"variants":"午前さま/午前様"},"ご存じ":{"variants":"ご存じ/ご存知/御存じ/御存知"},"ご存知":{"variants":"ご存じ/ご存知/御存じ/御存知"},"御存じ":{"variants":"ご存じ/ご存知/御存じ/御存知"},"御存知":{"variants":"ご存じ/ご存知/御存じ/御存知"},"ご託宣":{"variants":"ご託宣/御託宣"},"御託宣":{"variants":"ご託宣/御託宣"},"ごたごた":{"variants":"ごたごた/ゴタゴタ"},"ゴタゴタ":{"variants":"ごたごた/ゴタゴタ"},"ご多分":{"variants":"ご多分/御多分"},"御多分":{"variants":"ご多分/御多分"},"ご多忙":{"variants":"ご多忙/御多忙"},"御多忙":{"variants":"ご多忙/御多忙"},"ごちそう":{"variants":"ごちそう/ご馳走/御馳走"},"ご馳走":{"variants":"ごちそう/ご馳走/御馳走"},"御馳走":{"variants":"ごちそう/ご馳走/御馳走"},"ごちゃごちゃ":{"variants":"ごちゃごちゃ/ゴチャゴチャ"},"ゴチャゴチャ":{"variants":"ごちゃごちゃ/ゴチャゴチャ"},"ごったがえす":{"variants":"ごったがえす/ごった返す"},"ごった返す":{"variants":"ごったがえす/ごった返す"},"ご都合主義":{"variants":"ご都合主義/御都合主義"},"御都合主義":{"variants":"ご都合主義/御都合主義"},"ごつごつ":{"variants":"ごつごつ/ゴツゴツ"},"ゴツゴツ":{"variants":"ごつごつ/ゴツゴツ"},"ごと":{"variants":"ごと/毎"},"毎":{"variants":"ごと/毎"},"ゴトウ":{"variants":"ゴトウ/語頭"},"語頭":{"variants":"ゴトウ/語頭"},"ごとし":{"variants":"ごとし/如し"},"如し":{"variants":"ごとし/如し"},"ご難続き":{"variants":"ご難続き/御難続き"},"御難続き":{"variants":"ご難続き/御難続き"},"ご念":{"variants":"ご念/御念"},"御念":{"variants":"ご念/御念"},"ご破算":{"variants":"ご破算/御破算"},"御破算":{"variants":"ご破算/御破算"},"ご法度":{"variants":"ご法度/御法度"},"御法度":{"variants":"ご法度/御法度"},"ごはん":{"variants":"ごはん/ご飯/御飯/誤判"},"ご飯":{"variants":"ごはん/ご飯/御飯"},"御飯":{"variants":"ごはん/ご飯/御飯"},"誤びゅう":{"variants":"誤びゅう/誤謬"},"誤謬":{"variants":"誤びゅう/誤謬"},"ご不浄":{"variants":"ご不浄/御不浄"},"御不浄":{"variants":"ご不浄/御不浄"},"ご無沙汰":{"variants":"ご無沙汰/御無沙汰"},"御無沙汰":{"variants":"ご無沙汰/御無沙汰"},"ゴブランおり":{"variants":"ゴブランおり/ゴブラン織/ゴブラン織り"},"ゴブラン織":{"variants":"ゴブランおり/ゴブラン織/ゴブラン織り"},"ゴブラン織り":{"variants":"ゴブランおり/ゴブラン織/ゴブラン織り"},"ゴボウ":{"variants":"ゴボウ/牛蒡/御坊"},"ごま":{"variants":"ごま/ゴマ/胡麻/護摩"},"ゴマ":{"variants":"ごま/ゴマ/胡麻/護摩"},"胡麻あえ":{"variants":"胡麻あえ/胡麻和え"},"胡麻和え":{"variants":"胡麻あえ/胡麻和え"},"ごま油":{"variants":"ごま油/ゴマ油/胡麻油"},"ゴマ油":{"variants":"ごま油/ゴマ油/胡麻油"},"胡麻油":{"variants":"ごま油/ゴマ油/胡麻油"},"ごまかす":{"variants":"ごまかす/誤魔化す"},"誤魔化す":{"variants":"ごまかす/誤魔化す"},"ごま塩":{"variants":"ごま塩/胡麻塩"},"胡麻塩":{"variants":"ごま塩/胡麻塩"},"胡麻すり":{"variants":"胡麻すり/胡麻擂り"},"胡麻擂り":{"variants":"胡麻すり/胡麻擂り"},"ごみ":{"variants":"ごみ/ゴミ/五味"},"ゴミ":{"variants":"ごみ/ゴミ/五味"},"五味":{"variants":"ごみ/ゴミ/五味"},"ごみ箱":{"variants":"ごみ箱/ゴミ箱"},"ゴミ箱":{"variants":"ごみ箱/ゴミ箱"},"ゴム":{"variants":"ゴム/護謨"},"護謨":{"variants":"ゴム/護謨"},"ゴムノキ":{"variants":"ゴムノキ/護謨の木"},"護謨の木":{"variants":"ゴムノキ/護謨の木"},"ごめん":{"variants":"ごめん/ご免/御免"},"ゴメン":{"variants":"ごめん/ゴメン"},"ご免":{"variants":"ごめん/ご免/御免"},"御免":{"variants":"ごめん/ご免/御免"},"ご面相":{"variants":"ご面相/御面相"},"御面相":{"variants":"ご面相/御面相"},"ご用":{"variants":"ご用/誤用"},"誤用":{"variants":"ご用/誤用"},"ご用聞き":{"variants":"ご用聞き/御用聞"},"御用聞":{"variants":"ご用聞き/御用聞"},"ゴヨウマツ":{"variants":"ゴヨウマツ/五葉松"},"五葉松":{"variants":"ゴヨウマツ/五葉松"},"ご来光":{"variants":"ご来光/御来光"},"御来光":{"variants":"ご来光/御来光"},"ごらん":{"variants":"ごらん/ご覧/御覧"},"ご覧":{"variants":"ごらん/ご覧/御覧"},"御覧":{"variants":"ごらん/ご覧/御覧"},"ゴリ":{"variants":"ゴリ/鮴"},"鮴":{"variants":"ゴリ/鮴"},"ごり押し":{"variants":"ごり押し/ゴリ押し"},"ゴリ押し":{"variants":"ごり押し/ゴリ押し"},"ごりごり":{"variants":"ごりごり/ゴリゴリ"},"ゴリゴリ":{"variants":"ごりごり/ゴリゴリ"},"ご利益":{"variants":"ご利益/御利益"},"御利益":{"variants":"ご利益/御利益"},"ご両人":{"variants":"ご両人/御両人"},"御両人":{"variants":"ご両人/御両人"},"ごろ":{"variants":"ごろ/ゴロ/呉絽/語呂/語路"},"ゴロ":{"variants":"ごろ/ゴロ/呉絽/語呂/語路"},"ゴロあわせ":{"variants":"ゴロあわせ/語呂合せ/語呂合わせ/語路合せ"},"語呂合せ":{"variants":"ゴロあわせ/語呂合せ/語呂合わせ"},"語呂合わせ":{"variants":"ゴロあわせ/語呂合せ/語呂合わせ"},"ごわごわ":{"variants":"ごわごわ/ゴワゴワ"},"ゴワゴワ":{"variants":"ごわごわ/ゴワゴワ"},"権現造":{"variants":"権現造/権現造り"},"権現造り":{"variants":"権現造/権現造り"},"サイ":{"variants":"サイ/差異/差違/才/采/犀/賽"},"サイカチ":{"variants":"サイカチ/皀莢"},"皀莢":{"variants":"サイカチ/皀莢"},"サイキン":{"variants":"サイキン/細菌/細瑾"},"サイコロ":{"variants":"サイコロ/賽子"},"賽子":{"variants":"サイコロ/賽子"},"最後っぺ":{"variants":"最後っぺ/最後っ屁"},"最後っ屁":{"variants":"最後っぺ/最後っ屁"},"再再":{"variants":"再々/再再"},"歳歳":{"variants":"歳々/歳歳"},"歳々":{"variants":"歳々/歳歳"},"再々":{"variants":"再々/再再"},"さい先":{"variants":"さい先/幸先"},"幸先":{"variants":"さい先/幸先"},"さいし":{"variants":"さいし/再試/妻子/才子/祭司/祭祀"},"さいせん":{"variants":"さいせん/さい銭/再戦/細線/賽銭"},"賽銭":{"variants":"さいせん/さい銭/賽銭"},"さい銭":{"variants":"さいせん/さい銭/賽銭"},"さい帯":{"variants":"さい帯/妻帯"},"妻帯":{"variants":"さい帯/妻帯"},"さいなむ":{"variants":"さいなむ/苛む"},"苛む":{"variants":"さいなむ/苛む"},"さいの目":{"variants":"さいの目/采の目/賽の目"},"さい配":{"variants":"さい配/采配"},"采配":{"variants":"さい配/采配"},"さいはじける":{"variants":"さいはじける/才弾ける"},"才弾ける":{"variants":"さいはじける/才弾ける"},"菜ばし":{"variants":"菜ばし/菜箸"},"菜箸":{"variants":"菜ばし/菜箸"},"さいばしる":{"variants":"さいばしる/才走る"},"才走る":{"variants":"さいばしる/才走る"},"サイボウ":{"variants":"サイボウ/細胞"},"細胞":{"variants":"サイボウ/細胞"},"細胞しゅ":{"variants":"細胞しゅ/細胞腫"},"細胞腫":{"variants":"細胞しゅ/細胞腫"},"サウンド・トラック":{"variants":"サウンド・トラック/サウンドトラック"},"サウンドトラック":{"variants":"サウンド・トラック/サウンドトラック"},"さえかえる":{"variants":"さえかえる/冴え返る"},"冴え返る":{"variants":"さえかえる/冴え返る"},"さえぎる":{"variants":"さえぎる/遮る"},"遮る":{"variants":"さえぎる/遮る"},"さえぎれる":{"variants":"さえぎれる/遮れる"},"遮れる":{"variants":"さえぎれる/遮れる"},"さえずる":{"variants":"さえずる/囀る"},"囀る":{"variants":"さえずる/囀る"},"さえる":{"variants":"さえる/冴える"},"冴える":{"variants":"さえる/冴える"},"さえわたる":{"variants":"さえわたる/さえ渡る/冴えわたる/冴え渡る"},"さえ渡る":{"variants":"さえわたる/さえ渡る/冴えわたる/冴え渡る"},"冴えわたる":{"variants":"さえわたる/さえ渡る/冴えわたる/冴え渡る"},"冴え渡る":{"variants":"さえわたる/さえ渡る/冴えわたる/冴え渡る"},"サオ":{"variants":"サオ/竿/棹"},"さおさす":{"variants":"さおさす/棹さす"},"棹さす":{"variants":"さおさす/棹さす"},"境い目":{"variants":"境い目/境目"},"境目":{"variants":"境い目/境目"},"サカキ":{"variants":"サカキ/榊"},"榊":{"variants":"サカキ/榊"},"さかさ言葉":{"variants":"さかさ言葉/逆さことば/逆さ言葉"},"逆さことば":{"variants":"さかさ言葉/逆さことば/逆さ言葉"},"逆さ言葉":{"variants":"さかさ言葉/逆さことば/逆さ言葉"},"逆さま":{"variants":"逆さま/逆様"},"逆様":{"variants":"逆さま/逆様"},"逆さまつげ":{"variants":"逆さまつげ/逆さ睫"},"逆さ睫":{"variants":"逆さまつげ/逆さ睫"},"さかしい":{"variants":"さかしい/賢しい"},"賢しい":{"variants":"さかしい/賢しい"},"さかしま":{"variants":"さかしま/逆しま"},"逆しま":{"variants":"さかしま/逆しま"},"さかす":{"variants":"さかす/咲かす"},"咲かす":{"variants":"さかす/咲かす"},"さかずき":{"variants":"さかずき/盃"},"盃":{"variants":"さかずき/盃"},"さかせる":{"variants":"さかせる/咲かせる"},"咲かせる":{"variants":"さかせる/咲かせる"},"さかだつ":{"variants":"さかだつ/逆立つ"},"逆立つ":{"variants":"さかだつ/逆立つ"},"さかだてる":{"variants":"さかだてる/逆立てる"},"逆立てる":{"variants":"さかだてる/逆立てる"},"酒だる":{"variants":"酒だる/酒樽"},"酒樽":{"variants":"酒だる/酒樽"},"さかな":{"variants":"さかな/サカナ/肴"},"サカナ":{"variants":"さかな/サカナ/肴"},"肴":{"variants":"さかな/サカナ/肴"},"魚つり":{"variants":"魚つり/魚釣り"},"魚釣り":{"variants":"魚つり/魚釣り"},"逆ねじ":{"variants":"逆ねじ/逆捩じ"},"逆捩じ":{"variants":"逆ねじ/逆捩じ"},"さかのぼる":{"variants":"さかのぼる/遡る/溯る"},"さかのぼれる":{"variants":"さかのぼれる/遡れる"},"遡れる":{"variants":"さかのぼれる/遡れる"},"さかまく":{"variants":"さかまく/逆巻く"},"逆巻く":{"variants":"さかまく/逆巻く"},"サカマタ":{"variants":"サカマタ/逆叉"},"逆叉":{"variants":"サカマタ/逆叉"},"さからう":{"variants":"さからう/逆らう"},"逆らう":{"variants":"さからう/逆らう"},"さからえる":{"variants":"さからえる/逆らえる"},"逆らえる":{"variants":"さからえる/逆らえる"},"盛り場":{"variants":"盛り場/盛場"},"盛場":{"variants":"盛り場/盛場"},"さかん":{"variants":"さかん/盛ん"},"盛ん":{"variants":"さかん/盛ん"},"さがしあてる":{"variants":"さがしあてる/捜しあてる/捜し当てる/探しあてる/探し当てる"},"探しあてる":{"variants":"さがしあてる/探しあてる/探し当てる"},"探し当てる":{"variants":"さがしあてる/探しあてる/探し当てる"},"捜しあてる":{"variants":"さがしあてる/捜しあてる/捜し当てる"},"捜し当てる":{"variants":"さがしあてる/捜しあてる/捜し当てる"},"さがしだす":{"variants":"さがしだす/捜し出す/探し出す"},"さがしだせる":{"variants":"さがしだせる/捜し出せる/探し出せる"},"さがしまわる":{"variants":"さがしまわる/捜しまわる/探し回る"},"さがしもとめる":{"variants":"さがしもとめる/捜し求める/探し求める"},"さがす":{"variants":"さがす/捜す/探す"},"さがせる":{"variants":"さがせる/捜せる/探せる"},"さがり目":{"variants":"さがり目/下がり目"},"下がり目":{"variants":"さがり目/下がり目"},"さがる":{"variants":"さがる/下がる"},"下がる":{"variants":"さがる/下がる"},"さき":{"variants":"さき/左記/咲き/崎"},"一昨々日":{"variants":"一昨々日/一昨昨日"},"一昨昨日":{"variants":"一昨々日/一昨昨日"},"一昨々年":{"variants":"一昨々年/一昨昨年"},"一昨昨年":{"variants":"一昨々年/一昨昨年"},"さきがけ":{"variants":"さきがけ/魁"},"魁":{"variants":"さきがけ/魁"},"さきがける":{"variants":"さきがける/先がける/先駆ける"},"先がける":{"variants":"さきがける/先がける/先駆ける"},"先駆ける":{"variants":"さきがける/先がける/先駆ける"},"さきこぼれる":{"variants":"さきこぼれる/咲きこぼれる"},"咲きこぼれる":{"variants":"さきこぼれる/咲きこぼれる"},"先ごろ":{"variants":"先ごろ/先頃"},"先頃":{"variants":"先ごろ/先頃"},"先々":{"variants":"先々/先先"},"先先":{"variants":"先々/先先"},"さきそろう":{"variants":"さきそろう/咲きそろう/咲き揃う"},"咲きそろう":{"variants":"さきそろう/咲きそろう/咲き揃う"},"咲き揃う":{"variants":"さきそろう/咲きそろう/咲き揃う"},"さきだつ":{"variants":"さきだつ/先立つ"},"先立つ":{"variants":"さきだつ/先立つ"},"さきだてる":{"variants":"さきだてる/先立てる"},"先立てる":{"variants":"さきだてる/先立てる"},"さきでる":{"variants":"さきでる/咲きでる"},"咲きでる":{"variants":"さきでる/咲きでる"},"さきにおう":{"variants":"さきにおう/咲き匂う"},"咲き匂う":{"variants":"さきにおう/咲き匂う"},"さきのこる":{"variants":"さきのこる/咲き残る"},"咲き残る":{"variants":"さきのこる/咲き残る"},"さきばしる":{"variants":"さきばしる/先走る"},"先走る":{"variants":"さきばしる/先走る"},"先払":{"variants":"先払/先払い"},"先払い":{"variants":"先払/先払い"},"先ぶれ":{"variants":"先ぶれ/先触/先触れ"},"先触":{"variants":"先ぶれ/先触/先触れ"},"先触れ":{"variants":"先ぶれ/先触/先触れ"},"さきほこる":{"variants":"さきほこる/咲きほこる/咲き誇る"},"咲きほこる":{"variants":"さきほこる/咲きほこる/咲き誇る"},"咲き誇る":{"variants":"さきほこる/咲きほこる/咲き誇る"},"さきみだれる":{"variants":"さきみだれる/咲きみだれる/咲き乱れる/咲乱れる"},"咲きみだれる":{"variants":"さきみだれる/咲きみだれる/咲き乱れる/咲乱れる"},"咲き乱れる":{"variants":"さきみだれる/咲きみだれる/咲き乱れる/咲乱れる"},"咲乱れる":{"variants":"さきみだれる/咲きみだれる/咲き乱れる/咲乱れる"},"さきんじる":{"variants":"さきんじる/先んじる"},"先んじる":{"variants":"さきんじる/先んじる"},"さきんずる":{"variants":"さきんずる/先んずる"},"先んずる":{"variants":"さきんずる/先んずる"},"サギ":{"variants":"サギ/詐偽/鷺"},"さく":{"variants":"さく/作/策/索"},"嘖々":{"variants":"嘖々/嘖嘖"},"嘖嘖":{"variants":"嘖々/嘖嘖"},"サクサン":{"variants":"サクサン/酢酸/柞蚕/醋酸"},"さくしゃ":{"variants":"さくしゃ/作者"},"作者":{"variants":"さくしゃ/作者"},"さくする":{"variants":"さくする/策する"},"策する":{"variants":"さくする/策する"},"錯そう":{"variants":"錯そう/錯綜"},"錯綜":{"variants":"錯そう/錯綜"},"作付":{"variants":"作付/作付け"},"作付け":{"variants":"作付/作付け"},"さくら":{"variants":"さくら/サクラ/桜/櫻"},"サクラ":{"variants":"さくら/サクラ/桜/櫻"},"サクラエビ":{"variants":"サクラエビ/桜えび/桜蝦/桜海老"},"桜えび":{"variants":"サクラエビ/桜えび/桜蝦/桜海老"},"さくら貝":{"variants":"さくら貝/サクラガイ/桜貝"},"サクラガイ":{"variants":"さくら貝/サクラガイ/桜貝"},"桜貝":{"variants":"さくら貝/サクラガイ/桜貝"},"さくらそう":{"variants":"さくらそう/さくら草/サクラソウ/桜草"},"さくら草":{"variants":"さくらそう/さくら草/サクラソウ/桜草"},"サクラソウ":{"variants":"さくらそう/さくら草/サクラソウ/桜草"},"桜草":{"variants":"さくらそう/さくら草/サクラソウ/桜草"},"桜漬":{"variants":"桜漬/桜漬け"},"桜漬け":{"variants":"桜漬/桜漬け"},"桜もち":{"variants":"桜もち/桜餅"},"桜餅":{"variants":"桜もち/桜餅"},"さくらん坊":{"variants":"さくらん坊/桜んぼう/桜ん坊"},"桜んぼう":{"variants":"さくらん坊/桜んぼう/桜ん坊"},"桜ん坊":{"variants":"さくらん坊/桜んぼう/桜ん坊"},"さく裂":{"variants":"さく裂/炸れつ/炸裂"},"炸れつ":{"variants":"さく裂/炸れつ/炸裂"},"炸裂":{"variants":"さく裂/炸れつ/炸裂"},"さぐりあう":{"variants":"さぐりあう/さぐり合う"},"さぐり合う":{"variants":"さぐりあう/さぐり合う"},"さぐりあてる":{"variants":"さぐりあてる/探り当てる"},"探り当てる":{"variants":"さぐりあてる/探り当てる"},"さぐりだす":{"variants":"さぐりだす/探り出す"},"探り出す":{"variants":"さぐりだす/探り出す"},"さぐりだせる":{"variants":"さぐりだせる/探り出せる"},"探り出せる":{"variants":"さぐりだせる/探り出せる"},"さぐる":{"variants":"さぐる/探る"},"探る":{"variants":"さぐる/探る"},"さぐれる":{"variants":"さぐれる/探れる"},"探れる":{"variants":"さぐれる/探れる"},"さけ":{"variants":"さけ/サケ/酒"},"サケ":{"variants":"さけ/サケ/酒"},"酒":{"variants":"さけ/サケ/酒"},"酒カス":{"variants":"酒カス/酒糟/酒粕"},"酒ぐせ":{"variants":"酒ぐせ/酒癖"},"酒癖":{"variants":"酒ぐせ/酒癖"},"酒びたり":{"variants":"酒びたり/酒浸り"},"酒浸り":{"variants":"酒びたり/酒浸り"},"さけぶ":{"variants":"さけぶ/叫ぶ"},"叫ぶ":{"variants":"さけぶ/叫ぶ"},"さけべる":{"variants":"さけべる/叫べる"},"叫べる":{"variants":"さけべる/叫べる"},"裂けめ":{"variants":"裂けめ/裂け目"},"裂け目":{"variants":"裂けめ/裂け目"},"さける":{"variants":"さける/割ける/避ける/裂ける"},"さげすむ":{"variants":"さげすむ/蔑む/貶む"},"下げだな":{"variants":"下げだな/下げ棚"},"下げ棚":{"variants":"下げだな/下げ棚"},"下げもどし":{"variants":"下げもどし/下げ戻し"},"下げ戻し":{"variants":"下げもどし/下げ戻し"},"さげる":{"variants":"さげる/下げる"},"下げる":{"variants":"さげる/下げる"},"さげわたす":{"variants":"さげわたす/下げ渡す"},"下げ渡す":{"variants":"さげわたす/下げ渡す"},"左近の桜":{"variants":"左近の桜/左近桜"},"左近桜":{"variants":"左近の桜/左近桜"},"ササ":{"variants":"ササ/些々/些些/笹"},"些々":{"variants":"ササ/些々/些些"},"些些":{"variants":"ササ/些々/些些"},"ささい":{"variants":"ささい/些細/瑣細"},"ささがき":{"variants":"ささがき/笹掻き"},"笹掻き":{"variants":"ささがき/笹掻き"},"ささ栗":{"variants":"ささ栗/ササグリ"},"ササグリ":{"variants":"ささ栗/ササグリ"},"ササゲ":{"variants":"ササゲ/大角豆"},"大角豆":{"variants":"ササゲ/大角豆"},"ささげる":{"variants":"ささげる/捧げる"},"捧げる":{"variants":"ささげる/捧げる"},"ささ身":{"variants":"ささ身/笹身"},"笹身":{"variants":"ささ身/笹身"},"ささやく":{"variants":"ささやく/囁く/囁やく"},"囁く":{"variants":"ささやく/囁く/囁やく"},"囁やく":{"variants":"ささやく/囁く/囁やく"},"ササリンドウ":{"variants":"ササリンドウ/笹竜胆"},"笹竜胆":{"variants":"ササリンドウ/笹竜胆"},"ささる":{"variants":"ささる/刺さる"},"刺さる":{"variants":"ささる/刺さる"},"サザエ":{"variants":"サザエ/栄螺"},"栄螺":{"variants":"サザエ/栄螺"},"細波":{"variants":"さざ波/細波"},"さざ波":{"variants":"さざ波/細波/小波"},"小波":{"variants":"さざ波/小波"},"サザンカ":{"variants":"サザンカ/山茶花"},"山茶花":{"variants":"サザンカ/山茶花"},"サシ":{"variants":"サシ/差し/砂嘴/刺し/指し/注し/渣滓"},"さしあう":{"variants":"さしあう/差し合う/差合う"},"差し合う":{"variants":"さしあう/差し合う/差合う"},"差合う":{"variants":"さしあう/差し合う/差合う"},"さしあげる":{"variants":"さしあげる/差しあげる/差し上げる/差上げる"},"差しあげる":{"variants":"さしあげる/差しあげる/差し上げる/差上げる"},"差し上げる":{"variants":"さしあげる/差しあげる/差し上げる/差上げる"},"差上げる":{"variants":"さしあげる/差しあげる/差し上げる/差上げる"},"さしあたり":{"variants":"さしあたり/差し当たり"},"差し当たり":{"variants":"さしあたり/差し当たり"},"さしあたる":{"variants":"さしあたる/さし当たる/差し当る"},"さし当たる":{"variants":"さしあたる/さし当たる/差し当る"},"差し当る":{"variants":"さしあたる/さし当たる/差し当る"},"差し入れ":{"variants":"差し入れ/差入れ"},"差入れ":{"variants":"差し入れ/差入れ"},"さしいれる":{"variants":"さしいれる/差しいれる/差し入れる/差入れる"},"差しいれる":{"variants":"さしいれる/差しいれる/差し入れる/差入れる"},"差し入れる":{"variants":"さしいれる/差しいれる/差し入れる/差入れる"},"差入れる":{"variants":"さしいれる/差しいれる/差し入れる/差入れる"},"さし絵":{"variants":"さし絵/挿し絵/挿絵"},"挿し絵":{"variants":"さし絵/挿し絵/挿絵"},"挿絵":{"variants":"さし絵/挿し絵/挿絵"},"さしおく":{"variants":"さしおく/差し置く/差置く"},"差し置く":{"variants":"さしおく/差し置く/差置く"},"差置く":{"variants":"さしおく/差し置く/差置く"},"差し押さえ":{"variants":"差し押さえ/差押え"},"差押え":{"variants":"差し押さえ/差押え"},"さしおさえる":{"variants":"さしおさえる/差し押える/差し押さえる/差押える"},"差し押える":{"variants":"さしおさえる/差し押える/差し押さえる/差押える"},"差し押さえる":{"variants":"さしおさえる/差し押える/差し押さえる/差押える"},"差押える":{"variants":"さしおさえる/差し押える/差し押さえる/差押える"},"差し替え":{"variants":"差し替え/差替え"},"差替え":{"variants":"差し替え/差替え"},"さしかえる":{"variants":"さしかえる/差しかえる/差し換える/差し替える/差換える/差替える"},"差しかえる":{"variants":"さしかえる/差しかえる/差し換える/差し替える/差換える/差替える"},"差し替える":{"variants":"さしかえる/差しかえる/差し替える/差替える"},"差し換える":{"variants":"さしかえる/差しかえる/差し換える/差換える"},"差替える":{"variants":"さしかえる/差しかえる/差し替える/差替える"},"差換える":{"variants":"さしかえる/差しかえる/差し換える/差換える"},"さしかかる":{"variants":"さしかかる/差しかかる/差し掛かる/差し掛る/差掛る"},"差しかかる":{"variants":"さしかかる/差しかかる/差し掛かる/差し掛る/差掛る"},"差し掛かる":{"variants":"さしかかる/差しかかる/差し掛かる/差し掛る/差掛る"},"差し掛る":{"variants":"さしかかる/差しかかる/差し掛かる/差し掛る/差掛る"},"差掛る":{"variants":"さしかかる/差しかかる/差し掛かる/差し掛る/差掛る"},"さしかける":{"variants":"さしかける/差しかける/差し掛ける/差掛ける"},"差しかける":{"variants":"さしかける/差しかける/差し掛ける/差掛ける"},"差し掛ける":{"variants":"さしかける/差しかける/差し掛ける/差掛ける"},"差掛ける":{"variants":"さしかける/差しかける/差し掛ける/差掛ける"},"さしかざす":{"variants":"さしかざす/差しかざす/差し翳す"},"差しかざす":{"variants":"さしかざす/差しかざす/差し翳す"},"差し翳す":{"variants":"さしかざす/差しかざす/差し翳す"},"さしかためる":{"variants":"さしかためる/差し固める/差固める"},"差し固める":{"variants":"さしかためる/差し固める/差固める"},"差固める":{"variants":"さしかためる/差し固める/差固める"},"さしがね":{"variants":"さしがね/差し金"},"差し金":{"variants":"さしがね/差し金"},"さし木":{"variants":"さし木/挿し木"},"挿し木":{"variants":"さし木/挿し木"},"さしくる":{"variants":"さしくる/差し繰る/差繰る"},"差し繰る":{"variants":"さしくる/差し繰る/差繰る"},"差繰る":{"variants":"さしくる/差し繰る/差繰る"},"刺し子":{"variants":"刺し子/刺子"},"刺子":{"variants":"刺し子/刺子"},"さしこえる":{"variants":"さしこえる/差し越える/差越える"},"差し越える":{"variants":"さしこえる/差し越える/差越える"},"差越える":{"variants":"さしこえる/差し越える/差越える"},"さしこす":{"variants":"さしこす/差し越す/差越す"},"差し越す":{"variants":"さしこす/差し越す/差越す"},"差越す":{"variants":"さしこす/差し越す/差越す"},"差し込み":{"variants":"差し込み/差込み"},"差込み":{"variants":"差し込み/差込み"},"さしこむ":{"variants":"さしこむ/差し込む/射し込む"},"さしころす":{"variants":"さしころす/刺し殺す/刺殺す"},"刺し殺す":{"variants":"さしころす/刺し殺す/刺殺す"},"刺殺す":{"variants":"さしころす/刺し殺す/刺殺す"},"さしころせる":{"variants":"さしころせる/刺し殺せる"},"刺し殺せる":{"variants":"さしころせる/刺し殺せる"},"差し障り":{"variants":"差し障り/差障り"},"差障り":{"variants":"差し障り/差障り"},"さしさわる":{"variants":"さしさわる/差し障る"},"差し障る":{"variants":"さしさわる/差し障る"},"差し潮":{"variants":"差し潮/差潮"},"差潮":{"variants":"差し潮/差潮"},"さししめす":{"variants":"さししめす/指し示す"},"指し示す":{"variants":"さししめす/指し示す"},"さししめせる":{"variants":"さししめせる/指し示せる"},"指し示せる":{"variants":"さししめせる/指し示せる"},"さしせまる":{"variants":"さしせまる/さし迫る/差し迫る/差迫る"},"さし迫る":{"variants":"さしせまる/さし迫る/差し迫る/差迫る"},"差し迫る":{"variants":"さしせまる/さし迫る/差し迫る/差迫る"},"差迫る":{"variants":"さしせまる/さし迫る/差し迫る/差迫る"},"さしたてる":{"variants":"さしたてる/差し立てる/差立てる"},"差し立てる":{"variants":"さしたてる/差し立てる/差立てる"},"差立てる":{"variants":"さしたてる/差し立てる/差立てる"},"さしだす":{"variants":"さしだす/差しだす/差し出す/差出す"},"差しだす":{"variants":"さしだす/差しだす/差し出す/差出す"},"差し出す":{"variants":"さしだす/差しだす/差し出す/差出す"},"差出す":{"variants":"さしだす/差しだす/差し出す/差出す"},"さしだせる":{"variants":"さしだせる/差し出せる"},"差し出せる":{"variants":"さしだせる/差し出せる"},"さしちがえる":{"variants":"さしちがえる/差し違える/差違える/刺し違える/刺違える"},"差違える":{"variants":"さしちがえる/差し違える/差違える"},"刺違える":{"variants":"さしちがえる/刺し違える/刺違える"},"差し違える":{"variants":"さしちがえる/差し違える/差違える"},"刺し違える":{"variants":"さしちがえる/刺し違える/刺違える"},"さしつかえる":{"variants":"さしつかえる/差し支える/差支える"},"差し支える":{"variants":"さしつかえる/差し支える/差支える"},"差支える":{"variants":"さしつかえる/差し支える/差支える"},"さしつかわす":{"variants":"さしつかわす/差し遣わす"},"差し遣わす":{"variants":"さしつかわす/差し遣わす"},"さしつける":{"variants":"さしつける/差し付ける/差付ける"},"差し付ける":{"variants":"さしつける/差し付ける/差付ける"},"差付ける":{"variants":"さしつける/差し付ける/差付ける"},"さしでがましい":{"variants":"さしでがましい/差出がましい"},"差出がましい":{"variants":"さしでがましい/差出がましい"},"差し出口":{"variants":"差し出口/差出口"},"差出口":{"variants":"差し出口/差出口"},"差し出る":{"variants":"さしでる/差し出る/差出る"},"さしでる":{"variants":"さしでる/差し出る/差出る"},"差出る":{"variants":"さしでる/差し出る/差出る"},"さしとおす":{"variants":"さしとおす/刺し通す/刺通す"},"刺し通す":{"variants":"さしとおす/刺し通す/刺通す"},"刺通す":{"variants":"さしとおす/刺し通す/刺通す"},"さしとめる":{"variants":"さしとめる/差し止める/差止める"},"差し止める":{"variants":"さしとめる/差し止める/差止める"},"差止める":{"variants":"さしとめる/差し止める/差止める"},"指し値":{"variants":"指し値/指値"},"指値":{"variants":"指し値/指値"},"さしのべる":{"variants":"さしのべる/差しのべる/差し延べる/差し伸べる/差延べる/差伸べる"},"差しのべる":{"variants":"さしのべる/差しのべる/差し延べる/差し伸べる/差延べる/差伸べる"},"差延べる":{"variants":"さしのべる/差しのべる/差し延べる/差延べる"},"差し伸べる":{"variants":"さしのべる/差しのべる/差し伸べる/差伸べる"},"差伸べる":{"variants":"さしのべる/差しのべる/差し伸べる/差伸べる"},"差し延べる":{"variants":"さしのべる/差しのべる/差し延べる/差延べる"},"さしのぼる":{"variants":"さしのぼる/差し昇る/差し上る/差昇る/差上る"},"差し上る":{"variants":"さしのぼる/差し上る/差上る"},"差上る":{"variants":"さしのぼる/差し上る/差上る"},"差し昇る":{"variants":"さしのぼる/差し昇る/差昇る"},"差昇る":{"variants":"さしのぼる/差し昇る/差昇る"},"さしはさむ":{"variants":"さしはさむ/差し挟む"},"差し挟む":{"variants":"さしはさむ/差し挟む"},"差し歯":{"variants":"差し歯/差歯"},"差歯":{"variants":"差し歯/差歯"},"さしひかえる":{"variants":"さしひかえる/差し控える"},"差し控える":{"variants":"さしひかえる/差し控える"},"差し引き":{"variants":"差し引き/差引"},"差引":{"variants":"差し引き/差引"},"さしひく":{"variants":"さしひく/差し引く/差引く"},"差し引く":{"variants":"さしひく/差し引く/差引く"},"差引く":{"variants":"さしひく/差し引く/差引く"},"さしひびく":{"variants":"さしひびく/差し響く/差響く"},"差し響く":{"variants":"さしひびく/差し響く/差響く"},"差響く":{"variants":"さしひびく/差し響く/差響く"},"さしまねく":{"variants":"さしまねく/差し招く/差招く/麾く"},"差し招く":{"variants":"さしまねく/差し招く/差招く"},"差招く":{"variants":"さしまねく/差し招く/差招く"},"さしまわす":{"variants":"さしまわす/差し回す/差回す"},"差し回す":{"variants":"さしまわす/差し回す/差回す"},"差回す":{"variants":"さしまわす/差し回す/差回す"},"さしまわせる":{"variants":"さしまわせる/差し回せる"},"差し回せる":{"variants":"さしまわせる/差し回せる"},"刺し身":{"variants":"刺し身/刺身"},"刺身":{"variants":"刺し身/刺身"},"さし水":{"variants":"さし水/差水"},"差水":{"variants":"さし水/差水"},"さしむける":{"variants":"さしむける/差し向ける/差向ける"},"差し向ける":{"variants":"さしむける/差し向ける/差向ける"},"差向ける":{"variants":"さしむける/差し向ける/差向ける"},"差し戻し":{"variants":"差し戻し/差戻し"},"差戻し":{"variants":"差し戻し/差戻し"},"さしもどす":{"variants":"さしもどす/差し戻す/差戻す"},"差し戻す":{"variants":"さしもどす/差し戻す/差戻す"},"差戻す":{"variants":"さしもどす/差し戻す/差戻す"},"指し物":{"variants":"指し物/指物"},"指物":{"variants":"指し物/指物"},"差し渡し":{"variants":"差し渡し/差渡し"},"差渡し":{"variants":"差し渡し/差渡し"},"さじ":{"variants":"さじ/サジ/些事/匙/瑣事"},"サジ":{"variants":"さじ/サジ/些事/匙/瑣事"},"さじ加減":{"variants":"さじ加減/匙加減"},"匙加減":{"variants":"さじ加減/匙加減"},"砂塵":{"variants":"砂じん/砂塵"},"砂じん":{"variants":"砂じん/砂塵"},"さす":{"variants":"さす/差す/刺す/指す/射す/挿す/注す"},"さずかる":{"variants":"さずかる/授かる"},"授かる":{"variants":"さずかる/授かる"},"さそいあわす":{"variants":"さそいあわす/誘い合わす"},"誘い合わす":{"variants":"さそいあわす/誘い合わす"},"さそいあわせる":{"variants":"さそいあわせる/誘い合わせる"},"誘い合わせる":{"variants":"さそいあわせる/誘い合わせる"},"さそいかける":{"variants":"さそいかける/誘いかける/誘い掛ける"},"誘いかける":{"variants":"さそいかける/誘いかける/誘い掛ける"},"誘い掛ける":{"variants":"さそいかける/誘いかける/誘い掛ける"},"さそいこむ":{"variants":"さそいこむ/誘い込む"},"誘い込む":{"variants":"さそいこむ/誘い込む"},"さそいだす":{"variants":"さそいだす/誘い出す"},"誘い出す":{"variants":"さそいだす/誘い出す"},"さそいだせる":{"variants":"さそいだせる/誘い出せる"},"誘い出せる":{"variants":"さそいだせる/誘い出せる"},"さそえる":{"variants":"さそえる/誘える"},"誘える":{"variants":"さそえる/誘える"},"サソリ":{"variants":"サソリ/蠍"},"蠍":{"variants":"サソリ/蠍"},"さぞ":{"variants":"さぞ/嘸"},"嘸":{"variants":"さぞ/嘸"},"さぞかし":{"variants":"さぞかし/嘸かし"},"嘸かし":{"variants":"さぞかし/嘸かし"},"さぞや":{"variants":"さぞや/嘸や"},"嘸や":{"variants":"さぞや/嘸や"},"さだか":{"variants":"さだか/定か"},"定か":{"variants":"さだか/定か"},"さだまる":{"variants":"さだまる/定まる"},"定まる":{"variants":"さだまる/定まる"},"さだめし":{"variants":"さだめし/定めし"},"定めし":{"variants":"さだめし/定めし"},"さだめて":{"variants":"さだめて/定めて"},"定めて":{"variants":"さだめて/定めて"},"さだめる":{"variants":"さだめる/定める"},"定める":{"variants":"さだめる/定める"},"さっきだつ":{"variants":"さっきだつ/殺気だつ/殺気立つ"},"殺気だつ":{"variants":"さっきだつ/殺気だつ/殺気立つ"},"殺気立つ":{"variants":"さっきだつ/殺気だつ/殺気立つ"},"颯々":{"variants":"颯々/颯颯"},"颯颯":{"variants":"颯々/颯颯"},"サッシ":{"variants":"サッシ/冊子"},"冊子":{"variants":"サッシ/冊子"},"さっする":{"variants":"さっする/察する"},"察する":{"variants":"さっする/察する"},"さっそく":{"variants":"さっそく/早速"},"早速":{"variants":"さっそく/早速"},"さっと":{"variants":"さっと/サッと/颯と"},"サッと":{"variants":"さっと/サッと/颯と"},"颯と":{"variants":"さっと/サッと/颯と"},"さっぴく":{"variants":"さっぴく/さっ引く/差っ引く"},"さっ引く":{"variants":"さっぴく/さっ引く/差っ引く"},"差っ引く":{"variants":"さっぴく/さっ引く/差っ引く"},"サツキ":{"variants":"サツキ/皐/皐月/早月"},"サツキツツジ":{"variants":"サツキツツジ/五月躑躅/皐月躑躅/早月躑躅"},"五月晴れ":{"variants":"五月晴/五月晴れ"},"五月晴":{"variants":"五月晴/五月晴れ"},"殺ばつ":{"variants":"殺ばつ/殺伐"},"殺伐":{"variants":"殺ばつ/殺伐"},"さつばつと":{"variants":"さつばつと/殺伐と"},"殺伐と":{"variants":"さつばつと/殺伐と"},"さつま揚げ":{"variants":"さつま揚げ/薩摩揚"},"薩摩揚":{"variants":"さつま揚げ/薩摩揚"},"さつま芋":{"variants":"さつま芋/サツマイモ/薩摩芋"},"サツマイモ":{"variants":"さつま芋/サツマイモ/薩摩芋"},"薩摩芋":{"variants":"さつま芋/サツマイモ/薩摩芋"},"殺りく":{"variants":"殺りく/殺戮"},"殺戮":{"variants":"殺りく/殺戮"},"さておく":{"variants":"さておく/扠措く/扠置く"},"さとい":{"variants":"さとい/聡い/敏い/聰い"},"サトイモ":{"variants":"サトイモ/里いも/里芋"},"里いも":{"variants":"サトイモ/里いも/里芋"},"里芋":{"variants":"サトイモ/里いも/里芋"},"サトウキビ":{"variants":"サトウキビ/砂糖きび/砂糖黍"},"砂糖きび":{"variants":"サトウキビ/砂糖きび/砂糖黍"},"砂糖黍":{"variants":"サトウキビ/砂糖きび/砂糖黍"},"さとす":{"variants":"さとす/諭す"},"諭す":{"variants":"さとす/諭す"},"さとせる":{"variants":"さとせる/諭せる"},"諭せる":{"variants":"さとせる/諭せる"},"さとる":{"variants":"さとる/覚る/悟る/聰る"},"さとれる":{"variants":"さとれる/悟れる"},"悟れる":{"variants":"さとれる/悟れる"},"さながら":{"variants":"さながら/宛ら"},"宛ら":{"variants":"さながら/宛ら"},"サナギ":{"variants":"サナギ/蛹"},"蛹":{"variants":"サナギ/蛹"},"サナダムシ":{"variants":"サナダムシ/真田虫/絛虫"},"サネカズラ":{"variants":"サネカズラ/真葛"},"真葛":{"variants":"サネカズラ/真葛"},"サノウ":{"variants":"サノウ/左脳/砂嚢"},"サバ":{"variants":"サバ/鯖"},"鯖":{"variants":"サバ/鯖"},"さばく":{"variants":"さばく/裁く/捌く"},"さばける":{"variants":"さばける/裁ける"},"裁ける":{"variants":"さばける/裁ける"},"さばさば":{"variants":"さばさば/サバサバ"},"サバサバ":{"variants":"さばさば/サバサバ"},"さび":{"variants":"さび/サビ/錆/銹"},"サビ":{"variants":"さび/サビ/錆/銹"},"サビアユ":{"variants":"サビアユ/錆鮎"},"錆鮎":{"variants":"サビアユ/錆鮎"},"さびつく":{"variants":"さびつく/錆びつく/錆び付く/錆付く"},"錆びつく":{"variants":"さびつく/錆びつく/錆び付く/錆付く"},"錆び付く":{"variants":"さびつく/錆びつく/錆び付く/錆付く"},"錆付く":{"variants":"さびつく/錆びつく/錆び付く/錆付く"},"さびる":{"variants":"さびる/錆びる/寂びる"},"さびれる":{"variants":"さびれる/寂れる"},"寂れる":{"variants":"さびれる/寂れる"},"サボテン":{"variants":"サボテン/仙人掌"},"仙人掌":{"variants":"サボテン/仙人掌"},"さぼる":{"variants":"さぼる/サボる"},"サボる":{"variants":"さぼる/サボる"},"さま":{"variants":"さま/サマ/様"},"様":{"variants":"よう/様"},"サマ":{"variants":"さま/サマ/様"},"様変り":{"variants":"様変り/様変わり"},"様変わり":{"variants":"様変り/様変わり"},"様々":{"variants":"さまざま/様々/様様"},"様様":{"variants":"さまざま/様々/様様"},"さまざま":{"variants":"さまざま/様々/様様"},"さます":{"variants":"さます/覚す/覚ます/醒す/醒ます/冷ます"},"醒す":{"variants":"さます/醒す/醒ます"},"覚す":{"variants":"さます/覚す/覚ます"},"醒ます":{"variants":"さます/醒す/醒ます"},"覚ます":{"variants":"さます/覚す/覚ます"},"さませる":{"variants":"さませる/覚ませる/醒ませる/冷ませる"},"さまたげる":{"variants":"さまたげる/妨げる"},"妨げる":{"variants":"さまたげる/妨げる"},"さまよう":{"variants":"さまよう/さ迷う"},"さ迷う":{"variants":"さまよう/さ迷う"},"さむい":{"variants":"さむい/寒い"},"寒い":{"variants":"さむい/寒い"},"さむけだつ":{"variants":"さむけだつ/寒気立つ"},"寒気立つ":{"variants":"さむけだつ/寒気立つ"},"寒々":{"variants":"寒々/寒寒"},"寒寒":{"variants":"寒々/寒寒"},"サムライ":{"variants":"サムライ/侍"},"侍":{"variants":"サムライ/侍"},"サメ":{"variants":"サメ/鮫"},"鮫":{"variants":"サメ/鮫"},"さめる":{"variants":"さめる/覚める/醒める/冷める/褪める"},"さや":{"variants":"さや/紗綾/鞘/莢"},"サヤインゲン":{"variants":"サヤインゲン/莢隠元"},"莢隠元":{"variants":"サヤインゲン/莢隠元"},"サヤエンドウ":{"variants":"サヤエンドウ/莢豌豆"},"莢豌豆":{"variants":"サヤエンドウ/莢豌豆"},"さやけい":{"variants":"さやけい/清けい"},"清けい":{"variants":"さやけい/清けい"},"さやばしる":{"variants":"さやばしる/鞘走る"},"鞘走る":{"variants":"さやばしる/鞘走る"},"さよう":{"variants":"さよう/左様/然様"},"さよなら":{"variants":"さよなら/サヨナラ"},"サヨナラ":{"variants":"さよなら/サヨナラ"},"さら":{"variants":"さら/サラ/皿"},"サラ":{"variants":"さら/サラ/皿"},"皿":{"variants":"さら/サラ/皿"},"さらう":{"variants":"さらう/拐う/攫う/浚う/渫う"},"さらえる":{"variants":"さらえる/浚える"},"浚える":{"variants":"さらえる/浚える"},"さらけだす":{"variants":"さらけだす/さらけ出す"},"さらけ出す":{"variants":"さらけだす/さらけ出す"},"さらさら":{"variants":"さらさら/サラサラ/更々/更更"},"サラサラ":{"variants":"さらさら/サラサラ/更々/更更"},"更々":{"variants":"さらさら/サラサラ/更々/更更"},"更更":{"variants":"さらさら/サラサラ/更々/更更"},"晒":{"variants":"晒/晒し"},"晒し":{"variants":"晒/晒し"},"さらし飴":{"variants":"さらし飴/晒飴"},"晒飴":{"variants":"さらし飴/晒飴"},"さらし首":{"variants":"さらし首/晒首/曝首"},"さらし粉":{"variants":"さらし粉/晒粉"},"晒粉":{"variants":"さらし粉/晒粉"},"さらしもの":{"variants":"さらしもの/さらし者/晒者"},"さらし者":{"variants":"さらしもの/さらし者/晒者"},"晒者":{"variants":"さらしもの/さらし者/晒者"},"さらし木綿":{"variants":"さらし木綿/晒木綿"},"晒木綿":{"variants":"さらし木綿/晒木綿"},"さらす":{"variants":"さらす/晒す/曝す"},"さらせる":{"variants":"さらせる/晒せる/曝せる"},"サラソウジュ":{"variants":"サラソウジュ/沙羅双樹"},"沙羅双樹":{"variants":"サラソウジュ/沙羅双樹"},"さら地":{"variants":"さら地/更地"},"更地":{"variants":"さら地/更地"},"さらに":{"variants":"さらに/更に"},"更に":{"variants":"さらに/更に"},"皿まわし":{"variants":"皿まわし/皿回し/皿廻し"},"さらりと":{"variants":"さらりと/サラリと"},"サラリと":{"variants":"さらりと/サラリと"},"さりげ":{"variants":"さりげ/さり気"},"さり気":{"variants":"さりげ/さり気"},"さる":{"variants":"さる/去る"},"去る":{"variants":"さる/去る"},"サル":{"variants":"サル/申"},"申":{"variants":"サル/申"},"サルオガセ":{"variants":"サルオガセ/猿おがせ/松蘿"},"さるぐつわ":{"variants":"さるぐつわ/猿ぐつわ/猿轡"},"猿ぐつわ":{"variants":"さるぐつわ/猿ぐつわ/猿轡"},"猿轡":{"variants":"さるぐつわ/猿ぐつわ/猿轡"},"サルスベリ":{"variants":"サルスベリ/百日紅"},"百日紅":{"variants":"サルスベリ/百日紅"},"サルノコシカケ":{"variants":"サルノコシカケ/猿のこしかけ/猿の腰掛"},"猿のこしかけ":{"variants":"サルノコシカケ/猿のこしかけ/猿の腰掛"},"猿の腰掛":{"variants":"サルノコシカケ/猿のこしかけ/猿の腰掛"},"砂れき":{"variants":"砂れき/砂礫"},"砂礫":{"variants":"砂れき/砂礫"},"さわがしい":{"variants":"さわがしい/騒がしい"},"騒がしい":{"variants":"さわがしい/騒がしい"},"さわがす":{"variants":"さわがす/騒がす"},"騒がす":{"variants":"さわがす/騒がす"},"さわがせる":{"variants":"さわがせる/騒がせる"},"騒がせる":{"variants":"さわがせる/騒がせる"},"サワガニ":{"variants":"サワガニ/沢蟹"},"沢蟹":{"variants":"サワガニ/沢蟹"},"さわぎたてる":{"variants":"さわぎたてる/騒ぎ立てる"},"騒ぎ立てる":{"variants":"さわぎたてる/騒ぎ立てる"},"さわぎだす":{"variants":"さわぎだす/騒ぎだす/騒ぎ出す"},"騒ぎだす":{"variants":"さわぎだす/騒ぎだす/騒ぎ出す"},"騒ぎ出す":{"variants":"さわぎだす/騒ぎだす/騒ぎ出す"},"さわぐ":{"variants":"さわぐ/騒ぐ"},"騒ぐ":{"variants":"さわぐ/騒ぐ"},"さわげる":{"variants":"さわげる/騒げる"},"騒げる":{"variants":"さわげる/騒げる"},"さわやか":{"variants":"さわやか/爽やか"},"爽やか":{"variants":"さわやか/爽やか"},"サワラ":{"variants":"サワラ/椹/鰆"},"さわり":{"variants":"さわり/障り/触り"},"さわる":{"variants":"さわる/障る/触る"},"サン":{"variants":"サン/讃/酸"},"３":{"variants":"３/三"},"三":{"variants":"３/三"},"三角きん":{"variants":"三角きん/三角巾"},"三角巾":{"variants":"三角きん/三角巾"},"サンカメイチュウ":{"variants":"サンカメイチュウ/三化螟虫"},"三化螟虫":{"variants":"サンカメイチュウ/三化螟虫"},"３月":{"variants":"３月/三月"},"三月":{"variants":"３月/三月"},"三が日":{"variants":"三が日/三箇日"},"三箇日":{"variants":"三が日/三箇日"},"サンキライ":{"variants":"サンキライ/山帰来"},"山帰来":{"variants":"サンキライ/山帰来"},"参けい":{"variants":"参けい/参詣"},"参詣":{"variants":"参けい/参詣"},"さんけづく":{"variants":"さんけづく/産気づく"},"産気づく":{"variants":"さんけづく/産気づく"},"サンゴ":{"variants":"サンゴ/三五/珊瑚"},"さんご礁":{"variants":"さんご礁/サンゴショウ/サンゴ礁/珊瑚礁"},"サンゴショウ":{"variants":"さんご礁/サンゴショウ/サンゴ礁/珊瑚礁"},"サンゴ礁":{"variants":"さんご礁/サンゴショウ/サンゴ礁/珊瑚礁"},"珊瑚礁":{"variants":"さんご礁/サンゴショウ/サンゴ礁/珊瑚礁"},"サンゴジュ":{"variants":"サンゴジュ/珊瑚珠/珊瑚樹"},"燦燦":{"variants":"燦々/燦燦"},"潸潸":{"variants":"潸々/潸潸"},"燦々":{"variants":"燦々/燦燦"},"潸々":{"variants":"潸々/潸潸"},"三々九度":{"variants":"三々九度/三三九度"},"三三九度":{"variants":"三々九度/三三九度"},"さんさんごご":{"variants":"さんさんごご/三々五々/三三五五"},"三々五々":{"variants":"さんさんごご/三々五々/三三五五"},"三三五五":{"variants":"さんさんごご/三々五々/三三五五"},"サンザシ":{"variants":"サンザシ/山査子"},"山査子":{"variants":"サンザシ/山査子"},"散々":{"variants":"散々/散散"},"散散":{"variants":"散々/散散"},"サンシキスミレ":{"variants":"サンシキスミレ/三色菫"},"三色菫":{"variants":"サンシキスミレ/三色菫"},"サンショウ":{"variants":"サンショウ/山椒"},"山椒":{"variants":"サンショウ/山椒"},"サンショウウオ":{"variants":"サンショウウオ/山椒魚/鯢"},"産じょく":{"variants":"産じょく/産褥"},"産褥":{"variants":"産じょく/産褥"},"さんじる":{"variants":"さんじる/参じる/散じる"},"三すくみ":{"variants":"三すくみ/三竦み"},"三竦み":{"variants":"三すくみ/三竦み"},"さんする":{"variants":"さんする/参する/算する"},"さんずる":{"variants":"さんずる/参ずる/散ずる"},"さんぜん":{"variants":"さんぜん/さん然/燦然"},"さん然":{"variants":"さん然/燦然/潸然"},"燦然":{"variants":"さん然/燦然"},"潸然":{"variants":"さん然/潸然"},"惨たん":{"variants":"惨たん/惨憺/惨澹"},"三段跳":{"variants":"三段跳/三段跳び"},"三段飛":{"variants":"三段飛/三段飛び"},"三段跳び":{"variants":"三段跳/三段跳び"},"三段飛び":{"variants":"三段飛/三段飛び"},"サンチ":{"variants":"サンチ/山地/産地"},"ＳＵＮＤＡＥ":{"variants":"ＳＵＮＤＡＥ/サンデー"},"サンデー":{"variants":"ＳＵＮＤＡＥ/サンデー"},"サントウナ":{"variants":"サントウナ/山東菜"},"山東菜":{"variants":"サントウナ/山東菜"},"三の酉":{"variants":"三の酉/三酉"},"三酉":{"variants":"三の酉/三酉"},"サンバ":{"variants":"サンバ/産婆"},"産婆":{"variants":"サンバ/産婆"},"三羽がらす":{"variants":"三羽がらす/三羽烏"},"三羽烏":{"variants":"三羽がらす/三羽烏"},"サンボウカン":{"variants":"サンボウカン/三宝柑"},"三宝柑":{"variants":"サンボウカン/三宝柑"},"散歩みち":{"variants":"散歩みち/散歩道"},"散歩道":{"variants":"散歩みち/散歩道"},"サンマ":{"variants":"サンマ/秋刀魚"},"秋刀魚":{"variants":"サンマ/秋刀魚"},"三りんぼう":{"variants":"三りんぼう/三隣亡"},"三隣亡":{"variants":"三りんぼう/三隣亡"},"山れい":{"variants":"山れい/山嶺/山霊"},"山ろく":{"variants":"山ろく/山麓"},"山麓":{"variants":"山ろく/山麓"},"ザイン":{"variants":"ザイン/座員"},"座員":{"variants":"ザイン/座員"},"ざくざく":{"variants":"ざくざく/ザクザク"},"ザクザク":{"variants":"ざくざく/ザクザク"},"ザクロ":{"variants":"ザクロ/石榴/柘榴"},"ざくろ口":{"variants":"ざくろ口/石榴口"},"石榴口":{"variants":"ざくろ口/石榴口"},"ざこ寝":{"variants":"ざこ寝/雑魚寝"},"雑魚寝":{"variants":"ざこ寝/雑魚寝"},"ざす":{"variants":"ざす/坐す/座す"},"ざする":{"variants":"ざする/坐する/座する"},"ざつぜんと":{"variants":"ざつぜんと/雑然と"},"雑然と":{"variants":"ざつぜんと/雑然と"},"座ぶとん":{"variants":"座ぶとん/座蒲団/座布団"},"ザボン":{"variants":"ザボン/朱欒"},"朱欒":{"variants":"ザボン/朱欒"},"ざらざら":{"variants":"ざらざら/ザラザラ"},"ザラザラ":{"variants":"ざらざら/ザラザラ"},"ざる":{"variants":"ざる/ザル/笊"},"ザル":{"variants":"ざる/ザル/笊"},"笊":{"variants":"ざる/ザル/笊"},"ざる碁":{"variants":"ざる碁/笊碁"},"笊碁":{"variants":"ざる碁/笊碁"},"ざる耳":{"variants":"ざる耳/笊耳"},"笊耳":{"variants":"ざる耳/笊耳"},"戯事":{"variants":"戯れ事/戯事"},"戯れ事":{"variants":"戯れ事/戯事"},"ざわざわ":{"variants":"ざわざわ/ザワザワ"},"ザワザワ":{"variants":"ざわざわ/ザワザワ"},"残がい":{"variants":"残がい/残害"},"残害":{"variants":"残がい/残害"},"ざん首":{"variants":"ざん首/斬首"},"斬首":{"variants":"ざん首/斬首"},"ざん新":{"variants":"ざん新/斬新"},"斬新":{"variants":"ざん新/斬新"},"ざんする":{"variants":"ざんする/竄する/讒する"},"ＣＣ":{"variants":"ＣＣ/ｃｃ/シーシー"},"ｃｃ":{"variants":"ＣＣ/ｃｃ/シーシー"},"シーシー":{"variants":"ＣＣ/ｃｃ/シーシー"},"仕上がり":{"variants":"仕上がり/仕上り"},"仕上り":{"variants":"仕上がり/仕上り"},"しあがる":{"variants":"しあがる/仕上がる/仕上る"},"仕上がる":{"variants":"しあがる/仕上がる/仕上る"},"仕上る":{"variants":"しあがる/仕上がる/仕上る"},"しあげる":{"variants":"しあげる/仕上げる"},"仕上げる":{"variants":"しあげる/仕上げる"},"しあさって":{"variants":"しあさって/明明後日"},"明明後日":{"variants":"しあさって/明明後日"},"仕合わせ":{"variants":"しあわせ/仕合せ/仕合わせ"},"仕合せ":{"variants":"しあわせ/仕合せ/仕合わせ"},"しあわせ":{"variants":"しあわせ/幸せ/仕合せ/仕合わせ"},"シアン":{"variants":"シアン/私案/試案"},"シイ":{"variants":"シイ/四囲/私意/詩意/椎/恣意"},"しいする":{"variants":"しいする/弑する"},"弑する":{"variants":"しいする/弑する"},"シイタケ":{"variants":"シイタケ/椎茸"},"椎茸":{"variants":"シイタケ/椎茸"},"しいたげる":{"variants":"しいたげる/虐げる"},"虐げる":{"variants":"しいたげる/虐げる"},"しいて":{"variants":"しいて/強いて"},"強いて":{"variants":"しいて/強いて"},"しいる":{"variants":"しいる/強いる/誣いる"},"しいれる":{"variants":"しいれる/仕入れる"},"仕入れる":{"variants":"しいれる/仕入れる"},"仕打":{"variants":"仕打/仕打ち"},"仕打ち":{"variants":"仕打/仕打ち"},"塩あじ":{"variants":"塩あじ/塩味"},"塩味":{"variants":"塩あじ/塩味"},"塩から":{"variants":"塩から/塩辛"},"塩辛":{"variants":"塩から/塩辛"},"しおからい":{"variants":"しおからい/塩辛い"},"塩辛い":{"variants":"しおからい/塩辛い"},"シオカラトンボ":{"variants":"シオカラトンボ/塩辛蜻蛉"},"塩辛蜻蛉":{"variants":"シオカラトンボ/塩辛蜻蛉"},"仕置":{"variants":"仕置/仕置き"},"仕置き":{"variants":"仕置/仕置き"},"しおたれる":{"variants":"しおたれる/潮垂れる"},"潮垂れる":{"variants":"しおたれる/潮垂れる"},"シオデ":{"variants":"シオデ/牛尾菜"},"牛尾菜":{"variants":"シオデ/牛尾菜"},"潮どき":{"variants":"潮どき/潮時"},"潮時":{"variants":"潮どき/潮時"},"潮干狩":{"variants":"潮干狩/潮干狩り"},"潮干狩り":{"variants":"潮干狩/潮干狩り"},"塩引":{"variants":"塩引/塩引き"},"塩引き":{"variants":"塩引/塩引き"},"シオフキ":{"variants":"シオフキ/潮吹/潮吹き"},"潮吹":{"variants":"シオフキ/潮吹/潮吹き"},"潮吹き":{"variants":"シオフキ/潮吹/潮吹き"},"塩まめ":{"variants":"塩まめ/塩豆"},"塩豆":{"variants":"塩まめ/塩豆"},"塩もみ":{"variants":"塩もみ/塩揉み"},"塩揉み":{"variants":"塩もみ/塩揉み"},"塩焼":{"variants":"塩焼/塩焼き"},"塩焼き":{"variants":"塩焼/塩焼き"},"しおり戸":{"variants":"しおり戸/枝折り戸/枝折戸"},"枝折り戸":{"variants":"しおり戸/枝折り戸/枝折戸"},"枝折戸":{"variants":"しおり戸/枝折り戸/枝折戸"},"しおれる":{"variants":"しおれる/萎れる"},"萎れる":{"variants":"しおれる/萎れる"},"シオン":{"variants":"シオン/四恩/師恩/紫苑/歯音"},"シカ":{"variants":"シカ/史家/市価/私家/糸価/紙価/詞花/詞華/詩家/賜暇/歯科/鹿"},"しかくい":{"variants":"しかくい/四角い"},"四角い":{"variants":"しかくい/四角い"},"しかくばる":{"variants":"しかくばる/四角張る"},"四角張る":{"variants":"しかくばる/四角張る"},"仕掛":{"variants":"仕掛/仕掛け"},"仕掛け":{"variants":"仕掛/仕掛け"},"しかける":{"variants":"しかける/仕掛ける/仕掛る"},"仕掛ける":{"variants":"しかける/仕掛ける/仕掛る"},"仕掛る":{"variants":"しかける/仕掛ける/仕掛る"},"しかし":{"variants":"しかし/然し"},"然し":{"variants":"しかし/然し"},"しかして":{"variants":"しかして/然して"},"然して":{"variants":"しかして/然して"},"しかしながら":{"variants":"しかしながら/然し乍ら/併し乍ら"},"然しながら":{"variants":"しかしながら/然しながら/然し乍ら"},"然し乍ら":{"variants":"しかしながら/然しながら/然し乍ら"},"然然":{"variants":"然々/然然"},"然々":{"variants":"然々/然然"},"しかた":{"variants":"しかた/仕方"},"仕方":{"variants":"しかた/仕方"},"しかめっ面":{"variants":"しかめっ面/顰めっつら/顰めっ面"},"顰めっつら":{"variants":"しかめっ面/顰めっつら/顰めっ面"},"顰めっ面":{"variants":"しかめっ面/顰めっつら/顰めっ面"},"しかりつける":{"variants":"しかりつける/叱りつける/叱り付ける"},"叱りつける":{"variants":"しかりつける/叱りつける/叱り付ける"},"叱り付ける":{"variants":"しかりつける/叱りつける/叱り付ける"},"しかる":{"variants":"しかる/叱る/呵る"},"しかるに":{"variants":"しかるに/然るに"},"然るに":{"variants":"しかるに/然るに"},"しかるべき":{"variants":"しかるべき/然るべき"},"然るべき":{"variants":"しかるべき/然るべき"},"しかれる":{"variants":"しかれる/叱れる"},"叱れる":{"variants":"しかれる/叱れる"},"死がい":{"variants":"死がい/死骸"},"死骸":{"variants":"死がい/死骸"},"４月":{"variants":"４月/四月"},"四月":{"variants":"４月/四月"},"シキ":{"variants":"シキ/四季/士気/始期/志気/死期/私記/紙器/式/敷/鋪"},"しきたり":{"variants":"しきたり/仕来り"},"仕来り":{"variants":"しきたり/仕来り"},"しきつめる":{"variants":"しきつめる/敷きつめる/敷き詰める"},"敷きつめる":{"variants":"しきつめる/敷きつめる/敷き詰める"},"敷き詰める":{"variants":"しきつめる/敷きつめる/敷き詰める"},"敷布団":{"variants":"敷き布団/敷布団"},"敷き布団":{"variants":"敷き布団/敷布団"},"敷蒲団":{"variants":"敷き蒲団/敷蒲団"},"敷き蒲団":{"variants":"敷き蒲団/敷蒲団"},"シキミ":{"variants":"シキミ/樒"},"樒":{"variants":"シキミ/樒"},"しきゅう":{"variants":"しきゅう/至急"},"至急":{"variants":"しきゅう/至急"},"仕切":{"variants":"仕切/仕切り"},"仕切り":{"variants":"仕切/仕切り"},"しきりに":{"variants":"しきりに/頻りに"},"頻りに":{"variants":"しきりに/頻りに"},"しきる":{"variants":"しきる/仕切る/頻る"},"資金ぐり":{"variants":"資金ぐり/資金繰り"},"資金繰り":{"variants":"資金ぐり/資金繰り"},"シギ":{"variants":"シギ/仕儀/市議/試技/鴫"},"しく":{"variants":"しく/若く/如く/布く/敷く"},"仕組":{"variants":"仕組/仕組み"},"仕組み":{"variants":"仕組/仕組み"},"しくむ":{"variants":"しくむ/仕組む"},"仕組む":{"variants":"しくむ/仕組む"},"しくめる":{"variants":"しくめる/仕組める"},"仕組める":{"variants":"しくめる/仕組める"},"しぐさ":{"variants":"しぐさ/仕ぐさ/仕種/仕草"},"仕ぐさ":{"variants":"しぐさ/仕ぐさ/仕種/仕草"},"しぐれる":{"variants":"しぐれる/時雨れる"},"時雨れる":{"variants":"しぐれる/時雨れる"},"しけ":{"variants":"しけ/時化"},"時化":{"variants":"しけ/時化"},"しける":{"variants":"しける/時化る/湿気る/敷ける"},"しげい":{"variants":"しげい/繁い"},"繁い":{"variants":"しげい/繁い"},"しげしげ":{"variants":"しげしげ/繁繁"},"繁繁":{"variants":"しげしげ/繁繁"},"しげりあう":{"variants":"しげりあう/繁り合う/茂り合う"},"しげる":{"variants":"しげる/繁る/茂る"},"シコ":{"variants":"シコ/四股"},"四股":{"variants":"シコ/四股"},"嗜好":{"variants":"し好/嗜好"},"し好":{"variants":"し好/嗜好"},"しこしこ":{"variants":"しこしこ/シコシコ"},"シコシコ":{"variants":"しこしこ/シコシコ"},"しこ名":{"variants":"しこ名/醜名"},"醜名":{"variants":"しこ名/醜名"},"仕込":{"variants":"仕込/仕込み"},"仕込み":{"variants":"仕込/仕込み"},"しこむ":{"variants":"しこむ/仕込む"},"仕込む":{"variants":"しこむ/仕込む"},"しこめる":{"variants":"しこめる/仕込める"},"仕込める":{"variants":"しこめる/仕込める"},"しこり":{"variants":"しこり/痼"},"痼":{"variants":"しこり/痼"},"しごく":{"variants":"しごく/至極"},"至極":{"variants":"しごく/至極"},"子細":{"variants":"し細/子細"},"仔細":{"variants":"し細/仔細"},"し細":{"variants":"し細/仔細/子細"},"シシ":{"variants":"シシ/刺史/史詩/嗣子/四肢/師資/志士/孜々/孜孜/死屍/獅子/詩史"},"孜孜":{"variants":"シシ/孜々/孜孜"},"孜々":{"variants":"シシ/孜々/孜孜"},"子々孫々":{"variants":"子々孫々/子子孫孫"},"子子孫孫":{"variants":"子々孫々/子子孫孫"},"刺しゅう":{"variants":"刺しゅう/刺繍"},"刺繍":{"variants":"刺しゅう/刺繍"},"ししゅう":{"variants":"ししゅう/詩集"},"詩集":{"variants":"ししゅう/詩集"},"シジミ":{"variants":"シジミ/蜆"},"蜆":{"variants":"シジミ/蜆"},"シジミバナ":{"variants":"シジミバナ/蜆花"},"蜆花":{"variants":"シジミバナ/蜆花"},"シジュウカラ":{"variants":"シジュウカラ/四十雀"},"四十雀":{"variants":"シジュウカラ/四十雀"},"しす":{"variants":"しす/死す"},"死す":{"variants":"しす/死す"},"しする":{"variants":"しする/死する/資する"},"シズイ":{"variants":"シズイ/歯髄"},"歯髄":{"variants":"シズイ/歯髄"},"しずく":{"variants":"しずく/雫/滴"},"しずしず":{"variants":"しずしず/静静"},"静静":{"variants":"しずしず/静静"},"しずまりかえる":{"variants":"しずまりかえる/静まりかえる/静まり返る"},"静まりかえる":{"variants":"しずまりかえる/静まりかえる/静まり返る"},"静まり返る":{"variants":"しずまりかえる/静まりかえる/静まり返る"},"しずまる":{"variants":"しずまる/静まる/鎮まる"},"シズミウオ":{"variants":"シズミウオ/沈魚"},"沈魚":{"variants":"シズミウオ/沈魚"},"しずむ":{"variants":"しずむ/沈む"},"沈む":{"variants":"しずむ/沈む"},"しずめる":{"variants":"しずめる/静める/沈める/鎮める"},"シソ":{"variants":"シソ/始祖/紫蘇/緇素"},"歯槽のうろう":{"variants":"歯槽のうろう/歯槽膿漏"},"歯槽膿漏":{"variants":"歯槽のうろう/歯槽膿漏"},"しそこなう":{"variants":"しそこなう/為損なう"},"為損なう":{"variants":"しそこなう/為損なう"},"しそんじる":{"variants":"しそんじる/仕損じる"},"仕損じる":{"variants":"しそんじる/仕損じる"},"した":{"variants":"した/舌"},"舌":{"variants":"した/舌"},"したう":{"variants":"したう/慕う"},"慕う":{"variants":"したう/慕う"},"下請":{"variants":"下請/下請け"},"下請け":{"variants":"下請/下請け"},"したおす":{"variants":"したおす/下押す"},"下押す":{"variants":"したおす/下押す"},"したがう":{"variants":"したがう/従う/遵う"},"したがえる":{"variants":"したがえる/従える"},"従える":{"variants":"したがえる/従える"},"したがって":{"variants":"したがって/従って"},"従って":{"variants":"したがって/従って"},"下ごしらえ":{"variants":"下ごしらえ/下拵え"},"下拵え":{"variants":"下ごしらえ/下拵え"},"舌ざわり":{"variants":"舌ざわり/舌触り"},"舌触り":{"variants":"舌ざわり/舌触り"},"したしい":{"variants":"したしい/親しい"},"親しい":{"variants":"したしい/親しい"},"したしむ":{"variants":"したしむ/親しむ"},"親しむ":{"variants":"したしむ/親しむ"},"したしめる":{"variants":"したしめる/親しめる"},"親しめる":{"variants":"したしめる/親しめる"},"下じき":{"variants":"下じき/下敷/下敷き"},"下敷":{"variants":"下じき/下敷/下敷き"},"下敷き":{"variants":"下じき/下敷/下敷き"},"したたか":{"variants":"したたか/強か/健か"},"したたか者":{"variants":"したたか者/強か者"},"強か者":{"variants":"したたか者/強か者"},"したたらす":{"variants":"したたらす/滴らす"},"滴らす":{"variants":"したたらす/滴らす"},"したたる":{"variants":"したたる/滴る"},"滴る":{"variants":"したたる/滴る"},"したたるい":{"variants":"したたるい/舌たるい"},"舌たるい":{"variants":"したたるい/舌たるい"},"したっぱ":{"variants":"したっぱ/下っぱ/下っ端"},"下っぱ":{"variants":"したっぱ/下っぱ/下っ端"},"下っ端":{"variants":"したっぱ/下っぱ/下っ端"},"舌つづみ":{"variants":"舌つづみ/舌鼓"},"舌鼓":{"variants":"舌つづみ/舌鼓"},"仕立":{"variants":"仕立/仕立て"},"仕立て":{"variants":"仕立/仕立て"},"仕立ておろし":{"variants":"仕立ておろし/仕立下し"},"仕立下し":{"variants":"仕立ておろし/仕立下し"},"仕立て物":{"variants":"仕立て物/仕立物"},"仕立物":{"variants":"仕立て物/仕立物"},"したてる":{"variants":"したてる/仕立てる"},"仕立てる":{"variants":"したてる/仕立てる"},"舌なめずり":{"variants":"舌なめずり/舌舐り"},"舌舐り":{"variants":"舌なめずり/舌舐り"},"下塗":{"variants":"下塗/下塗り"},"下塗り":{"variants":"下塗/下塗り"},"下ばえ":{"variants":"下ばえ/下生え"},"下生え":{"variants":"下ばえ/下生え"},"下履":{"variants":"下履/下履き"},"下履き":{"variants":"下履/下履き"},"シタビラメ":{"variants":"シタビラメ/舌鮃"},"舌鮃":{"variants":"シタビラメ/舌鮃"},"したまわる":{"variants":"したまわる/下回る/下廻る"},"したわしい":{"variants":"したわしい/慕わしい"},"慕わしい":{"variants":"したわしい/慕わしい"},"シタン":{"variants":"シタン/始端/紫檀"},"シダ":{"variants":"シダ/歯朶/羊歯"},"しだいに":{"variants":"しだいに/次第に"},"次第に":{"variants":"しだいに/次第に"},"しだす":{"variants":"しだす/仕出す"},"仕出す":{"variants":"しだす/仕出す"},"シダレザクラ":{"variants":"シダレザクラ/枝垂れ桜/枝垂桜"},"枝垂れ桜":{"variants":"シダレザクラ/枝垂れ桜/枝垂桜"},"枝垂桜":{"variants":"シダレザクラ/枝垂れ桜/枝垂桜"},"シダレヤナギ":{"variants":"シダレヤナギ/枝垂柳"},"枝垂柳":{"variants":"シダレヤナギ/枝垂柳"},"しだれる":{"variants":"しだれる/枝垂れる"},"枝垂れる":{"variants":"しだれる/枝垂れる"},"７月":{"variants":"７月/七月"},"七月":{"variants":"７月/七月"},"シチク":{"variants":"シチク/紫竹"},"紫竹":{"variants":"シチク/紫竹"},"七さん":{"variants":"七さん/七三"},"七三":{"variants":"七さん/七三"},"七分づき":{"variants":"七分づき/七分搗"},"七分搗":{"variants":"七分づき/七分搗"},"シチヘンゲ":{"variants":"シチヘンゲ/七変化"},"七変化":{"variants":"シチヘンゲ/七変化"},"七味唐がらし":{"variants":"七味唐がらし/七味唐辛し/七味唐辛子"},"七味唐辛し":{"variants":"七味唐がらし/七味唐辛し/七味唐辛子"},"七味唐辛子":{"variants":"七味唐がらし/七味唐辛し/七味唐辛子"},"シチメンチョウ":{"variants":"シチメンチョウ/七面鳥"},"七面鳥":{"variants":"シチメンチョウ/七面鳥"},"しちめんどうくさい":{"variants":"しちめんどうくさい/七面倒臭い"},"七面倒臭い":{"variants":"しちめんどうくさい/七面倒臭い"},"しっかい":{"variants":"しっかい/悉皆"},"悉皆":{"variants":"しっかい/悉皆"},"しっしゃ":{"variants":"しっしゃ/膝射"},"膝射":{"variants":"しっしゃ/膝射"},"湿しん":{"variants":"湿しん/湿疹"},"湿疹":{"variants":"湿しん/湿疹"},"叱声":{"variants":"しっ声/叱声"},"しっ声":{"variants":"しっ声/叱声"},"失そう":{"variants":"失そう/失踪"},"失踪":{"variants":"失そう/失踪"},"知ったかぶり":{"variants":"知ったかぶり/知ったか振り"},"知ったか振り":{"variants":"知ったかぶり/知ったか振り"},"しつけ糸":{"variants":"しつけ糸/仕付け糸/仕付糸/躾糸"},"仕付け糸":{"variants":"しつけ糸/仕付け糸/仕付糸"},"仕付糸":{"variants":"しつけ糸/仕付け糸/仕付糸"},"しつける":{"variants":"しつける/仕付ける"},"仕付ける":{"variants":"しつける/仕付ける"},"しつよう":{"variants":"しつよう/執よう/執拗"},"執よう":{"variants":"しつよう/執よう/執拗"},"執拗":{"variants":"しつよう/執よう/執拗"},"しつらえる":{"variants":"しつらえる/設える"},"設える":{"variants":"しつらえる/設える"},"してき":{"variants":"してき/史的/私的/詩的"},"しでかす":{"variants":"しでかす/為出かす/仕出かす"},"しとげる":{"variants":"しとげる/為遂げる"},"為遂げる":{"variants":"しとげる/為遂げる"},"しとめる":{"variants":"しとめる/仕留める"},"仕留める":{"variants":"しとめる/仕留める"},"しとやか":{"variants":"しとやか/淑やか"},"淑やか":{"variants":"しとやか/淑やか"},"しなう":{"variants":"しなう/撓う"},"撓う":{"variants":"しなう/撓う"},"しなす":{"variants":"しなす/為成す/死なす"},"シナノキ":{"variants":"シナノキ/科の木"},"科の木":{"variants":"シナノキ/科の木"},"しなびる":{"variants":"しなびる/萎びる"},"萎びる":{"variants":"しなびる/萎びる"},"しにおくれる":{"variants":"しにおくれる/死におくれる/死に後れる/死に遅れる"},"死におくれる":{"variants":"しにおくれる/死におくれる/死に後れる/死に遅れる"},"しにかける":{"variants":"しにかける/死にかける"},"死にかける":{"variants":"しにかける/死にかける"},"しにかわる":{"variants":"しにかわる/死に変る"},"死に変る":{"variants":"しにかわる/死に変る"},"死にガネ":{"variants":"死にガネ/死金"},"死金":{"variants":"死にガネ/死金"},"死に神":{"variants":"死に神/死神"},"死神":{"variants":"死に神/死神"},"死に際":{"variants":"死に際/死際"},"死際":{"variants":"死に際/死際"},"死に装束":{"variants":"死に装束/死装束"},"死装束":{"variants":"死に装束/死装束"},"しにせ":{"variants":"しにせ/老舗"},"老舗":{"variants":"しにせ/老舗"},"しにそこなう":{"variants":"しにそこなう/死にそこなう/死に損なう"},"死にそこなう":{"variants":"しにそこなう/死にそこなう/死に損なう"},"死に損なう":{"variants":"しにそこなう/死にそこなう/死に損なう"},"死にぞこない":{"variants":"死にぞこない/死に損ない"},"死に損ない":{"variants":"死にぞこない/死に損ない"},"しにたえる":{"variants":"しにたえる/死に絶える"},"死に絶える":{"variants":"しにたえる/死に絶える"},"しにはてる":{"variants":"しにはてる/死に果てる"},"死に果てる":{"variants":"しにはてる/死に果てる"},"死に場所":{"variants":"死に場所/死場所"},"死場所":{"variants":"死に場所/死場所"},"死に水":{"variants":"死に水/死水"},"死水":{"variants":"死に水/死水"},"死に目":{"variants":"死に目/死目"},"死目":{"variants":"死に目/死目"},"死にものぐるい":{"variants":"死にものぐるい/死物狂い"},"死物狂い":{"variants":"死にものぐるい/死物狂い"},"し尿":{"variants":"し尿/屎尿"},"屎尿":{"variants":"し尿/屎尿"},"しにわかれる":{"variants":"しにわかれる/死に別れる"},"死に別れる":{"variants":"しにわかれる/死に別れる"},"しぬ":{"variants":"しぬ/死ぬ"},"死ぬ":{"variants":"しぬ/死ぬ"},"しねる":{"variants":"しねる/死ねる"},"死ねる":{"variants":"しねる/死ねる"},"しのぎ":{"variants":"しのぎ/凌ぎ/鎬"},"しのぐ":{"variants":"しのぐ/凌ぐ"},"凌ぐ":{"variants":"しのぐ/凌ぐ"},"しのげる":{"variants":"しのげる/凌げる"},"凌げる":{"variants":"しのげる/凌げる"},"シノダケ":{"variants":"シノダケ/篠竹"},"篠竹":{"variants":"シノダケ/篠竹"},"しのばす":{"variants":"しのばす/忍ばす"},"忍ばす":{"variants":"しのばす/忍ばす"},"しのばせる":{"variants":"しのばせる/忍ばせる"},"忍ばせる":{"variants":"しのばせる/忍ばせる"},"忍び返し":{"variants":"忍び返し/忍返し"},"忍返し":{"variants":"忍び返し/忍返し"},"しのびこむ":{"variants":"しのびこむ/忍び込む"},"忍び込む":{"variants":"しのびこむ/忍び込む"},"しのびこめる":{"variants":"しのびこめる/忍び込める"},"忍び込める":{"variants":"しのびこめる/忍び込める"},"忍び泣き":{"variants":"忍び泣き/忍泣き"},"忍泣き":{"variants":"忍び泣き/忍泣き"},"しのびなく":{"variants":"しのびなく/忍び泣く"},"忍び泣く":{"variants":"しのびなく/忍び泣く"},"忍び音":{"variants":"忍び音/忍音"},"忍音":{"variants":"忍び音/忍音"},"しのびよる":{"variants":"しのびよる/忍び寄る"},"忍び寄る":{"variants":"しのびよる/忍び寄る"},"忍び笑い":{"variants":"忍び笑い/忍笑い"},"忍笑い":{"variants":"忍び笑い/忍笑い"},"しのぶ":{"variants":"しのぶ/偲ぶ/忍ぶ"},"シノブグサ":{"variants":"シノブグサ/忍草"},"忍草":{"variants":"シノブグサ/忍草"},"しのべる":{"variants":"しのべる/偲べる/忍べる"},"支払":{"variants":"支払/支払い"},"支払い":{"variants":"支払/支払い"},"しはらう":{"variants":"しはらう/支払う"},"支払う":{"variants":"しはらう/支払う"},"しはらえる":{"variants":"しはらえる/支払える"},"支払える":{"variants":"しはらえる/支払える"},"シバ":{"variants":"シバ/柴/芝"},"しば犬":{"variants":"しば犬/シバイヌ/柴犬"},"シバイヌ":{"variants":"しば犬/シバイヌ/柴犬"},"柴犬":{"variants":"しば犬/シバイヌ/柴犬"},"シバエビ":{"variants":"シバエビ/芝蝦/芝海老"},"柴刈り":{"variants":"柴刈/柴刈り"},"柴刈":{"variants":"柴刈/柴刈り"},"シバグリ":{"variants":"シバグリ/柴栗"},"柴栗":{"variants":"シバグリ/柴栗"},"屡":{"variants":"屡/屡々"},"屡々":{"variants":"屡/屡々"},"しばりあげる":{"variants":"しばりあげる/しばり上げる/縛りあげる/縛り上げる"},"しばり上げる":{"variants":"しばりあげる/しばり上げる/縛りあげる/縛り上げる"},"縛りあげる":{"variants":"しばりあげる/しばり上げる/縛りあげる/縛り上げる"},"縛り上げる":{"variants":"しばりあげる/しばり上げる/縛りあげる/縛り上げる"},"縛り首":{"variants":"縛り首/縛首"},"縛首":{"variants":"縛り首/縛首"},"しばりつける":{"variants":"しばりつける/縛りつける/縛り付ける"},"縛りつける":{"variants":"しばりつける/縛りつける/縛り付ける"},"縛り付ける":{"variants":"しばりつける/縛りつける/縛り付ける"},"しばる":{"variants":"しばる/縛る"},"縛る":{"variants":"しばる/縛る"},"しばれる":{"variants":"しばれる/縛れる"},"縛れる":{"variants":"しばれる/縛れる"},"シビ":{"variants":"シビ/鴟尾"},"鴟尾":{"variants":"シビ/鴟尾"},"シビリアン・コントロール":{"variants":"シビリアン・コントロール/シビリアンコントロール"},"シビリアンコントロール":{"variants":"シビリアン・コントロール/シビリアンコントロール"},"しびれ":{"variants":"しびれ/痺れ"},"痺れ":{"variants":"しびれ/痺れ"},"しびれる":{"variants":"しびれる/痺れる"},"痺れる":{"variants":"しびれる/痺れる"},"しびん":{"variants":"しびん/尿瓶"},"尿瓶":{"variants":"しびん/尿瓶"},"しぶい":{"variants":"しぶい/渋い"},"渋い":{"variants":"しぶい/渋い"},"しぶ皮":{"variants":"しぶ皮/渋皮"},"渋皮":{"variants":"しぶ皮/渋皮"},"しぶしぶ":{"variants":"しぶしぶ/渋々/渋渋"},"渋々":{"variants":"しぶしぶ/渋々/渋渋"},"渋渋":{"variants":"しぶしぶ/渋々/渋渋"},"しぶっ面":{"variants":"しぶっ面/渋っつら/渋っ面"},"渋っつら":{"variants":"しぶっ面/渋っつら/渋っ面"},"渋っ面":{"variants":"しぶっ面/渋っつら/渋っ面"},"しぶる":{"variants":"しぶる/渋る"},"渋る":{"variants":"しぶる/渋る"},"しぼむ":{"variants":"しぼむ/萎む/凋む"},"しぼりあげる":{"variants":"しぼりあげる/しぼり上げる/絞りあげる/絞り上げる/搾り上げる"},"しぼり上げる":{"variants":"しぼりあげる/しぼり上げる/絞りあげる/絞り上げる/搾り上げる"},"絞り上げる":{"variants":"しぼりあげる/しぼり上げる/絞りあげる/絞り上げる"},"絞りあげる":{"variants":"しぼりあげる/しぼり上げる/絞りあげる/絞り上げる"},"絞り染め":{"variants":"絞り染め/絞染"},"絞染":{"variants":"絞り染め/絞染"},"しぼりだす":{"variants":"しぼりだす/絞り出す"},"絞り出す":{"variants":"しぼりだす/絞り出す"},"しぼりだせる":{"variants":"しぼりだせる/絞り出せる"},"絞り出せる":{"variants":"しぼりだせる/絞り出せる"},"しぼりとる":{"variants":"しぼりとる/搾り取る"},"搾り取る":{"variants":"しぼりとる/搾り取る"},"しぼりとれる":{"variants":"しぼりとれる/搾り取れる"},"搾り取れる":{"variants":"しぼりとれる/搾り取れる"},"しぼる":{"variants":"しぼる/絞る/搾る"},"しぼれる":{"variants":"しぼれる/絞れる/搾れる"},"しま":{"variants":"しま/シマ/死魔/縞/島"},"シマ":{"variants":"しま/シマ/死魔/縞/島"},"仕舞い":{"variants":"仕舞/仕舞い"},"仕舞":{"variants":"仕舞/仕舞い"},"しまう":{"variants":"しまう/仕舞う"},"仕舞う":{"variants":"しまう/仕舞う"},"シマウマ":{"variants":"シマウマ/縞馬"},"縞馬":{"variants":"シマウマ/縞馬"},"シマカ":{"variants":"シマカ/縞蚊"},"縞蚊":{"variants":"シマカ/縞蚊"},"しま柄":{"variants":"しま柄/縞柄"},"縞柄":{"variants":"しま柄/縞柄"},"シマヘビ":{"variants":"シマヘビ/縞蛇"},"縞蛇":{"variants":"シマヘビ/縞蛇"},"しまり屋":{"variants":"しまり屋/締まり屋/締り屋"},"締まり屋":{"variants":"しまり屋/締まり屋/締り屋"},"締り屋":{"variants":"しまり屋/締まり屋/締り屋"},"しまる":{"variants":"しまる/絞まる/締まる/閉まる"},"シミ":{"variants":"シミ/衣魚/紙魚/染み/凍み"},"しみいる":{"variants":"しみいる/染み入る/染入る"},"染み入る":{"variants":"しみいる/染み入る/染入る"},"染入る":{"variants":"しみいる/染み入る/染入る"},"しみこむ":{"variants":"しみこむ/染み込む/染込む"},"染み込む":{"variants":"しみこむ/染み込む/染込む"},"染込む":{"variants":"しみこむ/染み込む/染込む"},"しみつく":{"variants":"しみつく/染みつく/染み着く/染み付く/染付く"},"染みつく":{"variants":"しみつく/染みつく/染み着く/染み付く/染付く"},"染付く":{"variants":"しみつく/染みつく/染み付く/染付く"},"染み付く":{"variants":"しみつく/染みつく/染み付く/染付く"},"しみとおる":{"variants":"しみとおる/染みとおる/染み透る/染透る"},"染みとおる":{"variants":"しみとおる/染みとおる/染み透る/染透る"},"染み透る":{"variants":"しみとおる/染みとおる/染み透る/染透る"},"染透る":{"variants":"しみとおる/染みとおる/染み透る/染透る"},"しみ抜き":{"variants":"しみ抜き/染み抜き"},"染み抜き":{"variants":"しみ抜き/染み抜き"},"染みぬき":{"variants":"染みぬき/染抜き"},"染抜き":{"variants":"染みぬき/染抜き"},"しみる":{"variants":"しみる/染みる/凍みる/沁みる/滲みる"},"しみわたる":{"variants":"しみわたる/染み渡る"},"染み渡る":{"variants":"しみわたる/染み渡る"},"しむ":{"variants":"しむ/染む/凍む/沁む"},"仕向":{"variants":"仕向/仕向け"},"仕向け":{"variants":"仕向/仕向け"},"しむける":{"variants":"しむける/仕向ける"},"仕向ける":{"variants":"しむける/仕向ける"},"締め":{"variants":"締/締め"},"締":{"variants":"締/締め"},"しめ飾り":{"variants":"しめ飾り/注連飾り"},"注連飾り":{"variants":"しめ飾り/注連飾り"},"搾めかす":{"variants":"搾めかす/搾め滓"},"搾め滓":{"variants":"搾めかす/搾め滓"},"締め金":{"variants":"締め金/締金"},"締金":{"variants":"締め金/締金"},"締切り":{"variants":"締め切り/締切/締切り"},"締切":{"variants":"締め切り/締切/締切り"},"締め切り":{"variants":"締め切り/締切/締切り"},"しめきる":{"variants":"しめきる/しめ切る/締め切る/締切る/閉め切る"},"しめ切る":{"variants":"しめきる/しめ切る/締め切る/締切る/閉め切る"},"締切る":{"variants":"しめきる/しめ切る/締め切る/締切る"},"締め切る":{"variants":"しめきる/しめ切る/締め切る/締切る"},"締めくくり":{"variants":"締めくくり/締め括り"},"締め括り":{"variants":"締めくくり/締め括り"},"しめくくる":{"variants":"しめくくる/締めくくる/締め括る"},"締めくくる":{"variants":"しめくくる/締めくくる/締め括る"},"締め括る":{"variants":"しめくくる/締めくくる/締め括る"},"しめころす":{"variants":"しめころす/しめ殺す/絞め殺す/締め殺す"},"しめ殺す":{"variants":"しめころす/しめ殺す/絞め殺す/締め殺す"},"しめしあわす":{"variants":"しめしあわす/示し合わす"},"示し合わす":{"variants":"しめしあわす/示し合わす"},"しめしあわせる":{"variants":"しめしあわせる/示しあわせる/示し合せる/示し合わせる"},"示しあわせる":{"variants":"しめしあわせる/示しあわせる/示し合せる/示し合わせる"},"示し合せる":{"variants":"しめしあわせる/示しあわせる/示し合せる/示し合わせる"},"示し合わせる":{"variants":"しめしあわせる/示しあわせる/示し合せる/示し合わせる"},"しめす":{"variants":"しめす/示す/湿す"},"しめせる":{"variants":"しめせる/示せる"},"示せる":{"variants":"しめせる/示せる"},"締め高":{"variants":"締め高/締高"},"締高":{"variants":"締め高/締高"},"しめだす":{"variants":"しめだす/締め出す/締出す/閉め出す"},"締出す":{"variants":"しめだす/締め出す/締出す"},"締め出す":{"variants":"しめだす/締め出す/締出す"},"しめっぽい":{"variants":"しめっぽい/湿っぽい"},"湿っぽい":{"variants":"しめっぽい/湿っぽい"},"しめつける":{"variants":"しめつける/締めつける/締め付ける/締付ける"},"締めつける":{"variants":"しめつける/締めつける/締め付ける/締付ける"},"締め付ける":{"variants":"しめつける/締めつける/締め付ける/締付ける"},"締付ける":{"variants":"しめつける/締めつける/締め付ける/締付ける"},"しめて":{"variants":"しめて/締めて"},"締めて":{"variants":"しめて/締めて"},"しめ縄":{"variants":"しめ縄/七五三縄/注連縄/標縄"},"しめる":{"variants":"しめる/湿る"},"湿る":{"variants":"しめる/湿る"},"しめんそか":{"variants":"しめんそか/四面楚歌"},"四面楚歌":{"variants":"しめんそか/四面楚歌"},"しもがかる":{"variants":"しもがかる/下掛る"},"下掛る":{"variants":"しもがかる/下掛る"},"霜枯れどき":{"variants":"霜枯れどき/霜枯れ時/霜枯時"},"霜枯れ時":{"variants":"霜枯れどき/霜枯れ時/霜枯時"},"霜枯時":{"variants":"霜枯れどき/霜枯れ時/霜枯時"},"しもがれる":{"variants":"しもがれる/霜枯れる"},"霜枯れる":{"variants":"しもがれる/霜枯れる"},"下々":{"variants":"下々/下下"},"下下":{"variants":"下々/下下"},"霜どけ":{"variants":"霜どけ/霜解け/霜融け"},"霜ふり":{"variants":"霜ふり/霜降り"},"霜降り":{"variants":"霜ふり/霜降り"},"シャイ":{"variants":"シャイ/謝意"},"謝意":{"variants":"シャイ/謝意"},"遮音":{"variants":"しゃ音/遮音"},"しゃ音":{"variants":"しゃ音/遮音"},"シャガ":{"variants":"シャガ/胡蝶花/射干"},"しゃく":{"variants":"しゃく/勺/尺/酌/癪/笏"},"しゃくう":{"variants":"しゃくう/杓う"},"杓う":{"variants":"しゃくう/杓う"},"しゃくし定規":{"variants":"しゃくし定規/杓子定規"},"杓子定規":{"variants":"しゃくし定規/杓子定規"},"シャクシナ":{"variants":"シャクシナ/杓子菜"},"杓子菜":{"variants":"シャクシナ/杓子菜"},"綽々":{"variants":"綽々/綽綽"},"綽綽":{"variants":"綽々/綽綽"},"しゃくぜんと":{"variants":"しゃくぜんと/釈然と"},"釈然と":{"variants":"しゃくぜんと/釈然と"},"シャクトリムシ":{"variants":"シャクトリムシ/尺取り虫/尺取虫"},"尺取り虫":{"variants":"シャクトリムシ/尺取り虫/尺取虫"},"尺取虫":{"variants":"シャクトリムシ/尺取り虫/尺取虫"},"しゃくなげ":{"variants":"しゃくなげ/シャクナゲ/石南花/石楠花"},"シャクナゲ":{"variants":"しゃくなげ/シャクナゲ/石南花/石楠花"},"しゃく熱":{"variants":"しゃく熱/灼熱"},"灼熱":{"variants":"しゃく熱/灼熱"},"シャクヤク":{"variants":"シャクヤク/芍薬"},"芍薬":{"variants":"シャクヤク/芍薬"},"しゃくりあげる":{"variants":"しゃくりあげる/しゃくり上げる"},"しゃくり上げる":{"variants":"しゃくりあげる/しゃくり上げる"},"シャケ":{"variants":"シャケ/社家"},"社家":{"variants":"シャケ/社家"},"シャコ":{"variants":"シャコ/蝦蛄/車庫"},"洒々落々":{"variants":"洒々落々/洒洒落落"},"洒洒落落":{"variants":"洒々落々/洒洒落落"},"しゃしゃりでる":{"variants":"しゃしゃりでる/しゃしゃり出る"},"しゃしゃり出る":{"variants":"しゃしゃりでる/しゃしゃり出る"},"しゃする":{"variants":"しゃする/謝する"},"謝する":{"variants":"しゃする/謝する"},"しゃだつ":{"variants":"しゃだつ/しゃ脱/洒脱"},"しゃ脱":{"variants":"しゃだつ/しゃ脱/洒脱"},"洒脱":{"variants":"しゃだつ/しゃ脱/洒脱"},"しゃちこばる":{"variants":"しゃちこばる/しゃちこ張る"},"しゃちこ張る":{"variants":"しゃちこばる/しゃちこ張る"},"しゃちほこばる":{"variants":"しゃちほこばる/鯱張る"},"鯱張る":{"variants":"しゃちほこばる/鯱張る"},"借金取":{"variants":"借金取/借金取り"},"借金取り":{"variants":"借金取/借金取り"},"しゃっちょこばる":{"variants":"しゃっちょこばる/しゃっちょこ張る"},"しゃっちょこ張る":{"variants":"しゃっちょこばる/しゃっちょこ張る"},"しゃにむに":{"variants":"しゃにむに/遮二無二"},"遮二無二":{"variants":"しゃにむに/遮二無二"},"しゃぶしゃぶ":{"variants":"しゃぶしゃぶ/シャブシャブ"},"シャブシャブ":{"variants":"しゃぶしゃぶ/シャブシャブ"},"遮へい":{"variants":"遮へい/遮蔽"},"遮蔽":{"variants":"遮へい/遮蔽"},"しゃべる":{"variants":"しゃべる/喋る"},"喋る":{"variants":"しゃべる/喋る"},"しゃべれる":{"variants":"しゃべれる/喋れる"},"喋れる":{"variants":"しゃべれる/喋れる"},"しゃぼん":{"variants":"しゃぼん/シャボン"},"シャボン":{"variants":"しゃぼん/シャボン"},"しゃも":{"variants":"しゃも/シャモ/軍鶏"},"シャモ":{"variants":"しゃも/シャモ/軍鶏"},"軍鶏":{"variants":"しゃも/シャモ/軍鶏"},"しゃらくさい":{"variants":"しゃらくさい/洒落臭い"},"洒落臭い":{"variants":"しゃらくさい/洒落臭い"},"しゃれる":{"variants":"しゃれる/シャレる/洒落る/洒落れる"},"シャレる":{"variants":"しゃれる/シャレる/洒落る/洒落れる"},"洒落る":{"variants":"しゃれる/シャレる/洒落る/洒落れる"},"洒落れる":{"variants":"しゃれる/シャレる/洒落る/洒落れる"},"しゃんしゃん":{"variants":"しゃんしゃん/シャンシャン"},"シャンシャン":{"variants":"しゃんしゃん/シャンシャン"},"終演":{"variants":"終えん/終演"},"終えん":{"variants":"終えん/終演"},"シュウカイドウ":{"variants":"シュウカイドウ/秋海棠"},"秋海棠":{"variants":"シュウカイドウ/秋海棠"},"しゅう球":{"variants":"しゅう球/蹴球"},"蹴球":{"variants":"しゅう球/蹴球"},"しゅうし":{"variants":"しゅうし/終始"},"終始":{"variants":"しゅうし/終始"},"しゅうしいっかん":{"variants":"しゅうしいっかん/終始一貫"},"終始一貫":{"variants":"しゅうしいっかん/終始一貫"},"しゅうしゅう":{"variants":"しゅうしゅう/啾々/啾啾"},"啾々":{"variants":"しゅうしゅう/啾々/啾啾"},"啾啾":{"variants":"しゅうしゅう/啾々/啾啾"},"しゅうする":{"variants":"しゅうする/修する"},"修する":{"variants":"しゅうする/修する"},"しゅうち":{"variants":"しゅうち/習知/衆知/衆智/羞恥"},"しゅう恥心":{"variants":"しゅう恥心/羞恥心"},"羞恥心":{"variants":"しゅう恥心/羞恥心"},"しゅう長":{"variants":"しゅう長/酋長"},"酋長":{"variants":"しゅう長/酋長"},"しゅうねんぶかい":{"variants":"しゅうねんぶかい/執念深い"},"執念深い":{"variants":"しゅうねんぶかい/執念深い"},"収れん":{"variants":"収れん/収斂"},"収斂":{"variants":"収れん/収斂"},"粛々":{"variants":"粛々/粛粛"},"粛粛":{"variants":"粛々/粛粛"},"しゅくす":{"variants":"しゅくす/祝す"},"祝す":{"variants":"しゅくす/祝す"},"しゅくする":{"variants":"しゅくする/祝する"},"祝する":{"variants":"しゅくする/祝する"},"種々相":{"variants":"種々相/種種相"},"種種相":{"variants":"種々相/種種相"},"シュッコンソウ":{"variants":"シュッコンソウ/宿根草"},"宿根草":{"variants":"シュッコンソウ/宿根草"},"しゅとして":{"variants":"しゅとして/主として"},"主として":{"variants":"しゅとして/主として"},"しゅび":{"variants":"しゅび/首尾/麈尾"},"しゅもく":{"variants":"しゅもく/種目/撞木"},"しゅよう":{"variants":"しゅよう/主用/腫瘍/須要"},"手りゅう弾":{"variants":"手りゅう弾/手榴弾"},"手榴弾":{"variants":"手りゅう弾/手榴弾"},"シュロ":{"variants":"シュロ/棕櫚"},"棕櫚":{"variants":"シュロ/棕櫚"},"シュンギク":{"variants":"シュンギク/春菊"},"春菊":{"variants":"シュンギク/春菊"},"竣工":{"variants":"しゅん工/竣工"},"しゅん工":{"variants":"しゅん工/竣工"},"しゅん巡":{"variants":"しゅん巡/逡巡"},"逡巡":{"variants":"しゅん巡/逡巡"},"しゅんせつ":{"variants":"しゅんせつ/浚渫"},"浚渫":{"variants":"しゅんせつ/浚渫"},"しゅんせつ船":{"variants":"しゅんせつ船/浚渫船"},"浚渫船":{"variants":"しゅんせつ船/浚渫船"},"しゅん別":{"variants":"しゅん別/峻別"},"峻別":{"variants":"しゅん別/峻別"},"シュンラン":{"variants":"シュンラン/春蘭"},"春蘭":{"variants":"シュンラン/春蘭"},"しょい上げ":{"variants":"しょい上げ/背負い上げ"},"背負い上げ":{"variants":"しょい上げ/背負い上げ"},"しょいこむ":{"variants":"しょいこむ/しょい込む"},"しょい込む":{"variants":"しょいこむ/しょい込む"},"しょい投げ":{"variants":"しょい投げ/背負い投げ"},"背負い投げ":{"variants":"しょい投げ/背負い投げ"},"書院造":{"variants":"書院造/書院造り"},"書院造り":{"variants":"書院造/書院造り"},"ショウ":{"variants":"ショウ/升/商/将/小/省/章/賞/荘/笙/簫"},"少尉":{"variants":"少い/少尉"},"少い":{"variants":"すくない/少い/少ない"},"消化腺":{"variants":"消化せん/消化腺"},"消化せん":{"variants":"消化せん/消化腺"},"しょうが":{"variants":"しょうが/ショウガ/小我/生姜/生薑"},"ショウガ":{"variants":"しょうが/ショウガ/小我/生姜/生薑"},"ショウガクボウ":{"variants":"ショウガクボウ/正覚坊"},"正覚坊":{"variants":"ショウガクボウ/正覚坊"},"ショウキンルイ":{"variants":"ショウキンルイ/渉禽類"},"渉禽類":{"variants":"ショウキンルイ/渉禽類"},"しょうこう水":{"variants":"しょうこう水/昇汞水"},"昇汞水":{"variants":"しょうこう水/昇汞水"},"しょうこだてる":{"variants":"しょうこだてる/証拠立てる"},"証拠立てる":{"variants":"しょうこだてる/証拠立てる"},"悄悄":{"variants":"悄々/悄悄"},"悄々":{"variants":"悄々/悄悄"},"蕭蕭":{"variants":"蕭々/蕭蕭"},"蕭々":{"variants":"蕭々/蕭蕭"},"小心翼々":{"variants":"小心翼々/小心翼翼"},"小心翼翼":{"variants":"小心翼々/小心翼翼"},"しょうじいれる":{"variants":"しょうじいれる/請じ入れる"},"請じ入れる":{"variants":"しょうじいれる/請じ入れる"},"ショウジョウ":{"variants":"ショウジョウ/商状/小乗/掌上/症状/賞状/生生/猩々/猩猩/蕭条/霄壌"},"猩々":{"variants":"ショウジョウ/猩々/猩猩"},"猩猩":{"variants":"ショウジョウ/猩々/猩猩"},"生々世々":{"variants":"生々世々/生生世世"},"生生世世":{"variants":"生々世々/生生世世"},"ショウジョウバエ":{"variants":"ショウジョウバエ/猩々蝿/猩猩蝿"},"猩々蝿":{"variants":"ショウジョウバエ/猩々蝿/猩猩蝿"},"猩猩蝿":{"variants":"ショウジョウバエ/猩々蝿/猩猩蝿"},"猩々緋":{"variants":"猩々緋/猩猩緋"},"猩猩緋":{"variants":"猩々緋/猩猩緋"},"しょうじる":{"variants":"しょうじる/生じる"},"生じる":{"variants":"しょうじる/生じる"},"精進揚":{"variants":"精進揚/精進揚げ"},"精進揚げ":{"variants":"精進揚/精進揚げ"},"しょうする":{"variants":"しょうする/称する/証する/賞する/請する/誦する/頌する"},"しょうずる":{"variants":"しょうずる/招ずる/生ずる"},"小、中学生":{"variants":"小、中学生/小・中学生/小中学生"},"小・中学生":{"variants":"小、中学生/小・中学生/小中学生"},"小中学生":{"variants":"小、中学生/小・中学生/小中学生"},"小・中学校":{"variants":"小・中学校/小中学校"},"小中学校":{"variants":"小・中学校/小中学校"},"賞はい":{"variants":"賞はい/賞杯/賞盃/賞牌"},"賞杯":{"variants":"賞はい/賞杯"},"賞盃":{"variants":"賞はい/賞盃"},"賞牌":{"variants":"賞はい/賞牌"},"しょうび":{"variants":"しょうび/ショウビ/焦び/焦眉"},"ショウビ":{"variants":"しょうび/ショウビ/焦び/焦眉"},"焦び":{"variants":"しょうび/ショウビ/焦び/焦眉"},"焦眉":{"variants":"しょうび/ショウビ/焦び/焦眉"},"しょう婦":{"variants":"しょう婦/娼婦"},"娼婦":{"variants":"しょう婦/娼婦"},"しょうぶ":{"variants":"しょうぶ/ショウブ/尚武/菖蒲"},"ショウブ":{"variants":"しょうぶ/ショウブ/尚武/菖蒲"},"しょうぶ湯":{"variants":"しょうぶ湯/菖蒲湯"},"菖蒲湯":{"variants":"しょうぶ湯/菖蒲湯"},"招へい":{"variants":"招へい/招聘"},"招聘":{"variants":"招へい/招聘"},"しょうゆ":{"variants":"しょうゆ/しょう油/醤油"},"しょう油":{"variants":"しょうゆ/しょう油/醤油"},"醤油":{"variants":"しょうゆ/しょう油/醤油"},"ショウロ":{"variants":"ショウロ/捷路/松露"},"諸掛かり":{"variants":"諸掛かり/諸掛り"},"諸掛り":{"variants":"諸掛かり/諸掛り"},"食あたり":{"variants":"食あたり/食中り"},"食中り":{"variants":"食あたり/食中り"},"しょく罪":{"variants":"しょく罪/贖罪"},"贖罪":{"variants":"しょく罪/贖罪"},"しょくする":{"variants":"しょくする/嘱する/食する/蝕する"},"しょく台":{"variants":"しょく台/燭台"},"燭台":{"variants":"しょく台/燭台"},"ショクヨウガエル":{"variants":"ショクヨウガエル/食用蛙"},"食用蛙":{"variants":"ショクヨウガエル/食用蛙"},"しょげかえる":{"variants":"しょげかえる/悄気返る"},"悄気返る":{"variants":"しょげかえる/悄気返る"},"しょげこむ":{"variants":"しょげこむ/悄気込む"},"悄気込む":{"variants":"しょげこむ/悄気込む"},"しょげる":{"variants":"しょげる/悄げる"},"悄げる":{"variants":"しょげる/悄げる"},"しょざいない":{"variants":"しょざいない/所在無い"},"所在無い":{"variants":"しょざいない/所在無い"},"処処":{"variants":"ところどころ/処々/処処"},"処々":{"variants":"ところどころ/処々/処処"},"しょする":{"variants":"しょする/処する/署する/書する"},"しょせん":{"variants":"しょせん/所せん/所詮"},"所せん":{"variants":"しょせん/所せん/所詮"},"所詮":{"variants":"しょせん/所せん/所詮"},"しょたいじみる":{"variants":"しょたいじみる/所帯染みる/世帯染みる"},"所帯持":{"variants":"所帯持/所帯持ち"},"所帯持ち":{"variants":"所帯持/所帯持ち"},"初っ切り":{"variants":"初っ切り/初切"},"初切":{"variants":"初っ切り/初切"},"しょっぱい":{"variants":"しょっぱい/塩っぱい"},"塩っぱい":{"variants":"しょっぱい/塩っぱい"},"しょっぱな":{"variants":"しょっぱな/初っぱな/初っ端/初端"},"初っぱな":{"variants":"しょっぱな/初っぱな/初っ端/初端"},"初っ端":{"variants":"しょっぱな/初っぱな/初っ端/初端"},"初端":{"variants":"しょっぱな/初っぱな/初っ端/初端"},"しょ糖":{"variants":"しょ糖/蔗糖"},"蔗糖":{"variants":"しょ糖/蔗糖"},"処方せん":{"variants":"処方せん/処方箋"},"処方箋":{"variants":"処方せん/処方箋"},"しょぼぬれる":{"variants":"しょぼぬれる/しょぼ濡れる"},"しょぼ濡れる":{"variants":"しょぼぬれる/しょぼ濡れる"},"しよう":{"variants":"しよう/仕様/姿容/子葉/至要"},"シラウオ":{"variants":"シラウオ/白魚"},"白魚":{"variants":"シラウオ/白魚"},"シラカシ":{"variants":"シラカシ/白樫"},"白樫":{"variants":"シラカシ/白樫"},"白髪染":{"variants":"白髪染/白髪染め"},"白髪染め":{"variants":"白髪染/白髪染め"},"しらける":{"variants":"しらける/シラケる/白ける"},"シラケる":{"variants":"しらける/シラケる/白ける"},"白ける":{"variants":"しらける/シラケる/白ける"},"しらげる":{"variants":"しらげる/精げる"},"精げる":{"variants":"しらげる/精げる"},"シラサギ":{"variants":"シラサギ/白鷺"},"白鷺":{"variants":"シラサギ/白鷺"},"白々明け":{"variants":"白々明け/白白明け"},"白白明け":{"variants":"白々明け/白白明け"},"しらじらしい":{"variants":"しらじらしい/白々しい/白白しい"},"白々しい":{"variants":"しらじらしい/白々しい/白白しい"},"白白しい":{"variants":"しらじらしい/白々しい/白白しい"},"しらす":{"variants":"しらす/知らす"},"知らす":{"variants":"しらす/知らす"},"シラス":{"variants":"シラス/白州/白洲"},"知らずがお":{"variants":"知らずがお/知らず顔"},"知らず顔":{"variants":"知らずがお/知らず顔"},"しらせ":{"variants":"しらせ/知らせ/報せ"},"しらせる":{"variants":"しらせる/知らせる/報せる"},"シラタマ":{"variants":"シラタマ/白玉"},"白玉":{"variants":"シラタマ/白玉"},"シラタマツバキ":{"variants":"シラタマツバキ/白玉椿"},"白玉椿":{"variants":"シラタマツバキ/白玉椿"},"しらちゃける":{"variants":"しらちゃける/白茶ける"},"白茶ける":{"variants":"しらちゃける/白茶ける"},"しらべの緒":{"variants":"しらべの緒/調の緒"},"調の緒":{"variants":"しらべの緒/調の緒"},"しらべる":{"variants":"しらべる/調べる"},"調べる":{"variants":"しらべる/調べる"},"シラミ":{"variants":"シラミ/虱/蝨"},"しらむ":{"variants":"しらむ/白む"},"白む":{"variants":"しらむ/白む"},"シラン":{"variants":"シラン/紫蘭/白及"},"知らんかお":{"variants":"知らんかお/知らん顔"},"知らん顔":{"variants":"知らんかお/知らん顔"},"知らんぷり":{"variants":"知らんぷり/知らん振り"},"知らん振り":{"variants":"知らんぷり/知らん振り"},"しり":{"variants":"しり/私利/尻/臀"},"知りあい":{"variants":"知りあい/知り合い/知合/知合い"},"知り合い":{"variants":"知りあい/知り合い/知合/知合い"},"知合":{"variants":"知りあい/知り合い/知合/知合い"},"知合い":{"variants":"知りあい/知り合い/知合/知合い"},"しりあう":{"variants":"しりあう/知り合う/知合う"},"知り合う":{"variants":"しりあう/知り合う/知合う"},"知合う":{"variants":"しりあう/知り合う/知合う"},"しりあえる":{"variants":"しりあえる/知り合える"},"知り合える":{"variants":"しりあえる/知り合える"},"しり上がり":{"variants":"しり上がり/尻上がり/尻上り"},"尻上がり":{"variants":"しり上がり/尻上がり/尻上り"},"尻上り":{"variants":"しり上がり/尻上がり/尻上り"},"しり馬":{"variants":"しり馬/尻馬"},"尻馬":{"variants":"しり馬/尻馬"},"しり切れとんぼ":{"variants":"しり切れとんぼ/尻切れとんぼ/尻切れ蜻蛉"},"尻切れとんぼ":{"variants":"しり切れとんぼ/尻切れとんぼ/尻切れ蜻蛉"},"尻切れ蜻蛉":{"variants":"しり切れとんぼ/尻切れとんぼ/尻切れ蜻蛉"},"しりこそばい":{"variants":"しりこそばい/尻こそばい"},"尻こそばい":{"variants":"しりこそばい/尻こそばい"},"しりごみ":{"variants":"しりごみ/しり込み/後込み/尻ごみ/尻込み"},"しり込み":{"variants":"しりごみ/しり込み/後込み/尻ごみ/尻込み"},"尻込み":{"variants":"しりごみ/しり込み/尻ごみ/尻込み"},"尻ごみ":{"variants":"しりごみ/しり込み/尻ごみ/尻込み"},"しり下がり":{"variants":"しり下がり/尻下り"},"尻下り":{"variants":"しり下がり/尻下り"},"しりぞける":{"variants":"しりぞける/斥ける"},"斥ける":{"variants":"しりぞける/斥ける"},"しりぬく":{"variants":"しりぬく/知りぬく/知り抜く/知抜く"},"知りぬく":{"variants":"しりぬく/知りぬく/知り抜く/知抜く"},"知り抜く":{"variants":"しりぬく/知りぬく/知り抜く/知抜く"},"知抜く":{"variants":"しりぬく/知りぬく/知り抜く/知抜く"},"しり抜け":{"variants":"しり抜け/尻抜け"},"尻抜け":{"variants":"しり抜け/尻抜け"},"しりめ":{"variants":"しりめ/しり目/後目/尻目"},"しり目":{"variants":"しりめ/しり目/後目/尻目"},"尻もち":{"variants":"尻もち/尻餅"},"尻餅":{"variants":"尻もち/尻餅"},"しる":{"variants":"しる/知る"},"知る":{"variants":"しる/知る"},"しるい":{"variants":"しるい/著い"},"著い":{"variants":"しるい/著い"},"しるこ":{"variants":"しるこ/汁粉"},"汁粉":{"variants":"しるこ/汁粉"},"しるし":{"variants":"しるし/徴"},"徴":{"variants":"しるし/徴"},"印ばんてん":{"variants":"印ばんてん/印半纏"},"印半纏":{"variants":"印ばんてん/印半纏"},"しるす":{"variants":"しるす/印す/記す/標す"},"しるせる":{"variants":"しるせる/印せる/記せる"},"導べ":{"variants":"導/導べ"},"導":{"variants":"導/導べ"},"汁もの":{"variants":"汁もの/汁物"},"汁物":{"variants":"汁もの/汁物"},"し烈":{"variants":"し烈/シ烈/熾烈"},"シ烈":{"variants":"し烈/シ烈/熾烈"},"熾烈":{"variants":"し烈/シ烈/熾烈"},"痴れもの":{"variants":"痴れもの/痴れ者"},"痴れ者":{"variants":"痴れもの/痴れ者"},"しれる":{"variants":"しれる/知れる/痴れる"},"しれわたる":{"variants":"しれわたる/知れ渡る"},"知れ渡る":{"variants":"しれわたる/知れ渡る"},"シロ":{"variants":"シロ/城"},"城":{"variants":"シロ/城"},"シロアリ":{"variants":"シロアリ/白蟻"},"白蟻":{"variants":"シロアリ/白蟻"},"白あん":{"variants":"白あん/白餡"},"白餡":{"variants":"白あん/白餡"},"しろい":{"variants":"しろい/白い"},"白い":{"variants":"しろい/白い"},"シロウオ":{"variants":"シロウオ/素魚"},"素魚":{"variants":"シロウオ/素魚"},"しろうと":{"variants":"しろうと/素人"},"素人":{"variants":"しろうと/素人"},"シロウリ":{"variants":"シロウリ/白瓜"},"白瓜":{"variants":"シロウリ/白瓜"},"しろかき":{"variants":"しろかき/代かき/代掻き"},"代かき":{"variants":"しろかき/代かき/代掻き"},"代掻き":{"variants":"しろかき/代かき/代掻き"},"しろしめす":{"variants":"しろしめす/知ろしめす/知ろし食す"},"知ろしめす":{"variants":"しろしめす/知ろしめす/知ろし食す"},"知ろし食す":{"variants":"しろしめす/知ろしめす/知ろし食す"},"しろじろと":{"variants":"しろじろと/白白と"},"白白と":{"variants":"しろじろと/白白と"},"しろっぽい":{"variants":"しろっぽい/白っぽい"},"白っぽい":{"variants":"しろっぽい/白っぽい"},"シロネズミ":{"variants":"シロネズミ/白鼠"},"白鼠":{"variants":"シロネズミ/白鼠"},"シロヘビ":{"variants":"シロヘビ/白蛇"},"白蛇":{"variants":"シロヘビ/白蛇"},"白みそ":{"variants":"白みそ/白味噌"},"白味噌":{"variants":"白みそ/白味噌"},"白むく":{"variants":"白むく/白無垢"},"白無垢":{"variants":"白むく/白無垢"},"白め":{"variants":"白め/白目/白鑞"},"しわ":{"variants":"しわ/シワ/史話/私話/詩話/皴/皺"},"シワ":{"variants":"しわ/シワ/史話/私話/詩話/皴/皺"},"しわい":{"variants":"しわい/吝い"},"吝い":{"variants":"しわい/吝い"},"しわくちゃ":{"variants":"しわくちゃ/皺くちゃ"},"皺くちゃ":{"variants":"しわくちゃ/皺くちゃ"},"しわける":{"variants":"しわける/仕分ける"},"仕分ける":{"variants":"しわける/仕分ける"},"しわめる":{"variants":"しわめる/皺める"},"皺める":{"variants":"しわめる/皺める"},"しわ寄せ":{"variants":"しわ寄せ/シワ寄せ"},"シワ寄せ":{"variants":"しわ寄せ/シワ寄せ"},"しわる":{"variants":"しわる/撓る"},"撓る":{"variants":"しわる/撓る"},"吝んぼう":{"variants":"吝んぼう/吝ん坊"},"吝ん坊":{"variants":"吝んぼう/吝ん坊"},"しん":{"variants":"しん/信/審/新/臣/芯"},"真打":{"variants":"真打/真打ち"},"真打ち":{"variants":"真打/真打ち"},"震かん":{"variants":"震かん/震撼"},"震撼":{"variants":"震かん/震撼"},"シンガー・ソングライター":{"variants":"シンガー・ソングライター/シンガーソングライター"},"シンガーソングライター":{"variants":"シンガー・ソングライター/シンガーソングライター"},"しんきくさい":{"variants":"しんきくさい/辛気臭い"},"辛気臭い":{"variants":"しんきくさい/辛気臭い"},"しんきゅう":{"variants":"しんきゅう/しん灸/新旧/鍼灸"},"鍼灸":{"variants":"しんきゅう/しん灸/鍼灸"},"しん灸":{"variants":"しんきゅう/しん灸/鍼灸"},"しんきゅうし":{"variants":"しんきゅうし/鍼灸師"},"鍼灸師":{"variants":"しんきゅうし/鍼灸師"},"しんきろう":{"variants":"しんきろう/しん気楼/蜃気楼"},"しん気楼":{"variants":"しんきろう/しん気楼/蜃気楼"},"蜃気楼":{"variants":"しんきろう/しん気楼/蜃気楼"},"心筋こうそく":{"variants":"心筋こうそく/心筋梗塞"},"心筋梗塞":{"variants":"心筋こうそく/心筋梗塞"},"シンク":{"variants":"シンク/深紅/真紅"},"シンクイムシ":{"variants":"シンクイムシ/心食虫"},"心食虫":{"variants":"シンクイムシ/心食虫"},"シンクロナイズド・スイミング":{"variants":"シンクロナイズド・スイミング/シンクロナイズドスイミング"},"シンクロナイズドスイミング":{"variants":"シンクロナイズド・スイミング/シンクロナイズドスイミング"},"シンケイ":{"variants":"シンケイ/神経/晨鶏"},"しん材":{"variants":"しん材/心材"},"心材":{"variants":"しん材/心材"},"しんし":{"variants":"しんし/真摯"},"真摯":{"variants":"しんし/真摯"},"しん酌":{"variants":"しん酌/斟酌"},"斟酌":{"variants":"しん酌/斟酌"},"しんしん":{"variants":"しんしん/シンシン"},"シンシン":{"variants":"しんしん/シンシン"},"森森":{"variants":"森々/森森"},"津津":{"variants":"津々/津津"},"森々":{"variants":"森々/森森"},"津々":{"variants":"津々/津津"},"深々":{"variants":"深々/深深"},"深深":{"variants":"深々/深深"},"駸駸":{"variants":"駸々/駸駸"},"駸々":{"variants":"駸々/駸駸"},"津々たる":{"variants":"津々たる/津津たる"},"津津たる":{"variants":"津々たる/津津たる"},"津々と":{"variants":"津々と/津津と"},"津津と":{"variants":"津々と/津津と"},"しんじこむ":{"variants":"しんじこむ/信じ込む"},"信じ込む":{"variants":"しんじこむ/信じ込む"},"しんじこめる":{"variants":"しんじこめる/信じ込める"},"信じ込める":{"variants":"しんじこめる/信じ込める"},"シンジュ":{"variants":"シンジュ/真珠/神授"},"シンジュガイ":{"variants":"シンジュガイ/真珠貝"},"真珠貝":{"variants":"シンジュガイ/真珠貝"},"しんじる":{"variants":"しんじる/信じる"},"信じる":{"variants":"しんじる/信じる"},"しんずる":{"variants":"しんずる/信ずる/進ずる"},"親戚":{"variants":"親せき/親戚"},"親せき":{"variants":"親せき/親戚"},"しんぜる":{"variants":"しんぜる/進ぜる"},"進ぜる":{"variants":"しんぜる/進ぜる"},"心臓まひ":{"variants":"心臓まひ/心臓マヒ"},"心臓マヒ":{"variants":"心臓まひ/心臓マヒ"},"進退伺":{"variants":"進退伺/進退伺い"},"進退伺い":{"variants":"進退伺/進退伺い"},"真ちゅう":{"variants":"真ちゅう/真鍮"},"真鍮":{"variants":"真ちゅう/真鍮"},"進ちょく":{"variants":"進ちょく/進捗"},"進捗":{"variants":"進ちょく/進捗"},"寝殿造":{"variants":"寝殿造/寝殿造り"},"寝殿造り":{"variants":"寝殿造/寝殿造り"},"しん党":{"variants":"しん党/新党"},"新党":{"variants":"しん党/新党"},"しんどい":{"variants":"しんどい/シンドい"},"シンドい":{"variants":"しんどい/シンドい"},"しんどろーむ":{"variants":"しんどろーむ/シンドローム"},"シンドローム":{"variants":"しんどろーむ/シンドローム"},"シンパ":{"variants":"シンパ/新派"},"新派":{"variants":"シンパ/新派"},"信ぴょう":{"variants":"信ぴょう/信憑"},"信憑":{"variants":"信ぴょう/信憑"},"しんぶん":{"variants":"しんぶん/新聞"},"新聞":{"variants":"しんぶん/新聞"},"しんぼう":{"variants":"しんぼう/辛抱"},"辛抱":{"variants":"しんぼう/辛抱"},"しんぼうづよい":{"variants":"しんぼうづよい/辛抱強い"},"辛抱強い":{"variants":"しんぼうづよい/辛抱強い"},"親ぼく":{"variants":"親ぼく/親睦"},"親睦":{"variants":"親ぼく/親睦"},"しんぼく":{"variants":"しんぼく/神木"},"神木":{"variants":"しんぼく/神木"},"信用貸":{"variants":"信用貸/信用貸し"},"信用貸し":{"variants":"信用貸/信用貸し"},"しんらつ":{"variants":"しんらつ/辛らつ/辛辣"},"辛らつ":{"variants":"しんらつ/辛らつ/辛辣"},"辛辣":{"variants":"しんらつ/辛らつ/辛辣"},"親類付きあい":{"variants":"親類付きあい/親類付き合い/親類付合い"},"親類付き合い":{"variants":"親類付きあい/親類付き合い/親類付合い"},"親類付合い":{"variants":"親類付きあい/親類付き合い/親類付合い"},"地合":{"variants":"地合/地合い"},"地合い":{"variants":"地合/地合い"},"じいさん":{"variants":"じいさん/爺さん"},"爺さん":{"variants":"じいさん/爺さん"},"ジカ":{"variants":"ジカ/時価/自家/自火/直"},"耳下せん":{"variants":"耳下せん/耳下腺"},"耳下腺":{"variants":"耳下せん/耳下腺"},"耳下せん炎":{"variants":"耳下せん炎/耳下腺炎"},"耳下腺炎":{"variants":"耳下せん炎/耳下腺炎"},"じか談判":{"variants":"じか談判/直談判"},"直談判":{"variants":"じか談判/直談判"},"ジガバチ":{"variants":"ジガバチ/似我蜂"},"似我蜂":{"variants":"ジガバチ/似我蜂"},"じき":{"variants":"じき/時期/時季"},"じきじき":{"variants":"じきじき/直々/直直"},"直々":{"variants":"じきじき/直々/直直"},"直直":{"variants":"じきじき/直々/直直"},"軸受":{"variants":"軸受/軸受け"},"軸受け":{"variants":"軸受/軸受け"},"ジグモ":{"variants":"ジグモ/地蜘蛛"},"地蜘蛛":{"variants":"ジグモ/地蜘蛛"},"地ごく":{"variants":"地ごく/地獄"},"地獄":{"variants":"地ごく/地獄"},"自さつ":{"variants":"自さつ/自殺"},"自殺":{"variants":"自さつ/自殺"},"地しん":{"variants":"地しん/地震"},"地震":{"variants":"地しん/地震"},"じじこっこく":{"variants":"じじこっこく/時時刻刻"},"時時刻刻":{"variants":"じじこっこく/時時刻刻"},"事々物々":{"variants":"事々物々/事事物物"},"事事物物":{"variants":"事々物々/事事物物"},"じじむさい":{"variants":"じじむさい/爺むさい"},"爺むさい":{"variants":"じじむさい/爺むさい"},"じす":{"variants":"じす/辞す"},"辞す":{"variants":"じす/辞す"},"地すべり":{"variants":"地すべり/地滑り"},"地滑り":{"variants":"地すべり/地滑り"},"じする":{"variants":"じする/侍する/持する/辞する"},"じたい":{"variants":"じたい/事態/字体/自体"},"じだいがかる":{"variants":"じだいがかる/時代掛る"},"時代掛る":{"variants":"じだいがかる/時代掛る"},"時代もの":{"variants":"時代もの/時代物"},"時代物":{"variants":"時代もの/時代物"},"自ちょう":{"variants":"自ちょう/自重/自嘲"},"じっさいは":{"variants":"じっさいは/実際は"},"実際は":{"variants":"じっさいは/実際は"},"ジッチク":{"variants":"ジッチク/実竹"},"実竹":{"variants":"ジッチク/実竹"},"地つづき":{"variants":"地つづき/地続き"},"地続き":{"variants":"地つづき/地続き"},"じつに":{"variants":"じつに/実に"},"実に":{"variants":"じつに/実に"},"じつは":{"variants":"じつは/実は"},"実は":{"variants":"じつは/実は"},"地ならし":{"variants":"地ならし/地均し"},"地均し":{"variants":"地ならし/地均し"},"ジネズミ":{"variants":"ジネズミ/地鼠"},"地鼠":{"variants":"ジネズミ/地鼠"},"ジネンジョ":{"variants":"ジネンジョ/自然薯"},"自然薯":{"variants":"ジネンジョ/自然薯"},"ジバチ":{"variants":"ジバチ/地蜂"},"地蜂":{"variants":"ジバチ/地蜂"},"ジヒシンチョウ":{"variants":"ジヒシンチョウ/慈悲心鳥"},"慈悲心鳥":{"variants":"ジヒシンチョウ/慈悲心鳥"},"地ひびき":{"variants":"地ひびき/地響き"},"地響き":{"variants":"地ひびき/地響き"},"耳鼻いんこう":{"variants":"耳鼻いんこう/耳鼻咽喉"},"耳鼻咽喉":{"variants":"耳鼻いんこう/耳鼻咽喉"},"じまん":{"variants":"じまん/自まん/自慢"},"自まん":{"variants":"じまん/自まん/自慢"},"自慢":{"variants":"じまん/自まん/自慢"},"じまんたらしい":{"variants":"じまんたらしい/自慢たらしい"},"自慢たらしい":{"variants":"じまんたらしい/自慢たらしい"},"ジム":{"variants":"ジム/事務/寺務/時務"},"ジムシ":{"variants":"ジムシ/地虫"},"地虫":{"variants":"ジムシ/地虫"},"じめじめ":{"variants":"じめじめ/ジメジメ"},"ジメジメ":{"variants":"じめじめ/ジメジメ"},"じゃがいも":{"variants":"じゃがいも/じゃが芋/ジャガイモ"},"じゃが芋":{"variants":"じゃがいも/じゃが芋/ジャガイモ"},"ジャガイモ":{"variants":"じゃがいも/じゃが芋/ジャガイモ"},"ジャガタラいも":{"variants":"ジャガタラいも/ジャガタライモ/ジャガタラ芋"},"ジャガタライモ":{"variants":"ジャガタラいも/ジャガタライモ/ジャガタラ芋"},"ジャガタラ芋":{"variants":"ジャガタラいも/ジャガタライモ/ジャガタラ芋"},"じゃくする":{"variants":"じゃくする/寂する"},"寂する":{"variants":"じゃくする/寂する"},"じゃ香":{"variants":"じゃ香/ジャコウ/麝香"},"ジャコウ":{"variants":"じゃ香/ジャコウ/麝香"},"麝香":{"variants":"じゃ香/ジャコウ/麝香"},"ジャコウジカ":{"variants":"ジャコウジカ/麝香鹿"},"麝香鹿":{"variants":"ジャコウジカ/麝香鹿"},"ジャコウネコ":{"variants":"ジャコウネコ/麝香猫"},"麝香猫":{"variants":"ジャコウネコ/麝香猫"},"じゃじゃ馬":{"variants":"じゃじゃ馬/ジャジャ馬"},"ジャジャ馬":{"variants":"じゃじゃ馬/ジャジャ馬"},"ジャノヒゲ":{"variants":"ジャノヒゲ/蛇のひげ/蛇の髭"},"蛇のひげ":{"variants":"ジャノヒゲ/蛇のひげ/蛇の髭"},"蛇の髭":{"variants":"ジャノヒゲ/蛇のひげ/蛇の髭"},"じゃの目":{"variants":"じゃの目/蛇の目/蛇目"},"蛇の目":{"variants":"じゃの目/蛇の目/蛇目"},"蛇目":{"variants":"じゃの目/蛇の目/蛇目"},"ジャバラ":{"variants":"ジャバラ/蛇腹"},"蛇腹":{"variants":"ジャバラ/蛇腹"},"じゃまくさい":{"variants":"じゃまくさい/邪魔くさい"},"邪魔くさい":{"variants":"じゃまくさい/邪魔くさい"},"邪魔っけ":{"variants":"邪魔っけ/邪魔っ気/邪魔気"},"邪魔っ気":{"variants":"邪魔っけ/邪魔っ気/邪魔気"},"邪魔気":{"variants":"邪魔っけ/邪魔っ気/邪魔気"},"じゃらじゃら":{"variants":"じゃらじゃら/ジャラジャラ"},"ジャラジャラ":{"variants":"じゃらじゃら/ジャラジャラ"},"じゃん":{"variants":"じゃん/じゃン"},"じゃン":{"variants":"じゃん/じゃン"},"じゃん拳":{"variants":"じゃん拳/ジャンケン"},"ジャンケン":{"variants":"じゃん拳/ジャンケン"},"じゃん拳ぽん":{"variants":"じゃん拳ぽん/ジャンケンポン"},"ジャンケンポン":{"variants":"じゃん拳ぽん/ジャンケンポン"},"じゃんじゃん":{"variants":"じゃんじゃん/ジャンジャン"},"ジャンジャン":{"variants":"じゃんじゃん/ジャンジャン"},"じゅう":{"variants":"じゅう/獣"},"獣":{"variants":"じゅう/獣"},"１１月":{"variants":"１１月/十一月"},"十一月":{"variants":"１１月/十一月"},"１０月":{"variants":"１０月/十月"},"十月":{"variants":"１０月/十月"},"ジュウシマツ":{"variants":"ジュウシマツ/十姉妹"},"十姉妹":{"variants":"ジュウシマツ/十姉妹"},"じゅうじゅう":{"variants":"じゅうじゅう/重重"},"重重":{"variants":"じゅうじゅう/重重"},"じゅうたん":{"variants":"じゅうたん/絨毯/絨緞"},"充てん":{"variants":"充てん/充填"},"充填":{"variants":"充てん/充填"},"１２月":{"variants":"１２月/十二月"},"十二月":{"variants":"１２月/十二月"},"十二ひとえ":{"variants":"十二ひとえ/十二単"},"十二単":{"variants":"十二ひとえ/十二単"},"ジュウヤク":{"variants":"ジュウヤク/十薬/重役"},"重量挙":{"variants":"重量挙/重量挙げ"},"重量挙げ":{"variants":"重量挙/重量挙げ"},"ジュウロクササゲ":{"variants":"ジュウロクササゲ/十六大角豆"},"十六大角豆":{"variants":"ジュウロクササゲ/十六大角豆"},"じゅくしくさい":{"variants":"じゅくしくさい/熟柿臭い"},"熟柿臭い":{"variants":"じゅくしくさい/熟柿臭い"},"じゅくす":{"variants":"じゅくす/塾す/熟す"},"じゅくする":{"variants":"じゅくする/熟する"},"熟する":{"variants":"じゅくする/熟する"},"ジュゴン":{"variants":"ジュゴン/儒艮"},"儒艮":{"variants":"ジュゴン/儒艮"},"じゅ術":{"variants":"じゅ術/呪術"},"呪術":{"variants":"じゅ術/呪術"},"数珠つなぎ":{"variants":"数珠つなぎ/数珠繋ぎ"},"数珠繋ぎ":{"variants":"数珠つなぎ/数珠繋ぎ"},"Ｊｒ":{"variants":"Ｊｒ/ジュニア"},"ジュニア":{"variants":"Ｊｒ/ジュニア"},"Ｊフェザー":{"variants":"Ｊフェザー/ジュニアフェザー"},"ジュニアフェザー":{"variants":"Ｊフェザー/ジュニアフェザー"},"受・発信":{"variants":"受・発信/受発信"},"受発信":{"variants":"受・発信/受発信"},"じゅ縛":{"variants":"じゅ縛/呪縛"},"呪縛":{"variants":"じゅ縛/呪縛"},"じゅもん":{"variants":"じゅもん/じゅ文/呪文"},"じゅ文":{"variants":"じゅもん/じゅ文/呪文"},"呪文":{"variants":"じゅもん/じゅ文/呪文"},"順ぐり":{"variants":"順ぐり/順繰り"},"順繰り":{"variants":"順ぐり/順繰り"},"ジュンコ":{"variants":"ジュンコ/純乎/醇乎"},"ジュンサイ":{"variants":"ジュンサイ/蓴菜"},"蓴菜":{"variants":"ジュンサイ/蓴菜"},"じゅんじゅん":{"variants":"じゅんじゅん/順々"},"順々":{"variants":"順々/順順"},"諄諄":{"variants":"諄々/諄諄"},"順順":{"variants":"順々/順順"},"諄々":{"variants":"諄々/諄諄"},"じゅんじょづける":{"variants":"じゅんじょづける/順序づける/順序付ける"},"順序づける":{"variants":"じゅんじょづける/順序づける/順序付ける"},"順序付ける":{"variants":"じゅんじょづける/順序づける/順序付ける"},"じゅんじる":{"variants":"じゅんじる/殉じる/準じる"},"じゅんずる":{"variants":"じゅんずる/准ずる/殉ずる/準ずる"},"常打":{"variants":"常打/常打ち"},"常打ち":{"variants":"常打/常打ち"},"城さい":{"variants":"城さい/城塞"},"城塞":{"variants":"城さい/城塞"},"状差":{"variants":"状差/状差し"},"状差し":{"variants":"状差/状差し"},"条条":{"variants":"条々/条条"},"嫋嫋":{"variants":"嫋々/嫋嫋"},"条々":{"variants":"条々/条条"},"嫋々":{"variants":"嫋々/嫋嫋"},"じょうじる":{"variants":"じょうじる/乗じる"},"乗じる":{"variants":"じょうじる/乗じる"},"じょうずる":{"variants":"じょうずる/乗ずる"},"乗ずる":{"variants":"じょうずる/乗ずる"},"じょう舌":{"variants":"じょう舌/冗舌/饒舌"},"常とう":{"variants":"常とう/常套"},"常套":{"variants":"常とう/常套"},"常雇":{"variants":"常雇/常雇い"},"常雇い":{"variants":"常雇/常雇い"},"擾乱":{"variants":"じょう乱/擾乱"},"じょう乱":{"variants":"じょう乱/擾乱"},"ジョウリョク":{"variants":"ジョウリョク/常緑"},"常緑":{"variants":"ジョウリョク/常緑"},"じょうろ":{"variants":"じょうろ/如雨露"},"如雨露":{"variants":"じょうろ/如雨露"},"ジョオウバチ":{"variants":"ジョオウバチ/女王蜂"},"女王蜂":{"variants":"ジョオウバチ/女王蜂"},"じょさいない":{"variants":"じょさいない/如才無い"},"如才無い":{"variants":"じょさいない/如才無い"},"じょじょに":{"variants":"じょじょに/徐々に/徐徐に"},"徐々に":{"variants":"じょじょに/徐々に/徐徐に"},"徐徐に":{"variants":"じょじょに/徐々に/徐徐に"},"じょする":{"variants":"じょする/叙する/序する/恕する/除する"},"ジョチュウギク":{"variants":"ジョチュウギク/除虫菊"},"除虫菊":{"variants":"ジョチュウギク/除虫菊"},"序のくち":{"variants":"序のくち/序の口/序ノ口"},"序の口":{"variants":"序のくち/序の口/序ノ口"},"序ノ口":{"variants":"序のくち/序の口/序ノ口"},"ジョロウグモ":{"variants":"ジョロウグモ/女郎蜘蛛"},"女郎蜘蛛":{"variants":"ジョロウグモ/女郎蜘蛛"},"じらい":{"variants":"じらい/爾来"},"爾来":{"variants":"じらい/爾来"},"じらす":{"variants":"じらす/焦らす"},"焦らす":{"variants":"じらす/焦らす"},"じり高":{"variants":"じり高/ジリ高"},"ジリ高":{"variants":"じり高/ジリ高"},"じり貧":{"variants":"じり貧/ジリ貧"},"ジリ貧":{"variants":"じり貧/ジリ貧"},"じり安":{"variants":"じり安/ジリ安"},"ジリ安":{"variants":"じり安/ジリ安"},"じれこむ":{"variants":"じれこむ/焦れ込む"},"焦れ込む":{"variants":"じれこむ/焦れ込む"},"じれったい":{"variants":"じれったい/焦れったい"},"焦れったい":{"variants":"じれったい/焦れったい"},"じれる":{"variants":"じれる/焦れる"},"焦れる":{"variants":"じれる/焦れる"},"じろじろ":{"variants":"じろじろ/ジロジロ"},"ジロジロ":{"variants":"じろじろ/ジロジロ"},"じん":{"variants":"じん/ジン/仁/腎/陣"},"ジン":{"variants":"じん/ジン/仁/腎/陣"},"じん盂":{"variants":"じん盂/腎盂"},"腎盂":{"variants":"じん盂/腎盂"},"ジンギスカンなべ":{"variants":"ジンギスカンなべ/ジンギスカン鍋"},"ジンギスカン鍋":{"variants":"ジンギスカンなべ/ジンギスカン鍋"},"ジンコウ":{"variants":"ジンコウ/人口/人工/沈香"},"じん性":{"variants":"じん性/人性"},"人性":{"variants":"じん性/人性"},"じんぜん":{"variants":"じんぜん/荏苒"},"荏苒":{"variants":"じんぜん/荏苒"},"じん臓":{"variants":"じん臓/腎臓"},"腎臓":{"variants":"じん臓/腎臓"},"じん臓炎":{"variants":"じん臓炎/腎臓炎"},"腎臓炎":{"variants":"じん臓炎/腎臓炎"},"じん帯":{"variants":"じん帯/靱帯"},"靱帯":{"variants":"じん帯/靱帯"},"陣立":{"variants":"陣立/陣立て"},"陣立て":{"variants":"陣立/陣立て"},"ジンチョウゲ":{"variants":"ジンチョウゲ/沈丁花"},"沈丁花":{"variants":"ジンチョウゲ/沈丁花"},"陣とり":{"variants":"陣とり/陣取り"},"陣取り":{"variants":"陣とり/陣取り"},"じんどる":{"variants":"じんどる/陣どる/陣取る"},"陣どる":{"variants":"じんどる/陣どる/陣取る"},"陣取る":{"variants":"じんどる/陣どる/陣取る"},"人ぷん":{"variants":"人ぷん/人糞"},"人糞":{"variants":"人ぷん/人糞"},"じんましん":{"variants":"じんましん/じん麻しん/蕁麻疹"},"じん麻しん":{"variants":"じんましん/じん麻しん/蕁麻疹"},"蕁麻疹":{"variants":"じんましん/じん麻しん/蕁麻疹"},"すーっ":{"variants":"すーっ/スーッ"},"スーッ":{"variants":"すーっ/スーッ"},"ｓｕｐｅｒ":{"variants":"ｓｕｐｅｒ/スーパー"},"スーパー":{"variants":"ｓｕｐｅｒ/スーパー"},"酢あえ":{"variants":"酢あえ/酢和え"},"酢和え":{"variants":"酢あえ/酢和え"},"すい":{"variants":"すい/酸い"},"酸い":{"variants":"すい/酸い"},"すいあげる":{"variants":"すいあげる/吸い上げる"},"吸い上げる":{"variants":"すいあげる/吸い上げる"},"スイカ":{"variants":"スイカ/水火/水禍/西瓜"},"スイカズラ":{"variants":"スイカズラ/忍冬"},"忍冬":{"variants":"スイカズラ/忍冬"},"吸いがら":{"variants":"吸いがら/吸い殻/吸殻"},"吸い殻":{"variants":"吸いがら/吸い殻/吸殻"},"吸殻":{"variants":"吸いがら/吸い殻/吸殻"},"すいがん":{"variants":"すいがん/酔眼/酔顔"},"スイギュウ":{"variants":"スイギュウ/水牛"},"水牛":{"variants":"スイギュウ/水牛"},"すいこむ":{"variants":"すいこむ/吸いこむ/吸い込む/吸込む"},"吸いこむ":{"variants":"すいこむ/吸いこむ/吸い込む/吸込む"},"吸い込む":{"variants":"すいこむ/吸いこむ/吸い込む/吸込む"},"吸込む":{"variants":"すいこむ/吸いこむ/吸い込む/吸込む"},"すいこめる":{"variants":"すいこめる/吸い込める"},"吸い込める":{"variants":"すいこめる/吸い込める"},"水しゅ":{"variants":"水しゅ/水腫"},"水腫":{"variants":"水しゅ/水腫"},"スイジョウ":{"variants":"スイジョウ/水上/穂状"},"すいする":{"variants":"すいする/推する"},"推する":{"variants":"すいする/推する"},"水星":{"variants":"すい星/水星"},"すい星":{"variants":"すい星/水星/彗星"},"彗星":{"variants":"すい星/彗星"},"スイセン":{"variants":"スイセン/垂線/水仙/水線"},"垂ぜん":{"variants":"垂ぜん/垂涎"},"垂涎":{"variants":"垂ぜん/垂涎"},"すい臓":{"variants":"すい臓/膵臓"},"膵臓":{"variants":"すい臓/膵臓"},"すいたらしい":{"variants":"すいたらしい/好いたらしい"},"好いたらしい":{"variants":"すいたらしい/好いたらしい"},"吸い出し":{"variants":"吸い出し/吸出し"},"吸出し":{"variants":"吸い出し/吸出し"},"すいだす":{"variants":"すいだす/吸い出す"},"吸い出す":{"variants":"すいだす/吸い出す"},"吸付けたばこ":{"variants":"吸付けたばこ/吸付け煙草/吸付煙草"},"吸付け煙草":{"variants":"吸付けたばこ/吸付け煙草/吸付煙草"},"吸付煙草":{"variants":"吸付けたばこ/吸付け煙草/吸付煙草"},"すいつける":{"variants":"すいつける/吸いつける/吸い付ける/吸付ける"},"吸いつける":{"variants":"すいつける/吸いつける/吸い付ける/吸付ける"},"吸い付ける":{"variants":"すいつける/吸いつける/吸い付ける/吸付ける"},"吸付ける":{"variants":"すいつける/吸いつける/吸い付ける/吸付ける"},"スイトウ":{"variants":"スイトウ/水稲/水痘/水筒"},"すいとる":{"variants":"すいとる/吸い取る/吸取る"},"吸い取る":{"variants":"すいとる/吸い取る/吸取る"},"吸取る":{"variants":"すいとる/吸い取る/吸取る"},"すいとれる":{"variants":"すいとれる/吸い取れる"},"吸い取れる":{"variants":"すいとれる/吸い取れる"},"スイバ":{"variants":"スイバ/酸模/酸葉"},"スイミツ":{"variants":"スイミツ/水密/水蜜"},"吸い物":{"variants":"吸い物/吸物"},"吸物":{"variants":"吸い物/吸物"},"すいよせる":{"variants":"すいよせる/吸い寄せる/吸寄せる"},"吸い寄せる":{"variants":"すいよせる/吸い寄せる/吸寄せる"},"吸寄せる":{"variants":"すいよせる/吸い寄せる/吸寄せる"},"スイリュウ":{"variants":"スイリュウ/垂柳/水流/翠柳"},"スイレン":{"variants":"スイレン/水練/睡蓮"},"すう":{"variants":"すう/吸う"},"吸う":{"variants":"すう/吸う"},"据え置き":{"variants":"据え置き/据置"},"据置":{"variants":"据え置き/据置"},"すえおく":{"variants":"すえおく/据え置く"},"据え置く":{"variants":"すえおく/据え置く"},"すえおそろしい":{"variants":"すえおそろしい/末恐ろしい"},"末恐ろしい":{"variants":"すえおそろしい/末恐ろしい"},"すえしじゅう":{"variants":"すえしじゅう/末始終"},"末始終":{"variants":"すえしじゅう/末始終"},"末々":{"variants":"末々/末末"},"末末":{"variants":"末々/末末"},"据え膳":{"variants":"据え膳/据膳"},"据膳":{"variants":"据え膳/据膳"},"すえたのもしい":{"variants":"すえたのもしい/末頼もしい"},"末頼もしい":{"variants":"すえたのもしい/末頼もしい"},"すえ付":{"variants":"すえ付/すえ付け/据え付け/据付"},"すえ付け":{"variants":"すえ付/すえ付け/据え付け/据付"},"据え付け":{"variants":"すえ付/すえ付け/据え付け/据付"},"据付":{"variants":"すえ付/すえ付け/据え付け/据付"},"すえつける":{"variants":"すえつける/据えつける/据え付ける/据付ける"},"据えつける":{"variants":"すえつける/据えつける/据え付ける/据付ける"},"据え付ける":{"variants":"すえつける/据えつける/据え付ける/据付ける"},"据付ける":{"variants":"すえつける/据えつける/据え付ける/据付ける"},"スエツムハナ":{"variants":"スエツムハナ/末摘花"},"末摘花":{"variants":"スエツムハナ/末摘花"},"すえながい":{"variants":"すえながい/末永い"},"末永い":{"variants":"すえながい/末永い"},"末広がり":{"variants":"末広がり/末広り"},"末広り":{"variants":"末広がり/末広り"},"すえる":{"variants":"すえる/吸える/据える/饐える"},"スオウ":{"variants":"スオウ/素襖/素袍/蘇方/蘇芳/蘇枋"},"素おどり":{"variants":"素おどり/素踊"},"素踊":{"variants":"素おどり/素踊"},"すかす":{"variants":"すかす/空かす/透かす/賺す"},"すかすか":{"variants":"すかすか/スカスカ"},"スカスカ":{"variants":"すかすか/スカスカ"},"すかんぴん":{"variants":"すかんぴん/素寒貧"},"素寒貧":{"variants":"すかんぴん/素寒貧"},"すがすがしい":{"variants":"すがすがしい/清々しい/清清しい"},"清々しい":{"variants":"すがすがしい/清々しい/清清しい"},"清清しい":{"variants":"すがすがしい/清々しい/清清しい"},"すがめる":{"variants":"すがめる/眇める"},"眇める":{"variants":"すがめる/眇める"},"すがる":{"variants":"すがる/縋る"},"縋る":{"variants":"すがる/縋る"},"すがれる":{"variants":"すがれる/縋れる"},"縋れる":{"variants":"すがれる/縋れる"},"すき":{"variants":"すき/好き"},"スキ":{"variants":"すき/スキ/好き/鋤/数寄/透き"},"好き":{"variants":"すき/好き"},"透き写し":{"variants":"透き写し/透写し"},"透写し":{"variants":"透き写し/透写し"},"すきおこす":{"variants":"すきおこす/鋤き起す"},"鋤き起す":{"variants":"すきおこす/鋤き起す"},"すきかえす":{"variants":"すきかえす/すき返す/漉き返す/鋤き返す"},"すき返す":{"variants":"すきかえす/すき返す/漉き返す/鋤き返す"},"好ききらい":{"variants":"好ききらい/好き嫌い"},"好き嫌い":{"variants":"好ききらい/好き嫌い"},"すき櫛":{"variants":"すき櫛/梳き櫛/梳櫛"},"梳き櫛":{"variants":"すき櫛/梳き櫛/梳櫛"},"梳櫛":{"variants":"すき櫛/梳き櫛/梳櫛"},"すきこのむ":{"variants":"すきこのむ/好きこのむ/好き好む"},"好きこのむ":{"variants":"すきこのむ/好きこのむ/好き好む"},"好き好む":{"variants":"すきこのむ/好きこのむ/好き好む"},"好きごころ":{"variants":"好きごころ/好き心"},"好き心":{"variants":"好きごころ/好き心"},"好きごと":{"variants":"好きごと/好き事"},"好き事":{"variants":"好きごと/好き事"},"好きずき":{"variants":"好きずき/好き好き"},"好き好き":{"variants":"好きずき/好き好き"},"すきずきい":{"variants":"すきずきい/好きずきい/好き好きい"},"好きずきい":{"variants":"すきずきい/好きずきい/好き好きい"},"好き好きい":{"variants":"すきずきい/好きずきい/好き好きい"},"すきとおる":{"variants":"すきとおる/透きとおる/透き通る/透通る"},"透きとおる":{"variants":"すきとおる/透きとおる/透き通る/透通る"},"透き通る":{"variants":"すきとおる/透きとおる/透き通る/透通る"},"透通る":{"variants":"すきとおる/透きとおる/透き通る/透通る"},"すき間":{"variants":"すき間/空き間/隙間/透き間"},"すきま風":{"variants":"すきま風/すき間風/空き間風/隙間風/透き間風"},"すき間風":{"variants":"すきま風/すき間風/空き間風/隙間風/透き間風"},"透き目":{"variants":"透き目/透目"},"透目":{"variants":"透き目/透目"},"好きもの":{"variants":"好きもの/好き者"},"好き者":{"variants":"好きもの/好き者"},"すき焼き":{"variants":"すき焼き/鋤焼き"},"鋤焼き":{"variants":"すき焼き/鋤焼き"},"数寄屋造り":{"variants":"数寄屋造/数寄屋造り"},"数寄屋造":{"variants":"数寄屋造/数寄屋造り"},"スギ":{"variants":"スギ/杉"},"杉":{"variants":"スギ/杉"},"すぎ":{"variants":"すぎ/過ぎ"},"過ぎ":{"variants":"すぎ/過ぎ"},"スギゴケ":{"variants":"スギゴケ/杉苔/杉蘚"},"すぎさる":{"variants":"すぎさる/過ぎ去る"},"過ぎ去る":{"variants":"すぎさる/過ぎ去る"},"スギナ":{"variants":"スギナ/杉菜"},"杉菜":{"variants":"スギナ/杉菜"},"すぎる":{"variants":"すぎる/過ぎる"},"過ぎる":{"variants":"よぎる/過ぎる/過る"},"すく":{"variants":"すく/好く/漉く/鋤く/抄く/透く/梳く"},"すくいあげる":{"variants":"すくいあげる/すくい上げる"},"すくい上げる":{"variants":"すくいあげる/すくい上げる"},"すくいだす":{"variants":"すくいだす/救い出す"},"救い出す":{"variants":"すくいだす/救い出す"},"すくいだせる":{"variants":"すくいだせる/救い出せる"},"救い出せる":{"variants":"すくいだせる/救い出せる"},"すくう":{"variants":"すくう/掬う/救う/巣くう/巣食う"},"巣くう":{"variants":"すくう/巣くう/巣食う"},"巣食う":{"variants":"すくう/巣くう/巣食う"},"すくえる":{"variants":"すくえる/救える"},"救える":{"variants":"すくえる/救える"},"すくすく":{"variants":"すくすく/スクスク"},"スクスク":{"variants":"すくすく/スクスク"},"すくない":{"variants":"すくない/少い/少ない"},"少ない":{"variants":"すくない/少い/少ない"},"すくなくとも":{"variants":"すくなくとも/少なくとも"},"少なくとも":{"variants":"すくなくとも/少なくとも"},"すくなくも":{"variants":"すくなくも/少なくも"},"少なくも":{"variants":"すくなくも/少なくも"},"少なめ":{"variants":"少なめ/少な目"},"少な目":{"variants":"少なめ/少な目"},"すくみあがる":{"variants":"すくみあがる/すくみ上がる/竦み上がる"},"すくみ上がる":{"variants":"すくみあがる/すくみ上がる/竦み上がる"},"竦み上がる":{"variants":"すくみあがる/すくみ上がる/竦み上がる"},"すくむ":{"variants":"すくむ/竦む"},"竦む":{"variants":"すくむ/竦む"},"すくめる":{"variants":"すくめる/竦める"},"竦める":{"variants":"すくめる/竦める"},"すぐ":{"variants":"すぐ/スグ/直ぐ"},"スグ":{"variants":"すぐ/スグ/直ぐ"},"直ぐ":{"variants":"すぐ/スグ/直ぐ"},"すぐれる":{"variants":"すぐれる/勝れる/優れる"},"スケソウダラ":{"variants":"スケソウダラ/助惣鱈"},"助惣鱈":{"variants":"スケソウダラ/助惣鱈"},"助っ人":{"variants":"助っ人/助人"},"助人":{"variants":"助っ人/助人"},"スケトウダラ":{"variants":"スケトウダラ/介党鱈"},"介党鱈":{"variants":"スケトウダラ/介党鱈"},"すける":{"variants":"すける/透ける"},"透ける":{"variants":"すける/透ける"},"すげかえる":{"variants":"すげかえる/すげ替える"},"すげ替える":{"variants":"すげかえる/すげ替える"},"すこし":{"variants":"すこし/少し"},"少し":{"variants":"すこし/少し"},"すこしく":{"variants":"すこしく/少しく"},"少しく":{"variants":"すこしく/少しく"},"すこしも":{"variants":"すこしも/少しも"},"少しも":{"variants":"すこしも/少しも"},"すこぶる":{"variants":"すこぶる/頗る"},"頗る":{"variants":"すこぶる/頗る"},"すごい":{"variants":"すごい/凄い"},"凄い":{"variants":"すごい/凄い"},"すご腕":{"variants":"すご腕/凄腕"},"凄腕":{"variants":"すご腕/凄腕"},"すごす":{"variants":"すごす/過ごす/過す"},"過ごす":{"variants":"すごす/過ごす/過す"},"過す":{"variants":"すごす/過ごす/過す"},"すごせる":{"variants":"すごせる/過ごせる"},"過ごせる":{"variants":"すごせる/過ごせる"},"すごみ":{"variants":"すごみ/すご味/凄み/凄味"},"すご味":{"variants":"すごみ/すご味/凄み/凄味"},"凄み":{"variants":"すごみ/すご味/凄み/凄味"},"凄味":{"variants":"すごみ/すご味/凄み/凄味"},"すごむ":{"variants":"すごむ/凄む"},"凄む":{"variants":"すごむ/凄む"},"すごもる":{"variants":"すごもる/巣篭る"},"巣篭る":{"variants":"すごもる/巣篭る"},"すさぶ":{"variants":"すさぶ/荒ぶ"},"荒ぶ":{"variants":"すさぶ/荒ぶ"},"すさまじい":{"variants":"すさまじい/凄まじい"},"凄まじい":{"variants":"すさまじい/凄まじい"},"すさむ":{"variants":"すさむ/荒む"},"荒む":{"variants":"すさむ/荒む"},"すし":{"variants":"すし/寿し/寿司/鮓/鮨"},"寿司":{"variants":"すし/寿し/寿司"},"寿し":{"variants":"すし/寿し/寿司"},"すし詰め":{"variants":"すし詰め/鮨詰/鮨詰め"},"鮨詰":{"variants":"すし詰め/鮨詰/鮨詰め"},"鮨詰め":{"variants":"すし詰め/鮨詰/鮨詰め"},"すし飯":{"variants":"すし飯/鮨飯"},"鮨飯":{"variants":"すし飯/鮨飯"},"すじ":{"variants":"すじ/筋"},"スジ":{"variants":"すじ/スジ/筋"},"筋":{"variants":"すじ/筋"},"筋合":{"variants":"筋合/筋合い"},"筋合い":{"variants":"筋合/筋合い"},"筋書":{"variants":"筋書/筋書き"},"筋書き":{"variants":"筋書/筋書き"},"筋立":{"variants":"筋立/筋立て"},"筋立て":{"variants":"筋立/筋立て"},"筋ちがい":{"variants":"筋ちがい/筋違い"},"筋違い":{"variants":"筋ちがい/筋違い"},"すじばる":{"variants":"すじばる/筋張る"},"筋張る":{"variants":"すじばる/筋張る"},"筋向い":{"variants":"筋向い/筋向かい"},"筋向かい":{"variants":"筋向い/筋向かい"},"すす":{"variants":"すす/煤"},"煤":{"variants":"すす/煤"},"ススキ":{"variants":"ススキ/薄/芒"},"すすぐ":{"variants":"すすぐ/漱ぐ"},"漱ぐ":{"variants":"すすぐ/漱ぐ"},"すすける":{"variants":"すすける/煤ける"},"煤ける":{"variants":"すすける/煤ける"},"すすばむ":{"variants":"すすばむ/煤ばむ"},"煤ばむ":{"variants":"すすばむ/煤ばむ"},"すすみだす":{"variants":"すすみだす/進み出す"},"進み出す":{"variants":"すすみだす/進み出す"},"すすみだせる":{"variants":"すすみだせる/進み出せる"},"進み出せる":{"variants":"すすみだせる/進み出せる"},"すすみでる":{"variants":"すすみでる/進み出る"},"進み出る":{"variants":"すすみでる/進み出る"},"すすむ":{"variants":"すすむ/進む"},"進む":{"variants":"すすむ/進む"},"すすめ":{"variants":"すすめ/勧め/奨め"},"すすめる":{"variants":"すすめる/勧める/奨める/進める/推める/薦める/奬める"},"すすりあげる":{"variants":"すすりあげる/すすり上げる/啜り上げる"},"すすり上げる":{"variants":"すすりあげる/すすり上げる/啜り上げる"},"啜り上げる":{"variants":"すすりあげる/すすり上げる/啜り上げる"},"すすりなく":{"variants":"すすりなく/すすり泣く/啜り泣く"},"すすり泣く":{"variants":"すすりなく/すすり泣く/啜り泣く"},"啜り泣く":{"variants":"すすりなく/すすり泣く/啜り泣く"},"すする":{"variants":"すする/啜る"},"啜る":{"variants":"すする/啜る"},"スズ":{"variants":"スズ/錫"},"錫":{"variants":"スズ/錫"},"スズカケ":{"variants":"スズカケ/篠懸/鈴かけ/鈴掛"},"鈴掛":{"variants":"スズカケ/鈴かけ/鈴掛"},"鈴かけ":{"variants":"スズカケ/鈴かけ/鈴掛"},"すずかけの木":{"variants":"すずかけの木/スズカケノキ/篠懸の木/鈴掛の木"},"スズカケノキ":{"variants":"すずかけの木/スズカケノキ/篠懸の木/鈴掛の木"},"スズキ":{"variants":"スズキ/鱸"},"鱸":{"variants":"スズキ/鱸"},"すずしい":{"variants":"すずしい/涼しい"},"涼しい":{"variants":"すずしい/涼しい"},"スズナ":{"variants":"スズナ/菘"},"菘":{"variants":"スズナ/菘"},"鈴なり":{"variants":"鈴なり/鈴生り"},"鈴生り":{"variants":"鈴なり/鈴生り"},"すずむ":{"variants":"すずむ/涼む"},"涼む":{"variants":"すずむ/涼む"},"スズムシ":{"variants":"スズムシ/鈴虫"},"鈴虫":{"variants":"スズムシ/鈴虫"},"スズメ":{"variants":"スズメ/雀"},"雀":{"variants":"スズメ/雀"},"スズメバチ":{"variants":"スズメバチ/雀蜂"},"雀蜂":{"variants":"スズメバチ/雀蜂"},"すずめる":{"variants":"すずめる/涼める"},"涼める":{"variants":"すずめる/涼める"},"スズラン":{"variants":"スズラン/鈴蘭"},"鈴蘭":{"variants":"スズラン/鈴蘭"},"スズラントウ":{"variants":"スズラントウ/鈴蘭灯"},"鈴蘭灯":{"variants":"スズラントウ/鈴蘭灯"},"すずり箱":{"variants":"すずり箱/硯箱"},"硯箱":{"variants":"すずり箱/硯箱"},"すそ":{"variants":"すそ/裾"},"裾":{"variants":"すそ/裾"},"すそ取り":{"variants":"すそ取り/裾取り"},"裾取り":{"variants":"すそ取り/裾取り"},"すそ野":{"variants":"すそ野/裾野"},"裾野":{"variants":"すそ野/裾野"},"すたる":{"variants":"すたる/廃る"},"廃る":{"variants":"すたる/廃る"},"すたれ物":{"variants":"すたれ物/廃れもの/廃れ物"},"廃れもの":{"variants":"すたれ物/廃れもの/廃れ物"},"廃れ物":{"variants":"すたれ物/廃れもの/廃れ物"},"すたれる":{"variants":"すたれる/廃れる"},"廃れる":{"variants":"すたれる/廃れる"},"酢だこ":{"variants":"酢だこ/酢蛸"},"酢蛸":{"variants":"酢だこ/酢蛸"},"すだつ":{"variants":"すだつ/巣立つ"},"巣立つ":{"variants":"すだつ/巣立つ"},"すだてる":{"variants":"すだてる/巣立てる"},"巣立てる":{"variants":"すだてる/巣立てる"},"すっきり":{"variants":"すっきり/スッキリ"},"スッキリ":{"variants":"すっきり/スッキリ"},"すっとぶ":{"variants":"すっとぶ/すっ飛ぶ"},"すっ飛ぶ":{"variants":"すっとぶ/すっ飛ぶ"},"素っ頓狂":{"variants":"素っ頓狂/素頓狂"},"素頓狂":{"variants":"素っ頓狂/素頓狂"},"すっぱい":{"variants":"すっぱい/スッぱい/酸っぱい"},"スッぱい":{"variants":"すっぱい/スッぱい/酸っぱい"},"酸っぱい":{"variants":"すっぱい/スッぱい/酸っぱい"},"すっ裸":{"variants":"すっ裸/素っぱだか/素っ裸/素裸"},"素っぱだか":{"variants":"すっ裸/素っぱだか/素っ裸/素裸"},"素っ裸":{"variants":"すっ裸/素っぱだか/素っ裸/素裸"},"素裸":{"variants":"すっ裸/素っぱだか/素っ裸/素裸"},"すっぱぬく":{"variants":"すっぱぬく/すっぱ抜く/素っ破抜く"},"すっぱ抜く":{"variants":"すっぱぬく/すっぱ抜く/素っ破抜く"},"素っ破抜く":{"variants":"すっぱぬく/すっぱ抜く/素っ破抜く"},"すっぱぬける":{"variants":"すっぱぬける/すっぱ抜ける"},"すっぱ抜ける":{"variants":"すっぱぬける/すっぱ抜ける"},"スッポン":{"variants":"スッポン/鼈"},"鼈":{"variants":"スッポン/鼈"},"捨て石":{"variants":"捨て石/捨石"},"捨石":{"variants":"捨て石/捨石"},"すておく":{"variants":"すておく/捨て置く/捨置く"},"捨て置く":{"variants":"すておく/捨て置く/捨置く"},"捨置く":{"variants":"すておく/捨て置く/捨置く"},"すてき":{"variants":"すてき/ステキ/素敵/素的"},"ステキ":{"variants":"すてき/ステキ/素敵/素的"},"捨て子":{"variants":"捨て子/捨子"},"捨子":{"variants":"捨て子/捨子"},"すてさる":{"variants":"すてさる/捨て去る"},"捨て去る":{"variants":"すてさる/捨て去る"},"捨てどころ":{"variants":"捨てどころ/捨て所"},"捨て所":{"variants":"捨てどころ/捨て所"},"捨て値":{"variants":"捨て値/捨値"},"捨値":{"variants":"捨て値/捨値"},"すて鉢":{"variants":"すて鉢/捨鉢"},"捨鉢":{"variants":"すて鉢/捨鉢"},"すてる":{"variants":"すてる/棄てる/捨てる"},"すでに":{"variants":"すでに/既に/已に"},"素泊まり":{"variants":"素泊まり/素泊り"},"素泊り":{"variants":"素泊まり/素泊り"},"砂けむり":{"variants":"砂けむり/砂煙"},"砂煙":{"variants":"砂けむり/砂煙"},"砂ぼこり":{"variants":"砂ぼこり/砂埃"},"砂埃":{"variants":"砂ぼこり/砂埃"},"すなわち":{"variants":"すなわち/即ち"},"即ち":{"variants":"すなわち/即ち"},"すね当て":{"variants":"すね当て/臑当"},"臑当":{"variants":"すね当て/臑当"},"すねる":{"variants":"すねる/拗ねる"},"拗ねる":{"variants":"すねる/拗ねる"},"簀の子":{"variants":"簀の子/簀子"},"簀子":{"variants":"簀の子/簀子"},"酢のもの":{"variants":"酢のもの/酢の物"},"酢の物":{"variants":"酢のもの/酢の物"},"すばやい":{"variants":"すばやい/素早い"},"素早い":{"variants":"すばやい/素早い"},"すばらしい":{"variants":"すばらしい/素晴らしい"},"素晴らしい":{"variants":"すばらしい/素晴らしい"},"スバル":{"variants":"スバル/昴"},"昴":{"variants":"スバル/昴"},"すぱすぱ":{"variants":"すぱすぱ/スパスパ"},"スパスパ":{"variants":"すぱすぱ/スパスパ"},"すべからく":{"variants":"すべからく/須らく"},"須らく":{"variants":"すべからく/須らく"},"すべくくる":{"variants":"すべくくる/統べくくる/統べ括る"},"統べくくる":{"variants":"すべくくる/統べくくる/統べ括る"},"統べ括る":{"variants":"すべくくる/統べくくる/統べ括る"},"すべて":{"variants":"すべて/全て/総て/凡て"},"すべらす":{"variants":"すべらす/滑らす/辷らす"},"すべりおちる":{"variants":"すべりおちる/滑り降ちる/滑り落ちる"},"すべりおりる":{"variants":"すべりおりる/滑り降りる"},"滑り降りる":{"variants":"すべりおりる/滑り降りる"},"すべりこむ":{"variants":"すべりこむ/すべり込む/滑り込む/辷り込む"},"すべり込む":{"variants":"すべりこむ/すべり込む/滑り込む/辷り込む"},"すべりこめる":{"variants":"すべりこめる/滑り込める"},"滑り込める":{"variants":"すべりこめる/滑り込める"},"すべり台":{"variants":"すべり台/滑り台"},"滑り台":{"variants":"すべり台/滑り台"},"すべり出し":{"variants":"すべり出し/滑り出し"},"滑り出し":{"variants":"すべり出し/滑り出し"},"すべりだす":{"variants":"すべりだす/滑り出す"},"滑り出す":{"variants":"すべりだす/滑り出す"},"すべりだせる":{"variants":"すべりだせる/滑り出せる"},"滑り出せる":{"variants":"すべりだせる/滑り出せる"},"スベリヒユ":{"variants":"スベリヒユ/滑ひゆ/馬歯ひゆ"},"すべる":{"variants":"すべる/滑べる/滑る/辷る"},"滑べる":{"variants":"すべる/滑べる/滑る"},"滑る":{"variants":"すべる/滑べる/滑る"},"すべれる":{"variants":"すべれる/滑れる"},"滑れる":{"variants":"すべれる/滑れる"},"すぼむ":{"variants":"すぼむ/窄む"},"窄む":{"variants":"すぼむ/窄む"},"住い":{"variants":"住い/住まい"},"住まい":{"variants":"住い/住まい"},"すまう":{"variants":"すまう/住まう"},"住まう":{"variants":"すまう/住まう"},"す巻き":{"variants":"す巻き/簀巻/簀巻き"},"簀巻":{"variants":"す巻き/簀巻/簀巻き"},"簀巻き":{"variants":"す巻き/簀巻/簀巻き"},"すまし汁":{"variants":"すまし汁/澄し汁/澄まし汁/清汁"},"澄し汁":{"variants":"すまし汁/澄し汁/澄まし汁"},"澄まし汁":{"variants":"すまし汁/澄し汁/澄まし汁"},"すます":{"variants":"すます/済ます/澄ます/清ます"},"すませる":{"variants":"すませる/済ませる"},"済ませる":{"variants":"すませる/済ませる"},"すまわす":{"variants":"すまわす/住まわす"},"住まわす":{"variants":"すまわす/住まわす"},"すまわせる":{"variants":"すまわせる/住まわせる"},"住まわせる":{"variants":"すまわせる/住まわせる"},"すみあらす":{"variants":"すみあらす/住み荒らす"},"住み荒らす":{"variants":"すみあらす/住み荒らす"},"スミイカ":{"variants":"スミイカ/墨烏賊"},"墨烏賊":{"variants":"スミイカ/墨烏賊"},"すみか":{"variants":"すみか/住処"},"住処":{"variants":"すみか/住処"},"すみかえる":{"variants":"すみかえる/住みかえる/住み替える"},"住みかえる":{"variants":"すみかえる/住みかえる/住み替える"},"住み替える":{"variants":"すみかえる/住みかえる/住み替える"},"すみかわる":{"variants":"すみかわる/住み替る/住替る"},"住み替る":{"variants":"すみかわる/住み替る/住替る"},"住替る":{"variants":"すみかわる/住み替る/住替る"},"すみきる":{"variants":"すみきる/澄みきる/澄み切る/澄切る"},"澄みきる":{"variants":"すみきる/澄みきる/澄み切る/澄切る"},"澄み切る":{"variants":"すみきる/澄みきる/澄み切る/澄切る"},"澄切る":{"variants":"すみきる/澄みきる/澄み切る/澄切る"},"住み込み":{"variants":"住み込み/住込み"},"住込み":{"variants":"住み込み/住込み"},"すみこむ":{"variants":"すみこむ/住み込む"},"住み込む":{"variants":"すみこむ/住み込む"},"すみこめる":{"variants":"すみこめる/住み込める"},"住み込める":{"variants":"すみこめる/住み込める"},"隅々":{"variants":"隅々/隅隅"},"隅隅":{"variants":"隅々/隅隅"},"酢みそ":{"variants":"酢みそ/酢味噌"},"酢味噌":{"variants":"酢みそ/酢味噌"},"墨染":{"variants":"墨染/墨染め"},"墨染め":{"variants":"墨染/墨染め"},"すみつく":{"variants":"すみつく/住みつく/住み着く"},"住みつく":{"variants":"すみつく/住みつく/住み着く"},"住み着く":{"variants":"すみつく/住みつく/住み着く"},"すみつける":{"variants":"すみつける/住み着ける"},"住み着ける":{"variants":"すみつける/住み着ける"},"すみつぶ":{"variants":"すみつぶ/住みつぶ"},"住みつぶ":{"variants":"すみつぶ/住みつぶ"},"すみつべる":{"variants":"すみつべる/住みつべる"},"住みつべる":{"variants":"すみつべる/住みつべる"},"すみなす":{"variants":"すみなす/住みなす/住み成す/住成す"},"住みなす":{"variants":"すみなす/住みなす/住み成す/住成す"},"住み成す":{"variants":"すみなす/住みなす/住み成す/住成す"},"住成す":{"variants":"すみなす/住みなす/住み成す/住成す"},"すみなれる":{"variants":"すみなれる/住み慣れる/住み馴れる"},"すみやか":{"variants":"すみやか/速やか"},"速やか":{"variants":"すみやか/速やか"},"炭焼":{"variants":"炭焼/炭焼き"},"炭焼き":{"variants":"炭焼/炭焼き"},"スミレ":{"variants":"スミレ/菫"},"菫":{"variants":"スミレ/菫"},"すみれ色":{"variants":"すみれ色/スミレイロ/菫色"},"スミレイロ":{"variants":"すみれ色/スミレイロ/菫色"},"菫色":{"variants":"すみれ色/スミレイロ/菫色"},"すみわたる":{"variants":"すみわたる/澄みわたる/澄み渡る/澄渡る"},"澄みわたる":{"variants":"すみわたる/澄みわたる/澄み渡る/澄渡る"},"澄み渡る":{"variants":"すみわたる/澄みわたる/澄み渡る/澄渡る"},"澄渡る":{"variants":"すみわたる/澄みわたる/澄み渡る/澄渡る"},"すむ":{"variants":"すむ/済む/住む/澄む/棲む"},"すめる":{"variants":"すめる/住める"},"住める":{"variants":"すめる/住める"},"相撲とり":{"variants":"相撲とり/相撲取"},"相撲取":{"variants":"相撲とり/相撲取"},"スモモ":{"variants":"スモモ/李"},"李":{"variants":"スモモ/李"},"素焼":{"variants":"素焼/素焼き"},"素焼き":{"variants":"素焼/素焼き"},"すらすら":{"variants":"すらすら/スラスラ"},"スラスラ":{"variants":"すらすら/スラスラ"},"すり":{"variants":"すり/スリ/刷/刷り/摺/摺り/掏児/掏摸"},"スリ":{"variants":"すり/スリ/刷/刷り/摺/摺り/掏児/掏摸"},"摺り":{"variants":"すり/スリ/摺/摺り"},"摺":{"variants":"すり/スリ/摺/摺り"},"刷り":{"variants":"すり/スリ/刷/刷り"},"刷":{"variants":"すり/スリ/刷/刷り"},"すりあがる":{"variants":"すりあがる/刷り上がる"},"刷り上がる":{"variants":"すりあがる/刷り上がる"},"すりあげる":{"variants":"すりあげる/刷り上げる"},"刷り上げる":{"variants":"すりあげる/刷り上げる"},"すり足":{"variants":"すり足/摺足"},"摺足":{"variants":"すり足/摺足"},"すりかえる":{"variants":"すりかえる/すり替える/摩り替える"},"すり替える":{"variants":"すりかえる/すり替える/摩り替える"},"摩り替える":{"variants":"すりかえる/すり替える/摩り替える"},"すりガラス":{"variants":"すりガラス/磨ガラス"},"磨ガラス":{"variants":"すりガラス/磨ガラス"},"擦り傷":{"variants":"擦り傷/擦傷"},"擦傷":{"variants":"擦り傷/擦傷"},"すり切り":{"variants":"すり切り/摺切り"},"摺切り":{"variants":"すり切り/摺切り"},"すりきる":{"variants":"すりきる/擦り切る/擦切る"},"擦り切る":{"variants":"すりきる/擦り切る/擦切る"},"擦切る":{"variants":"すりきる/擦り切る/擦切る"},"すりきれる":{"variants":"すりきれる/擦り切れる/擦切れる"},"擦り切れる":{"variants":"すりきれる/擦り切れる/擦切れる"},"擦切れる":{"variants":"すりきれる/擦り切れる/擦切れる"},"すりこ木":{"variants":"すりこ木/擂り粉木/擂粉木"},"擂り粉木":{"variants":"すりこ木/擂り粉木/擂粉木"},"擂粉木":{"variants":"すりこ木/擂り粉木/擂粉木"},"すりこむ":{"variants":"すりこむ/すり込む/刷りこむ/刷り込む/刷込む/擦り込む/擦込む/擂り込む"},"すり込む":{"variants":"すりこむ/すり込む/刷りこむ/刷り込む/刷込む/擦り込む/擦込む/擂り込む"},"刷り込む":{"variants":"すりこむ/すり込む/刷りこむ/刷り込む/刷込む"},"刷りこむ":{"variants":"すりこむ/すり込む/刷りこむ/刷り込む/刷込む"},"刷込む":{"variants":"すりこむ/すり込む/刷りこむ/刷り込む/刷込む"},"擦り込む":{"variants":"すりこむ/すり込む/擦り込む/擦込む"},"擦込む":{"variants":"すりこむ/すり込む/擦り込む/擦込む"},"すりこめる":{"variants":"すりこめる/刷り込める/擦り込める"},"すりつける":{"variants":"すりつける/すり付ける/擦付ける"},"すり付ける":{"variants":"すりつける/すり付ける/擦付ける"},"擦付ける":{"variants":"すりつける/すり付ける/擦付ける"},"すりつぶす":{"variants":"すりつぶす/すり潰す/磨りつぶす/磨り潰す/擂りつぶす/擂り潰す"},"すり潰す":{"variants":"すりつぶす/すり潰す/磨りつぶす/磨り潰す/擂りつぶす/擂り潰す"},"磨り潰す":{"variants":"すりつぶす/すり潰す/磨りつぶす/磨り潰す"},"擂り潰す":{"variants":"すりつぶす/すり潰す/擂りつぶす/擂り潰す"},"磨りつぶす":{"variants":"すりつぶす/すり潰す/磨りつぶす/磨り潰す"},"擂りつぶす":{"variants":"すりつぶす/すり潰す/擂りつぶす/擂り潰す"},"すりぬける":{"variants":"すりぬける/すり抜ける/摺り抜ける"},"すり抜ける":{"variants":"すりぬける/すり抜ける/摺り抜ける"},"摺り抜ける":{"variants":"すりぬける/すり抜ける/摺り抜ける"},"すりばち":{"variants":"すりばち/すり鉢/擂り鉢/擂鉢"},"すり鉢":{"variants":"すりばち/すり鉢/擂り鉢/擂鉢"},"擂り鉢":{"variants":"すりばち/すり鉢/擂り鉢/擂鉢"},"擂鉢":{"variants":"すりばち/すり鉢/擂り鉢/擂鉢"},"すりへらす":{"variants":"すりへらす/すり減らす"},"すり減らす":{"variants":"すりへらす/すり減らす"},"すりへる":{"variants":"すりへる/すり減る"},"すり減る":{"variants":"すりへる/すり減る"},"すりまぜる":{"variants":"すりまぜる/すり混ぜる"},"すり混ぜる":{"variants":"すりまぜる/すり混ぜる"},"すり身":{"variants":"すり身/擂身"},"擂身":{"variants":"すり身/擂身"},"すりむく":{"variants":"すりむく/擦りむく"},"擦りむく":{"variants":"すりむく/擦りむく"},"すりむける":{"variants":"すりむける/擦りむける/擦り剥ける"},"擦りむける":{"variants":"すりむける/擦りむける/擦り剥ける"},"擦り剥ける":{"variants":"すりむける/擦りむける/擦り剥ける"},"すりよる":{"variants":"すりよる/すり寄る/擦り寄る/擦寄る"},"すり寄る":{"variants":"すりよる/すり寄る/擦り寄る/擦寄る"},"擦り寄る":{"variants":"すりよる/すり寄る/擦り寄る/擦寄る"},"擦寄る":{"variants":"すりよる/すり寄る/擦り寄る/擦寄る"},"する":{"variants":"する/スる/刷る/摺る/磨る/擂る"},"スる":{"variants":"する/スる/刷る/摺る/磨る/擂る"},"するする":{"variants":"するする/スルスル"},"スルスル":{"variants":"するする/スルスル"},"するどい":{"variants":"するどい/鋭い"},"鋭い":{"variants":"するどい/鋭い"},"スルメ":{"variants":"スルメ/鯣"},"鯣":{"variants":"スルメ/鯣"},"スルメイカ":{"variants":"スルメイカ/鯣烏賊"},"鯣烏賊":{"variants":"スルメイカ/鯣烏賊"},"すれあう":{"variants":"すれあう/擦れあう/擦れ合う"},"擦れあう":{"variants":"すれあう/擦れあう/擦れ合う"},"擦れ合う":{"variants":"すれあう/擦れあう/擦れ合う"},"すれすれ":{"variants":"すれすれ/擦れすれ/擦れ擦れ"},"擦れすれ":{"variants":"すれすれ/擦れすれ/擦れ擦れ"},"擦れ擦れ":{"variants":"すれすれ/擦れすれ/擦れ擦れ"},"すれちがう":{"variants":"すれちがう/すれ違う/スレ違う/擦れ違う"},"すれ違う":{"variants":"すれちがう/すれ違う/スレ違う/擦れ違う"},"スレ違う":{"variants":"すれちがう/すれ違う/スレ違う/擦れ違う"},"擦れ違う":{"variants":"すれちがう/すれ違う/スレ違う/擦れ違う"},"すれる":{"variants":"すれる/刷れる/摺れる/摩れる/磨れる/擂れる"},"坐り込み":{"variants":"坐り込み/坐込み"},"座り込み":{"variants":"座りこみ/座り込み/座込み"},"座りこみ":{"variants":"座りこみ/座り込み/座込み"},"坐込み":{"variants":"坐り込み/坐込み"},"座込み":{"variants":"座りこみ/座り込み/座込み"},"すわりこむ":{"variants":"すわりこむ/すわり込む/坐りこむ/坐り込む/座りこむ/座り込む"},"すわり込む":{"variants":"すわりこむ/すわり込む/坐りこむ/坐り込む/座りこむ/座り込む"},"坐り込む":{"variants":"すわりこむ/すわり込む/坐りこむ/坐り込む"},"坐りこむ":{"variants":"すわりこむ/すわり込む/坐りこむ/坐り込む"},"座り込む":{"variants":"すわりこむ/すわり込む/座りこむ/座り込む"},"座りこむ":{"variants":"すわりこむ/すわり込む/座りこむ/座り込む"},"すわりこめる":{"variants":"すわりこめる/すわり込める/座りこめる/座り込める"},"すわり込める":{"variants":"すわりこめる/すわり込める/座りこめる/座り込める"},"座りこめる":{"variants":"すわりこめる/すわり込める/座りこめる/座り込める"},"座り込める":{"variants":"すわりこめる/すわり込める/座りこめる/座り込める"},"座り胼胝":{"variants":"座りだこ/座り胼胝/座胼胝"},"坐胼胝":{"variants":"坐りだこ/坐り胼胝/坐胼胝"},"座胼胝":{"variants":"座りだこ/座り胼胝/座胼胝"},"坐りだこ":{"variants":"坐りだこ/坐り胼胝/坐胼胝"},"座りだこ":{"variants":"座りだこ/座り胼胝/座胼胝"},"坐り胼胝":{"variants":"坐りだこ/坐り胼胝/坐胼胝"},"すわる":{"variants":"すわる/坐る/座る/据わる"},"すわれる":{"variants":"すわれる/座れる"},"座れる":{"variants":"すわれる/座れる"},"寸々":{"variants":"寸々/寸寸"},"寸寸":{"variants":"寸々/寸寸"},"すんたる":{"variants":"すんたる/寸たる"},"寸たる":{"variants":"すんたる/寸たる"},"寸づまり":{"variants":"寸づまり/寸詰り"},"寸詰り":{"variants":"寸づまり/寸詰り"},"すんなり":{"variants":"すんなり/スンナリ"},"スンナリ":{"variants":"すんなり/スンナリ"},"ズイ":{"variants":"ズイ/随/髄/隋"},"ずいぶん":{"variants":"ずいぶん/随分"},"随分":{"variants":"ずいぶん/随分"},"ズイムシ":{"variants":"ズイムシ/螟虫"},"螟虫":{"variants":"ズイムシ/螟虫"},"ずうずうしい":{"variants":"ずうずうしい/図々しい/図図しい"},"図々しい":{"variants":"ずうずうしい/図々しい/図図しい"},"図図しい":{"variants":"ずうずうしい/図々しい/図図しい"},"ずうたい":{"variants":"ずうたい/図体"},"図体":{"variants":"ずうたい/図体"},"頭がい骨":{"variants":"頭がい骨/頭蓋骨"},"頭蓋骨":{"variants":"頭がい骨/頭蓋骨"},"ずきずき":{"variants":"ずきずき/ズキズキ"},"ズキズキ":{"variants":"ずきずき/ズキズキ"},"ズク":{"variants":"ズク/銑"},"銑":{"variants":"ズク/銑"},"ずけずけ":{"variants":"ずけずけ/ズケズケ"},"ズケズケ":{"variants":"ずけずけ/ズケズケ"},"ズサン":{"variants":"ズサン/杜撰"},"杜撰":{"variants":"ズサン/杜撰"},"ずだ袋":{"variants":"ずだ袋/頭陀袋"},"頭陀袋":{"variants":"ずだ袋/頭陀袋"},"ずぬける":{"variants":"ずぬける/図抜ける/頭抜ける"},"ずばずば":{"variants":"ずばずば/ズバズバ"},"ズバズバ":{"variants":"ずばずば/ズバズバ"},"ずばぬける":{"variants":"ずばぬける/ずば抜ける"},"ずば抜ける":{"variants":"ずばぬける/ずば抜ける"},"ずぶとい":{"variants":"ずぶとい/図太い"},"図太い":{"variants":"ずぶとい/図太い"},"ズボンした":{"variants":"ズボンした/ズボン下"},"ズボン下":{"variants":"ズボンした/ズボン下"},"ズボンつり":{"variants":"ズボンつり/ズボン吊"},"ズボン吊":{"variants":"ズボンつり/ズボン吊"},"ずみ":{"variants":"ずみ/済み"},"済み":{"variants":"ずみ/済み"},"ずり":{"variants":"ずり/図利"},"図利":{"variants":"ずり/図利"},"ずりあがる":{"variants":"ずりあがる/ずり上がる"},"ずり上がる":{"variants":"ずりあがる/ずり上がる"},"ずりおちる":{"variants":"ずりおちる/ずり落ちる"},"ずり落ちる":{"variants":"ずりおちる/ずり落ちる"},"ずるずる":{"variants":"ずるずる/ズルズル"},"ズルズル":{"variants":"ずるずる/ズルズル"},"ずれこむ":{"variants":"ずれこむ/ずれ込む/ズレ込む"},"ずれ込む":{"variants":"ずれこむ/ずれ込む/ズレ込む"},"ズレ込む":{"variants":"ずれこむ/ずれ込む/ズレ込む"},"ずれこめる":{"variants":"ずれこめる/ずれ込める"},"ずれ込める":{"variants":"ずれこめる/ずれ込める"},"ずれる":{"variants":"ずれる/ズレる"},"ズレる":{"variants":"ずれる/ズレる"},"セ":{"variants":"セ/瀬"},"瀬":{"variants":"セ/瀬"},"せいいっぱい":{"variants":"せいいっぱい/精いっぱい/精一杯"},"精いっぱい":{"variants":"精いっぱい/精一杯"},"精一杯":{"variants":"精いっぱい/精一杯"},"セイウチ":{"variants":"セイウチ/海象"},"海象":{"variants":"セイウチ/海象"},"精かん":{"variants":"精かん/精悍"},"精悍":{"variants":"精かん/精悍"},"制ガン剤":{"variants":"制ガン剤/制癌剤"},"制癌剤":{"variants":"制ガン剤/制癌剤"},"セイゴ":{"variants":"セイゴ/成語/生後"},"成算":{"variants":"成さん/成算"},"せい惨":{"variants":"せい惨/凄惨"},"凄惨":{"variants":"せい惨/凄惨"},"成さん":{"variants":"成さん/成算"},"星ざ":{"variants":"星ざ/星座"},"星座":{"variants":"星ざ/星座"},"せいす":{"variants":"せいす/制す"},"制す":{"variants":"せいす/制す"},"せいする":{"variants":"せいする/制する/征する/製する"},"せいせい":{"variants":"せいせい/清々/清清/生成/精製"},"清々":{"variants":"せいせい/清々/清清"},"清清":{"variants":"せいせい/清々/清清"},"せいせいどうどう":{"variants":"せいせいどうどう/正々堂々/正正堂堂"},"正々堂々":{"variants":"正々堂々/正正堂堂"},"正正堂堂":{"variants":"正々堂々/正正堂堂"},"性腺":{"variants":"性せん/性腺"},"性せん":{"variants":"性せん/性腺"},"せいぜんと":{"variants":"せいぜんと/整然と"},"整然と":{"variants":"せいぜんと/整然と"},"せいだす":{"variants":"せいだす/精出す"},"精出す":{"variants":"せいだす/精出す"},"せいだせる":{"variants":"せいだせる/精出せる"},"精出せる":{"variants":"せいだせる/精出せる"},"精緻":{"variants":"精ち/精緻"},"精ち":{"variants":"精ち/精緻"},"整とん":{"variants":"整とん/整頓"},"整頓":{"variants":"整とん/整頓"},"精農":{"variants":"精のう/精農"},"精のう":{"variants":"精のう/精農"},"静ひつ":{"variants":"静ひつ/静謐"},"静謐":{"variants":"静ひつ/静謐"},"せいらい":{"variants":"せいらい/生来"},"生来":{"variants":"せいらい/生来"},"せおいこめる":{"variants":"せおいこめる/背負い込める"},"背負い込める":{"variants":"せおいこめる/背負い込める"},"背おいなげ":{"variants":"背おいなげ/背負投"},"背負投":{"variants":"背おいなげ/背負投"},"せおえる":{"variants":"せおえる/背負える"},"背負える":{"variants":"せおえる/背負える"},"世界じゅう":{"variants":"世界じゅう/世界中"},"世界中":{"variants":"世界じゅう/世界中"},"せかす":{"variants":"せかす/急かす"},"急かす":{"variants":"せかす/急かす"},"せかせる":{"variants":"せかせる/急かせる"},"急かせる":{"variants":"せかせる/急かせる"},"セガレ":{"variants":"セガレ/倅/伜/悴"},"せきあげる":{"variants":"せきあげる/咳きあげる/咳き上げる/塞き上げる"},"咳きあげる":{"variants":"せきあげる/咳きあげる/咳き上げる"},"咳き上げる":{"variants":"せきあげる/咳きあげる/咳き上げる"},"せきいる":{"variants":"せきいる/せき入る/咳き入る"},"せき入る":{"variants":"せきいる/せき入る/咳き入る"},"咳き入る":{"variants":"せきいる/せき入る/咳き入る"},"せきこむ":{"variants":"せきこむ/せき込む/咳きこむ/咳き込む/咳込む/急き込む"},"せき込む":{"variants":"せきこむ/せき込む/咳きこむ/咳き込む/咳込む/急き込む"},"咳き込む":{"variants":"せきこむ/せき込む/咳きこむ/咳き込む/咳込む"},"咳きこむ":{"variants":"せきこむ/せき込む/咳きこむ/咳き込む/咳込む"},"咳込む":{"variants":"せきこむ/せき込む/咳きこむ/咳き込む/咳込む"},"セキショウ":{"variants":"セキショウ/石菖"},"石菖":{"variants":"セキショウ/石菖"},"せき髄":{"variants":"せき髄/セキズイ/脊髄"},"セキズイ":{"variants":"せき髄/セキズイ/脊髄"},"脊髄":{"variants":"せき髄/セキズイ/脊髄"},"セキセイインコ":{"variants":"セキセイインコ/脊黄青いんこ"},"脊黄青いんこ":{"variants":"セキセイインコ/脊黄青いんこ"},"寂々":{"variants":"寂々/寂寂"},"寂寂":{"variants":"寂々/寂寂"},"せきたてる":{"variants":"せきたてる/せき立てる/急き立てる"},"せき立てる":{"variants":"せきたてる/せき立てる/急き立てる"},"急き立てる":{"variants":"せきたてる/せき立てる/急き立てる"},"セキチク":{"variants":"セキチク/石竹"},"石竹":{"variants":"セキチク/石竹"},"セキチクイロ":{"variants":"セキチクイロ/石竹色"},"石竹色":{"variants":"セキチクイロ/石竹色"},"せき柱":{"variants":"せき柱/石柱/脊柱"},"せきつい":{"variants":"せきつい/セキツイ/脊椎"},"セキツイ":{"variants":"せきつい/セキツイ/脊椎"},"脊椎":{"variants":"せきつい/セキツイ/脊椎"},"せきつい動物":{"variants":"せきつい動物/セキツイ動物/脊椎動物"},"セキツイ動物":{"variants":"せきつい動物/セキツイ動物/脊椎動物"},"脊椎動物":{"variants":"せきつい動物/セキツイ動物/脊椎動物"},"せきとめる":{"variants":"せきとめる/せき止める/塞き止める"},"せき止める":{"variants":"せきとめる/せき止める/塞き止める"},"塞き止める":{"variants":"せきとめる/せき止める/塞き止める"},"咳ばらい":{"variants":"咳ばらい/咳払い"},"咳払い":{"variants":"咳ばらい/咳払い"},"赤裸々":{"variants":"赤裸々/赤裸裸"},"赤裸裸":{"variants":"赤裸々/赤裸裸"},"セキレイ":{"variants":"セキレイ/鶺鴒"},"鶺鴒":{"variants":"セキレイ/鶺鴒"},"せぎる":{"variants":"せぎる/瀬切る"},"瀬切る":{"variants":"せぎる/瀬切る"},"せく":{"variants":"せく/堰く/咳く/急く/塞く"},"せぐくまる":{"variants":"せぐくまる/跼る"},"跼る":{"variants":"せぐくまる/跼る"},"背すじ":{"variants":"背すじ/背筋"},"背筋":{"variants":"背すじ/背筋"},"せせらわらう":{"variants":"せせらわらう/せせら笑う"},"せせら笑う":{"variants":"せせらわらう/せせら笑う"},"せせらわらえる":{"variants":"せせらわらえる/せせら笑える"},"せせら笑える":{"variants":"せせらわらえる/せせら笑える"},"世々":{"variants":"世々/世世"},"世世":{"variants":"世々/世世"},"背たけ":{"variants":"背たけ/背丈"},"背丈":{"variants":"背たけ/背丈"},"せちがらい":{"variants":"せちがらい/せち辛い/世知辛い"},"せち辛い":{"variants":"せちがらい/せち辛い/世知辛い"},"世知辛い":{"variants":"せちがらい/せち辛い/世知辛い"},"せっけん":{"variants":"せっけん/石けん/石鹸/節倹"},"石鹸":{"variants":"せっけん/石けん/石鹸"},"石けん":{"variants":"せっけん/石けん/石鹸"},"石こう":{"variants":"石こう/石膏"},"石膏":{"variants":"石こう/石膏"},"セッコク":{"variants":"セッコク/石刻/石斛"},"せっさたくま":{"variants":"せっさたくま/切磋琢磨"},"切磋琢磨":{"variants":"せっさたくま/切磋琢磨"},"せっする":{"variants":"せっする/接する/摂する/節する"},"セッソク動物":{"variants":"セッソク動物/節足動物"},"節足動物":{"variants":"セッソク動物/節足動物"},"せっぱつまる":{"variants":"せっぱつまる/せっぱ詰まる/切羽詰まる/切羽詰る"},"せっぱ詰まる":{"variants":"せっぱつまる/せっぱ詰まる/切羽詰まる/切羽詰る"},"切羽詰まる":{"variants":"せっぱつまる/せっぱ詰まる/切羽詰まる/切羽詰る"},"切羽詰る":{"variants":"せっぱつまる/せっぱ詰まる/切羽詰まる/切羽詰る"},"摂護せん":{"variants":"摂護せん/摂護腺"},"摂護腺":{"variants":"摂護せん/摂護腺"},"切々":{"variants":"切々/切切"},"切切":{"variants":"切々/切切"},"せつせつと":{"variants":"せつせつと/切々と"},"切々と":{"variants":"せつせつと/切々と"},"せつない":{"variants":"せつない/切ない"},"切ない":{"variants":"せつない/切ない"},"せつに":{"variants":"せつに/切に"},"切に":{"variants":"せつに/切に"},"背なか":{"variants":"背なか/背中"},"背中":{"variants":"背なか/背中"},"背中合せ":{"variants":"背中合せ/背中合わせ"},"背中合わせ":{"variants":"背中合せ/背中合わせ"},"背のび":{"variants":"背のび/背伸び"},"背伸び":{"variants":"背のび/背伸び"},"せばまる":{"variants":"せばまる/狭まる"},"狭まる":{"variants":"せばまる/狭まる"},"せばめる":{"variants":"せばめる/狭める"},"狭める":{"variants":"せばめる/狭める"},"背びれ":{"variants":"背びれ/背鰭"},"背鰭":{"variants":"背びれ/背鰭"},"せまい":{"variants":"せまい/狭い"},"狭い":{"variants":"せまい/狭い"},"せまくるしい":{"variants":"せまくるしい/狭苦しい"},"狭苦しい":{"variants":"せまくるしい/狭苦しい"},"せまる":{"variants":"せまる/迫る"},"迫る":{"variants":"せまる/迫る"},"せまれる":{"variants":"せまれる/迫れる"},"迫れる":{"variants":"せまれる/迫れる"},"セミ":{"variants":"セミ/蝉"},"蝉":{"variants":"セミ/蝉"},"蝉しぐれ":{"variants":"蝉しぐれ/蝉時雨"},"蝉時雨":{"variants":"蝉しぐれ/蝉時雨"},"責":{"variants":"責/責め"},"責め":{"variants":"責/責め"},"せめあう":{"variants":"せめあう/責め合う"},"責め合う":{"variants":"せめあう/責め合う"},"せめおとす":{"variants":"せめおとす/攻め落す/攻め落とす/責め落とす"},"攻め落とす":{"variants":"せめおとす/攻め落す/攻め落とす"},"攻め落す":{"variants":"せめおとす/攻め落す/攻め落とす"},"せめおとせる":{"variants":"せめおとせる/攻め落とせる/責め落とせる"},"せめかける":{"variants":"せめかける/攻めかける/攻め懸ける/攻懸ける"},"攻めかける":{"variants":"せめかける/攻めかける/攻め懸ける/攻懸ける"},"攻め懸ける":{"variants":"せめかける/攻めかける/攻め懸ける/攻懸ける"},"攻懸ける":{"variants":"せめかける/攻めかける/攻め懸ける/攻懸ける"},"攻め口":{"variants":"攻め口/攻口"},"攻口":{"variants":"攻め口/攻口"},"せめこむ":{"variants":"せめこむ/攻め込む"},"攻め込む":{"variants":"せめこむ/攻め込む"},"せめさいなむ":{"variants":"せめさいなむ/責めさいなむ/責め苛む"},"責めさいなむ":{"variants":"せめさいなむ/責めさいなむ/責め苛む"},"責め苛む":{"variants":"せめさいなむ/責めさいなむ/責め苛む"},"せめたてる":{"variants":"せめたてる/攻めたてる/攻め立てる/攻立てる/責めたてる/責め立てる/責立てる"},"攻めたてる":{"variants":"せめたてる/攻めたてる/攻め立てる/攻立てる"},"攻め立てる":{"variants":"せめたてる/攻めたてる/攻め立てる/攻立てる"},"責立てる":{"variants":"せめたてる/責めたてる/責め立てる/責立てる"},"責めたてる":{"variants":"せめたてる/責めたてる/責め立てる/責立てる"},"責め立てる":{"variants":"せめたてる/責めたてる/責め立てる/責立てる"},"攻立てる":{"variants":"せめたてる/攻めたてる/攻め立てる/攻立てる"},"攻め太鼓":{"variants":"攻め太鼓/攻太鼓"},"攻太鼓":{"variants":"攻め太鼓/攻太鼓"},"せめつける":{"variants":"せめつける/責めつける/責め付ける/責付ける"},"責めつける":{"variants":"せめつける/責めつける/責め付ける/責付ける"},"責め付ける":{"variants":"せめつける/責めつける/責め付ける/責付ける"},"責付ける":{"variants":"せめつける/責めつける/責め付ける/責付ける"},"攻道具":{"variants":"攻め道具/攻道具"},"攻め道具":{"variants":"攻め道具/攻道具"},"せめのぼる":{"variants":"せめのぼる/攻めのぼる/攻め上る/攻上る"},"攻めのぼる":{"variants":"せめのぼる/攻めのぼる/攻め上る/攻上る"},"攻め上る":{"variants":"せめのぼる/攻めのぼる/攻め上る/攻上る"},"攻上る":{"variants":"せめのぼる/攻めのぼる/攻め上る/攻上る"},"せめよせる":{"variants":"せめよせる/攻め寄せる/攻寄せる"},"攻め寄せる":{"variants":"せめよせる/攻め寄せる/攻寄せる"},"攻寄せる":{"variants":"せめよせる/攻め寄せる/攻寄せる"},"せめよる":{"variants":"せめよる/攻め寄る/攻寄る"},"攻め寄る":{"variants":"せめよる/攻め寄る/攻寄る"},"攻寄る":{"variants":"せめよる/攻め寄る/攻寄る"},"せめる":{"variants":"せめる/攻める/責める"},"セリ":{"variants":"セリ/競り/芹/糶り"},"競り合い":{"variants":"競り合い/競合い"},"競合い":{"variants":"競り合い/競合い"},"せりあう":{"variants":"せりあう/せり合う/競り合う/競合う"},"せり合う":{"variants":"せりあう/せり合う/競り合う/競合う"},"競り合う":{"variants":"せりあう/せり合う/競り合う/競合う"},"競合う":{"variants":"せりあう/せり合う/競り合う/競合う"},"せりあえる":{"variants":"せりあえる/競り合える"},"競り合える":{"variants":"せりあえる/競り合える"},"せりあげる":{"variants":"せりあげる/せり上げる/競り上げる/競上げる/迫り上げる"},"せり上げる":{"variants":"せりあげる/せり上げる/競り上げる/競上げる/迫り上げる"},"競り上げる":{"variants":"せりあげる/せり上げる/競り上げる/競上げる"},"競上げる":{"variants":"せりあげる/せり上げる/競り上げる/競上げる"},"競り市":{"variants":"競り市/競市"},"競市":{"variants":"競り市/競市"},"せりおとす":{"variants":"せりおとす/せり落す/競り落す"},"せり落す":{"variants":"せりおとす/せり落す/競り落す"},"競り落す":{"variants":"せりおとす/せり落す/競り落す"},"せり出し":{"variants":"せり出し/迫り出し"},"迫り出し":{"variants":"せり出し/迫り出し"},"せりだす":{"variants":"せりだす/せり出す/迫り出す"},"せり出す":{"variants":"せりだす/せり出す/迫り出す"},"迫り出す":{"variants":"せりだす/せり出す/迫り出す"},"せりふ":{"variants":"せりふ/セリフ/科白"},"セリフ":{"variants":"せりふ/セリフ/科白"},"科白":{"variants":"せりふ/セリフ/科白"},"せる":{"variants":"せる/競る/糶る"},"セロ":{"variants":"セロ/世路"},"世路":{"variants":"セロ/世路"},"せわしない":{"variants":"せわしない/忙しない"},"忙しない":{"variants":"せわしない/忙しない"},"せん":{"variants":"せん/栓/潜/線/腺/詮/選"},"セン":{"variants":"セン/戦/線/腺/船/選"},"せんえつ":{"variants":"せんえつ/僭越"},"僭越":{"variants":"せんえつ/僭越"},"せん方":{"variants":"せん方/詮方"},"詮方":{"variants":"せん方/詮方"},"繊切り":{"variants":"繊切/繊切り"},"繊切":{"variants":"繊切/繊切り"},"せんこう":{"variants":"せんこう/せん孔/先攻/先行/専攻/専行/潜幸/潜航/潜行/穿孔/選好/選考/選鉱/遷幸/銓衡"},"せん孔":{"variants":"せんこう/せん孔/穿孔"},"穿孔":{"variants":"せんこう/せん孔/穿孔"},"せん光":{"variants":"せん光/閃光"},"閃光":{"variants":"せん光/閃光"},"煎じぐすり":{"variants":"煎じぐすり/煎じ薬"},"煎じ薬":{"variants":"煎じぐすり/煎じ薬"},"せんじつめる":{"variants":"せんじつめる/煎じつめる/煎じ詰める"},"煎じつめる":{"variants":"せんじつめる/煎じつめる/煎じ詰める"},"煎じ詰める":{"variants":"せんじつめる/煎じつめる/煎じ詰める"},"せんじる":{"variants":"せんじる/煎じる"},"煎じる":{"variants":"せんじる/煎じる"},"センス":{"variants":"センス/扇子"},"扇子":{"variants":"センス/扇子"},"せんする":{"variants":"せんする/宣する/撰する/僭する"},"せんせい":{"variants":"せんせい/先生/専制/穿井"},"戦々兢々":{"variants":"戦々兢々/戦戦兢兢"},"戦々恐々":{"variants":"戦々恐々/戦戦恐恐"},"戦戦兢兢":{"variants":"戦々兢々/戦戦兢兢"},"戦戦恐恐":{"variants":"戦々恐々/戦戦恐恐"},"せんだって":{"variants":"せんだって/先だって"},"先だって":{"variants":"せんだって/先だって"},"せん断":{"variants":"せん断/専断/擅断"},"センダン":{"variants":"センダン/栴檀/船団"},"センチ":{"variants":"センチ/戦地/糎"},"ｃｍ":{"variants":"ｃｍ/センチメートル/糎"},"センチメートル":{"variants":"ｃｍ/センチメートル/糎"},"糎":{"variants":"ｃｍ/センチメートル/糎"},"せん茶":{"variants":"せん茶/煎茶"},"煎茶":{"variants":"せん茶/煎茶"},"せん痛":{"variants":"せん痛/疝痛"},"疝痛":{"variants":"せん痛/疝痛"},"せん定":{"variants":"せん定/選定/剪定"},"尖塔":{"variants":"せん塔/尖塔"},"せん塔":{"variants":"せん塔/尖塔"},"煽動":{"variants":"せん動/煽動"},"扇動":{"variants":"せん動/扇動"},"せん動":{"variants":"せん動/扇動/煽動"},"せんない":{"variants":"せんない/詮無い"},"詮無い":{"variants":"せんない/詮無い"},"センニチコウ":{"variants":"センニチコウ/千日紅"},"千日紅":{"variants":"センニチコウ/千日紅"},"せん馬":{"variants":"せん馬/騙馬"},"騙馬":{"variants":"せん馬/騙馬"},"千羽づる":{"variants":"千羽づる/千羽鶴"},"千羽鶴":{"variants":"千羽づる/千羽鶴"},"センブリ":{"variants":"センブリ/千振"},"千振":{"variants":"センブリ/千振"},"せんべい":{"variants":"せんべい/せん餅/煎餅"},"せん餅":{"variants":"せんべい/せん餅/煎餅"},"煎餅":{"variants":"せんべい/せん餅/煎餅"},"せんべい布団":{"variants":"せんべい布団/煎餅布団"},"煎餅布団":{"variants":"せんべい布団/煎餅布団"},"せん別":{"variants":"せん別/選別"},"選別":{"variants":"せん別/選別"},"先べん":{"variants":"先べん/先鞭"},"先鞭":{"variants":"先べん/先鞭"},"せん望":{"variants":"せん望/羨望"},"羨望":{"variants":"せん望/羨望"},"センボンシメジ":{"variants":"センボンシメジ/千本しめじ"},"千本しめじ":{"variants":"センボンシメジ/千本しめじ"},"先鋒":{"variants":"先ぽう/先鋒"},"先ぽう":{"variants":"先ぽう/先方/先鋒"},"先方":{"variants":"先ぽう/先方"},"千枚漬":{"variants":"千枚漬/千枚漬け"},"千枚漬け":{"variants":"千枚漬/千枚漬け"},"せん滅":{"variants":"せん滅/殲滅"},"殲滅":{"variants":"せん滅/殲滅"},"繊毛":{"variants":"せん毛/繊毛"},"せん妄":{"variants":"せん妄/譫妄"},"せん毛":{"variants":"せん毛/旋毛/繊毛"},"譫妄":{"variants":"せん妄/譫妄"},"旋毛":{"variants":"せん毛/旋毛"},"戦りつ":{"variants":"戦りつ/戦慄"},"戦慄":{"variants":"戦りつ/戦慄"},"せんりゅう":{"variants":"せんりゅう/川柳"},"川柳":{"variants":"せんりゅう/川柳"},"センリョウ":{"variants":"センリョウ/千両/染料/線量/選良"},"ぜい金":{"variants":"ぜい金/税金"},"税金":{"variants":"ぜい金/税金"},"税込":{"variants":"税込/税込み"},"税込み":{"variants":"税込/税込み"},"ぜい弱":{"variants":"ぜい弱/脆弱"},"脆弱":{"variants":"ぜい弱/脆弱"},"ぜい沢":{"variants":"ぜいたく/ぜい沢/贅沢"},"贅沢":{"variants":"ぜいたく/ぜい沢/贅沢"},"ぜいたく":{"variants":"ぜいたく/ぜい沢/贅沢"},"ぜい肉":{"variants":"ぜい肉/ゼイ肉/贅肉"},"ゼイ肉":{"variants":"ぜい肉/ゼイ肉/贅肉"},"贅肉":{"variants":"ぜい肉/ゼイ肉/贅肉"},"是々非々":{"variants":"是々非々/是是非非"},"是是非非":{"variants":"是々非々/是是非非"},"ぜっする":{"variants":"ぜっする/絶する"},"絶する":{"variants":"ぜっする/絶する"},"ぜったい":{"variants":"ぜったい/絶対"},"絶対":{"variants":"ぜったい/絶対"},"ぜったいに":{"variants":"ぜったいに/絶対に"},"絶対に":{"variants":"ぜったいに/絶対に"},"ゼニガメ":{"variants":"ゼニガメ/銭龜"},"銭龜":{"variants":"ゼニガメ/銭龜"},"ゼニゴケ":{"variants":"ゼニゴケ/銭苔"},"銭苔":{"variants":"ゼニゴケ/銭苔"},"ぜひ":{"variants":"ぜひ/是非"},"是非":{"variants":"ぜひ/是非"},"ぜひとも":{"variants":"ぜひとも/是非とも"},"是非とも":{"variants":"ぜひとも/是非とも"},"ぜん":{"variants":"ぜん/膳"},"膳":{"variants":"ぜん/膳"},"前景":{"variants":"前けい/前景"},"前けい":{"variants":"前けい/前掲/前景"},"前掲":{"variants":"前けい/前掲"},"ぜんじ":{"variants":"ぜんじ/漸次"},"漸次":{"variants":"ぜんじ/漸次"},"ぜんそく":{"variants":"ぜんそく/ぜん息/喘息"},"ぜん息":{"variants":"ぜんそく/ぜん息/喘息"},"喘息":{"variants":"ぜんそく/ぜん息/喘息"},"ぜんたい":{"variants":"ぜんたい/全体"},"全体":{"variants":"ぜんたい/全体"},"ぜんぱんに":{"variants":"ぜんぱんに/全般に"},"全般に":{"variants":"ぜんぱんに/全般に"},"ぜんぶ":{"variants":"ぜんぶ/全部"},"全部":{"variants":"ぜんぶ/全部"},"全ぼう":{"variants":"全ぼう/全貌"},"全貌":{"variants":"全ぼう/全貌"},"ゼンマイ":{"variants":"ゼンマイ/薇"},"薇":{"variants":"ゼンマイ/薇"},"前立せん":{"variants":"前立せん/前立腺"},"前立腺":{"variants":"前立せん/前立腺"},"そいとげる":{"variants":"そいとげる/添いとげる/添い遂げる"},"添いとげる":{"variants":"そいとげる/添いとげる/添い遂げる"},"添い遂げる":{"variants":"そいとげる/添いとげる/添い遂げる"},"そう":{"variants":"そう/層/艘"},"そうい":{"variants":"そうい/僧位/僧衣/創意/創痍/総意"},"そういっそう":{"variants":"そういっそう/層一層"},"層一層":{"variants":"そういっそう/層一層"},"そう快":{"variants":"そう快/壮快/爽快"},"総掛かり":{"variants":"総掛かり/総掛り"},"総掛り":{"variants":"総掛かり/総掛り"},"ソウギョ":{"variants":"ソウギョ/草魚"},"草魚":{"variants":"ソウギョ/草魚"},"総くずれ":{"variants":"総くずれ/総崩れ"},"総崩れ":{"variants":"総くずれ/総崩れ"},"巣くつ":{"variants":"巣くつ/巣窟"},"巣窟":{"variants":"巣くつ/巣窟"},"そうけだつ":{"variants":"そうけだつ/総毛立つ"},"総毛立つ":{"variants":"そうけだつ/総毛立つ"},"総ざらい":{"variants":"総ざらい/総浚い"},"総浚い":{"variants":"総ざらい/総浚い"},"ソウシジュ":{"variants":"ソウシジュ/相思樹"},"相思樹":{"variants":"ソウシジュ/相思樹"},"そう失":{"variants":"そう失/喪失"},"喪失":{"variants":"そう失/喪失"},"そう身":{"variants":"そう身/痩身/総身"},"そうじて":{"variants":"そうじて/惣じて"},"惣じて":{"variants":"そうじて/惣じて"},"そうぜんと":{"variants":"そうぜんと/騒然と"},"騒然と":{"variants":"そうぜんと/騒然と"},"そうそう":{"variants":"そうそう/早々/早早/草々/草創/草草/葬送/蒼々/蒼蒼/匆々/匆匆/怱々/怱怱/淙々/淙淙/錚々/錚錚"},"淙淙":{"variants":"そうそう/淙々/淙淙"},"淙々":{"variants":"そうそう/淙々/淙淙"},"草草":{"variants":"そうそう/草々/草草"},"錚錚":{"variants":"そうそう/錚々/錚錚"},"早早":{"variants":"はやばや/早早"},"怱々":{"variants":"そうそう/怱々/怱怱"},"怱怱":{"variants":"そうそう/怱々/怱怱"},"匆匆":{"variants":"そうそう/匆々/匆匆"},"蒼蒼":{"variants":"そうそう/蒼々/蒼蒼"},"草々":{"variants":"そうそう/草々/草草"},"錚々":{"variants":"そうそう/錚々/錚錚"},"早々":{"variants":"そうそう/早々/早早"},"匆々":{"variants":"そうそう/匆々/匆匆"},"蒼々":{"variants":"そうそう/蒼々/蒼蒼"},"そうぞうしい":{"variants":"そうぞうしい/騒々しい/騒騒しい"},"騒々しい":{"variants":"そうぞうしい/騒々しい/騒騒しい"},"騒騒しい":{"variants":"そうぞうしい/騒々しい/騒騒しい"},"ソウダガツオ":{"variants":"ソウダガツオ/宗太鰹/惣太鰹"},"そうてい":{"variants":"そうてい/壮丁/漕艇"},"装てん":{"variants":"装てん/装填"},"装填":{"variants":"装てん/装填"},"総なめ":{"variants":"総なめ/総嘗め"},"総嘗め":{"variants":"総なめ/総嘗め"},"そう入":{"variants":"そう入/挿入"},"挿入":{"variants":"そう入/挿入"},"そうばん":{"variants":"そうばん/早晩"},"早晩":{"variants":"そうばん/早晩"},"そう病":{"variants":"そう病/躁病"},"躁病":{"variants":"そう病/躁病"},"双へき":{"variants":"双へき/双璧"},"双璧":{"variants":"双へき/双璧"},"そうべつ":{"variants":"そうべつ/総別"},"総別":{"variants":"そうべつ/総別"},"総まくり":{"variants":"総まくり/総捲り"},"総捲り":{"variants":"総まくり/総捲り"},"僧りょ":{"variants":"僧りょ/僧侶"},"僧侶":{"variants":"僧りょ/僧侶"},"そうろう":{"variants":"そうろう/候う"},"候う":{"variants":"そうろう/候う"},"添え書き":{"variants":"添え書き/添書"},"添書":{"variants":"添え書き/添書"},"添え木":{"variants":"添え木/添木"},"添木":{"variants":"添え木/添木"},"添乳":{"variants":"添え乳/添乳"},"添え乳":{"variants":"添え乳/添乳"},"添えもの":{"variants":"添えもの/添え物/添物"},"添え物":{"variants":"添えもの/添え物/添物"},"添物":{"variants":"添えもの/添え物/添物"},"そえる":{"variants":"そえる/添える/副える"},"そぎ板":{"variants":"そぎ板/殺ぎ板"},"殺ぎ板":{"variants":"そぎ板/殺ぎ板"},"そぎ竹":{"variants":"そぎ竹/殺ぎ竹"},"殺ぎ竹":{"variants":"そぎ竹/殺ぎ竹"},"そくす":{"variants":"そくす/則す/即す"},"そくする":{"variants":"そくする/則する/即する"},"側側":{"variants":"側々/側側"},"側々":{"variants":"側々/側側"},"惻惻":{"variants":"惻々/惻惻"},"惻々":{"variants":"惻々/惻惻"},"そぐ":{"variants":"そぐ/削ぐ/殺ぐ"},"ソケイ":{"variants":"ソケイ/粗景/素馨/鼠径/鼠蹊"},"そげる":{"variants":"そげる/削げる/殺げる"},"そこしる":{"variants":"そこしる/底知る"},"底知る":{"variants":"そこしる/底知る"},"そこなう":{"variants":"そこなう/損なう"},"損なう":{"variants":"そこなう/損なう"},"底なし":{"variants":"底なし/底無し"},"底無し":{"variants":"底なし/底無し"},"底ぬけ":{"variants":"底ぬけ/底抜け"},"底抜け":{"variants":"底ぬけ/底抜け"},"そこねる":{"variants":"そこねる/損ねる"},"損ねる":{"variants":"そこねる/損ねる"},"底ひ":{"variants":"底ひ/底翳"},"底翳":{"variants":"底ひ/底翳"},"底引網":{"variants":"底引き網/底引網"},"底引き網":{"variants":"底引き網/底引網"},"そ菜":{"variants":"そ菜/蔬菜"},"蔬菜":{"variants":"そ菜/蔬菜"},"組織だつ":{"variants":"組織だつ/組織立つ"},"組織立つ":{"variants":"組織だつ/組織立つ"},"そしる":{"variants":"そしる/誹る/謗る/譏る"},"そ上":{"variants":"そ上/俎上"},"俎上":{"variants":"そ上/俎上"},"楚々":{"variants":"楚々/楚楚"},"楚楚":{"variants":"楚々/楚楚"},"そそぎいれる":{"variants":"そそぎいれる/そそぎ入れる"},"そそぎ入れる":{"variants":"そそぎいれる/そそぎ入れる"},"そそぎこむ":{"variants":"そそぎこむ/そそぎ込む"},"そそぎ込む":{"variants":"そそぎこむ/そそぎ込む"},"そそぐ":{"variants":"そそぐ/雪ぐ"},"雪ぐ":{"variants":"そそぐ/雪ぐ"},"そそげる":{"variants":"そそげる/濯げる"},"濯げる":{"variants":"そそげる/濯げる"},"そそと":{"variants":"そそと/楚々と"},"楚々と":{"variants":"そそと/楚々と"},"そそのかす":{"variants":"そそのかす/唆す"},"唆す":{"variants":"そそのかす/唆す"},"そそりたつ":{"variants":"そそりたつ/そそり立つ"},"そそり立つ":{"variants":"そそりたつ/そそり立つ"},"そそりたてる":{"variants":"そそりたてる/そそり立てる"},"そそり立てる":{"variants":"そそりたてる/そそり立てる"},"そぞろ歩き":{"variants":"そぞろ歩き/漫ろ歩き"},"漫ろ歩き":{"variants":"そぞろ歩き/漫ろ歩き"},"漫ろごころ":{"variants":"そぞろ心/漫ろごころ/漫ろ言/漫ろ心"},"漫ろ心":{"variants":"そぞろ心/漫ろごころ/漫ろ心"},"そぞろ心":{"variants":"そぞろ心/漫ろごころ/漫ろ心"},"そだつ":{"variants":"そだつ/育つ"},"育つ":{"variants":"そだつ/育つ"},"そだてあげる":{"variants":"そだてあげる/育てあげる/育て上げる"},"育てあげる":{"variants":"そだてあげる/育てあげる/育て上げる"},"育て上げる":{"variants":"そだてあげる/育てあげる/育て上げる"},"そだてる":{"variants":"そだてる/育てる"},"育てる":{"variants":"そだてる/育てる"},"そっきゅう":{"variants":"そっきゅう/即急/速急"},"素っくび":{"variants":"素っくび/素っ首"},"素っ首":{"variants":"素っくび/素っ首"},"そっくりかえる":{"variants":"そっくりかえる/そっくり返る/反っくり返る"},"そっくり返る":{"variants":"そっくりかえる/そっくり返る/反っくり返る"},"反っくり返る":{"variants":"そっくりかえる/そっくり返る/反っくり返る"},"そっけ":{"variants":"そっけ/素っ気"},"素っ気":{"variants":"そっけ/素っ気"},"そっする":{"variants":"そっする/卒する"},"卒する":{"variants":"そっする/卒する"},"そっ歯":{"variants":"そっ歯/反っ歯"},"反っ歯":{"variants":"そっ歯/反っ歯"},"ソツ":{"variants":"ソツ/卒/卆"},"ソテツ":{"variants":"ソテツ/蘇鉄"},"蘇鉄":{"variants":"ソテツ/蘇鉄"},"そで":{"variants":"そで/袖"},"袖":{"variants":"そで/袖"},"そで口":{"variants":"そで口/袖口"},"袖口":{"variants":"そで口/袖口"},"外まわり":{"variants":"外まわり/外回り"},"外回り":{"variants":"外まわり/外回り"},"そなえつける":{"variants":"そなえつける/備えつける/備え付ける/備付ける"},"備えつける":{"variants":"そなえつける/備えつける/備え付ける/備付ける"},"備え付ける":{"variants":"そなえつける/備えつける/備え付ける/備付ける"},"備付ける":{"variants":"そなえつける/備えつける/備え付ける/備付ける"},"そなえる":{"variants":"そなえる/供える/具える/備える"},"磯馴れ松":{"variants":"磯馴れ松/磯馴松"},"磯馴松":{"variants":"磯馴れ松/磯馴松"},"そなわる":{"variants":"そなわる/具わる/備わる"},"そねむ":{"variants":"そねむ/嫉む"},"嫉む":{"variants":"そねむ/嫉む"},"その":{"variants":"その/其の"},"其の":{"variants":"その/其の"},"そのもの":{"variants":"そのもの/其の物"},"其の物":{"variants":"そのもの/其の物"},"そば":{"variants":"そば/ソバ/蕎/蕎麦"},"ソバ":{"variants":"そば/ソバ/蕎/蕎麦"},"ソバカス":{"variants":"ソバカス/蕎麦滓/雀斑"},"そば切り":{"variants":"そば切り/蕎麦切り"},"蕎麦切り":{"variants":"そば切り/蕎麦切り"},"そばだつ":{"variants":"そばだつ/峙つ"},"峙つ":{"variants":"そばだつ/峙つ"},"そばだてる":{"variants":"そばだてる/欹てる"},"欹てる":{"variants":"そばだてる/欹てる"},"そばめる":{"variants":"そばめる/側める"},"側める":{"variants":"そばめる/側める"},"そば湯":{"variants":"そば湯/蕎麦湯"},"蕎麦湯":{"variants":"そば湯/蕎麦湯"},"そびえたつ":{"variants":"そびえたつ/そびえ立つ"},"そびえ立つ":{"variants":"そびえたつ/そびえ立つ"},"そびえる":{"variants":"そびえる/聳える"},"聳える":{"variants":"そびえる/聳える"},"そびやかす":{"variants":"そびやかす/聳やかす"},"聳やかす":{"variants":"そびやかす/聳やかす"},"そぼぬれる":{"variants":"そぼぬれる/そぼ濡れる"},"そぼ濡れる":{"variants":"そぼぬれる/そぼ濡れる"},"そぼふる":{"variants":"そぼふる/そぼ降る"},"そぼ降る":{"variants":"そぼふる/そぼ降る"},"そまる":{"variants":"そまる/染まる/染る"},"染まる":{"variants":"そまる/染まる/染る"},"染る":{"variants":"そまる/染まる/染る"},"そむく":{"variants":"そむく/背く"},"背く":{"variants":"そむく/背く"},"そむける":{"variants":"そむける/背ける"},"背ける":{"variants":"そむける/背ける"},"染":{"variants":"染/染め"},"染め":{"variants":"染/染め"},"染め上り":{"variants":"染め上り/染上り"},"染上り":{"variants":"染め上り/染上り"},"そめあげる":{"variants":"そめあげる/染めあげる/染め上げる/染上げる"},"染めあげる":{"variants":"そめあげる/染めあげる/染め上げる/染上げる"},"染め上げる":{"variants":"そめあげる/染めあげる/染め上げる/染上げる"},"染上げる":{"variants":"そめあげる/染めあげる/染め上げる/染上げる"},"ソメイヨシノ":{"variants":"ソメイヨシノ/染井吉野"},"染井吉野":{"variants":"ソメイヨシノ/染井吉野"},"染め替え":{"variants":"染め替え/染替え"},"染替え":{"variants":"染め替え/染替え"},"そめかえす":{"variants":"そめかえす/染めかえす/染め返す/染返す"},"染めかえす":{"variants":"そめかえす/染めかえす/染め返す/染返す"},"染め返す":{"variants":"そめかえす/染めかえす/染め返す/染返す"},"染返す":{"variants":"そめかえす/染めかえす/染め返す/染返す"},"染め粉":{"variants":"染め粉/染粉"},"染粉":{"variants":"染め粉/染粉"},"そめだす":{"variants":"そめだす/染め出す/染出す"},"染め出す":{"variants":"そめだす/染め出す/染出す"},"染出す":{"variants":"そめだす/染め出す/染出す"},"そめだせる":{"variants":"そめだせる/染め出せる"},"染め出せる":{"variants":"そめだせる/染め出せる"},"染め付け":{"variants":"染め付け/染付け"},"染付け":{"variants":"染め付け/染付け"},"そめつける":{"variants":"そめつける/染め付ける"},"染め付ける":{"variants":"そめつける/染め付ける"},"そめなおす":{"variants":"そめなおす/染め直す/染直す"},"染め直す":{"variants":"そめなおす/染め直す/染直す"},"染直す":{"variants":"そめなおす/染め直す/染直す"},"そめなおせる":{"variants":"そめなおせる/染め直せる"},"染め直せる":{"variants":"そめなおせる/染め直せる"},"そめぬく":{"variants":"そめぬく/染め抜く/染抜く"},"染め抜く":{"variants":"そめぬく/染め抜く/染抜く"},"染抜く":{"variants":"そめぬく/染め抜く/染抜く"},"染め物":{"variants":"染め物/染物"},"染物":{"variants":"染め物/染物"},"染め模様":{"variants":"染め模様/染模様"},"染模様":{"variants":"染め模様/染模様"},"そめる":{"variants":"そめる/初める/染める"},"染め分け":{"variants":"染め分け/染分け"},"染分け":{"variants":"染め分け/染分け"},"そめわける":{"variants":"そめわける/染めわける/染め分ける/染分ける"},"染めわける":{"variants":"そめわける/染めわける/染め分ける/染分ける"},"染め分ける":{"variants":"そめわける/染めわける/染め分ける/染分ける"},"染分ける":{"variants":"そめわける/染めわける/染め分ける/染分ける"},"そもさん":{"variants":"そもさん/什麼生"},"什麼生":{"variants":"そもさん/什麼生"},"そもそも":{"variants":"そもそも/抑"},"抑":{"variants":"そもそも/抑"},"そよがす":{"variants":"そよがす/戦がす"},"戦がす":{"variants":"そよがす/戦がす"},"そよぐ":{"variants":"そよぐ/戦ぐ"},"戦ぐ":{"variants":"そよぐ/戦ぐ"},"そよふく":{"variants":"そよふく/そよ吹く"},"そよ吹く":{"variants":"そよふく/そよ吹く"},"そらうそぶく":{"variants":"そらうそぶく/空嘯く"},"空嘯く":{"variants":"そらうそぶく/空嘯く"},"そらおそろしい":{"variants":"そらおそろしい/空恐ろしい"},"空恐ろしい":{"variants":"そらおそろしい/空恐ろしい"},"そらす":{"variants":"そらす/逸らす/外らす/反らす"},"そらせる":{"variants":"そらせる/逸らせる/外らせる/反らせる"},"そらぞらしい":{"variants":"そらぞらしい/空々しい/空空しい"},"空々しい":{"variants":"そらぞらしい/空々しい/空空しい"},"空空しい":{"variants":"そらぞらしい/空々しい/空空しい"},"そらとぼける":{"variants":"そらとぼける/空惚ける"},"空惚ける":{"variants":"そらとぼける/空惚ける"},"そら似":{"variants":"そら似/空似"},"空似":{"variants":"そら似/空似"},"そらはずかしい":{"variants":"そらはずかしい/空恥しい"},"空恥しい":{"variants":"そらはずかしい/空恥しい"},"そら豆":{"variants":"そら豆/ソラマメ/空豆/蚕豆"},"ソラマメ":{"variants":"そら豆/ソラマメ/空豆/蚕豆"},"そら耳":{"variants":"そら耳/空耳"},"空耳":{"variants":"そら耳/空耳"},"そらんずる":{"variants":"そらんずる/諳んずる"},"諳んずる":{"variants":"そらんずる/諳んずる"},"そり":{"variants":"そり/反り/橇"},"そりおとす":{"variants":"そりおとす/剃り落とす"},"剃り落とす":{"variants":"そりおとす/剃り落とす"},"そりおとせる":{"variants":"そりおとせる/剃り落とせる"},"剃り落とせる":{"variants":"そりおとせる/剃り落とせる"},"そりかえる":{"variants":"そりかえる/そり返る/反り返る/反返る"},"そり返る":{"variants":"そりかえる/そり返る/反り返る/反返る"},"反り返る":{"variants":"そりかえる/そり返る/反り返る/反返る"},"反返る":{"variants":"そりかえる/そり返る/反り返る/反返る"},"そりくりかえる":{"variants":"そりくりかえる/そりくり返る/反りくり返る"},"そりくり返る":{"variants":"そりくりかえる/そりくり返る/反りくり返る"},"反りくり返る":{"variants":"そりくりかえる/そりくり返る/反りくり返る"},"反り橋":{"variants":"反り橋/反橋"},"反橋":{"variants":"反り橋/反橋"},"反り身":{"variants":"反り身/反身"},"反身":{"variants":"反り身/反身"},"そる":{"variants":"そる/反る"},"反る":{"variants":"そる/反る"},"それほど":{"variants":"それほど/それ程"},"それ程":{"variants":"それほど/それ程"},"それる":{"variants":"それる/逸れる/反れる"},"そろい":{"variants":"そろい/揃"},"揃":{"variants":"そろい/揃"},"そろう":{"variants":"そろう/揃う"},"揃う":{"variants":"そろう/揃う"},"そろえる":{"variants":"そろえる/揃える"},"揃える":{"variants":"そろえる/揃える"},"ソロバン":{"variants":"ソロバン/算盤/十露盤"},"そろばんだかい":{"variants":"そろばんだかい/算盤高い/十露盤高い"},"そわせる":{"variants":"そわせる/添わせる"},"添わせる":{"variants":"そわせる/添わせる"},"そわそわ":{"variants":"そわそわ/ソワソワ"},"ソワソワ":{"variants":"そわそわ/ソワソワ"},"そわる":{"variants":"そわる/添わる"},"添わる":{"variants":"そわる/添わる"},"そんしょく":{"variants":"そんしょく/そん色/遜色"},"そん色":{"variants":"そんしょく/そん色/遜色"},"遜色":{"variants":"そんしょく/そん色/遜色"},"そんじる":{"variants":"そんじる/損じる"},"損じる":{"variants":"そんじる/損じる"},"そんする":{"variants":"そんする/存する/損する"},"そんずる":{"variants":"そんずる/損ずる"},"損ずる":{"variants":"そんずる/損ずる"},"ゾウ":{"variants":"ゾウ/象/像/増/造"},"造けい":{"variants":"造けい/造型/造形"},"ぞうする":{"variants":"ぞうする/蔵する"},"蔵する":{"variants":"ぞうする/蔵する"},"ゾウムシ":{"variants":"ゾウムシ/象虫"},"象虫":{"variants":"ゾウムシ/象虫"},"ゾウリムシ":{"variants":"ゾウリムシ/草履虫"},"草履虫":{"variants":"ゾウリムシ/草履虫"},"ぞくす":{"variants":"ぞくす/属す"},"属す":{"variants":"ぞくす/属す"},"ぞくする":{"variants":"ぞくする/属する/賊する"},"ぞくぞく":{"variants":"ぞくぞく/ゾクゾク/続続"},"ゾクゾク":{"variants":"ぞくぞく/ゾクゾク/続続"},"続続":{"variants":"ぞくぞく/ゾクゾク/続続"},"ぞくっぽい":{"variants":"ぞくっぽい/俗っぽい"},"俗っぽい":{"variants":"ぞくっぽい/俗っぽい"},"ぞっと":{"variants":"ぞっと/ゾッと"},"ゾッと":{"variants":"ぞっと/ゾッと"},"ぞろぞろ":{"variants":"ぞろぞろ/ゾロゾロ"},"ゾロゾロ":{"variants":"ぞろぞろ/ゾロゾロ"},"ぞんがい":{"variants":"ぞんがい/存外"},"存外":{"variants":"ぞんがい/存外"},"存じ":{"variants":"存じ/存知"},"存知":{"variants":"存じ/存知"},"ぞんじあげる":{"variants":"ぞんじあげる/存じ上げる"},"存じ上げる":{"variants":"ぞんじあげる/存じ上げる"},"ぞんじる":{"variants":"ぞんじる/存じる"},"存じる":{"variants":"ぞんじる/存じる"},"ぞんずる":{"variants":"ぞんずる/存ずる"},"存ずる":{"variants":"ぞんずる/存ずる"},"ぞんぶん":{"variants":"ぞんぶん/存分"},"存分":{"variants":"ぞんぶん/存分"},"たあい":{"variants":"たあい/他愛"},"他愛":{"variants":"たあい/他愛"},"田遊":{"variants":"田遊/田遊び"},"田遊び":{"variants":"田遊/田遊び"},"タイ":{"variants":"タイ/他意/態/隊/鯛"},"たいおうづける":{"variants":"たいおうづける/対応付ける"},"対応付ける":{"variants":"たいおうづける/対応付ける"},"たいがい":{"variants":"たいがい/体外/対外/大概"},"対がん":{"variants":"対がん/対顔"},"対顔":{"variants":"対がん/対顔"},"たいこ腹":{"variants":"たいこ腹/太鼓腹"},"太鼓腹":{"variants":"たいこ腹/太鼓腹"},"タイサンボク":{"variants":"タイサンボク/泰山木/大山木"},"たいした":{"variants":"たいした/大した"},"大した":{"variants":"たいした/大した"},"たいして":{"variants":"たいして/大して"},"大して":{"variants":"たいして/大して"},"たいじ":{"variants":"たいじ/対じ/対峠/対峙/帯磁/退治"},"対峠":{"variants":"たいじ/対じ/対峠"},"対峙":{"variants":"たいじ/対じ/対峙"},"対じ":{"variants":"たいじ/対じ/対峠/対峙"},"たいす":{"variants":"たいす/対す"},"対す":{"variants":"たいす/対す"},"たいする":{"variants":"たいする/体する/対する/帯する"},"堆積":{"variants":"たい積/堆積"},"たい積":{"variants":"たい積/堆積/滞積"},"滞積":{"variants":"たい積/滞積"},"たいそう":{"variants":"たいそう/大層"},"大層":{"variants":"たいそう/大層"},"たいそうらしい":{"variants":"たいそうらしい/大層らしい"},"大層らしい":{"variants":"たいそうらしい/大層らしい"},"タイマ":{"variants":"タイマ/大麻"},"大麻":{"variants":"タイマ/大麻"},"タイマイ":{"variants":"たい瑁/タイマイ/大枚/玳瑁"},"たい瑁":{"variants":"たい瑁/タイマイ/玳瑁"},"玳瑁":{"variants":"たい瑁/タイマイ/玳瑁"},"タイヤ":{"variants":"タイヤ/逮夜"},"逮夜":{"variants":"タイヤ/逮夜"},"平":{"variants":"平/平ら"},"平ら":{"variants":"平/平ら"},"たいらぐ":{"variants":"たいらぐ/平らぐ"},"平らぐ":{"variants":"たいらぐ/平らぐ"},"たいらげる":{"variants":"たいらげる/平らげる"},"平らげる":{"variants":"たいらげる/平らげる"},"たえいる":{"variants":"たえいる/絶え入る/絶入る"},"絶え入る":{"variants":"たえいる/絶え入る/絶入る"},"絶入る":{"variants":"たえいる/絶え入る/絶入る"},"たえがたい":{"variants":"たえがたい/堪えがたい/堪え難い/堪難い/耐えがたい/耐え難い/耐難い"},"堪難い":{"variants":"たえがたい/堪えがたい/堪え難い/堪難い"},"耐難い":{"variants":"たえがたい/耐えがたい/耐え難い/耐難い"},"堪えがたい":{"variants":"たえがたい/堪えがたい/堪え難い/堪難い"},"耐えがたい":{"variants":"たえがたい/耐えがたい/耐え難い/耐難い"},"堪え難い":{"variants":"たえがたい/堪えがたい/堪え難い/堪難い"},"耐え難い":{"variants":"たえがたい/耐えがたい/耐え難い/耐難い"},"たえしのぶ":{"variants":"たえしのぶ/堪え忍ぶ/堪忍ぶ/耐え忍ぶ/耐忍ぶ"},"堪え忍ぶ":{"variants":"たえしのぶ/堪え忍ぶ/堪忍ぶ"},"耐え忍ぶ":{"variants":"たえしのぶ/耐え忍ぶ/耐忍ぶ"},"堪忍ぶ":{"variants":"たえしのぶ/堪え忍ぶ/堪忍ぶ"},"耐忍ぶ":{"variants":"たえしのぶ/耐え忍ぶ/耐忍ぶ"},"たえしのべる":{"variants":"たえしのべる/堪え忍べる"},"堪え忍べる":{"variants":"たえしのべる/堪え忍べる"},"たえず":{"variants":"たえず/絶えず"},"絶えず":{"variants":"たえず/絶えず"},"絶えだえ":{"variants":"絶えだえ/絶え絶え"},"絶え絶え":{"variants":"絶えだえ/絶え絶え"},"たえぬく":{"variants":"たえぬく/耐え抜く"},"耐え抜く":{"variants":"たえぬく/耐え抜く"},"たえはてる":{"variants":"たえはてる/絶えはてる/絶え果てる"},"絶えはてる":{"variants":"たえはてる/絶えはてる/絶え果てる"},"絶え果てる":{"variants":"たえはてる/絶えはてる/絶え果てる"},"絶えま":{"variants":"絶えま/絶え間/絶間"},"絶え間":{"variants":"絶えま/絶え間/絶間"},"絶間":{"variants":"絶えま/絶え間/絶間"},"たえる":{"variants":"たえる/絶える/耐える"},"たおす":{"variants":"たおす/倒す"},"倒す":{"variants":"たおす/倒す"},"たおせる":{"variants":"たおせる/倒せる"},"倒せる":{"variants":"たおせる/倒せる"},"たおる":{"variants":"たおる/手折る"},"手折る":{"variants":"たおる/手折る"},"たおれる":{"variants":"たおれる/手折れる/倒れる"},"タカ":{"variants":"タカ/多寡/鷹"},"たかい":{"variants":"たかい/高い"},"高い":{"variants":"たかい/高い"},"高いびき":{"variants":"高いびき/高鼾"},"高鼾":{"variants":"高いびき/高鼾"},"タカキビ":{"variants":"タカキビ/高黍"},"高黍":{"variants":"タカキビ/高黍"},"高曇":{"variants":"高曇/高曇り"},"高曇り":{"variants":"高曇/高曇り"},"高げた":{"variants":"高げた/高下駄"},"高下駄":{"variants":"高げた/高下駄"},"高々指":{"variants":"高々指/高高指"},"高高指":{"variants":"高々指/高高指"},"たかだか":{"variants":"たかだか/高々/高高"},"高々":{"variants":"たかだか/高々/高高"},"高高":{"variants":"たかだか/高々/高高"},"タカナ":{"variants":"タカナ/高菜"},"高菜":{"variants":"タカナ/高菜"},"たかなる":{"variants":"たかなる/高鳴る"},"高鳴る":{"variants":"たかなる/高鳴る"},"たかぶる":{"variants":"たかぶる/昂る/高ぶる"},"たかまる":{"variants":"たかまる/高まる"},"高まる":{"variants":"たかまる/高まる"},"たかめる":{"variants":"たかめる/高める"},"高める":{"variants":"たかめる/高める"},"宝くじ":{"variants":"宝くじ/宝籤"},"宝籤":{"variants":"宝くじ/宝籤"},"宝尽くし":{"variants":"宝尽くし/宝尽し"},"宝尽し":{"variants":"宝尽くし/宝尽し"},"たかる":{"variants":"たかる/集る"},"集る":{"variants":"たかる/集る"},"タガ":{"variants":"タガ/箍"},"箍":{"variants":"タガ/箍"},"互いちがい":{"variants":"互いちがい/互い違い/互違い"},"互い違い":{"variants":"互いちがい/互い違い/互違い"},"互違い":{"variants":"互いちがい/互い違い/互違い"},"タガメ":{"variants":"タガメ/田龜"},"田龜":{"variants":"タガメ/田龜"},"たがやす":{"variants":"たがやす/耕す"},"耕す":{"variants":"たがやす/耕す"},"たがやせる":{"variants":"たがやせる/耕せる"},"耕せる":{"variants":"たがやせる/耕せる"},"たきあがる":{"variants":"たきあがる/炊きあがる"},"炊きあがる":{"variants":"たきあがる/炊きあがる"},"たき合わせ":{"variants":"たき合わせ/炊合せ"},"炊合せ":{"variants":"たき合わせ/炊合せ"},"たきこむ":{"variants":"たきこむ/炊き込む"},"炊き込む":{"variants":"たきこむ/炊き込む"},"たきしめる":{"variants":"たきしめる/焚きしめる/焚き染める"},"焚きしめる":{"variants":"たきしめる/焚きしめる/焚き染める"},"焚き染める":{"variants":"たきしめる/焚きしめる/焚き染める"},"炊き出し":{"variants":"炊き出し/炊出し"},"炊出し":{"variants":"炊き出し/炊出し"},"たきつける":{"variants":"たきつける/焚きつける/焚き付ける"},"焚きつける":{"variants":"たきつける/焚きつける/焚き付ける"},"焚き付ける":{"variants":"たきつける/焚きつける/焚き付ける"},"滝つぼ":{"variants":"滝つぼ/滝壷"},"滝壷":{"variants":"滝つぼ/滝壷"},"焚き火":{"variants":"焚き火/焚火"},"焚火":{"variants":"焚き火/焚火"},"たき物":{"variants":"たき物/薫物/焚物"},"たぎつ":{"variants":"たぎつ/激つ/滾つ"},"たぎる":{"variants":"たぎる/滾る"},"滾る":{"variants":"たぎる/滾る"},"たく":{"variants":"たく/炊く/焚く"},"たくさん":{"variants":"たくさん/沢山"},"沢山":{"variants":"たくさん/沢山"},"たくす":{"variants":"たくす/托す/託す"},"たくする":{"variants":"たくする/托する/託する"},"たく鉢":{"variants":"たく鉢/托鉢"},"托鉢":{"variants":"たく鉢/托鉢"},"タクボク":{"variants":"タクボク/啄木"},"啄木":{"variants":"タクボク/啄木"},"たくましい":{"variants":"たくましい/逞しい"},"逞しい":{"variants":"たくましい/逞しい"},"たくましゅうする":{"variants":"たくましゅうする/逞しゅうする"},"逞しゅうする":{"variants":"たくましゅうする/逞しゅうする"},"たくみ":{"variants":"たくみ/巧み"},"巧み":{"variants":"たくみ/巧み"},"たくむ":{"variants":"たくむ/巧む"},"巧む":{"variants":"たくむ/巧む"},"たくらむ":{"variants":"たくらむ/企む"},"企む":{"variants":"たくらむ/企む"},"たくわえる":{"variants":"たくわえる/蓄える/貯える"},"たぐえる":{"variants":"たぐえる/比える/類える"},"たぐる":{"variants":"たぐる/手繰る"},"手繰る":{"variants":"たぐる/手繰る"},"たけ":{"variants":"たけ/タケ/岳/丈/他家/竹"},"タケ":{"variants":"たけ/タケ/岳/丈/他家/竹"},"竹ざお":{"variants":"竹ざお/竹竿"},"竹竿":{"variants":"竹ざお/竹竿"},"たけだけしい":{"variants":"たけだけしい/猛々しい/猛猛しい"},"猛々しい":{"variants":"たけだけしい/猛々しい/猛猛しい"},"猛猛しい":{"variants":"たけだけしい/猛々しい/猛猛しい"},"竹とんぼ":{"variants":"竹とんぼ/竹蜻蛉"},"竹蜻蛉":{"variants":"竹とんぼ/竹蜻蛉"},"たけなわ":{"variants":"たけなわ/酣/闌"},"タケニグサ":{"variants":"タケニグサ/竹似草"},"竹似草":{"variants":"タケニグサ/竹似草"},"タケノコ":{"variants":"タケノコ/竹の子/筍"},"たけのこ生活":{"variants":"たけのこ生活/筍生活"},"筍生活":{"variants":"たけのこ生活/筍生活"},"竹やぶ":{"variants":"竹やぶ/竹薮"},"竹薮":{"variants":"竹やぶ/竹薮"},"竹やり":{"variants":"竹やり/竹槍"},"竹槍":{"variants":"竹やり/竹槍"},"たけりたつ":{"variants":"たけりたつ/たけり立つ/猛り立つ/哮り立つ"},"たけり立つ":{"variants":"たけりたつ/たけり立つ/猛り立つ/哮り立つ"},"たける":{"variants":"たける/猛る/哮る"},"たこ":{"variants":"たこ/タコ/章魚/凧/蛸/胼胝/鮹"},"タコ":{"variants":"たこ/タコ/章魚/凧/蛸/胼胝/鮹"},"たこの木":{"variants":"たこの木/タコノキ/蛸の木"},"タコノキ":{"variants":"たこの木/タコノキ/蛸の木"},"蛸の木":{"variants":"たこの木/タコノキ/蛸の木"},"たしか":{"variants":"たしか/確か/慥か"},"たしかめる":{"variants":"たしかめる/確かめる/慥かめる"},"足し算":{"variants":"足し算/足算"},"足算":{"variants":"足し算/足算"},"たしなむ":{"variants":"たしなむ/嗜む"},"嗜む":{"variants":"たしなむ/嗜む"},"たしなめる":{"variants":"たしなめる/嗜める/窘める"},"たじたじ":{"variants":"たじたじ/タジタジ"},"タジタジ":{"variants":"たじたじ/タジタジ"},"たす":{"variants":"たす/足す"},"足す":{"variants":"たす/足す"},"たすかる":{"variants":"たすかる/助かる"},"助かる":{"variants":"たすかる/助かる"},"たすき":{"variants":"たすき/タスキ/襷"},"タスキ":{"variants":"たすき/タスキ/襷"},"襷":{"variants":"たすき/タスキ/襷"},"たすけあう":{"variants":"たすけあう/助け合う"},"助け合う":{"variants":"たすけあう/助け合う"},"たすけあえる":{"variants":"たすけあえる/助け合える"},"助け合える":{"variants":"たすけあえる/助け合える"},"たすけだす":{"variants":"たすけだす/助け出す"},"助け出す":{"variants":"たすけだす/助け出す"},"たすけだせる":{"variants":"たすけだせる/助け出せる"},"助け出せる":{"variants":"たすけだせる/助け出せる"},"助けぶね":{"variants":"助けぶね/助け舟/助け船"},"たすける":{"variants":"たすける/救ける"},"救ける":{"variants":"たすける/救ける"},"たずさえる":{"variants":"たずさえる/携える"},"携える":{"variants":"たずさえる/携える"},"たずさわる":{"variants":"たずさわる/携わる"},"携わる":{"variants":"たずさわる/携わる"},"たずねあわせる":{"variants":"たずねあわせる/尋ねあわせる/尋ね合せる"},"尋ねあわせる":{"variants":"たずねあわせる/尋ねあわせる/尋ね合せる"},"尋ね合せる":{"variants":"たずねあわせる/尋ねあわせる/尋ね合せる"},"たずね人":{"variants":"たずね人/尋ねびと/尋ね人"},"尋ねびと":{"variants":"たずね人/尋ねびと/尋ね人"},"尋ね人":{"variants":"たずね人/尋ねびと/尋ね人"},"尋ねもの":{"variants":"たずね者/たずね物/尋ねもの/尋ね者/尋ね物"},"尋ね者":{"variants":"たずね者/尋ねもの/尋ね者"},"たずね者":{"variants":"たずね者/尋ねもの/尋ね者"},"尋ね物":{"variants":"たずね物/尋ねもの/尋ね物"},"たずね物":{"variants":"たずね物/尋ねもの/尋ね物"},"たずねる":{"variants":"たずねる/尋ねる/訊ねる/訪ねる"},"たせる":{"variants":"たせる/足せる"},"足せる":{"variants":"たせる/足せる"},"たそがれ":{"variants":"たそがれ/黄昏"},"黄昏":{"variants":"たそがれ/黄昏"},"たた":{"variants":"たた/多々/多多"},"多々":{"variants":"たた/多々/多多"},"多多":{"variants":"たた/多々/多多"},"たたえる":{"variants":"たたえる/讃える/湛える/讚える/頌える"},"たたかう":{"variants":"たたかう/戦う/闘う"},"たたかえる":{"variants":"たたかえる/戦える/闘える"},"たたき":{"variants":"たたき/敲き"},"敲き":{"variants":"たたき/敲き"},"たたきあげる":{"variants":"たたきあげる/たたき上げる/叩きあげる/叩き上げる"},"たたき上げる":{"variants":"たたきあげる/たたき上げる/叩きあげる/叩き上げる"},"叩きあげる":{"variants":"たたきあげる/たたき上げる/叩きあげる/叩き上げる"},"叩き上げる":{"variants":"たたきあげる/たたき上げる/叩きあげる/叩き上げる"},"たたき売":{"variants":"たたき売/たたき売り/叩き売"},"たたき売り":{"variants":"たたき売/たたき売り/叩き売"},"叩き売":{"variants":"たたき売/たたき売り/叩き売"},"たたきおこす":{"variants":"たたきおこす/たたき起こす/たたき起す/叩き起す"},"たたき起こす":{"variants":"たたきおこす/たたき起こす/たたき起す/叩き起す"},"たたき起す":{"variants":"たたきおこす/たたき起こす/たたき起す/叩き起す"},"叩き起す":{"variants":"たたきおこす/たたき起こす/たたき起す/叩き起す"},"たたきおこせる":{"variants":"たたきおこせる/たたき起こせる"},"たたき起こせる":{"variants":"たたきおこせる/たたき起こせる"},"たたきおとす":{"variants":"たたきおとす/たたき落とす"},"たたき落とす":{"variants":"たたきおとす/たたき落とす"},"たたきこむ":{"variants":"たたきこむ/たたき込む/叩き込む"},"たたき込む":{"variants":"たたきこむ/たたき込む/叩き込む"},"叩き込む":{"variants":"たたきこむ/たたき込む/叩き込む"},"たたきこめる":{"variants":"たたきこめる/たたき込める"},"たたき込める":{"variants":"たたきこめる/たたき込める"},"たたき台":{"variants":"たたき台/叩き台"},"叩き台":{"variants":"たたき台/叩き台"},"たたきだす":{"variants":"たたきだす/たたき出す"},"たたき出す":{"variants":"たたきだす/たたき出す"},"たたきだせる":{"variants":"たたきだせる/たたき出せる"},"たたき出せる":{"variants":"たたきだせる/たたき出せる"},"たたきつける":{"variants":"たたきつける/叩きつける/叩き付ける"},"叩きつける":{"variants":"たたきつける/叩きつける/叩き付ける"},"叩き付ける":{"variants":"たたきつける/叩きつける/叩き付ける"},"たたく":{"variants":"たたく/敲く"},"敲く":{"variants":"たたく/敲く"},"たたす":{"variants":"たたす/立たす"},"立たす":{"variants":"たたす/立たす"},"たたずまい":{"variants":"たたずまい/佇まい"},"佇まい":{"variants":"たたずまい/佇まい"},"たたずむ":{"variants":"たたずむ/佇む"},"佇む":{"variants":"たたずむ/佇む"},"たたみかける":{"variants":"たたみかける/畳みかける/畳み掛ける"},"畳みかける":{"variants":"たたみかける/畳みかける/畳み掛ける"},"畳み掛ける":{"variants":"たたみかける/畳みかける/畳み掛ける"},"たたみこむ":{"variants":"たたみこむ/畳み込む"},"畳み込む":{"variants":"たたみこむ/畳み込む"},"たたみこめる":{"variants":"たたみこめる/畳み込める"},"畳み込める":{"variants":"たたみこめる/畳み込める"},"たたむ":{"variants":"たたむ/畳む"},"畳む":{"variants":"たたむ/畳む"},"たためる":{"variants":"たためる/畳める"},"畳める":{"variants":"たためる/畳める"},"たたり":{"variants":"たたり/祟"},"祟":{"variants":"たたり/祟"},"たたり目":{"variants":"たたり目/祟り目"},"祟り目":{"variants":"たたり目/祟り目"},"たたる":{"variants":"たたる/祟る"},"祟る":{"variants":"たたる/祟る"},"ただ":{"variants":"ただ/タダ/只/唯"},"タダ":{"variants":"ただ/タダ/只/唯"},"ただいま":{"variants":"ただいま/ただ今"},"ただ今":{"variants":"ただ今/只今/唯今"},"ただ事":{"variants":"ただ事/只事/徒事/唯事"},"ただし":{"variants":"ただし/但/但し"},"但":{"variants":"ただし/但/但し"},"但し":{"variants":"ただし/但/但し"},"ただしい":{"variants":"ただしい/正しい"},"正しい":{"variants":"ただしい/正しい"},"ただし書き":{"variants":"ただし書き/但し書き/但書/但書き"},"但し書き":{"variants":"ただし書き/但し書き/但書/但書き"},"但書":{"variants":"ただし書き/但し書き/但書/但書き"},"但書き":{"variants":"ただし書き/但し書き/但書/但書き"},"ただす":{"variants":"ただす/糾す/質す/正す/糺す"},"ただせる":{"variants":"ただせる/質せる/正せる"},"ただただ":{"variants":"ただただ/只只/唯唯"},"ただちに":{"variants":"ただちに/直ちに"},"直ちに":{"variants":"ただちに/直ちに"},"ただ中":{"variants":"ただ中/直中"},"直中":{"variants":"ただ中/直中"},"ただに":{"variants":"ただに/啻に"},"啻に":{"variants":"ただに/啻に"},"ただ者":{"variants":"ただ者/只者/徒者"},"ただよう":{"variants":"ただよう/漂う"},"漂う":{"variants":"ただよう/漂う"},"ただよわす":{"variants":"ただよわす/漂わす"},"漂わす":{"variants":"ただよわす/漂わす"},"ただれる":{"variants":"ただれる/爛れる"},"爛れる":{"variants":"ただれる/爛れる"},"たち":{"variants":"たち/達"},"達":{"variants":"たち/達"},"立ち会い":{"variants":"立ち会い/立会"},"立会":{"variants":"立ち会い/立会"},"たちあう":{"variants":"たちあう/立ち会う/立ち合う/立会う/立合う"},"立合う":{"variants":"たちあう/立ち合う/立合う"},"立会う":{"variants":"たちあう/立ち会う/立会う"},"立ち合う":{"variants":"たちあう/立ち合う/立合う"},"立ち会う":{"variants":"たちあう/立ち会う/立会う"},"たちあえる":{"variants":"たちあえる/立ち会える/立ち合える"},"タチアオイ":{"variants":"タチアオイ/立葵"},"立葵":{"variants":"タチアオイ/立葵"},"立ちあがり":{"variants":"立ちあがり/立ち上がり/立ち上り/立上り"},"立上り":{"variants":"立ちあがり/立ち上がり/立ち上り/立上り"},"裁ち上り":{"variants":"裁ちあがり/裁ち上り"},"立ち上り":{"variants":"立ちあがり/立ち上がり/立ち上り/立上り"},"立ち上がり":{"variants":"立ちあがり/立ち上がり/立ち上り/立上り"},"裁ちあがり":{"variants":"裁ちあがり/裁ち上り"},"たちあがる":{"variants":"たちあがる/立ちあがる/立ち上がる/立上がる"},"立ちあがる":{"variants":"たちあがる/立ちあがる/立ち上がる/立上がる"},"立ち上がる":{"variants":"たちあがる/立ちあがる/立ち上がる/立上がる"},"立上がる":{"variants":"たちあがる/立ちあがる/立ち上がる/立上がる"},"たちあがれる":{"variants":"たちあがれる/立ち上がれる"},"立ち上がれる":{"variants":"たちあがれる/立ち上がれる"},"立ち居":{"variants":"立ち居/立居"},"立居":{"variants":"立ち居/立居"},"たちいたる":{"variants":"たちいたる/立ち至る/立至る"},"立ち至る":{"variants":"たちいたる/立ち至る/立至る"},"立至る":{"variants":"たちいたる/立ち至る/立至る"},"立ち居ふるまい":{"variants":"立ち居ふるまい/立居振舞"},"立居振舞":{"variants":"立ち居ふるまい/立居振舞"},"たちいる":{"variants":"たちいる/立ち入る/立入る"},"立ち入る":{"variants":"たちいる/立ち入る/立入る"},"立入る":{"variants":"たちいる/立ち入る/立入る"},"たちいれる":{"variants":"たちいれる/立ち入れる"},"立ち入れる":{"variants":"たちいれる/立ち入れる"},"タチウオ":{"variants":"タチウオ/太刀魚"},"太刀魚":{"variants":"タチウオ/太刀魚"},"立ち往生":{"variants":"立ち往生/立往生"},"立往生":{"variants":"立ち往生/立往生"},"たちおくれる":{"variants":"たちおくれる/立ち後れる/立ち遅れる/立後れる/立遅れる"},"立遅れる":{"variants":"たちおくれる/立ち遅れる/立遅れる"},"立後れる":{"variants":"たちおくれる/立ち後れる/立後れる"},"立ち遅れる":{"variants":"たちおくれる/立ち遅れる/立遅れる"},"立ち後れる":{"variants":"たちおくれる/立ち後れる/立後れる"},"たちかえる":{"variants":"たちかえる/立ち返る/立返る"},"立ち返る":{"variants":"たちかえる/立ち返る/立返る"},"立返る":{"variants":"たちかえる/立ち返る/立返る"},"たちかわる":{"variants":"たちかわる/立ち代る/立ち代わる"},"立ち代る":{"variants":"たちかわる/立ち代る/立ち代わる"},"立ち代わる":{"variants":"たちかわる/立ち代る/立ち代わる"},"たちかわれる":{"variants":"たちかわれる/立ち代われる"},"立ち代われる":{"variants":"たちかわれる/立ち代われる"},"立ち枯れ":{"variants":"立ち枯れ/立枯れ"},"立枯れ":{"variants":"立ち枯れ/立枯れ"},"たちきる":{"variants":"たちきる/裁ち切る/断ち切る/断切る"},"断切る":{"variants":"たちきる/断ち切る/断切る"},"断ち切る":{"variants":"たちきる/断ち切る/断切る"},"たちきれる":{"variants":"たちきれる/断ち切れる"},"断ち切れる":{"variants":"たちきれる/断ち切れる"},"立ち消え":{"variants":"立ち消え/立消え"},"立消え":{"variants":"立ち消え/立消え"},"裁ち切れ":{"variants":"裁ち切れ/裁切れ"},"裁切れ":{"variants":"裁ち切れ/裁切れ"},"たちこむ":{"variants":"たちこむ/立ちこむ"},"立ちこむ":{"variants":"たちこむ/立ちこむ"},"たちこめる":{"variants":"たちこめる/立ちこめる/立ち込める/立ち篭める/立込める"},"立ちこめる":{"variants":"たちこめる/立ちこめる/立ち込める/立ち篭める/立込める"},"立込める":{"variants":"たちこめる/立ちこめる/立ち込める/立込める"},"立ち込める":{"variants":"たちこめる/立ちこめる/立ち込める/立込める"},"太刀さばき":{"variants":"太刀さばき/太刀捌き"},"太刀捌き":{"variants":"太刀さばき/太刀捌き"},"たちさる":{"variants":"たちさる/立ち去る/立去る"},"立ち去る":{"variants":"たちさる/立ち去る/立去る"},"立去る":{"variants":"たちさる/立ち去る/立去る"},"たちされる":{"variants":"たちされる/立ち去れる"},"立ち去れる":{"variants":"たちされる/立ち去れる"},"立ち姿":{"variants":"立ち姿/立姿"},"立姿":{"variants":"立ち姿/立姿"},"たちすくむ":{"variants":"たちすくむ/立ちすくむ/立ち竦む"},"立ちすくむ":{"variants":"たちすくむ/立ちすくむ/立ち竦む"},"立ち竦む":{"variants":"たちすくむ/立ちすくむ/立ち竦む"},"たちそう":{"variants":"たちそう/立ち添う/立添う"},"立ち添う":{"variants":"たちそう/立ち添う/立添う"},"立添う":{"variants":"たちそう/立ち添う/立添う"},"たちつくす":{"variants":"たちつくす/立ちつくす/立ち尽くす/立ち尽す"},"立ちつくす":{"variants":"たちつくす/立ちつくす/立ち尽くす/立ち尽す"},"立ち尽くす":{"variants":"たちつくす/立ちつくす/立ち尽くす/立ち尽す"},"立ち尽す":{"variants":"たちつくす/立ちつくす/立ち尽くす/立ち尽す"},"たちどころに":{"variants":"たちどころに/立ちどころに/立ち所に"},"立ちどころに":{"variants":"たちどころに/立ちどころに/立ち所に"},"立ち所に":{"variants":"たちどころに/立ちどころに/立ち所に"},"たちどまる":{"variants":"たちどまる/立ちどまる/立ち止まる/立ち止る"},"立ちどまる":{"variants":"たちどまる/立ちどまる/立ち止まる/立ち止る"},"立ち止まる":{"variants":"たちどまる/立ちどまる/立ち止まる/立ち止る"},"立ち止る":{"variants":"たちどまる/立ちどまる/立ち止まる/立ち止る"},"たちなおる":{"variants":"たちなおる/立ち直る/立直る"},"立ち直る":{"variants":"たちなおる/立ち直る/立直る"},"立直る":{"variants":"たちなおる/立ち直る/立直る"},"たちなおれる":{"variants":"たちなおれる/立ち直れる"},"立ち直れる":{"variants":"たちなおれる/立ち直れる"},"たちならぶ":{"variants":"たちならぶ/建ち並ぶ/立ちならぶ/立ち並ぶ/立並ぶ"},"立ちならぶ":{"variants":"たちならぶ/立ちならぶ/立ち並ぶ/立並ぶ"},"立ち並ぶ":{"variants":"たちならぶ/立ちならぶ/立ち並ぶ/立並ぶ"},"立並ぶ":{"variants":"たちならぶ/立ちならぶ/立ち並ぶ/立並ぶ"},"たちのく":{"variants":"たちのく/立ち退く/立退く"},"立ち退く":{"variants":"たちのく/立ち退く/立退く"},"立退く":{"variants":"たちのく/立ち退く/立退く"},"たちのける":{"variants":"たちのける/立ち退ける"},"立ち退ける":{"variants":"たちのける/立ち退ける"},"たちのぼる":{"variants":"たちのぼる/立ちのぼる/立ち上る"},"立ちのぼる":{"variants":"たちのぼる/立ちのぼる/立ち上る"},"立ち上る":{"variants":"たちのぼる/立ちのぼる/立ち上る"},"たちはたらく":{"variants":"たちはたらく/立ち働く/立働く"},"立ち働く":{"variants":"たちはたらく/立ち働く/立働く"},"立働く":{"variants":"たちはたらく/立ち働く/立働く"},"たちはだかる":{"variants":"たちはだかる/立ちはだかる"},"立ちはだかる":{"variants":"たちはだかる/立ちはだかる"},"タチバナ":{"variants":"タチバナ/橘"},"橘":{"variants":"タチバナ/橘"},"たちふさがる":{"variants":"たちふさがる/立ちふさがる/立ち塞がる"},"立ちふさがる":{"variants":"たちふさがる/立ちふさがる/立ち塞がる"},"立ち塞がる":{"variants":"たちふさがる/立ちふさがる/立ち塞がる"},"たちまちに":{"variants":"たちまちに/忽ちに"},"忽ちに":{"variants":"たちまちに/忽ちに"},"立待の月":{"variants":"立待の月/立待月"},"立待月":{"variants":"立待の月/立待月"},"たちまよう":{"variants":"たちまよう/立ち迷う/立迷う"},"立ち迷う":{"variants":"たちまよう/立ち迷う/立迷う"},"立迷う":{"variants":"たちまよう/立ち迷う/立迷う"},"立ち回り":{"variants":"立ち回り/立回り"},"立回り":{"variants":"立ち回り/立回り"},"たちまわる":{"variants":"たちまわる/立ち回る/立回る"},"立ち回る":{"variants":"たちまわる/立ち回る/立回る"},"立回る":{"variants":"たちまわる/立ち回る/立回る"},"立ち見":{"variants":"立ち見/立見"},"立見":{"variants":"立ち見/立見"},"たちむかう":{"variants":"たちむかう/立ち向かう/立向かう"},"立ち向かう":{"variants":"たちむかう/立ち向かう/立向かう"},"立向かう":{"variants":"たちむかう/立ち向かう/立向かう"},"たちむかえる":{"variants":"たちむかえる/立ち向かえる"},"立ち向かえる":{"variants":"たちむかえる/立ち向かえる"},"太刀持":{"variants":"太刀持/太刀持ち"},"太刀持ち":{"variants":"太刀持/太刀持ち"},"たちもどる":{"variants":"たちもどる/立ち戻る"},"立ち戻る":{"variants":"たちもどる/立ち戻る"},"断ち物":{"variants":"断ちもの/断ち物"},"断ちもの":{"variants":"断ちもの/断ち物"},"たちゆく":{"variants":"たちゆく/立ち行く/立行く"},"立ち行く":{"variants":"たちゆく/立ち行く/立行く"},"立行く":{"variants":"たちゆく/立ち行く/立行く"},"たちよる":{"variants":"たちよる/立ち寄る/立寄る"},"立ち寄る":{"variants":"たちよる/立ち寄る/立寄る"},"立寄る":{"variants":"たちよる/立ち寄る/立寄る"},"たちよれる":{"variants":"たちよれる/立ち寄れる"},"立ち寄れる":{"variants":"たちよれる/立ち寄れる"},"たちわる":{"variants":"たちわる/断ち割る"},"断ち割る":{"variants":"たちわる/断ち割る"},"たちわれる":{"variants":"たちわれる/断ち割れる"},"断ち割れる":{"variants":"たちわれる/断ち割れる"},"立ちんぼう":{"variants":"立ちんぼう/立ちん坊"},"立ちん坊":{"variants":"立ちんぼう/立ちん坊"},"達し":{"variants":"達し/達示"},"達示":{"variants":"達し/達示"},"たっする":{"variants":"たっする/達する/達っする"},"達する":{"variants":"たっする/達する/達っする"},"達っする":{"variants":"たっする/達する/達っする"},"たっとべる":{"variants":"たっとべる/貴べる/尊べる"},"たつ":{"variants":"たつ/起つ/経つ/建つ/裁つ/絶つ/断つ/発つ/立つ/佇つ/截つ"},"タツノオトシゴ":{"variants":"タツノオトシゴ/竜の落し子"},"竜の落し子":{"variants":"タツノオトシゴ/竜の落し子"},"田作":{"variants":"田作/田作り"},"田作り":{"variants":"田作/田作り"},"手綱さばき":{"variants":"手綱さばき/手綱捌き"},"手綱捌き":{"variants":"手綱さばき/手綱捌き"},"タテ":{"variants":"タテ/縦/楯/盾/竪"},"たて穴":{"variants":"たて穴/縦穴/竪穴"},"たて糸":{"variants":"たて糸/経糸/縦糸"},"建て売り":{"variants":"建て売り/建売/建売り"},"建売":{"variants":"建て売り/建売/建売り"},"建売り":{"variants":"建て売り/建売/建売り"},"たてかえる":{"variants":"たてかえる/建て替える/立て替える/立替える"},"立て替える":{"variants":"たてかえる/立て替える/立替える"},"立替える":{"variants":"たてかえる/立て替える/立替える"},"たてかける":{"variants":"たてかける/立てかける/立て掛ける/立掛ける"},"立てかける":{"variants":"たてかける/立てかける/立て掛ける/立掛ける"},"立て掛ける":{"variants":"たてかける/立てかける/立て掛ける/立掛ける"},"立掛ける":{"variants":"たてかける/立てかける/立て掛ける/立掛ける"},"たてがみ":{"variants":"たてがみ/鬣"},"鬣":{"variants":"たてがみ/鬣"},"たてこむ":{"variants":"たてこむ/たて込む/建て込む/立て込む/立込む"},"たて込む":{"variants":"たてこむ/たて込む/建て込む/立て込む/立込む"},"立込む":{"variants":"たてこむ/たて込む/立て込む/立込む"},"立て込む":{"variants":"たてこむ/たて込む/立て込む/立込む"},"たてこめる":{"variants":"たてこめる/立て込める"},"立て込める":{"variants":"たてこめる/立て込める"},"たてこもる":{"variants":"たてこもる/立てこもる/立て篭る"},"立てこもる":{"variants":"たてこもる/立てこもる/立て篭る"},"立て篭る":{"variants":"たてこもる/立てこもる/立て篭る"},"たてこもれる":{"variants":"たてこもれる/立てこもれる"},"立てこもれる":{"variants":"たてこもれる/立てこもれる"},"縦じま":{"variants":"縦じま/縦縞"},"縦縞":{"variants":"縦じま/縦縞"},"たてつく":{"variants":"たてつく/楯突く/盾突く"},"立て付け":{"variants":"立て付け/立付け"},"立付け":{"variants":"立て付け/立付け"},"たて続け":{"variants":"たて続け/立て続け"},"立て続け":{"variants":"たて続け/立て続け"},"たてとおす":{"variants":"たてとおす/立て通す/立通す"},"立て通す":{"variants":"たてとおす/立て通す/立通す"},"立通す":{"variants":"たてとおす/立て通す/立通す"},"たてなおす":{"variants":"たてなおす/建て直す/立て直す/立直す"},"立て直す":{"variants":"たてなおす/立て直す/立直す"},"立直す":{"variants":"たてなおす/立て直す/立直す"},"たてなおせる":{"variants":"たてなおせる/建て直せる/立て直せる"},"立て札":{"variants":"立て札/立札"},"立札":{"variants":"立て札/立札"},"建て前":{"variants":"建て前/建前"},"建前":{"variants":"建て前/建前"},"建て増し":{"variants":"建て増し/建増し"},"建増し":{"variants":"建て増し/建増し"},"立て役者":{"variants":"立て役者/立役者"},"立役者":{"variants":"立て役者/立役者"},"たてる":{"variants":"たてる/起てる/建てる/裁てる/絶てる/断てる/点てる/立てる"},"タデ":{"variants":"タデ/蓼"},"蓼":{"variants":"タデ/蓼"},"たとえ":{"variants":"たとえ/仮令"},"仮令":{"variants":"たとえ/仮令"},"たとえば":{"variants":"たとえば/例えば/譬えば"},"たとえる":{"variants":"たとえる/例える/喩える/譬える"},"たとへば":{"variants":"たとへば/例へば/譬へば"},"たどりつく":{"variants":"たどりつく/たどり着く"},"たどり着く":{"variants":"たどりつく/たどり着く"},"たどりつける":{"variants":"たどりつける/たどり着ける"},"たどり着ける":{"variants":"たどりつける/たどり着ける"},"たどる":{"variants":"たどる/辿る"},"辿る":{"variants":"たどる/辿る"},"たどれる":{"variants":"たどれる/辿れる"},"辿れる":{"variants":"たどれる/辿れる"},"タナ":{"variants":"タナ/棚"},"棚":{"variants":"タナ/棚"},"棚おろし":{"variants":"棚おろし/棚卸し"},"棚卸し":{"variants":"棚おろし/棚卸し"},"たなびく":{"variants":"たなびく/棚引く"},"棚引く":{"variants":"たなびく/棚引く"},"タナぼた":{"variants":"タナぼた/棚ぼた"},"棚ぼた":{"variants":"タナぼた/棚ぼた"},"タニク":{"variants":"タニク/多肉"},"多肉":{"variants":"タニク/多肉"},"タニシ":{"variants":"タニシ/田螺"},"田螺":{"variants":"タニシ/田螺"},"タヌキ":{"variants":"タヌキ/狸"},"狸":{"variants":"タヌキ/狸"},"たぬき寝入り":{"variants":"たぬき寝入り/狸寝入り"},"狸寝入り":{"variants":"たぬき寝入り/狸寝入り"},"狸ばやし":{"variants":"狸ばやし/狸囃子"},"狸囃子":{"variants":"狸ばやし/狸囃子"},"タネ":{"variants":"タネ/胤"},"胤":{"variants":"タネ/胤"},"タネ明かし":{"variants":"タネ明かし/種明かし/種明し"},"種明かし":{"variants":"タネ明かし/種明かし/種明し"},"種明し":{"variants":"タネ明かし/種明かし/種明し"},"種まき":{"variants":"種まき/種蒔"},"種蒔":{"variants":"種まき/種蒔"},"種もみ":{"variants":"種もみ/種籾"},"種籾":{"variants":"種もみ/種籾"},"タネン":{"variants":"タネン/他念"},"他念":{"variants":"タネン/他念"},"タネンソウ":{"variants":"タネンソウ/多年草"},"多年草":{"variants":"タネンソウ/多年草"},"たのしい":{"variants":"たのしい/楽しい/愉しい"},"たのしむ":{"variants":"たのしむ/楽しむ"},"楽しむ":{"variants":"たのしむ/楽しむ"},"たのしめる":{"variants":"たのしめる/楽しめる"},"楽しめる":{"variants":"たのしめる/楽しめる"},"たのみいる":{"variants":"たのみいる/頼み入る"},"頼み入る":{"variants":"たのみいる/頼み入る"},"たのみこむ":{"variants":"たのみこむ/頼みこむ/頼み込む"},"頼みこむ":{"variants":"たのみこむ/頼みこむ/頼み込む"},"頼み込む":{"variants":"たのみこむ/頼みこむ/頼み込む"},"たのみこめる":{"variants":"たのみこめる/頼み込める"},"頼み込める":{"variants":"たのみこめる/頼み込める"},"たのみすくない":{"variants":"たのみすくない/頼み少ない"},"頼み少ない":{"variants":"たのみすくない/頼み少ない"},"たのむ":{"variants":"たのむ/頼む"},"頼む":{"variants":"たのむ/頼む"},"たのめる":{"variants":"たのめる/頼める"},"頼める":{"variants":"たのめる/頼める"},"たのもしい":{"variants":"たのもしい/頼もしい"},"頼もしい":{"variants":"たのもしい/頼もしい"},"たのもし講":{"variants":"たのもし講/頼母子講"},"頼母子講":{"variants":"たのもし講/頼母子講"},"たばこ":{"variants":"たばこ/タバコ/煙草/烟草/莨"},"タバコ":{"variants":"たばこ/タバコ/煙草/烟草/莨"},"たばさむ":{"variants":"たばさむ/手挟む"},"手挟む":{"variants":"たばさむ/手挟む"},"たび":{"variants":"たび/度"},"度":{"variants":"たび/度"},"たびかさなる":{"variants":"たびかさなる/度重なる"},"度重なる":{"variants":"たびかさなる/度重なる"},"たびたび":{"variants":"たびたび/度々"},"度々":{"variants":"たびたび/度々"},"たびだつ":{"variants":"たびだつ/旅立つ"},"旅立つ":{"variants":"たびだつ/旅立つ"},"たびだてる":{"variants":"たびだてる/旅立てる"},"旅立てる":{"variants":"たびだてる/旅立てる"},"旅もの":{"variants":"旅もの/旅物"},"旅物":{"variants":"旅もの/旅物"},"たぶらかす":{"variants":"たぶらかす/誑かす"},"誑かす":{"variants":"たぶらかす/誑かす"},"たぶん":{"variants":"たぶん/多分"},"多分":{"variants":"たぶん/多分"},"食べかす":{"variants":"食べかす/食べ滓"},"食べ滓":{"variants":"食べかす/食べ滓"},"食べごろ":{"variants":"食べごろ/食べ頃"},"食べ頃":{"variants":"食べごろ/食べ頃"},"食べずぎらい":{"variants":"食べずぎらい/食べず嫌い"},"食べず嫌い":{"variants":"食べずぎらい/食べず嫌い"},"食べもの":{"variants":"食べもの/食べ物"},"食べ物":{"variants":"食べもの/食べ物"},"たべる":{"variants":"たべる/食べる"},"食べる":{"variants":"たべる/食べる"},"たま":{"variants":"たま/球/珠"},"たまう":{"variants":"たまう/給う/賜う"},"玉ぐし":{"variants":"玉ぐし/玉串"},"玉串":{"variants":"玉ぐし/玉串"},"たまげる":{"variants":"たまげる/魂消る"},"魂消る":{"variants":"たまげる/魂消る"},"タマゴ":{"variants":"タマゴ/玉子"},"玉子":{"variants":"タマゴ/玉子"},"玉子とじ":{"variants":"玉子とじ/玉子綴じ"},"玉子綴じ":{"variants":"玉子とじ/玉子綴じ"},"玉つき":{"variants":"玉つき/玉突き"},"玉突き":{"variants":"玉つき/玉突き"},"タマナ":{"variants":"タマナ/玉菜"},"玉菜":{"variants":"タマナ/玉菜"},"タマネギ":{"variants":"タマネギ/玉ねぎ/玉葱"},"玉ねぎ":{"variants":"タマネギ/玉ねぎ/玉葱"},"玉葱":{"variants":"タマネギ/玉ねぎ/玉葱"},"玉のこし":{"variants":"玉のこし/玉の輿"},"玉の輿":{"variants":"玉のこし/玉の輿"},"タマムシ":{"variants":"タマムシ/玉虫"},"玉虫":{"variants":"タマムシ/玉虫"},"タマムシイロ":{"variants":"タマムシイロ/玉虫色"},"玉虫色":{"variants":"タマムシイロ/玉虫色"},"たまりかねる":{"variants":"たまりかねる/堪りかねる/堪り兼ねる"},"堪りかねる":{"variants":"たまりかねる/堪りかねる/堪り兼ねる"},"堪り兼ねる":{"variants":"たまりかねる/堪りかねる/堪り兼ねる"},"たまり場":{"variants":"たまり場/溜まり場/溜り場"},"溜まり場":{"variants":"たまり場/溜まり場/溜り場"},"溜り場":{"variants":"たまり場/溜まり場/溜り場"},"たまる":{"variants":"たまる/堪る/貯まる/溜まる/溜る"},"溜る":{"variants":"たまる/溜まる/溜る"},"溜まる":{"variants":"たまる/溜まる/溜る"},"賜りもの":{"variants":"賜りもの/賜り物"},"賜り物":{"variants":"賜りもの/賜り物"},"たまわる":{"variants":"たまわる/給わる/賜る/賜わる"},"賜る":{"variants":"たまわる/賜る/賜わる"},"賜わる":{"variants":"たまわる/賜る/賜わる"},"たむける":{"variants":"たむける/手向ける"},"手向ける":{"variants":"たむける/手向ける"},"たむろ":{"variants":"たむろ/屯"},"屯":{"variants":"たむろ/屯"},"ため":{"variants":"ため/為"},"為":{"variants":"ため/為"},"ためいき":{"variants":"ためいき/タメ息/溜め息/溜息"},"タメ息":{"variants":"ためいき/タメ息/溜め息/溜息"},"溜め息":{"variants":"ためいき/タメ息/溜め息/溜息"},"溜息":{"variants":"ためいき/タメ息/溜め息/溜息"},"ため池":{"variants":"ため池/溜池"},"溜池":{"variants":"ため池/溜池"},"ためこむ":{"variants":"ためこむ/ため込む/貯め込む/溜めこむ/溜め込む"},"ため込む":{"variants":"ためこむ/ため込む/貯め込む/溜めこむ/溜め込む"},"溜め込む":{"variants":"ためこむ/ため込む/溜めこむ/溜め込む"},"溜めこむ":{"variants":"ためこむ/ため込む/溜めこむ/溜め込む"},"ためこめる":{"variants":"ためこめる/ため込める"},"ため込める":{"variants":"ためこめる/ため込める"},"ためし":{"variants":"ためし/験し/試し"},"ためす":{"variants":"ためす/験す/試す"},"ためせる":{"variants":"ためせる/試せる"},"試せる":{"variants":"ためせる/試せる"},"ためらう":{"variants":"ためらう/躊躇う"},"躊躇う":{"variants":"ためらう/躊躇う"},"ためる":{"variants":"ためる/矯める/貯める/溜める"},"たもちあう":{"variants":"たもちあう/保ち合う"},"保ち合う":{"variants":"たもちあう/保ち合う"},"たもちあえる":{"variants":"たもちあえる/保ち合える"},"保ち合える":{"variants":"たもちあえる/保ち合える"},"たもつ":{"variants":"たもつ/保つ"},"保つ":{"variants":"たもつ/保つ"},"たもてる":{"variants":"たもてる/保てる"},"保てる":{"variants":"たもてる/保てる"},"たもと":{"variants":"たもと/袂"},"袂":{"variants":"たもと/袂"},"たやす":{"variants":"たやす/絶やす"},"絶やす":{"variants":"たやす/絶やす"},"たやすい":{"variants":"たやすい/容易い"},"容易い":{"variants":"たやすい/容易い"},"たやせる":{"variants":"たやせる/絶やせる"},"絶やせる":{"variants":"たやせる/絶やせる"},"たゆい":{"variants":"たゆい/弛い/懈い"},"たより":{"variants":"たより/頼り"},"頼り":{"variants":"たより/頼り"},"たよる":{"variants":"たよる/便る/頼る"},"たよれる":{"variants":"たよれる/頼れる"},"頼れる":{"variants":"たよれる/頼れる"},"タラ":{"variants":"タラ/鱈"},"鱈":{"variants":"タラ/鱈"},"たらい":{"variants":"たらい/タライ/盥"},"タライ":{"variants":"たらい/タライ/盥"},"盥":{"variants":"たらい/タライ/盥"},"たらしこむ":{"variants":"たらしこむ/たらし込む/誑し込む"},"たらし込む":{"variants":"たらしこむ/たらし込む/誑し込む"},"誑し込む":{"variants":"たらしこむ/たらし込む/誑し込む"},"たらす":{"variants":"たらす/垂らす/誑す"},"たらたら":{"variants":"たらたら/タラタラ"},"タラタラ":{"variants":"たらたら/タラタラ"},"たらの木":{"variants":"たらの木/タラノキ"},"タラノキ":{"variants":"たらの木/タラノキ"},"たらの子":{"variants":"たらの子/鱈の子"},"鱈の子":{"variants":"たらの子/鱈の子"},"たらば蟹":{"variants":"たらば蟹/タラバガニ/鱈場蟹"},"タラバガニ":{"variants":"たらば蟹/タラバガニ/鱈場蟹"},"鱈場蟹":{"variants":"たらば蟹/タラバガニ/鱈場蟹"},"たりる":{"variants":"たりる/足りる"},"足りる":{"variants":"たりる/足りる"},"たる":{"variants":"たる/樽"},"足る":{"variants":"たる/足る"},"樽":{"variants":"タル/樽"},"タル":{"variants":"タル/樽"},"たる木":{"variants":"たる木/垂木"},"垂木":{"variants":"たる木/垂木"},"たるみ":{"variants":"たるみ/垂水"},"垂水":{"variants":"たるみ/垂水"},"たるむ":{"variants":"たるむ/弛む"},"弛む":{"variants":"たるむ/弛む"},"たれ":{"variants":"たれ/タレ/垂れ"},"タレ":{"variants":"たれ/タレ/垂れ"},"垂れ":{"variants":"たれ/タレ/垂れ"},"たれこむ":{"variants":"たれこむ/たれ込む/垂れ込む"},"たれ込む":{"variants":"たれこむ/たれ込む/垂れ込む"},"垂れ込む":{"variants":"たれこむ/たれ込む/垂れ込む"},"たれこめる":{"variants":"たれこめる/垂れこめる/垂れ篭める"},"垂れこめる":{"variants":"たれこめる/垂れこめる/垂れ篭める"},"垂れ篭める":{"variants":"たれこめる/垂れこめる/垂れ篭める"},"たれさがる":{"variants":"たれさがる/垂れ下がる"},"垂れ下がる":{"variants":"たれさがる/垂れ下がる"},"たれ流し":{"variants":"たれ流し/タレ流し/垂れ流し"},"タレ流し":{"variants":"たれ流し/タレ流し/垂れ流し"},"垂れ流し":{"variants":"たれ流し/タレ流し/垂れ流し"},"たれ幕":{"variants":"たれ幕/垂れ幕/垂幕"},"垂れ幕":{"variants":"たれ幕/垂れ幕/垂幕"},"垂幕":{"variants":"たれ幕/垂れ幕/垂幕"},"たれる":{"variants":"たれる/垂れる"},"垂れる":{"variants":"たれる/垂れる"},"タロいも":{"variants":"タロいも/タロイモ/タロ芋"},"タロイモ":{"variants":"タロいも/タロイモ/タロ芋"},"タロ芋":{"variants":"タロいも/タロイモ/タロ芋"},"たわけ者":{"variants":"たわけ者/戯け者"},"戯け者":{"variants":"たわけ者/戯け者"},"たわける":{"variants":"たわける/戯ける"},"戯ける":{"variants":"たわける/戯ける"},"たわごと":{"variants":"たわごと/たわ言"},"たわ言":{"variants":"たわごと/たわ言"},"たわむ":{"variants":"たわむ/撓む"},"撓む":{"variants":"たわむ/撓む"},"たん":{"variants":"たん/タン/短/反/痰"},"タン":{"variants":"たん/タン/短/反/痰"},"タンカ":{"variants":"タンカ/丹花/単価/単科/担架/炭価/短歌/啖呵/譚歌"},"タンク":{"variants":"タンク/短躯"},"短躯":{"variants":"タンク/短躯"},"たんこぶ":{"variants":"たんこぶ/たん瘤"},"たん瘤":{"variants":"たんこぶ/たん瘤"},"タンゴ":{"variants":"タンゴ/単語/端午"},"たんじょう":{"variants":"たんじょう/誕生"},"誕生":{"variants":"たんじょう/誕生"},"炭じん":{"variants":"炭じん/炭塵"},"炭塵":{"variants":"炭じん/炭塵"},"たんす":{"variants":"たんす/タンス/箪笥"},"タンス":{"variants":"たんす/タンス/箪笥"},"箪笥":{"variants":"たんす/タンス/箪笥"},"たんずる":{"variants":"たんずる/嘆ずる/歎ずる"},"たんぜんと":{"variants":"たんぜんと/端然と"},"端然と":{"variants":"たんぜんと/端然と"},"眈眈":{"variants":"眈々/眈眈"},"坦々":{"variants":"坦々/坦坦"},"淡々":{"variants":"淡々/淡淡"},"淡淡":{"variants":"淡々/淡淡"},"眈々":{"variants":"眈々/眈眈"},"坦坦":{"variants":"坦々/坦坦"},"たんたんと":{"variants":"たんたんと/淡々と"},"淡々と":{"variants":"たんたんと/淡々と"},"タンチョウ":{"variants":"タンチョウ/丹頂/単調/短調/短長"},"たんなる":{"variants":"たんなる/単なる"},"単なる":{"variants":"たんなる/単なる"},"たんに":{"variants":"たんに/単に"},"単に":{"variants":"たんに/単に"},"たん能":{"variants":"たん能/堪能"},"堪能":{"variants":"たん能/堪能"},"胆のう":{"variants":"胆のう/胆嚢"},"胆嚢":{"variants":"胆のう/胆嚢"},"タンパク":{"variants":"タンパク/淡泊/淡白/蛋白"},"たんぱく質":{"variants":"たんぱく質/タンパク質"},"タンパク質":{"variants":"たんぱく質/タンパク質"},"たんび":{"variants":"たんび/耽美"},"耽美":{"variants":"たんび/耽美"},"たんぼ":{"variants":"たんぼ/旦暮/田んぼ/田圃"},"田んぼ":{"variants":"たんぼ/田んぼ/田圃"},"田圃":{"variants":"たんぼ/田んぼ/田圃"},"たんぽぽ":{"variants":"たんぽぽ/タンポポ"},"タンポポ":{"variants":"たんぽぽ/タンポポ"},"タンメン":{"variants":"タンメン/湯麺"},"湯麺":{"variants":"タンメン/湯麺"},"ダイオウ":{"variants":"ダイオウ/大王/大黄"},"代替り":{"variants":"代替り/代替わり"},"代替わり":{"variants":"代替り/代替わり"},"だいこん":{"variants":"だいこん/ダイコン/大根"},"ダイコン":{"variants":"だいこん/ダイコン/大根"},"大根":{"variants":"だいこん/ダイコン/大根"},"大根おろし":{"variants":"大根おろし/大根卸"},"大根卸":{"variants":"大根おろし/大根卸"},"だいごみ":{"variants":"だいごみ/だいご味/醍醐味"},"だいご味":{"variants":"だいごみ/だいご味/醍醐味"},"醍醐味":{"variants":"だいごみ/だいご味/醍醐味"},"だいじない":{"variants":"だいじない/大事無い"},"大事無い":{"variants":"だいじない/大事無い"},"ダイス":{"variants":"ダイス/台子"},"台子":{"variants":"ダイス/台子"},"だいする":{"variants":"だいする/題する"},"題する":{"variants":"だいする/題する"},"ダイズ":{"variants":"ダイズ/大豆"},"大豆":{"variants":"ダイズ/大豆"},"だいたい":{"variants":"だいたい/大腿/大隊"},"大体":{"variants":"だいたい/大体"},"ダイダイ":{"variants":"ダイダイ/橙"},"橙":{"variants":"ダイダイ/橙"},"代々":{"variants":"代々/代代"},"代代":{"variants":"代々/代代"},"太々神楽":{"variants":"太々神楽/太太神楽"},"太太神楽":{"variants":"太々神楽/太太神楽"},"大々的":{"variants":"大々的/大大的"},"大大的":{"variants":"大々的/大大的"},"ダイナゴン":{"variants":"ダイナゴン/大納言"},"大納言":{"variants":"ダイナゴン/大納言"},"ダイフウシ":{"variants":"ダイフウシ/大風子"},"大風子":{"variants":"ダイフウシ/大風子"},"大福もち":{"variants":"大福もち/大福餅"},"大福餅":{"variants":"大福もち/大福餅"},"内裏びな":{"variants":"内裏びな/内裏雛"},"内裏雛":{"variants":"内裏びな/内裏雛"},"だ液":{"variants":"だ液/唾液"},"唾液":{"variants":"だ液/唾液"},"だ円":{"variants":"だ円/楕円/橢円"},"だきあう":{"variants":"だきあう/抱き合う"},"抱き合う":{"variants":"だきあう/抱き合う"},"だきあえる":{"variants":"だきあえる/抱き合える"},"抱き合える":{"variants":"だきあえる/抱き合える"},"だきあげる":{"variants":"だきあげる/抱き上げる"},"抱き上げる":{"variants":"だきあげる/抱き上げる"},"だきあわせる":{"variants":"だきあわせる/抱き合わせる"},"抱き合わせる":{"variants":"だきあわせる/抱き合わせる"},"だきおこす":{"variants":"だきおこす/抱き起こす"},"抱き起こす":{"variants":"だきおこす/抱き起こす"},"だきおこせる":{"variants":"だきおこせる/抱き起こせる"},"抱き起こせる":{"variants":"だきおこせる/抱き起こせる"},"だきこむ":{"variants":"だきこむ/抱きこむ/抱き込む/抱込む"},"抱きこむ":{"variants":"だきこむ/抱きこむ/抱き込む/抱込む"},"抱き込む":{"variants":"だきこむ/抱きこむ/抱き込む/抱込む"},"抱込む":{"variants":"だきこむ/抱きこむ/抱き込む/抱込む"},"だきこめる":{"variants":"だきこめる/抱き込める"},"抱き込める":{"variants":"だきこめる/抱き込める"},"だきしめる":{"variants":"だきしめる/抱きしめる/抱き締める/抱締める"},"抱きしめる":{"variants":"だきしめる/抱きしめる/抱き締める/抱締める"},"抱き締める":{"variants":"だきしめる/抱きしめる/抱き締める/抱締める"},"抱締める":{"variants":"だきしめる/抱きしめる/抱き締める/抱締める"},"だきすくめる":{"variants":"だきすくめる/抱きすくめる/抱き竦める"},"抱きすくめる":{"variants":"だきすくめる/抱きすくめる/抱き竦める"},"抱き竦める":{"variants":"だきすくめる/抱きすくめる/抱き竦める"},"だきつく":{"variants":"だきつく/抱きつく/抱き着く/抱着く"},"抱きつく":{"variants":"だきつく/抱きつく/抱き着く/抱着く"},"抱き着く":{"variants":"だきつく/抱きつく/抱き着く/抱着く"},"抱着く":{"variants":"だきつく/抱きつく/抱き着く/抱着く"},"だきとめる":{"variants":"だきとめる/抱きとめる/抱き留める/抱留める"},"抱きとめる":{"variants":"だきとめる/抱きとめる/抱き留める/抱留める"},"抱き留める":{"variants":"だきとめる/抱きとめる/抱き留める/抱留める"},"抱留める":{"variants":"だきとめる/抱きとめる/抱き留める/抱留める"},"だきとる":{"variants":"だきとる/抱きとる/抱き取る/抱取る"},"抱きとる":{"variants":"だきとる/抱きとる/抱き取る/抱取る"},"抱き取る":{"variants":"だきとる/抱きとる/抱き取る/抱取る"},"抱取る":{"variants":"だきとる/抱きとる/抱き取る/抱取る"},"抱き寝":{"variants":"抱き寝/抱寝"},"抱寝":{"variants":"抱き寝/抱寝"},"だくする":{"variants":"だくする/諾する"},"諾する":{"variants":"だくする/諾する"},"諾々":{"variants":"諾々/諾諾"},"諾諾":{"variants":"諾々/諾諾"},"だこ":{"variants":"だこ/凧"},"凧":{"variants":"だこ/凧"},"だし":{"variants":"だし/ダシ/山車/出し/出汁"},"ダシ":{"variants":"だし/ダシ/山車/出し/出汁"},"出し":{"variants":"だし/ダシ/出し/出汁"},"出汁":{"variants":"だし/ダシ/出し/出汁"},"だしあう":{"variants":"だしあう/出し合う"},"出し合う":{"variants":"だしあう/出し合う"},"だしきる":{"variants":"だしきる/出し切る"},"出し切る":{"variants":"だしきる/出し切る"},"だしきれる":{"variants":"だしきれる/出し切れる"},"出し切れる":{"variants":"だしきれる/出し切れる"},"だし汁":{"variants":"だし汁/出し汁"},"出し汁":{"variants":"だし汁/出し汁"},"だしぬく":{"variants":"だしぬく/出し抜く"},"出し抜く":{"variants":"だしぬく/出し抜く"},"出しぬけ":{"variants":"出しぬけ/出し抜け"},"出し抜け":{"variants":"出しぬけ/出し抜け"},"だしぬける":{"variants":"だしぬける/出し抜ける"},"出し抜ける":{"variants":"だしぬける/出し抜ける"},"ダジャレ":{"variants":"ダジャレ/駄洒落"},"駄洒落":{"variants":"ダジャレ/駄洒落"},"だす":{"variants":"だす/出す"},"出す":{"variants":"だす/出す"},"だする":{"variants":"だする/堕する"},"堕する":{"variants":"だする/堕する"},"だせる":{"variants":"だせる/出せる"},"出せる":{"variants":"だせる/出せる"},"ダダ":{"variants":"ダダ/駄々/駄駄"},"駄々":{"variants":"ダダ/駄々/駄駄"},"駄駄":{"variants":"ダダ/駄々/駄駄"},"だだっ子":{"variants":"だだっ子/駄々っ子"},"駄々っ子":{"variants":"だだっ子/駄々っ子"},"だだっぴろい":{"variants":"だだっぴろい/だだっ広い"},"だだっ広い":{"variants":"だだっぴろい/だだっ広い"},"ダチョウ":{"variants":"ダチョウ/駝鳥"},"駝鳥":{"variants":"ダチョウ/駝鳥"},"脱きゅう":{"variants":"脱きゅう/脱臼"},"脱臼":{"variants":"脱きゅう/脱臼"},"ダッシュ":{"variants":"ダッシュ/奪取"},"奪取":{"variants":"ダッシュ/奪取"},"だっする":{"variants":"だっする/脱する"},"脱する":{"variants":"だっする/脱する"},"だて巻き":{"variants":"だて巻き/伊達巻"},"伊達巻":{"variants":"だて巻き/伊達巻"},"ダニ":{"variants":"ダニ/壁蝨"},"壁蝨":{"variants":"ダニ/壁蝨"},"だび":{"variants":"だび/蛇尾/荼毘"},"だぶだぶ":{"variants":"だぶだぶ/ダブダブ"},"ダブダブ":{"variants":"だぶだぶ/ダブダブ"},"だぶつく":{"variants":"だぶつく/ダブつく"},"ダブつく":{"variants":"だぶつく/ダブつく"},"だぶる":{"variants":"だぶる/ダブる"},"ダブる":{"variants":"だぶる/ダブる"},"だ捕":{"variants":"だ捕/拿捕"},"拿捕":{"variants":"だ捕/拿捕"},"だぼ鯊":{"variants":"だぼ鯊/ダボハゼ"},"ダボハゼ":{"variants":"だぼ鯊/ダボハゼ"},"だまかす":{"variants":"だまかす/騙かす"},"騙かす":{"variants":"だまかす/騙かす"},"だましうち":{"variants":"だましうち/だまし討/騙し討"},"だまし討":{"variants":"だましうち/だまし討/騙し討"},"騙し討":{"variants":"だましうち/だまし討/騙し討"},"だましこむ":{"variants":"だましこむ/だまし込む/騙しこむ/騙し込む"},"だまし込む":{"variants":"だましこむ/だまし込む/騙しこむ/騙し込む"},"騙しこむ":{"variants":"だましこむ/だまし込む/騙しこむ/騙し込む"},"騙し込む":{"variants":"だましこむ/だまし込む/騙しこむ/騙し込む"},"だましとる":{"variants":"だましとる/だまし取る"},"だまし取る":{"variants":"だましとる/だまし取る"},"だます":{"variants":"だます/騙す"},"騙す":{"variants":"だます/騙す"},"だまりこくる":{"variants":"だまりこくる/黙りこくる"},"黙りこくる":{"variants":"だまりこくる/黙りこくる"},"だまりこむ":{"variants":"だまりこむ/黙り込む"},"黙り込む":{"variants":"だまりこむ/黙り込む"},"だまる":{"variants":"だまる/黙る"},"黙る":{"variants":"だまる/黙る"},"だめ":{"variants":"だめ/ダメ/駄目"},"ダメ":{"variants":"だめ/ダメ/駄目"},"駄目":{"variants":"だめ/ダメ/駄目"},"ダメ押し":{"variants":"ダメ押し/駄目押し"},"駄目押し":{"variants":"ダメ押し/駄目押し"},"だらだら":{"variants":"だらだら/ダラダラ"},"ダラダラ":{"variants":"だらだら/ダラダラ"},"だるま":{"variants":"だるま/ダルマ/達磨"},"ダルマ":{"variants":"だるま/ダルマ/達磨"},"達磨":{"variants":"だるま/ダルマ/達磨"},"誰々":{"variants":"誰々/誰誰"},"誰誰":{"variants":"誰々/誰誰"},"だれる":{"variants":"だれる/弛れる"},"弛れる":{"variants":"だれる/弛れる"},"ダン":{"variants":"ダン/団/壇/断/暖/段/談"},"断がい":{"variants":"断がい/断崖"},"断崖":{"variants":"断がい/断崖"},"だんこ":{"variants":"だんこ/断乎/断固"},"ダンゴ":{"variants":"ダンゴ/団子"},"団子":{"variants":"ダンゴ/団子"},"だんじこむ":{"variants":"だんじこむ/談じ込む"},"談じ込む":{"variants":"だんじこむ/談じ込む"},"だんじこめる":{"variants":"だんじこめる/談じ込める"},"談じ込める":{"variants":"だんじこめる/談じ込める"},"だんじて":{"variants":"だんじて/断じて"},"断じて":{"variants":"だんじて/断じて"},"だんずる":{"variants":"だんずる/弾ずる/断ずる/談ずる"},"だんぜん":{"variants":"だんぜん/断然"},"断然":{"variants":"だんぜん/断然"},"だんぜんと":{"variants":"だんぜんと/断然と"},"断然と":{"variants":"だんぜんと/断然と"},"段々":{"variants":"段々/段段"},"段段":{"variants":"段々/段段"},"団々":{"variants":"団々/団団"},"団団":{"variants":"団々/団団"},"断々乎":{"variants":"断々乎/断断乎"},"断断乎":{"variants":"断々乎/断断乎"},"だんだんと":{"variants":"だんだんと/段々と/段段と"},"段々と":{"variants":"だんだんと/段々と/段段と"},"段段と":{"variants":"だんだんと/段々と/段段と"},"だんだんに":{"variants":"だんだんに/段々に/段段に"},"段々に":{"variants":"だんだんに/段々に/段段に"},"段段に":{"variants":"だんだんに/段々に/段段に"},"ダントツ":{"variants":"ダントツ/断トツ"},"断トツ":{"variants":"ダントツ/断トツ"},"だんな":{"variants":"だんな/ダンナ/旦那/檀那"},"ダンナ":{"variants":"だんな/ダンナ/旦那/檀那"},"ダンボール":{"variants":"ダンボール/段ボール"},"段ボール":{"variants":"ダンボール/段ボール"},"だんまり":{"variants":"だんまり/黙り"},"黙り":{"variants":"だんまり/黙り"},"段もの":{"variants":"段もの/段物"},"段物":{"variants":"段もの/段物"},"団らん":{"variants":"団らん/団欒"},"団欒":{"variants":"団らん/団欒"},"血合":{"variants":"血合/血合い"},"血合い":{"variants":"血合/血合い"},"ちいさい":{"variants":"ちいさい/小さい"},"小さい":{"variants":"ちいさい/小さい"},"ちいさな":{"variants":"ちいさな/小さな"},"小さな":{"variants":"ちいさな/小さな"},"小さめ":{"variants":"小さめ/小さ目"},"小さ目":{"variants":"小さめ/小さ目"},"ちえづく":{"variants":"ちえづく/知恵づく/智慧づく"},"ちえの輪":{"variants":"ちえの輪/知恵の輪/智慧の輪"},"ちかい":{"variants":"ちかい/近い"},"近い":{"variants":"ちかい/近い"},"ちかう":{"variants":"ちかう/誓う"},"誓う":{"variants":"ちかう/誓う"},"ちかごろ":{"variants":"ちかごろ/近頃"},"近頃":{"variants":"近ごろ/近頃"},"近ごろ":{"variants":"近ごろ/近頃"},"ちかしい":{"variants":"ちかしい/近しい"},"近しい":{"variants":"ちかしい/近しい"},"ちかちか":{"variants":"ちかちか/チカチカ"},"チカチカ":{"variants":"ちかちか/チカチカ"},"ちかぢか":{"variants":"ちかぢか/近近"},"近近":{"variants":"ちかぢか/近近"},"ちかぢかと":{"variants":"ちかぢかと/近々と"},"近々と":{"variants":"ちかぢかと/近々と"},"ちかぢかの":{"variants":"ちかぢかの/近々の"},"近々の":{"variants":"ちかぢかの/近々の"},"ちかづく":{"variants":"ちかづく/近づく/近付く"},"近づく":{"variants":"ちかづく/近づく/近付く"},"近付く":{"variants":"ちかづく/近づく/近付く"},"ちかづける":{"variants":"ちかづける/近づける/近付ける"},"近づける":{"variants":"ちかづける/近づける/近付ける"},"近付ける":{"variants":"ちかづける/近づける/近付ける"},"ちかよせる":{"variants":"ちかよせる/近寄せる"},"近寄せる":{"variants":"ちかよせる/近寄せる"},"ちかよる":{"variants":"ちかよる/近寄る"},"近寄る":{"variants":"ちかよる/近寄る"},"ちかよれる":{"variants":"ちかよれる/近寄れる"},"近寄れる":{"variants":"ちかよれる/近寄れる"},"ちからいっぱい":{"variants":"ちからいっぱい/力いっぱい/力一杯"},"力いっぱい":{"variants":"ちからいっぱい/力いっぱい/力一杯"},"力一杯":{"variants":"ちからいっぱい/力いっぱい/力一杯"},"力落し":{"variants":"力落し/力落とし"},"力落とし":{"variants":"力落し/力落とし"},"力こぶ":{"variants":"力こぶ/力瘤"},"力瘤":{"variants":"力こぶ/力瘤"},"ちからつきる":{"variants":"ちからつきる/力つきる/力尽きる"},"力つきる":{"variants":"ちからつきる/力つきる/力尽きる"},"力尽きる":{"variants":"ちからつきる/力つきる/力尽きる"},"ちからづける":{"variants":"ちからづける/力づける/力付ける"},"力づける":{"variants":"ちからづける/力づける/力付ける"},"力付ける":{"variants":"ちからづける/力づける/力付ける"},"ちからづよい":{"variants":"ちからづよい/力強い"},"力強い":{"variants":"ちからづよい/力強い"},"力まかせ":{"variants":"力まかせ/力任せ"},"力任せ":{"variants":"力まかせ/力任せ"},"力持":{"variants":"力持/力持ち"},"力持ち":{"variants":"力持/力持ち"},"力わざ":{"variants":"力わざ/力業"},"力業":{"variants":"力わざ/力業"},"ちがい":{"variants":"ちがい/違い"},"違い":{"variants":"ちがい/違い"},"ちがい棚":{"variants":"ちがい棚/違い棚/違棚"},"違い棚":{"variants":"ちがい棚/違い棚/違棚"},"違棚":{"variants":"ちがい棚/違い棚/違棚"},"ちがう":{"variants":"ちがう/違う"},"違う":{"variants":"ちがう/違う"},"契り":{"variants":"契/契り"},"契":{"variants":"契/契り"},"ちぎる":{"variants":"ちぎる/契る"},"契る":{"variants":"ちぎる/契る"},"ちぎれ雲":{"variants":"ちぎれ雲/千切れ雲"},"千切れ雲":{"variants":"ちぎれ雲/千切れ雲"},"ちぎれる":{"variants":"ちぎれる/契れる"},"契れる":{"variants":"ちぎれる/契れる"},"ちくいち":{"variants":"ちくいち/逐一"},"逐一":{"variants":"ちくいち/逐一"},"ちくしょう":{"variants":"ちくしょう/畜生/蓄妾"},"ちくじ":{"variants":"ちくじ/逐次"},"逐次":{"variants":"ちくじ/逐次"},"ちくじつ":{"variants":"ちくじつ/逐日"},"逐日":{"variants":"ちくじつ/逐日"},"ちくちく":{"variants":"ちくちく/チクチク"},"チクチク":{"variants":"ちくちく/チクチク"},"ちくねん":{"variants":"ちくねん/逐年"},"逐年":{"variants":"ちくねん/逐年"},"ちぐはぐ":{"variants":"ちぐはぐ/チグハグ"},"チグハグ":{"variants":"ちぐはぐ/チグハグ"},"チシャ":{"variants":"チシャ/治者/知者/智者"},"千千":{"variants":"千々/千千"},"千々":{"variants":"千々/千千"},"血すじ":{"variants":"血すじ/血筋"},"血筋":{"variants":"血すじ/血筋"},"血だるま":{"variants":"血だるま/血達磨"},"血達磨":{"variants":"血だるま/血達磨"},"遅々":{"variants":"遅々/遅遅"},"遅遅":{"variants":"遅々/遅遅"},"ちちくさい":{"variants":"ちちくさい/乳臭い"},"乳臭い":{"variants":"ちちくさい/乳臭い"},"ちちくる":{"variants":"ちちくる/乳繰る"},"乳繰る":{"variants":"ちちくる/乳繰る"},"ちちと":{"variants":"ちちと/遅々と"},"遅々と":{"variants":"ちちと/遅々と"},"ちぢかむ":{"variants":"ちぢかむ/縮かむ"},"縮かむ":{"variants":"ちぢかむ/縮かむ"},"ちぢくれる":{"variants":"ちぢくれる/縮くれる"},"縮くれる":{"variants":"ちぢくれる/縮くれる"},"ちぢこまる":{"variants":"ちぢこまる/縮こまる"},"縮こまる":{"variants":"ちぢこまる/縮こまる"},"ちぢまる":{"variants":"ちぢまる/縮まる"},"縮まる":{"variants":"ちぢまる/縮まる"},"ちぢみあがる":{"variants":"ちぢみあがる/縮みあがる/縮み上がる"},"縮みあがる":{"variants":"ちぢみあがる/縮みあがる/縮み上がる"},"縮み上がる":{"variants":"ちぢみあがる/縮みあがる/縮み上がる"},"ちぢむ":{"variants":"ちぢむ/縮む"},"縮む":{"variants":"ちぢむ/縮む"},"ちぢめる":{"variants":"ちぢめる/縮める"},"縮める":{"variants":"ちぢめる/縮める"},"ちぢらす":{"variants":"ちぢらす/縮らす"},"縮らす":{"variants":"ちぢらす/縮らす"},"ちぢれ毛":{"variants":"ちぢれ毛/縮れ毛"},"縮れ毛":{"variants":"ちぢれ毛/縮れ毛"},"ちぢれる":{"variants":"ちぢれる/縮れる"},"縮れる":{"variants":"ちぢれる/縮れる"},"千歳あめ":{"variants":"千歳あめ/千歳飴"},"千歳飴":{"variants":"千歳あめ/千歳飴"},"チドメグサ":{"variants":"チドメグサ/血止め草"},"血止め草":{"variants":"チドメグサ/血止め草"},"チドリ":{"variants":"チドリ/千鳥"},"千鳥":{"variants":"チドリ/千鳥"},"チドリアシ":{"variants":"チドリアシ/千鳥足"},"千鳥足":{"variants":"チドリアシ/千鳥足"},"チドリガケ":{"variants":"チドリガケ/千鳥掛"},"千鳥掛":{"variants":"チドリガケ/千鳥掛"},"ちなまぐさい":{"variants":"ちなまぐさい/血なまぐさい/血腥い"},"血なまぐさい":{"variants":"ちなまぐさい/血なまぐさい/血腥い"},"血腥い":{"variants":"ちなまぐさい/血なまぐさい/血腥い"},"ちなみに":{"variants":"ちなみに/因みに"},"因みに":{"variants":"ちなみに/因みに"},"ちなむ":{"variants":"ちなむ/因む"},"因む":{"variants":"ちなむ/因む"},"ちぬる":{"variants":"ちぬる/血塗る"},"血塗る":{"variants":"ちぬる/血塗る"},"ちばしる":{"variants":"ちばしる/血走る"},"血走る":{"variants":"ちばしる/血走る"},"ちびる":{"variants":"ちびる/禿びる"},"禿びる":{"variants":"ちびる/禿びる"},"ちほう":{"variants":"ちほう/地方/痴ほう/痴呆"},"痴ほう":{"variants":"ちほう/痴ほう/痴呆"},"痴呆":{"variants":"ちほう/痴ほう/痴呆"},"ちまき":{"variants":"ちまき/粽"},"粽":{"variants":"ちまき/粽"},"ちまた":{"variants":"ちまた/巷"},"巷":{"variants":"ちまた/巷"},"血祭":{"variants":"血祭/血祭り"},"血祭り":{"variants":"血祭/血祭り"},"血まみれ":{"variants":"血まみれ/血塗れ"},"血塗れ":{"variants":"血まみれ/血塗れ"},"ちまよう":{"variants":"ちまよう/血迷う"},"血迷う":{"variants":"ちまよう/血迷う"},"ち密":{"variants":"ち密/緻密"},"緻密":{"variants":"ち密/緻密"},"チャーハン":{"variants":"チャーハン/炒飯"},"炒飯":{"variants":"チャーハン/炒飯"},"茶入":{"variants":"茶入/茶入れ"},"茶入れ":{"variants":"茶入/茶入れ"},"ちゃかす":{"variants":"ちゃかす/茶化す"},"茶化す":{"variants":"ちゃかす/茶化す"},"茶掛":{"variants":"茶掛/茶掛け"},"茶掛け":{"variants":"茶掛/茶掛け"},"茶がら":{"variants":"茶がら/茶殻"},"茶殻":{"variants":"茶がら/茶殻"},"ちゃきちゃき":{"variants":"ちゃきちゃき/チャキチャキ"},"チャキチャキ":{"variants":"ちゃきちゃき/チャキチャキ"},"着い":{"variants":"着い/着意/着衣"},"ちゃくちゃく":{"variants":"ちゃくちゃく/着着"},"着着":{"variants":"ちゃくちゃく/着着"},"嫡々":{"variants":"嫡々/嫡嫡"},"嫡嫡":{"variants":"嫡々/嫡嫡"},"着々と":{"variants":"着々と/着着と"},"着着と":{"variants":"着々と/着着と"},"着払":{"variants":"着払/着払い"},"着払い":{"variants":"着払/着払い"},"茶こし":{"variants":"茶こし/茶漉"},"茶漉":{"variants":"茶こし/茶漉"},"茶しぶ":{"variants":"茶しぶ/茶渋"},"茶渋":{"variants":"茶しぶ/茶渋"},"茶しゃく":{"variants":"茶しゃく/茶杓"},"茶杓":{"variants":"茶しゃく/茶杓"},"茶せん":{"variants":"茶せん/茶筌/茶筅"},"茶だんす":{"variants":"茶だんす/茶箪笥"},"茶箪笥":{"variants":"茶だんす/茶箪笥"},"ちゃちゃ":{"variants":"ちゃちゃ/茶々/茶茶"},"茶々":{"variants":"ちゃちゃ/茶々/茶茶"},"茶茶":{"variants":"ちゃちゃ/茶々/茶茶"},"茶漬":{"variants":"茶漬/茶漬け"},"茶漬け":{"variants":"茶漬/茶漬け"},"茶どころ":{"variants":"茶どころ/茶所"},"茶所":{"variants":"茶どころ/茶所"},"茶びん":{"variants":"茶びん/茶瓶"},"茶瓶":{"variants":"茶びん/茶瓶"},"ちゃぶ台":{"variants":"ちゃぶ台/卓袱台"},"卓袱台":{"variants":"ちゃぶ台/卓袱台"},"チャボ":{"variants":"チャボ/矮鶏"},"矮鶏":{"variants":"チャボ/矮鶏"},"ちゃめ":{"variants":"ちゃめ/茶目"},"茶目":{"variants":"ちゃめ/茶目"},"茶めし":{"variants":"茶めし/茶飯"},"茶飯":{"variants":"茶めし/茶飯"},"ちゃめっ気":{"variants":"ちゃめっ気/茶目っ気"},"茶目っ気":{"variants":"ちゃめっ気/茶目っ気"},"茶わん":{"variants":"茶わん/茶碗"},"茶碗":{"variants":"茶わん/茶碗"},"茶碗蒸":{"variants":"茶碗蒸/茶碗蒸し"},"茶碗蒸し":{"variants":"茶碗蒸/茶碗蒸し"},"ちゃん":{"variants":"ちゃん/チャン"},"チャン":{"variants":"ちゃん/チャン"},"ちゅういぶかい":{"variants":"ちゅういぶかい/注意深い"},"注意深い":{"variants":"ちゅういぶかい/注意深い"},"中・高生":{"variants":"中・高生/中高生"},"中高生":{"variants":"中・高生/中高生"},"ちゅう射":{"variants":"ちゅう射/注射"},"注射":{"variants":"ちゅう射/注射"},"ちゅうする":{"variants":"ちゅうする/沖する/注する/註する/冲する/誅する"},"抽せん":{"variants":"抽せん/抽選/抽籤"},"ちゅうちょ":{"variants":"ちゅうちょ/躊躇"},"躊躇":{"variants":"ちゅうちょ/躊躇"},"中っぱら":{"variants":"中っぱら/中っ腹"},"中っ腹":{"variants":"中っぱら/中っ腹"},"宙づり":{"variants":"宙づり/宙吊り"},"宙吊り":{"variants":"宙づり/宙吊り"},"中途はんぱ":{"variants":"中途はんぱ/中途半端"},"中途半端":{"variants":"中途はんぱ/中途半端"},"ちゅう房":{"variants":"ちゅう房/厨房"},"厨房":{"variants":"ちゅう房/厨房"},"チュンタオ":{"variants":"チュンタオ/春桃"},"春桃":{"variants":"チュンタオ/春桃"},"チョウ":{"variants":"チョウ/丁/喋/庁/腸/蝶/超/長/疔"},"ちょう愛":{"variants":"ちょう愛/寵愛"},"寵愛":{"variants":"ちょう愛/寵愛"},"鳥かん":{"variants":"鳥かん/鳥観/鳥瞰"},"チョウザメ":{"variants":"チョウザメ/蝶鮫"},"蝶鮫":{"variants":"チョウザメ/蝶鮫"},"ちょうし":{"variants":"ちょうし/弔詞/弔詩/聴視/調子/銚子/長姉/長子"},"ちょうしづく":{"variants":"ちょうしづく/調子づく/調子付く"},"調子づく":{"variants":"ちょうしづく/調子づく/調子付く"},"調子付く":{"variants":"ちょうしづく/調子づく/調子付く"},"調子はずれ":{"variants":"調子はずれ/調子外れ"},"調子外れ":{"variants":"調子はずれ/調子外れ"},"調子もの":{"variants":"調子もの/調子者"},"調子者":{"variants":"調子もの/調子者"},"ちょう笑":{"variants":"ちょう笑/嘲笑"},"嘲笑":{"variants":"ちょう笑/嘲笑"},"ちょうしょう":{"variants":"ちょうしょう/寵妾/弔鐘/徴証"},"チョウジ":{"variants":"ちょう児/チョウジ/丁子/寵児/弔辞"},"寵児":{"variants":"ちょう児/チョウジ/寵児"},"ちょう児":{"variants":"ちょう児/チョウジ/寵児"},"帳じり":{"variants":"帳じり/帳尻"},"帳尻":{"variants":"帳じり/帳尻"},"ちょうする":{"variants":"ちょうする/寵する/弔する/徴する/朝する"},"ちょうずる":{"variants":"ちょうずる/長ずる"},"長ずる":{"variants":"ちょうずる/長ずる"},"ちょう戦":{"variants":"ちょう戦/挑戦"},"挑戦":{"variants":"ちょう戦/挑戦"},"チョウセンニンジン":{"variants":"チョウセンニンジン/朝鮮ニンジン"},"朝鮮ニンジン":{"variants":"チョウセンニンジン/朝鮮ニンジン"},"ちょうぜんと":{"variants":"ちょうぜんと/超然と"},"超然と":{"variants":"ちょうぜんと/超然と"},"ちょうだい":{"variants":"ちょうだい/頂戴"},"頂戴":{"variants":"ちょうだい/頂戴"},"喋喋":{"variants":"喋々/喋喋"},"蝶々":{"variants":"蝶々/蝶蝶"},"丁々":{"variants":"丁々/丁丁"},"喋々":{"variants":"喋々/喋喋"},"丁丁":{"variants":"丁々/丁丁"},"蝶蝶":{"variants":"蝶々/蝶蝶"},"ちょうちん持ち":{"variants":"ちょうちん持ち/提灯持ち"},"提灯持ち":{"variants":"ちょうちん持ち/提灯持ち"},"腸詰":{"variants":"腸詰/腸詰め"},"腸詰め":{"variants":"腸詰/腸詰め"},"ちょうと":{"variants":"ちょうと/丁と"},"丁と":{"variants":"ちょうと/丁と"},"ちょうど":{"variants":"ちょうど/丁度"},"丁度":{"variants":"ちょうど/丁度"},"ちょうどきゅう":{"variants":"ちょうどきゅう/超弩級"},"超弩級":{"variants":"ちょうどきゅう/超弩級"},"腸へいそく":{"variants":"腸へいそく/腸閉塞"},"腸閉塞":{"variants":"腸へいそく/腸閉塞"},"諜報":{"variants":"ちょう報/諜報"},"ちょう報":{"variants":"ちょう報/諜報"},"帳面々":{"variants":"帳面々/帳面面"},"帳面面":{"variants":"帳面々/帳面面"},"ちょうらい":{"variants":"ちょうらい/朝来"},"朝来":{"variants":"ちょうらい/朝来"},"ちょう落":{"variants":"ちょう落/凋落"},"凋落":{"variants":"ちょう落/凋落"},"チョウルイ":{"variants":"チョウルイ/鳥類"},"鳥類":{"variants":"チョウルイ/鳥類"},"チョコ":{"variants":"チョコ/猪口"},"猪口":{"variants":"チョコ/猪口"},"ちょ突猛進":{"variants":"ちょ突猛進/猪突猛進"},"猪突猛進":{"variants":"ちょ突猛進/猪突猛進"},"ちょびひげ":{"variants":"ちょびひげ/ちょび髭"},"ちょび髭":{"variants":"ちょびひげ/ちょび髭"},"ちょろちょろ":{"variants":"ちょろちょろ/チョロチョロ"},"チョロチョロ":{"variants":"ちょろちょろ/チョロチョロ"},"ちょんまげ":{"variants":"ちょんまげ/ちょん髷/丁髷"},"ちょん髷":{"variants":"ちょんまげ/ちょん髷/丁髷"},"丁髷":{"variants":"ちょんまげ/ちょん髷/丁髷"},"ちらかす":{"variants":"ちらかす/散らかす"},"散らかす":{"variants":"ちらかす/散らかす"},"ちらかる":{"variants":"ちらかる/散らかる"},"散らかる":{"variants":"ちらかる/散らかる"},"チラシ":{"variants":"チラシ/散らし"},"散らし":{"variants":"チラシ/散らし"},"散らしずし":{"variants":"ちらし鮨/散らしずし/散らし鮨/散寿司"},"散らし鮨":{"variants":"ちらし鮨/散らしずし/散らし鮨"},"ちらし鮨":{"variants":"ちらし鮨/散らしずし/散らし鮨"},"ちらす":{"variants":"ちらす/散らす"},"散らす":{"variants":"ちらす/散らす"},"ちらつく":{"variants":"ちらつく/チラつく"},"チラつく":{"variants":"ちらつく/チラつく"},"ちらばる":{"variants":"ちらばる/散らばる"},"散らばる":{"variants":"ちらばる/散らばる"},"チリ":{"variants":"チリ/塵/地理"},"ちりいそぐ":{"variants":"ちりいそぐ/散り急ぐ"},"散り急ぐ":{"variants":"ちりいそぐ/散り急ぐ"},"ちり紙":{"variants":"ちり紙/塵紙"},"塵紙":{"variants":"ちり紙/塵紙"},"ちりしく":{"variants":"ちりしく/散り敷く/散敷く"},"散り敷く":{"variants":"ちりしく/散り敷く/散敷く"},"散敷く":{"variants":"ちりしく/散り敷く/散敷く"},"ちりちり":{"variants":"ちりちり/チリチリ"},"チリチリ":{"variants":"ちりちり/チリチリ"},"ちりとり":{"variants":"ちりとり/塵取"},"塵取":{"variants":"ちりとり/塵取"},"ちりのこる":{"variants":"ちりのこる/散り残る/散残る"},"散り残る":{"variants":"ちりのこる/散り残る/散残る"},"散残る":{"variants":"ちりのこる/散り残る/散残る"},"ちりはてる":{"variants":"ちりはてる/散りはてる"},"散りはてる":{"variants":"ちりはてる/散りはてる"},"ちりばめる":{"variants":"ちりばめる/散りばめる/鏤める"},"治りょう":{"variants":"治りょう/治療"},"治療":{"variants":"治りょう/治療"},"ちる":{"variants":"ちる/散る"},"散る":{"variants":"ちる/散る"},"ちんうつ":{"variants":"ちんうつ/沈うつ/沈鬱"},"沈うつ":{"variants":"沈うつ/沈鬱"},"沈鬱":{"variants":"沈うつ/沈鬱"},"ちんずる":{"variants":"ちんずる/陳ずる"},"陳ずる":{"variants":"ちんずる/陳ずる"},"沈々":{"variants":"沈々/沈沈"},"沈沈":{"variants":"沈々/沈沈"},"ちん入":{"variants":"ちん入/闖入"},"闖入":{"variants":"ちん入/闖入"},"ちんぴら":{"variants":"ちんぴら/チンピラ"},"チンピラ":{"variants":"ちんぴら/チンピラ"},"っぱなし":{"variants":"っぱなし/っ放し"},"っ放し":{"variants":"っぱなし/っ放し"},"ついえる":{"variants":"ついえる/潰える/費える"},"つい間板":{"variants":"つい間板/椎間板"},"椎間板":{"variants":"つい間板/椎間板"},"つい骨":{"variants":"つい骨/椎骨"},"椎骨":{"variants":"つい骨/椎骨"},"ついたて":{"variants":"ついたて/衝立"},"衝立":{"variants":"ついたて/衝立"},"ついたてぞめ":{"variants":"ついたてぞめ/付立染"},"付立染":{"variants":"ついたてぞめ/付立染"},"ついで":{"variants":"ついで/序/序で"},"次いで":{"variants":"ついで/次いで"},"序":{"variants":"ついで/序/序で"},"序で":{"variants":"ついで/序/序で"},"ついに":{"variants":"ついに/終に/遂に"},"ついばむ":{"variants":"ついばむ/啄む"},"啄む":{"variants":"ついばむ/啄む"},"ついばめる":{"variants":"ついばめる/啄める"},"啄める":{"variants":"ついばめる/啄める"},"ついやす":{"variants":"ついやす/費す/費やす"},"費す":{"variants":"ついやす/費す/費やす"},"費やす":{"variants":"ついやす/費す/費やす"},"ついやせる":{"variants":"ついやせる/費やせる"},"費やせる":{"variants":"ついやせる/費やせる"},"つう":{"variants":"つう/通"},"通":{"variants":"どおり/通/通り"},"つうがる":{"variants":"つうがる/通がる"},"通がる":{"variants":"つうがる/通がる"},"通じ":{"variants":"通じ/通詞/通事/通辞"},"つうじる":{"variants":"つうじる/通じる"},"通じる":{"variants":"つうじる/通じる"},"つうずる":{"variants":"つうずる/通ずる"},"通ずる":{"variants":"つうずる/通ずる"},"つうぶる":{"variants":"つうぶる/通ぶる"},"通ぶる":{"variants":"つうぶる/通ぶる"},"ツェツェバエ":{"variants":"ツェツェバエ/ツェツェ蝿"},"ツェツェ蝿":{"variants":"ツェツェバエ/ツェツェ蝿"},"つえ":{"variants":"つえ/ツエ/杖"},"ツエ":{"variants":"つえ/ツエ/杖"},"杖":{"variants":"つえ/ツエ/杖"},"つかいこなす":{"variants":"つかいこなす/使いこなす"},"使いこなす":{"variants":"つかいこなす/使いこなす"},"つかいこなせる":{"variants":"つかいこなせる/使いこなせる"},"使いこなせる":{"variants":"つかいこなせる/使いこなせる"},"つかいこむ":{"variants":"つかいこむ/遣いこむ/遣い込む/使いこむ/使い込む"},"使い込む":{"variants":"つかいこむ/使いこむ/使い込む"},"使いこむ":{"variants":"つかいこむ/使いこむ/使い込む"},"遣い込む":{"variants":"つかいこむ/遣いこむ/遣い込む"},"遣いこむ":{"variants":"つかいこむ/遣いこむ/遣い込む"},"つかいはたす":{"variants":"つかいはたす/使い果す/使い果たす"},"使い果す":{"variants":"つかいはたす/使い果す/使い果たす"},"使い果たす":{"variants":"つかいはたす/使い果す/使い果たす"},"つかいふるす":{"variants":"つかいふるす/使い古す"},"使い古す":{"variants":"つかいふるす/使い古す"},"使いみち":{"variants":"使いみち/使い途/使い道"},"使いもの":{"variants":"使いもの/使い物"},"遣い物":{"variants":"遣いもの/遣い物"},"遣いもの":{"variants":"遣いもの/遣い物"},"使い物":{"variants":"使いもの/使い物"},"つかいわける":{"variants":"つかいわける/使い分ける"},"使い分ける":{"variants":"つかいわける/使い分ける"},"つかう":{"variants":"つかう/遣う/使う"},"つかうまつる":{"variants":"つかうまつる/仕うまつる"},"仕うまつる":{"variants":"つかうまつる/仕うまつる"},"つかえる":{"variants":"つかえる/遣える/仕える/使える/事える/閊える"},"つかさどる":{"variants":"つかさどる/司る"},"司る":{"variants":"つかさどる/司る"},"つかす":{"variants":"つかす/尽かす"},"尽かす":{"variants":"つかす/尽かす"},"つかの間":{"variants":"つかの間/束の間"},"束の間":{"variants":"つかの間/束の間"},"つかまえる":{"variants":"つかまえる/掴まえる/捕まえる"},"つかまつる":{"variants":"つかまつる/仕る"},"仕る":{"variants":"つかまつる/仕る"},"つかまる":{"variants":"つかまる/掴まる/捕まる"},"つかみ":{"variants":"つかみ/掴み"},"掴み":{"variants":"つかみ/掴み"},"つかみあう":{"variants":"つかみあう/つかみ合う/掴みあう/掴み合う"},"つかみ合う":{"variants":"つかみあう/つかみ合う/掴みあう/掴み合う"},"掴みあう":{"variants":"つかみあう/つかみ合う/掴みあう/掴み合う"},"掴み合う":{"variants":"つかみあう/つかみ合う/掴みあう/掴み合う"},"つかみかかる":{"variants":"つかみかかる/掴みかかる/掴み掛る"},"掴みかかる":{"variants":"つかみかかる/掴みかかる/掴み掛る"},"掴み掛る":{"variants":"つかみかかる/掴みかかる/掴み掛る"},"掴みどころ":{"variants":"掴みどころ/掴み所"},"掴み所":{"variants":"掴みどころ/掴み所"},"つかみ取り":{"variants":"つかみ取り/掴み取り"},"掴み取り":{"variants":"つかみ取り/掴み取り"},"つかむ":{"variants":"つかむ/掴む/攫む"},"つかめる":{"variants":"つかめる/掴める"},"掴める":{"variants":"つかめる/掴める"},"つからす":{"variants":"つからす/疲らす"},"疲らす":{"variants":"つからす/疲らす"},"つからせる":{"variants":"つからせる/疲らせる"},"疲らせる":{"variants":"つからせる/疲らせる"},"つかる":{"variants":"つかる/浸かる/漬かる"},"つかれはてる":{"variants":"つかれはてる/つかれ果てる/疲れはてる"},"つかれ果てる":{"variants":"つかれはてる/つかれ果てる/疲れはてる"},"疲れはてる":{"variants":"つかれはてる/つかれ果てる/疲れはてる"},"つかれる":{"variants":"つかれる/疲れる/憑かれる"},"つかわす":{"variants":"つかわす/遣わす"},"遣わす":{"variants":"つかわす/遣わす"},"つかわれだす":{"variants":"つかわれだす/使われだす"},"使われだす":{"variants":"つかわれだす/使われだす"},"ツガ":{"variants":"ツガ/栂"},"栂":{"variants":"ツガ/栂"},"つがえる":{"variants":"つがえる/番える"},"番える":{"variants":"つがえる/番える"},"ツキ":{"variants":"ツキ/尽き/槻/突き/付き"},"つき":{"variants":"つき/付き"},"付き":{"variants":"つき/付き"},"つきあい":{"variants":"つきあい/つき合い/付き合い/付合/付合い"},"つき合い":{"variants":"つきあい/つき合い/付き合い/付合/付合い"},"付き合い":{"variants":"つきあい/つき合い/付き合い/付合/付合い"},"付合":{"variants":"つきあい/つき合い/付き合い/付合/付合い"},"付合い":{"variants":"つきあい/つき合い/付き合い/付合/付合い"},"つきあう":{"variants":"つきあう/つき合う/付き合う/付合う"},"つき合う":{"variants":"つきあう/つき合う/付き合う/付合う"},"付き合う":{"variants":"つきあう/つき合う/付き合う/付合う"},"付合う":{"variants":"つきあう/つき合う/付き合う/付合う"},"つきあえる":{"variants":"つきあえる/つき合える/付き合える"},"つき合える":{"variants":"つきあえる/つき合える/付き合える"},"付き合える":{"variants":"つきあえる/つき合える/付き合える"},"月あかり":{"variants":"月あかり/月明かり"},"月明かり":{"variants":"月あかり/月明かり"},"つきあげる":{"variants":"つきあげる/突き上げる"},"突き上げる":{"variants":"つきあげる/突き上げる"},"つきあたる":{"variants":"つきあたる/突きあたる/突き当たる/突き当る/突当る"},"突きあたる":{"variants":"つきあたる/突きあたる/突き当たる/突き当る/突当る"},"突き当たる":{"variants":"つきあたる/突きあたる/突き当たる/突き当る/突当る"},"突き当る":{"variants":"つきあたる/突きあたる/突き当たる/突き当る/突当る"},"突当る":{"variants":"つきあたる/突きあたる/突き当たる/突き当る/突当る"},"つきあわす":{"variants":"つきあわす/突きあわす/突き合す/突き合わす/突合す"},"突きあわす":{"variants":"つきあわす/突きあわす/突き合す/突き合わす/突合す"},"突き合す":{"variants":"つきあわす/突きあわす/突き合す/突き合わす/突合す"},"突き合わす":{"variants":"つきあわす/突きあわす/突き合す/突き合わす/突合す"},"突合す":{"variants":"つきあわす/突きあわす/突き合す/突き合わす/突合す"},"つきあわせる":{"variants":"つきあわせる/つき合せる/突きあわせる/突き合せる/突き合わせる/突合せる"},"つき合せる":{"variants":"つきあわせる/つき合せる/突きあわせる/突き合せる/突き合わせる/突合せる"},"突きあわせる":{"variants":"つきあわせる/つき合せる/突きあわせる/突き合せる/突き合わせる/突合せる"},"突き合せる":{"variants":"つきあわせる/つき合せる/突きあわせる/突き合せる/突き合わせる/突合せる"},"突き合わせる":{"variants":"つきあわせる/つき合せる/突きあわせる/突き合せる/突き合わせる/突合せる"},"突合せる":{"variants":"つきあわせる/つき合せる/突きあわせる/突き合せる/突き合わせる/突合せる"},"つきかえす":{"variants":"つきかえす/突き返す"},"突き返す":{"variants":"つきかえす/突き返す"},"月掛":{"variants":"月掛/月掛け"},"月掛け":{"variants":"月掛/月掛け"},"月極":{"variants":"月極/月極め"},"月極め":{"variants":"月極/月極め"},"ツキクサ":{"variants":"ツキクサ/鴨跖草/月草"},"つきささる":{"variants":"つきささる/つき刺さる/突き刺さる"},"つき刺さる":{"variants":"つきささる/つき刺さる/突き刺さる"},"突き刺さる":{"variants":"つきささる/つき刺さる/突き刺さる"},"つきさす":{"variants":"つきさす/突き刺す/突刺す"},"突き刺す":{"variants":"つきさす/突き刺す/突刺す"},"突刺す":{"variants":"つきさす/突き刺す/突刺す"},"つきさせる":{"variants":"つきさせる/突き刺せる"},"突き刺せる":{"variants":"つきさせる/突き刺せる"},"つきしたがう":{"variants":"つきしたがう/付き従う/付き随う/付従う/付随う"},"付従う":{"variants":"つきしたがう/付き従う/付従う"},"付き従う":{"variants":"つきしたがう/付き従う/付従う"},"付随う":{"variants":"つきしたがう/付き随う/付随う"},"付き随う":{"variants":"つきしたがう/付き随う/付随う"},"つきすすむ":{"variants":"つきすすむ/突き進む"},"突き進む":{"variants":"つきすすむ/突き進む"},"つきすすめる":{"variants":"つきすすめる/突き進める"},"突き進める":{"variants":"つきすすめる/突き進める"},"付き添い":{"variants":"付き添い/付添/付添い"},"付添":{"variants":"付き添い/付添/付添い"},"付添い":{"variants":"付き添い/付添/付添い"},"つきそう":{"variants":"つきそう/付き添う/付添う"},"付き添う":{"variants":"つきそう/付き添う/付添う"},"付添う":{"variants":"つきそう/付き添う/付添う"},"つきそえる":{"variants":"つきそえる/付き添える"},"付き添える":{"variants":"つきそえる/付き添える"},"つきたてる":{"variants":"つきたてる/突き立てる"},"突き立てる":{"variants":"つきたてる/突き立てる"},"突き出し":{"variants":"突き出し/突出し"},"突出し":{"variants":"突き出し/突出し"},"つきだす":{"variants":"つきだす/突きだす/突き出す/突出す"},"突きだす":{"variants":"つきだす/突きだす/突き出す/突出す"},"突き出す":{"variants":"つきだす/突きだす/突き出す/突出す"},"突出す":{"variants":"つきだす/突きだす/突き出す/突出す"},"つきだせる":{"variants":"つきだせる/突き出せる"},"突き出せる":{"variants":"つきだせる/突き出せる"},"つきっきり":{"variants":"つきっきり/付きっきり/付きっ切り"},"付きっきり":{"variants":"つきっきり/付きっきり/付きっ切り"},"付きっ切り":{"variants":"つきっきり/付きっきり/付きっ切り"},"つきつける":{"variants":"つきつける/突きつける/突き付ける/突付ける"},"突きつける":{"variants":"つきつける/突きつける/突き付ける/突付ける"},"突き付ける":{"variants":"つきつける/突きつける/突き付ける/突付ける"},"突付ける":{"variants":"つきつける/突きつける/突き付ける/突付ける"},"つきつめる":{"variants":"つきつめる/突きつめる/突き詰める/突詰める"},"突きつめる":{"variants":"つきつめる/突きつめる/突き詰める/突詰める"},"突き詰める":{"variants":"つきつめる/突きつめる/突き詰める/突詰める"},"突詰める":{"variants":"つきつめる/突きつめる/突き詰める/突詰める"},"つきでる":{"variants":"つきでる/突き出る"},"突き出る":{"variants":"つきでる/突き出る"},"つきとおす":{"variants":"つきとおす/突き通す"},"突き通す":{"variants":"つきとおす/突き通す"},"つきとおせる":{"variants":"つきとおせる/突き通せる"},"突き通せる":{"variants":"つきとおせる/突き通せる"},"つきとおる":{"variants":"つきとおる/突き通る/突通る"},"突き通る":{"variants":"つきとおる/突き通る/突通る"},"突通る":{"variants":"つきとおる/突き通る/突通る"},"つきとばす":{"variants":"つきとばす/突きとばす/突き飛ばす/突飛ばす"},"突きとばす":{"variants":"つきとばす/突きとばす/突き飛ばす/突飛ばす"},"突き飛ばす":{"variants":"つきとばす/突きとばす/突き飛ばす/突飛ばす"},"突飛ばす":{"variants":"つきとばす/突きとばす/突き飛ばす/突飛ばす"},"つきとばせる":{"variants":"つきとばせる/突き飛ばせる"},"突き飛ばせる":{"variants":"つきとばせる/突き飛ばせる"},"つきとめる":{"variants":"つきとめる/突き止める/突止める"},"突き止める":{"variants":"つきとめる/突き止める/突止める"},"突止める":{"variants":"つきとめる/突き止める/突止める"},"月並":{"variants":"月並/月並み"},"月並み":{"variants":"月並/月並み"},"つきぬく":{"variants":"つきぬく/突き抜く"},"突き抜く":{"variants":"つきぬく/突き抜く"},"つきぬける":{"variants":"つきぬける/つき抜ける/突きぬける/突き抜ける/突抜ける"},"つき抜ける":{"variants":"つきぬける/つき抜ける/突きぬける/突き抜ける/突抜ける"},"突きぬける":{"variants":"つきぬける/つき抜ける/突きぬける/突き抜ける/突抜ける"},"突き抜ける":{"variants":"つきぬける/つき抜ける/突きぬける/突き抜ける/突抜ける"},"突抜ける":{"variants":"つきぬける/つき抜ける/突きぬける/突き抜ける/突抜ける"},"つきのける":{"variants":"つきのける/突き除ける"},"突き除ける":{"variants":"つきのける/突き除ける"},"つきのめす":{"variants":"つきのめす/突きのめす"},"突きのめす":{"variants":"つきのめす/突きのめす"},"月のもの":{"variants":"月のもの/月の物"},"月の物":{"variants":"月のもの/月の物"},"ツキノワグマ":{"variants":"ツキノワグマ/月のわぐま/月の輪熊/月輪熊"},"月のわぐま":{"variants":"ツキノワグマ/月のわぐま/月の輪熊/月輪熊"},"月の輪熊":{"variants":"ツキノワグマ/月のわぐま/月の輪熊/月輪熊"},"月輪熊":{"variants":"ツキノワグマ/月のわぐま/月の輪熊/月輪熊"},"つきはなす":{"variants":"つきはなす/突き放す/突放す"},"突き放す":{"variants":"つきはなす/突き放す/突放す"},"突放す":{"variants":"つきはなす/突き放す/突放す"},"つきはなせる":{"variants":"つきはなせる/突き放せる"},"突き放せる":{"variants":"つきはなせる/突き放せる"},"つきまとう":{"variants":"つきまとう/付きまとう/付き纏う"},"付きまとう":{"variants":"つきまとう/付きまとう/付き纏う"},"付き纏う":{"variants":"つきまとう/付きまとう/付き纏う"},"ツキミソウ":{"variants":"ツキミソウ/月見草"},"月見草":{"variants":"ツキミソウ/月見草"},"つきもどす":{"variants":"つきもどす/突き戻す/突戻す"},"突き戻す":{"variants":"つきもどす/突き戻す/突戻す"},"突戻す":{"variants":"つきもどす/突き戻す/突戻す"},"つきもどせる":{"variants":"つきもどせる/突き戻せる"},"突き戻せる":{"variants":"つきもどせる/突き戻せる"},"つきもの":{"variants":"つきもの/付きもの/付き物/憑き物/憑物"},"付き物":{"variants":"つきもの/付きもの/付き物"},"付きもの":{"variants":"つきもの/付きもの/付き物"},"憑物":{"variants":"つきもの/憑き物/憑物"},"憑き物":{"variants":"つきもの/憑き物/憑物"},"つきやぶる":{"variants":"つきやぶる/突き破る/突破る"},"突き破る":{"variants":"つきやぶる/突き破る/突破る"},"突破る":{"variants":"つきやぶる/突き破る/突破る"},"つきやぶれる":{"variants":"つきやぶれる/突き破れる"},"突き破れる":{"variants":"つきやぶれる/突き破れる"},"突き指":{"variants":"突き指/突指"},"突指":{"variants":"突き指/突指"},"つきる":{"variants":"つきる/尽きる"},"尽きる":{"variants":"つきる/尽きる"},"月割":{"variants":"月割/月割り"},"月割り":{"variants":"月割/月割り"},"つぎ":{"variants":"つぎ/継ぎ/次"},"つぎあわせる":{"variants":"つぎあわせる/継ぎあわせる/継ぎ合せる"},"継ぎあわせる":{"variants":"つぎあわせる/継ぎあわせる/継ぎ合せる"},"継ぎ合せる":{"variants":"つぎあわせる/継ぎあわせる/継ぎ合せる"},"ツギキ":{"variants":"ツギキ/接ぎ木/接木"},"接ぎ木":{"variants":"ツギキ/接ぎ木/接木"},"接木":{"variants":"ツギキ/接ぎ木/接木"},"つぎこむ":{"variants":"つぎこむ/つぎ込む"},"つぎ込む":{"variants":"つぎこむ/つぎ込む"},"つぎこめる":{"variants":"つぎこめる/つぎ込める"},"つぎ込める":{"variants":"つぎこめる/つぎ込める"},"つぎたす":{"variants":"つぎたす/つぎ足す/継ぎ足す/継足す"},"つぎ足す":{"variants":"つぎたす/つぎ足す/継ぎ足す/継足す"},"継ぎ足す":{"variants":"つぎたす/つぎ足す/継ぎ足す/継足す"},"継足す":{"variants":"つぎたす/つぎ足す/継ぎ足す/継足す"},"つぎたせる":{"variants":"つぎたせる/継ぎ足せる"},"継ぎ足せる":{"variants":"つぎたせる/継ぎ足せる"},"ツギダイ":{"variants":"ツギダイ/継台/接台"},"つぎつぎ":{"variants":"つぎつぎ/次々"},"次々":{"variants":"次々/次次"},"次次":{"variants":"次々/次次"},"つぎつぎに":{"variants":"つぎつぎに/次々に/次ぎ次ぎに/次次に"},"次々に":{"variants":"つぎつぎに/次々に/次ぎ次ぎに/次次に"},"次ぎ次ぎに":{"variants":"つぎつぎに/次々に/次ぎ次ぎに/次次に"},"次次に":{"variants":"つぎつぎに/次々に/次ぎ次ぎに/次次に"},"継ぎ手":{"variants":"継ぎ手/継手"},"継手":{"variants":"継ぎ手/継手"},"ツギホ":{"variants":"ツギホ/接穂"},"接穂":{"variants":"ツギホ/接穂"},"継ぎ目":{"variants":"継ぎ目/継目"},"継目":{"variants":"継ぎ目/継目"},"つく":{"variants":"つく/就く/従く/衝く/着く/点く/撞く/突く/付く/附く/搗く"},"ツクシ":{"variants":"ツクシ/土筆"},"土筆":{"variants":"ツクシ/土筆"},"つくす":{"variants":"つくす/尽くす"},"尽くす":{"variants":"つくす/尽くす"},"尽す":{"variants":"つくす/尽くす/尽す"},"つくせる":{"variants":"つくせる/尽くせる"},"尽くせる":{"variants":"つくせる/尽くせる"},"つくだ煮":{"variants":"つくだ煮/佃煮"},"佃煮":{"variants":"つくだ煮/佃煮"},"つくつく法師":{"variants":"つくつく法師/ツクツクボウシ"},"ツクツクボウシ":{"variants":"つくつく法師/ツクツクボウシ"},"つくづく":{"variants":"つくづく/熟"},"熟":{"variants":"つくづく/熟"},"ツクネイモ":{"variants":"ツクネイモ/仏掌薯"},"仏掌薯":{"variants":"ツクネイモ/仏掌薯"},"つくばう":{"variants":"つくばう/蹲う"},"蹲う":{"variants":"つくばう/蹲う"},"つくり":{"variants":"つくり/作り/造り/旁"},"つくりあげる":{"variants":"つくりあげる/つくり上げる/作りあげる/作り上げる/造りあげる/造り上げる"},"つくり上げる":{"variants":"つくりあげる/つくり上げる/作りあげる/作り上げる/造りあげる/造り上げる"},"作りあげる":{"variants":"つくりあげる/つくり上げる/作りあげる/作り上げる"},"造り上げる":{"variants":"つくりあげる/つくり上げる/造りあげる/造り上げる"},"作り上げる":{"variants":"つくりあげる/つくり上げる/作りあげる/作り上げる"},"造りあげる":{"variants":"つくりあげる/つくり上げる/造りあげる/造り上げる"},"つくりかえる":{"variants":"つくりかえる/作りかえる/作り替える"},"作りかえる":{"variants":"つくりかえる/作りかえる/作り替える"},"作り替える":{"variants":"つくりかえる/作りかえる/作り替える"},"つくり声":{"variants":"つくり声/作りごえ/作り声"},"作りごえ":{"variants":"つくり声/作りごえ/作り声"},"作り声":{"variants":"つくり声/作りごえ/作り声"},"作りごと":{"variants":"作りごと/作り事"},"作り事":{"variants":"作りごと/作り事"},"作りたて":{"variants":"作りたて/作り立て"},"作り立て":{"variants":"作りたて/作り立て"},"つくりだす":{"variants":"つくりだす/つくり出す/作りだす/作り出す/創り出す/造りだす/造り出す"},"つくり出す":{"variants":"つくりだす/つくり出す/作りだす/作り出す/創り出す/造りだす/造り出す"},"作り出す":{"variants":"つくりだす/つくり出す/作りだす/作り出す"},"造りだす":{"variants":"つくりだす/つくり出す/造りだす/造り出す"},"作りだす":{"variants":"つくりだす/つくり出す/作りだす/作り出す"},"造り出す":{"variants":"つくりだす/つくり出す/造りだす/造り出す"},"つくりだせる":{"variants":"つくりだせる/作り出せる/創り出せる"},"つくりなおす":{"variants":"つくりなおす/作り直す"},"作り直す":{"variants":"つくりなおす/作り直す"},"つくりなす":{"variants":"つくりなす/作り成す"},"作り成す":{"variants":"つくりなす/作り成す"},"作りばなし":{"variants":"作りばなし/作り話"},"作り話":{"variants":"作りばなし/作り話"},"作りもの":{"variants":"作りもの/作り物"},"作り物":{"variants":"作りもの/作り物"},"つくり笑い":{"variants":"つくり笑い/作り笑い"},"作り笑い":{"variants":"つくり笑い/作り笑い"},"つくる":{"variants":"つくる/ツクる/作る/創る/造る"},"ツクる":{"variants":"つくる/ツクる/作る/創る/造る"},"つくれる":{"variants":"つくれる/作れる/創れる/造れる"},"つくろう":{"variants":"つくろう/繕う"},"繕う":{"variants":"つくろう/繕う"},"つくろえる":{"variants":"つくろえる/繕える"},"繕える":{"variants":"つくろえる/繕える"},"つぐ":{"variants":"つぐ/継ぐ/告ぐ/嗣ぐ/次ぐ/接ぐ/訃ぐ"},"つぐなう":{"variants":"つぐなう/償う"},"償う":{"variants":"つぐなう/償う"},"つぐなえる":{"variants":"つぐなえる/償える"},"償える":{"variants":"つぐなえる/償える"},"ツグミ":{"variants":"ツグミ/鶫"},"鶫":{"variants":"ツグミ/鶫"},"つぐむ":{"variants":"つぐむ/噤む/鉗む"},"つけ":{"variants":"つけ/ツケ/漬け/付け"},"ツケ":{"variants":"つけ/ツケ/漬け/付け"},"つけあがる":{"variants":"つけあがる/つけ上がる/付け上がる"},"つけ上がる":{"variants":"つけあがる/つけ上がる/付け上がる"},"付け上がる":{"variants":"つけあがる/つけ上がる/付け上がる"},"つけあわせる":{"variants":"つけあわせる/付け合わせる"},"付け合わせる":{"variants":"つけあわせる/付け合わせる"},"つけいる":{"variants":"つけいる/つけ入る/付け入る/付入る"},"つけ入る":{"variants":"つけいる/つけ入る/付け入る/付入る"},"付け入る":{"variants":"つけいる/つけ入る/付け入る/付入る"},"付入る":{"variants":"つけいる/つけ入る/付け入る/付入る"},"付け落ち":{"variants":"付け落ち/付落ち"},"付落ち":{"variants":"付け落ち/付落ち"},"つけかえる":{"variants":"つけかえる/付けかえる/付け替える"},"付けかえる":{"variants":"つけかえる/付けかえる/付け替える"},"付け替える":{"variants":"つけかえる/付けかえる/付け替える"},"つけくわえる":{"variants":"つけくわえる/つけ加える/付け加える/付加える"},"つけ加える":{"variants":"つけくわえる/つけ加える/付け加える/付加える"},"付け加える":{"variants":"つけくわえる/つけ加える/付け加える/付加える"},"付加える":{"variants":"つけくわえる/つけ加える/付け加える/付加える"},"つけくわわる":{"variants":"つけくわわる/つけ加わる/付け加わる/付加わる"},"つけ加わる":{"variants":"つけくわわる/つけ加わる/付け加わる/付加わる"},"付け加わる":{"variants":"つけくわわる/つけ加わる/付け加わる/付加わる"},"付加わる":{"variants":"つけくわわる/つけ加わる/付け加わる/付加わる"},"つけこむ":{"variants":"つけこむ/つけ込む/漬けこむ/漬け込む/漬込む/付け込む/付込む"},"つけ込む":{"variants":"つけこむ/つけ込む/漬けこむ/漬け込む/漬込む/付け込む/付込む"},"漬込む":{"variants":"つけこむ/つけ込む/漬けこむ/漬け込む/漬込む"},"漬け込む":{"variants":"つけこむ/つけ込む/漬けこむ/漬け込む/漬込む"},"漬けこむ":{"variants":"つけこむ/つけ込む/漬けこむ/漬け込む/漬込む"},"付込む":{"variants":"つけこむ/つけ込む/付け込む/付込む"},"付け込む":{"variants":"つけこむ/つけ込む/付け込む/付込む"},"付け差し":{"variants":"付け差し/付差し"},"付差し":{"variants":"付け差し/付差し"},"つけたす":{"variants":"つけたす/つけ足す/付け足す/付足す"},"つけ足す":{"variants":"つけたす/つけ足す/付け足す/付足す"},"付け足す":{"variants":"つけたす/つけ足す/付け足す/付足す"},"付足す":{"variants":"つけたす/つけ足す/付け足す/付足す"},"つけたせる":{"variants":"つけたせる/付け足せる"},"付け足せる":{"variants":"つけたせる/付け足せる"},"付け出し":{"variants":"付け出し/付出し"},"付出し":{"variants":"付け出し/付出し"},"つけだす":{"variants":"つけだす/付け出す/付出す"},"付け出す":{"variants":"つけだす/付け出す/付出す"},"付出す":{"variants":"つけだす/付け出す/付出す"},"付け届け":{"variants":"付け届け/付届け"},"付届け":{"variants":"付け届け/付届け"},"つけどころ":{"variants":"つけどころ/付けどころ/付け所"},"付けどころ":{"variants":"つけどころ/付けどころ/付け所"},"付け所":{"variants":"つけどころ/付けどころ/付け所"},"漬け菜":{"variants":"漬け菜/漬菜"},"漬菜":{"variants":"漬け菜/漬菜"},"付け値":{"variants":"付け値/付値"},"つけ根":{"variants":"つけ根/付け根/付根"},"付根":{"variants":"つけ根/付け根/付根"},"付け根":{"variants":"つけ根/付け根/付根"},"付値":{"variants":"付け値/付値"},"つけねらう":{"variants":"つけねらう/つけ狙う/付け狙う"},"つけ狙う":{"variants":"つけねらう/つけ狙う/付け狙う"},"付け狙う":{"variants":"つけねらう/つけ狙う/付け狙う"},"つけ髭":{"variants":"つけ髭/付けひげ/付け髭"},"付けひげ":{"variants":"つけ髭/付けひげ/付け髭"},"付け髭":{"variants":"つけ髭/付けひげ/付け髭"},"付けひも":{"variants":"付けひも/付け紐"},"付け紐":{"variants":"付けひも/付け紐"},"付け火":{"variants":"付け火/付火"},"付火":{"variants":"付け火/付火"},"付け文":{"variants":"付け文/付文"},"付文":{"variants":"付け文/付文"},"付けまげ":{"variants":"付けまげ/付け髷"},"付け髷":{"variants":"付けまげ/付け髷"},"付けまつげ":{"variants":"付けまつげ/付け睫"},"付け睫":{"variants":"付けまつげ/付け睫"},"つけまわす":{"variants":"つけまわす/つけ回す/つけ廻す/付け回す/付け廻す/付回す/付廻す"},"付回す":{"variants":"つけまわす/つけ回す/付け回す/付回す"},"つけ廻す":{"variants":"つけまわす/つけ廻す/付け廻す/付廻す"},"付廻す":{"variants":"つけまわす/つけ廻す/付け廻す/付廻す"},"付け回す":{"variants":"つけまわす/つけ回す/付け回す/付回す"},"付け廻す":{"variants":"つけまわす/つけ廻す/付け廻す/付廻す"},"つけ回す":{"variants":"つけまわす/つけ回す/付け回す/付回す"},"つけ目":{"variants":"つけ目/付け目/付目"},"付け目":{"variants":"つけ目/付け目/付目"},"付目":{"variants":"つけ目/付け目/付目"},"つけもの":{"variants":"つけもの/つけ物/漬物"},"つけ物":{"variants":"つけもの/つけ物/漬物"},"漬物":{"variants":"つけもの/つけ物/漬物"},"付け焼":{"variants":"付け焼/付け焼き/付焼"},"付け焼き":{"variants":"付け焼/付け焼き/付焼"},"付焼":{"variants":"付け焼/付け焼き/付焼"},"付け焼き刃":{"variants":"付け焼き刃/付け焼刃/付焼刃"},"付け焼刃":{"variants":"付け焼き刃/付け焼刃/付焼刃"},"付焼刃":{"variants":"付け焼き刃/付け焼刃/付焼刃"},"つける":{"variants":"つける/就ける/衝ける/浸ける/即ける/着ける/漬ける/突ける/付ける/附ける"},"ツゲ":{"variants":"ツゲ/黄楊/告げ/柘植"},"つげ口":{"variants":"つげ口/告げぐち/告げ口"},"告げぐち":{"variants":"つげ口/告げぐち/告げ口"},"告げ口":{"variants":"つげ口/告げぐち/告げ口"},"つげる":{"variants":"つげる/継げる/告げる/嗣げる/接げる/訃げる"},"辻斬":{"variants":"辻斬/辻斬り"},"辻斬り":{"variants":"辻斬/辻斬り"},"つじつま":{"variants":"つじつま/辻つま/辻褄"},"辻つま":{"variants":"つじつま/辻つま/辻褄"},"辻褄":{"variants":"つじつま/辻つま/辻褄"},"ツタ":{"variants":"ツタ/蔦"},"蔦":{"variants":"ツタ/蔦"},"つたう":{"variants":"つたう/伝う"},"伝う":{"variants":"つたう/伝う"},"つたえきく":{"variants":"つたえきく/伝え聞く"},"伝え聞く":{"variants":"つたえきく/伝え聞く"},"つたえる":{"variants":"つたえる/伝える/傳える"},"つたない":{"variants":"つたない/拙い"},"拙い":{"variants":"つたない/拙い"},"つたわる":{"variants":"つたわる/伝わる"},"伝わる":{"variants":"つたわる/伝わる"},"つちかう":{"variants":"つちかう/培う"},"培う":{"variants":"つちかう/培う"},"つちかえる":{"variants":"つちかえる/培える"},"培える":{"variants":"つちかえる/培える"},"つちくさい":{"variants":"つちくさい/土臭い"},"土臭い":{"variants":"つちくさい/土臭い"},"ツチグモ":{"variants":"ツチグモ/土蜘蛛"},"土蜘蛛":{"variants":"ツチグモ/土蜘蛛"},"土ぼこり":{"variants":"土ぼこり/土埃"},"土埃":{"variants":"土ぼこり/土埃"},"つっかえす":{"variants":"つっかえす/つっ返す/突っかえす/突っ返す"},"つっ返す":{"variants":"つっかえす/つっ返す/突っかえす/突っ返す"},"突っかえす":{"variants":"つっかえす/つっ返す/突っかえす/突っ返す"},"突っ返す":{"variants":"つっかえす/つっ返す/突っかえす/突っ返す"},"つっかえせる":{"variants":"つっかえせる/突っ返せる"},"突っ返せる":{"variants":"つっかえせる/突っ返せる"},"つっかかる":{"variants":"つっかかる/突っかかる/突っ掛る"},"突っかかる":{"variants":"つっかかる/突っかかる/突っ掛る"},"突っ掛る":{"variants":"つっかかる/突っかかる/突っ掛る"},"つっきる":{"variants":"つっきる/つっ切る/突っきる/突っ切る"},"つっ切る":{"variants":"つっきる/つっ切る/突っきる/突っ切る"},"突っきる":{"variants":"つっきる/つっ切る/突っきる/突っ切る"},"突っ切る":{"variants":"つっきる/つっ切る/突っきる/突っ切る"},"突っこみ":{"variants":"突っこみ/突っ込み/突込み"},"突っ込み":{"variants":"突っこみ/突っ込み/突込み"},"突込み":{"variants":"突っこみ/突っ込み/突込み"},"つっこむ":{"variants":"つっこむ/つっ込む/突っこむ/突っ込む"},"つっ込む":{"variants":"つっこむ/つっ込む/突っこむ/突っ込む"},"突っこむ":{"variants":"つっこむ/つっ込む/突っこむ/突っ込む"},"突っ込む":{"variants":"つっこむ/つっ込む/突っこむ/突っ込む"},"つっこめる":{"variants":"つっこめる/突っ込める"},"突っ込める":{"variants":"つっこめる/突っ込める"},"つっころばす":{"variants":"つっころばす/突っころばす/突っ転ばす"},"突っころばす":{"variants":"つっころばす/突っころばす/突っ転ばす"},"突っ転ばす":{"variants":"つっころばす/突っころばす/突っ転ばす"},"つったてる":{"variants":"つったてる/突っ立てる"},"突っ立てる":{"variants":"つったてる/突っ立てる"},"つっつく":{"variants":"つっつく/突っつく/突っ突く"},"突っつく":{"variants":"つっつく/突っつく/突っ突く"},"突っ突く":{"variants":"つっつく/突っつく/突っ突く"},"つっぱしる":{"variants":"つっぱしる/つっ走る/突っ走る"},"つっ走る":{"variants":"つっぱしる/つっ走る/突っ走る"},"突っ走る":{"variants":"つっぱしる/つっ走る/突っ走る"},"つっぱしれる":{"variants":"つっぱしれる/突っ走れる"},"突っ走れる":{"variants":"つっぱしれる/突っ走れる"},"つっぱなす":{"variants":"つっぱなす/つっ放す/突っぱなす/突っ放す"},"つっ放す":{"variants":"つっぱなす/つっ放す/突っぱなす/突っ放す"},"突っぱなす":{"variants":"つっぱなす/つっ放す/突っぱなす/突っ放す"},"突っ放す":{"variants":"つっぱなす/つっ放す/突っぱなす/突っ放す"},"つっぱねる":{"variants":"つっぱねる/突っぱねる/突っ撥ねる"},"突っぱねる":{"variants":"つっぱねる/突っぱねる/突っ撥ねる"},"突っ撥ねる":{"variants":"つっぱねる/突っぱねる/突っ撥ねる"},"つっぱる":{"variants":"つっぱる/ツッパる/突っぱる/突っ張る"},"ツッパる":{"variants":"つっぱる/ツッパる/突っぱる/突っ張る"},"突っぱる":{"variants":"つっぱる/ツッパる/突っぱる/突っ張る"},"突っ張る":{"variants":"つっぱる/ツッパる/突っぱる/突っ張る"},"つっぱれる":{"variants":"つっぱれる/突っ張れる"},"突っ張れる":{"variants":"つっぱれる/突っ張れる"},"つっぷす":{"variants":"つっぷす/つっ伏す/突っぷす/突っ伏す"},"つっ伏す":{"variants":"つっぷす/つっ伏す/突っぷす/突っ伏す"},"突っぷす":{"variants":"つっぷす/つっ伏す/突っぷす/突っ伏す"},"突っ伏す":{"variants":"つっぷす/つっ伏す/突っぷす/突っ伏す"},"つつがない":{"variants":"つつがない/恙無い"},"恙無い":{"variants":"つつがない/恙無い"},"ツツガムシ":{"variants":"ツツガムシ/恙虫"},"恙虫":{"variants":"ツツガムシ/恙虫"},"つつしむ":{"variants":"つつしむ/謹しむ/謹む/慎む"},"謹しむ":{"variants":"つつしむ/謹しむ/謹む"},"謹む":{"variants":"つつしむ/謹しむ/謹む"},"つつしんで":{"variants":"つつしんで/謹んで"},"謹んで":{"variants":"つつしんで/謹んで"},"ツツジ":{"variants":"ツツジ/躑躅"},"躑躅":{"variants":"ツツジ/躑躅"},"ツツドリ":{"variants":"ツツドリ/筒鳥"},"筒鳥":{"variants":"ツツドリ/筒鳥"},"つつましい":{"variants":"つつましい/慎ましい"},"慎ましい":{"variants":"つつましい/慎ましい"},"包":{"variants":"包/包み"},"包み":{"variants":"包/包み"},"つつみかくす":{"variants":"つつみかくす/包み隠す"},"包み隠す":{"variants":"つつみかくす/包み隠す"},"つつみこむ":{"variants":"つつみこむ/包み込む"},"包み込む":{"variants":"つつみこむ/包み込む"},"つつみこめる":{"variants":"つつみこめる/包み込める"},"包み込める":{"variants":"つつみこめる/包み込める"},"つつむ":{"variants":"つつむ/障む/包む/恙む"},"つつめる":{"variants":"つつめる/包める"},"包める":{"variants":"つつめる/包める"},"続き柄":{"variants":"続き柄/続柄"},"続柄":{"variants":"続き柄/続柄"},"続き物":{"variants":"続き物/続物"},"続物":{"variants":"続き物/続物"},"つづく":{"variants":"つづく/続く"},"続く":{"variants":"つづく/続く"},"続けざま":{"variants":"続けざま/続け様"},"続け様":{"variants":"続けざま/続け様"},"つづける":{"variants":"つづける/続ける"},"続ける":{"variants":"つづける/続ける"},"つづまる":{"variants":"つづまる/約まる"},"約まる":{"variants":"つづまる/約まる"},"つづめる":{"variants":"つづめる/約める"},"約める":{"variants":"つづめる/約める"},"つづら":{"variants":"つづら/ツヅラ/葛篭"},"ツヅラ":{"variants":"つづら/ツヅラ/葛篭"},"葛篭":{"variants":"つづら/ツヅラ/葛篭"},"つづら折り":{"variants":"つづら折り/葛折/九十九折"},"つづり":{"variants":"つづり/綴/綴り"},"綴":{"variants":"つづり/綴/綴り"},"綴り":{"variants":"つづり/綴/綴り"},"つづりあわす":{"variants":"つづりあわす/つづり合す/綴り合す"},"つづり合す":{"variants":"つづりあわす/つづり合す/綴り合す"},"綴り合す":{"variants":"つづりあわす/つづり合す/綴り合す"},"つづりあわせる":{"variants":"つづりあわせる/綴りあわせる/綴り合せる/綴合せる"},"綴りあわせる":{"variants":"つづりあわせる/綴りあわせる/綴り合せる/綴合せる"},"綴り合せる":{"variants":"つづりあわせる/綴りあわせる/綴り合せる/綴合せる"},"綴合せる":{"variants":"つづりあわせる/綴りあわせる/綴り合せる/綴合せる"},"つづり方":{"variants":"つづり方/綴方"},"綴方":{"variants":"つづり方/綴方"},"つづる":{"variants":"つづる/綴る"},"綴る":{"variants":"つづる/綴る"},"つづれる":{"variants":"つづれる/綴れる"},"綴れる":{"variants":"つづれる/綴れる"},"つて":{"variants":"つて/伝手"},"伝手":{"variants":"つて/伝手"},"つとに":{"variants":"つとに/夙に"},"夙に":{"variants":"つとに/夙に"},"つとまる":{"variants":"つとまる/勤まる/努まる/務まる"},"つとめて":{"variants":"つとめて/努めて/勉めて"},"つとめる":{"variants":"つとめる/勤める/努める/勉める/務める"},"つど":{"variants":"つど/都度"},"都度":{"variants":"つど/都度"},"つどう":{"variants":"つどう/集う"},"集う":{"variants":"つどう/集う"},"つどえる":{"variants":"つどえる/集える"},"集える":{"variants":"つどえる/集える"},"つながり":{"variants":"つながり/繋がり"},"繋がり":{"variants":"つながり/繋がり"},"つながる":{"variants":"つながる/継る/繋がる"},"つなぎ":{"variants":"つなぎ/繋/繋ぎ"},"繋":{"variants":"つなぎ/繋/繋ぎ"},"繋ぎ":{"variants":"つなぎ/繋/繋ぎ"},"つなぎとめる":{"variants":"つなぎとめる/つなぎ止める"},"つなぎ止める":{"variants":"つなぎとめる/つなぎ止める"},"つなぐ":{"variants":"つなぐ/繋ぐ"},"繋ぐ":{"variants":"つなぐ/繋ぐ"},"つなげる":{"variants":"つなげる/繋げる"},"繋げる":{"variants":"つなげる/繋げる"},"綱曳":{"variants":"綱曳/綱曳き"},"綱曳き":{"variants":"綱曳/綱曳き"},"綱引":{"variants":"綱引/綱引き"},"綱引き":{"variants":"綱引/綱引き"},"つねづね":{"variants":"つねづね/常常"},"常常":{"variants":"つねづね/常常"},"つねに":{"variants":"つねに/常に"},"常に":{"variants":"つねに/常に"},"角書":{"variants":"角書/角書き"},"角書き":{"variants":"角書/角書き"},"つのぐむ":{"variants":"つのぐむ/角ぐむ"},"角ぐむ":{"variants":"つのぐむ/角ぐむ"},"ツノマタ":{"variants":"ツノマタ/角叉"},"角叉":{"variants":"ツノマタ/角叉"},"つのめだつ":{"variants":"つのめだつ/角目立つ"},"角目立つ":{"variants":"つのめだつ/角目立つ"},"つのる":{"variants":"つのる/募る"},"募る":{"variants":"つのる/募る"},"つば":{"variants":"つば/唾/鍔/鐔"},"ツバキ":{"variants":"ツバキ/椿"},"椿":{"variants":"ツバキ/椿"},"つばくら":{"variants":"つばくら/ツバクラ"},"ツバクラ":{"variants":"つばくら/ツバクラ"},"つばくらめ":{"variants":"つばくらめ/ツバクラメ"},"ツバクラメ":{"variants":"つばくらめ/ツバクラメ"},"つばくろ":{"variants":"つばくろ/ツバクロ"},"ツバクロ":{"variants":"つばくろ/ツバクロ"},"つばぜり合い":{"variants":"つばぜり合い/鍔迫り合い"},"鍔迫り合い":{"variants":"つばぜり合い/鍔迫り合い"},"ツバナ":{"variants":"ツバナ/茅花"},"茅花":{"variants":"ツバナ/茅花"},"ツバメ":{"variants":"ツバメ/燕"},"燕":{"variants":"ツバメ/燕"},"つぶ":{"variants":"つぶ/粒"},"粒":{"variants":"つぶ/粒"},"つぶさに":{"variants":"つぶさに/具に/備に"},"つぶし":{"variants":"つぶし/潰し"},"潰し":{"variants":"つぶし/潰し"},"つぶす":{"variants":"つぶす/潰す"},"潰す":{"variants":"つぶす/潰す"},"つぶせる":{"variants":"つぶせる/潰せる"},"潰せる":{"variants":"つぶせる/潰せる"},"粒ぞろい":{"variants":"粒ぞろい/粒揃い"},"粒揃い":{"variants":"粒ぞろい/粒揃い"},"つぶだつ":{"variants":"つぶだつ/粒立つ"},"粒立つ":{"variants":"つぶだつ/粒立つ"},"つぶやく":{"variants":"つぶやく/呟く"},"呟く":{"variants":"つぶやく/呟く"},"つぶれる":{"variants":"つぶれる/潰れる"},"潰れる":{"variants":"つぶれる/潰れる"},"ツボ":{"variants":"ツボ/坪/壷/壺"},"ツボスミレ":{"variants":"ツボスミレ/坪菫"},"坪菫":{"variants":"ツボスミレ/坪菫"},"つぼみ":{"variants":"つぼみ/莟/蕾"},"つぼむ":{"variants":"つぼむ/蕾む"},"蕾む":{"variants":"つぼむ/蕾む"},"つぼ焼き":{"variants":"つぼ焼き/壷焼/壷焼き"},"壷焼":{"variants":"つぼ焼き/壷焼/壷焼き"},"壷焼き":{"variants":"つぼ焼き/壷焼/壷焼き"},"ツマクレナイ":{"variants":"ツマクレナイ/爪紅"},"爪紅":{"variants":"ツマクレナイ/爪紅"},"つまぐる":{"variants":"つまぐる/爪繰る"},"爪繰る":{"variants":"つまぐる/爪繰る"},"ツマグロヨコバイ":{"variants":"ツマグロヨコバイ/褄黒横這"},"褄黒横這":{"variants":"ツマグロヨコバイ/褄黒横這"},"つま先":{"variants":"つま先/爪先/褄先"},"つまさきだつ":{"variants":"つまさきだつ/つま先立つ/爪先立つ"},"つま先立つ":{"variants":"つまさきだつ/つま先立つ/爪先立つ"},"爪先立つ":{"variants":"つまさきだつ/つま先立つ/爪先立つ"},"つまずく":{"variants":"つまずく/躓く"},"躓く":{"variants":"つまずく/躓く"},"妻たち":{"variants":"妻たち/妻達"},"妻達":{"variants":"妻たち/妻達"},"つまだつ":{"variants":"つまだつ/爪立つ"},"爪立つ":{"variants":"つまだつ/爪立つ"},"つまだてる":{"variants":"つまだてる/爪立てる"},"爪立てる":{"variants":"つまだてる/爪立てる"},"つまどる":{"variants":"つまどる/褄取る"},"褄取る":{"variants":"つまどる/褄取る"},"つまびく":{"variants":"つまびく/つま弾く/爪弾く"},"つま弾く":{"variants":"つまびく/つま弾く/爪弾く"},"爪弾く":{"variants":"つまびく/つま弾く/爪弾く"},"つまびらか":{"variants":"つまびらか/詳らか/審らか"},"つまみあげる":{"variants":"つまみあげる/つまみ上げる"},"つまみ上げる":{"variants":"つまみあげる/つまみ上げる"},"つまみ洗い":{"variants":"つまみ洗い/摘み洗い"},"摘み洗い":{"variants":"つまみ洗い/摘み洗い"},"つまみ食い":{"variants":"つまみ食い/摘み食い"},"摘み食い":{"variants":"つまみ食い/摘み食い"},"つまみだす":{"variants":"つまみだす/つまみ出す/撮み出す"},"つまみ出す":{"variants":"つまみだす/つまみ出す/撮み出す"},"撮み出す":{"variants":"つまみだす/つまみ出す/撮み出す"},"つまみだせる":{"variants":"つまみだせる/つまみ出せる"},"つまみ出せる":{"variants":"つまみだせる/つまみ出せる"},"つまみ菜":{"variants":"つまみ菜/摘み菜"},"摘み菜":{"variants":"つまみ菜/摘み菜"},"つまみ物":{"variants":"つまみ物/摘み物"},"摘み物":{"variants":"つまみ物/摘み物"},"つまむ":{"variants":"つまむ/撮む/抓む"},"つま楊枝":{"variants":"つま楊枝/爪楊枝"},"爪楊枝":{"variants":"つま楊枝/爪楊枝"},"つまり":{"variants":"つまり/詰まり"},"詰まり":{"variants":"つまり/詰まり"},"つまる":{"variants":"つまる/詰まる"},"詰まる":{"variants":"つまる/詰まる"},"つみ":{"variants":"つみ/詰み/罪"},"つみあげる":{"variants":"つみあげる/積み上げる/積上げる"},"積み上げる":{"variants":"つみあげる/積み上げる/積上げる"},"積上げる":{"variants":"つみあげる/積み上げる/積上げる"},"摘み入れ":{"variants":"摘み入れ/摘入れ"},"摘入れ":{"variants":"摘み入れ/摘入れ"},"積換え":{"variants":"積み換え/積換え"},"積み換え":{"variants":"積み換え/積換え"},"つみかえる":{"variants":"つみかえる/積み替える"},"積み替える":{"variants":"つみかえる/積み替える"},"つみかさなる":{"variants":"つみかさなる/積み重なる/積重なる"},"積み重なる":{"variants":"つみかさなる/積み重なる/積重なる"},"積重なる":{"variants":"つみかさなる/積み重なる/積重なる"},"つみかさねる":{"variants":"つみかさねる/積み重ねる/積重ねる"},"積み重ねる":{"variants":"つみかさねる/積み重ねる/積重ねる"},"積重ねる":{"variants":"つみかさねる/積み重ねる/積重ねる"},"積み木":{"variants":"積み木/積木"},"積木":{"variants":"積み木/積木"},"摘み草":{"variants":"摘み草/摘草"},"摘草":{"variants":"摘み草/摘草"},"つみこむ":{"variants":"つみこむ/積み込む/積込む"},"積み込む":{"variants":"つみこむ/積み込む/積込む"},"積込む":{"variants":"つみこむ/積み込む/積込む"},"つみこめる":{"variants":"つみこめる/積み込める"},"積み込める":{"variants":"つみこめる/積み込める"},"積み肥":{"variants":"積み肥/積肥"},"積肥":{"variants":"積み肥/積肥"},"つみする":{"variants":"つみする/罪する"},"罪する":{"variants":"つみする/罪する"},"積み立て":{"variants":"積み立て/積立/積立て"},"積立":{"variants":"積み立て/積立/積立て"},"積立て":{"variants":"積み立て/積立/積立て"},"つみたてる":{"variants":"つみたてる/積み立てる/積立てる"},"積み立てる":{"variants":"つみたてる/積み立てる/積立てる"},"積立てる":{"variants":"つみたてる/積み立てる/積立てる"},"つみだす":{"variants":"つみだす/積み出す/積出す"},"積み出す":{"variants":"つみだす/積み出す/積出す"},"積出す":{"variants":"つみだす/積み出す/積出す"},"つみだせる":{"variants":"つみだせる/積み出せる"},"積み出せる":{"variants":"つみだせる/積み出せる"},"つみとる":{"variants":"つみとる/摘み取る"},"摘み取る":{"variants":"つみとる/摘み取る"},"積み荷":{"variants":"積み荷/積荷"},"積荷":{"variants":"積み荷/積荷"},"つみのこす":{"variants":"つみのこす/積み残す"},"積み残す":{"variants":"つみのこす/積み残す"},"つみぶかい":{"variants":"つみぶかい/罪深い"},"罪深い":{"variants":"つみぶかい/罪深い"},"罪ほろぼし":{"variants":"罪ほろぼし/罪滅ぼし"},"罪滅ぼし":{"variants":"罪ほろぼし/罪滅ぼし"},"つみわける":{"variants":"つみわける/積み分ける"},"積み分ける":{"variants":"つみわける/積み分ける"},"つむ":{"variants":"つむ/詰む/積む"},"つむぐ":{"variants":"つむぐ/紡ぐ"},"紡ぐ":{"variants":"つむぐ/紡ぐ"},"旋毛曲がり":{"variants":"旋毛曲がり/旋毛曲り"},"旋毛曲り":{"variants":"旋毛曲がり/旋毛曲り"},"つめ":{"variants":"つめ/ツメ/詰め/爪"},"ツメ":{"variants":"つめ/ツメ/詰め/爪"},"つめ跡":{"variants":"つめ跡/爪跡"},"爪跡":{"variants":"つめ跡/爪跡"},"詰め合わせ":{"variants":"詰め合わせ/詰合せ"},"詰合せ":{"variants":"詰め合わせ/詰合せ"},"詰め襟":{"variants":"詰め襟/詰襟"},"詰襟":{"variants":"詰め襟/詰襟"},"つめかえる":{"variants":"つめかえる/詰め替える"},"詰め替える":{"variants":"つめかえる/詰め替える"},"つめかける":{"variants":"つめかける/詰めかける/詰め掛ける"},"詰めかける":{"variants":"つめかける/詰めかける/詰め掛ける"},"詰め掛ける":{"variants":"つめかける/詰めかける/詰め掛ける"},"つめきる":{"variants":"つめきる/詰め切る/詰切る"},"詰め切る":{"variants":"つめきる/詰め切る/詰切る"},"詰切る":{"variants":"つめきる/詰め切る/詰切る"},"詰め込み":{"variants":"詰め込み/詰込/詰込み"},"詰込":{"variants":"詰め込み/詰込/詰込み"},"詰込み":{"variants":"詰め込み/詰込/詰込み"},"つめこむ":{"variants":"つめこむ/詰めこむ/詰め込む/詰込む"},"詰めこむ":{"variants":"つめこむ/詰めこむ/詰め込む/詰込む"},"詰め込む":{"variants":"つめこむ/詰めこむ/詰め込む/詰込む"},"詰込む":{"variants":"つめこむ/詰めこむ/詰め込む/詰込む"},"つめこめる":{"variants":"つめこめる/詰め込める"},"詰め込める":{"variants":"つめこめる/詰め込める"},"詰め所":{"variants":"詰め所/詰所"},"詰所":{"variants":"詰め所/詰所"},"詰め将棋":{"variants":"詰め将棋/詰将棋"},"詰将棋":{"variants":"詰め将棋/詰将棋"},"つめたい":{"variants":"つめたい/冷たい"},"冷たい":{"variants":"つめたい/冷たい"},"詰め直し":{"variants":"詰め直し/詰直し"},"詰直し":{"variants":"詰め直し/詰直し"},"詰め腹":{"variants":"詰め腹/詰腹"},"詰腹":{"variants":"詰め腹/詰腹"},"つめよる":{"variants":"つめよる/詰め寄る/詰寄る"},"詰め寄る":{"variants":"つめよる/詰め寄る/詰寄る"},"詰寄る":{"variants":"つめよる/詰め寄る/詰寄る"},"つめる":{"variants":"つめる/詰める/積める"},"つもり":{"variants":"つもり/積り"},"積り":{"variants":"つもり/積り"},"つもる":{"variants":"つもる/積もる"},"積もる":{"variants":"つもる/積もる"},"つや":{"variants":"つや/艶"},"艶":{"variants":"つや/艶"},"つや消":{"variants":"つや消/つや消し/艷消し"},"つや消し":{"variants":"つや消/つや消し/艷消し"},"艷消し":{"variants":"つや消/つや消し/艷消し"},"つやめく":{"variants":"つやめく/艷めく"},"艷めく":{"variants":"つやめく/艷めく"},"つゆ":{"variants":"つゆ/露"},"露":{"variants":"つゆ/露"},"梅雨あけ":{"variants":"梅雨あけ/梅雨明け"},"梅雨明け":{"variants":"梅雨あけ/梅雨明け"},"つゆ草":{"variants":"つゆ草/ツユクサ/露草"},"ツユクサ":{"variants":"つゆ草/ツユクサ/露草"},"露草":{"variants":"つゆ草/ツユクサ/露草"},"つゆけい":{"variants":"つゆけい/露けい"},"露けい":{"variants":"つゆけい/露けい"},"露払":{"variants":"露払/露払い"},"露払い":{"variants":"露払/露払い"},"梅雨晴":{"variants":"梅雨晴/梅雨晴れ"},"梅雨晴れ":{"variants":"梅雨晴/梅雨晴れ"},"つよい":{"variants":"つよい/強い"},"強い":{"variants":"つよい/強い"},"強き":{"variants":"強き/強気"},"強気":{"variants":"強き/強気"},"強ふくみ":{"variants":"強ふくみ/強含み"},"強含み":{"variants":"強ふくみ/強含み"},"つよまる":{"variants":"つよまる/強まる"},"強まる":{"variants":"つよまる/強まる"},"強み":{"variants":"強み/強味"},"強味":{"variants":"強み/強味"},"つよめる":{"variants":"つよめる/強める"},"強める":{"variants":"つよめる/強める"},"つらさ":{"variants":"つらさ/ツラさ"},"ツラさ":{"variants":"つらさ/ツラさ"},"つらなる":{"variants":"つらなる/列なる/連なる"},"つらにくい":{"variants":"つらにくい/面憎い"},"面憎い":{"variants":"つらにくい/面憎い"},"つらぬきとおす":{"variants":"つらぬきとおす/貫き通す"},"貫き通す":{"variants":"つらぬきとおす/貫き通す"},"つらぬきとおせる":{"variants":"つらぬきとおせる/貫き通せる"},"貫き通せる":{"variants":"つらぬきとおせる/貫き通せる"},"つらぬく":{"variants":"つらぬく/貫く"},"貫く":{"variants":"つらぬく/貫く"},"つらぬける":{"variants":"つらぬける/貫ける"},"貫ける":{"variants":"つらぬける/貫ける"},"つらねる":{"variants":"つらねる/列ねる/連ねる"},"つり":{"variants":"つり/釣/釣り"},"釣":{"variants":"つり/釣/釣り"},"釣り":{"variants":"つり/釣/釣り"},"釣り合":{"variants":"釣り合/釣り合い/釣合"},"釣り合い":{"variants":"釣り合/釣り合い/釣合"},"釣合":{"variants":"釣り合/釣り合い/釣合"},"つりあう":{"variants":"つりあう/つり合う/釣りあう/釣り合う/釣合う"},"つり合う":{"variants":"つりあう/つり合う/釣りあう/釣り合う/釣合う"},"釣りあう":{"variants":"つりあう/つり合う/釣りあう/釣り合う/釣合う"},"釣り合う":{"variants":"つりあう/つり合う/釣りあう/釣り合う/釣合う"},"釣合う":{"variants":"つりあう/つり合う/釣りあう/釣り合う/釣合う"},"つりあがる":{"variants":"つりあがる/つり上がる/吊りあがる/吊り上がる/吊上がる/釣りあがる/釣り上がる/釣上がる"},"つり上がる":{"variants":"つりあがる/つり上がる/吊りあがる/吊り上がる/吊上がる/釣りあがる/釣り上がる/釣上がる"},"吊り上がる":{"variants":"つりあがる/つり上がる/吊りあがる/吊り上がる/吊上がる"},"釣り上がる":{"variants":"つりあがる/つり上がる/釣りあがる/釣り上がる/釣上がる"},"吊上がる":{"variants":"つりあがる/つり上がる/吊りあがる/吊り上がる/吊上がる"},"釣上がる":{"variants":"つりあがる/つり上がる/釣りあがる/釣り上がる/釣上がる"},"吊りあがる":{"variants":"つりあがる/つり上がる/吊りあがる/吊り上がる/吊上がる"},"釣りあがる":{"variants":"つりあがる/つり上がる/釣りあがる/釣り上がる/釣上がる"},"つりあげる":{"variants":"つりあげる/つり上げる/吊りあげる/吊り上げる/吊上げる/釣りあげる/釣り上げる/釣上げる"},"つり上げる":{"variants":"つりあげる/つり上げる/吊りあげる/吊り上げる/吊上げる/釣りあげる/釣り上げる/釣上げる"},"吊り上げる":{"variants":"つりあげる/つり上げる/吊りあげる/吊り上げる/吊上げる"},"釣り上げる":{"variants":"つりあげる/つり上げる/釣りあげる/釣り上げる/釣上げる"},"吊上げる":{"variants":"つりあげる/つり上げる/吊りあげる/吊り上げる/吊上げる"},"釣上げる":{"variants":"つりあげる/つり上げる/釣りあげる/釣り上げる/釣上げる"},"吊りあげる":{"variants":"つりあげる/つり上げる/吊りあげる/吊り上げる/吊上げる"},"釣りあげる":{"variants":"つりあげる/つり上げる/釣りあげる/釣り上げる/釣上げる"},"釣り糸":{"variants":"釣り糸/釣糸"},"釣糸":{"variants":"釣り糸/釣糸"},"吊り革":{"variants":"吊り革/吊革"},"吊革":{"variants":"吊り革/吊革"},"つり鐘":{"variants":"つり鐘/ツリガネ/釣り鐘/釣鐘"},"ツリガネ":{"variants":"つり鐘/ツリガネ/釣り鐘/釣鐘"},"釣り鐘":{"variants":"つり鐘/ツリガネ/釣り鐘/釣鐘"},"釣鐘":{"variants":"つり鐘/ツリガネ/釣り鐘/釣鐘"},"ツリガネソウ":{"variants":"ツリガネソウ/釣鐘草"},"釣鐘草":{"variants":"ツリガネソウ/釣鐘草"},"つり具":{"variants":"つり具/釣具"},"釣具":{"variants":"つり具/釣具"},"つりこむ":{"variants":"つりこむ/釣り込む/釣込む"},"釣り込む":{"variants":"つりこむ/釣り込む/釣込む"},"釣込む":{"variants":"つりこむ/釣り込む/釣込む"},"釣り竿":{"variants":"釣り竿/釣竿"},"釣竿":{"variants":"釣り竿/釣竿"},"つり銭":{"variants":"つり銭/釣り銭/釣銭"},"釣り銭":{"variants":"つり銭/釣り銭/釣銭"},"釣銭":{"variants":"つり銭/釣り銭/釣銭"},"つりだす":{"variants":"つりだす/吊り出す/釣り出す/釣出す"},"釣り出す":{"variants":"つりだす/釣り出す/釣出す"},"釣出す":{"variants":"つりだす/釣り出す/釣出す"},"釣り手":{"variants":"釣り手/釣手"},"釣手":{"variants":"釣り手/釣手"},"つり橋":{"variants":"つり橋/吊り橋/吊橋/釣り橋/釣橋"},"釣橋":{"variants":"つり橋/釣り橋/釣橋"},"吊り橋":{"variants":"つり橋/吊り橋/吊橋"},"釣り橋":{"variants":"つり橋/釣り橋/釣橋"},"吊橋":{"variants":"つり橋/吊り橋/吊橋"},"釣り針":{"variants":"釣り針/釣針"},"釣針":{"variants":"釣り針/釣針"},"釣り船":{"variants":"釣り船/釣船"},"釣船":{"variants":"釣り船/釣船"},"釣り堀":{"variants":"釣り堀/釣堀"},"釣堀":{"variants":"釣り堀/釣堀"},"つる":{"variants":"つる/ツル/鶴/蔓"},"ツル":{"variants":"つる/ツル/鶴/蔓"},"つるし上げ":{"variants":"つるし上げ/吊しあげ/吊し上げ"},"吊しあげ":{"variants":"つるし上げ/吊しあげ/吊し上げ"},"吊し上げ":{"variants":"つるし上げ/吊しあげ/吊し上げ"},"つるしあげる":{"variants":"つるしあげる/つるし上げる"},"つるし上げる":{"variants":"つるしあげる/つるし上げる"},"つるす":{"variants":"つるす/吊す/吊るす"},"吊す":{"variants":"つるす/吊す/吊るす"},"吊るす":{"variants":"つるす/吊す/吊るす"},"つるせる":{"variants":"つるせる/吊せる/吊るせる"},"吊せる":{"variants":"つるせる/吊せる/吊るせる"},"吊るせる":{"variants":"つるせる/吊せる/吊るせる"},"ツルナ":{"variants":"ツルナ/蔓菜"},"蔓菜":{"variants":"ツルナ/蔓菜"},"ツルレイシ":{"variants":"ツルレイシ/蔓茘枝"},"蔓茘枝":{"variants":"ツルレイシ/蔓茘枝"},"つれ":{"variants":"つれ/連れ"},"連れ":{"variants":"つれ/連れ"},"つれあい":{"variants":"つれあい/連れあい/連れ合い"},"連れあい":{"variants":"つれあい/連れあい/連れ合い"},"連れ合い":{"variants":"つれあい/連れあい/連れ合い"},"つれあう":{"variants":"つれあう/連れあう/連れ合う/連合う"},"連れあう":{"variants":"つれあう/連れあう/連れ合う/連合う"},"連れ合う":{"variants":"つれあう/連れあう/連れ合う/連合う"},"連合う":{"variants":"つれあう/連れあう/連れ合う/連合う"},"つれかえる":{"variants":"つれかえる/連れ帰る"},"連れ帰る":{"variants":"つれかえる/連れ帰る"},"連れ子":{"variants":"連れ子/連子"},"連子":{"variants":"連れ子/連子"},"つれこむ":{"variants":"つれこむ/連れこむ/連れ込む/連込む"},"連れこむ":{"variants":"つれこむ/連れこむ/連れ込む/連込む"},"連れ込む":{"variants":"つれこむ/連れこむ/連れ込む/連込む"},"連込む":{"variants":"つれこむ/連れこむ/連れ込む/連込む"},"つれこめる":{"variants":"つれこめる/連れ込める"},"連れ込める":{"variants":"つれこめる/連れ込める"},"つれさる":{"variants":"つれさる/つれ去る/連れ去る"},"つれ去る":{"variants":"つれさる/つれ去る/連れ去る"},"連れ去る":{"variants":"つれさる/つれ去る/連れ去る"},"つれそう":{"variants":"つれそう/連れ添う/連添う"},"連れ添う":{"variants":"つれそう/連れ添う/連添う"},"連添う":{"variants":"つれそう/連れ添う/連添う"},"つれそえる":{"variants":"つれそえる/連れ添える"},"連れ添える":{"variants":"つれそえる/連れ添える"},"つれだす":{"variants":"つれだす/連れ出す/連出す"},"連れ出す":{"variants":"つれだす/連れ出す/連出す"},"連出す":{"variants":"つれだす/連れ出す/連出す"},"つれだせる":{"variants":"つれだせる/連れ出せる"},"連れ出せる":{"variants":"つれだせる/連れ出せる"},"つれだつ":{"variants":"つれだつ/連れ立つ/連立つ"},"連れ立つ":{"variants":"つれだつ/連れ立つ/連立つ"},"連立つ":{"variants":"つれだつ/連れ立つ/連立つ"},"つれづれ":{"variants":"つれづれ/徒然"},"徒然":{"variants":"つれづれ/徒然"},"連れ舞":{"variants":"連れ舞/連舞"},"連舞":{"variants":"連れ舞/連舞"},"つれもどす":{"variants":"つれもどす/連れ戻す"},"連れ戻す":{"variants":"つれもどす/連れ戻す"},"つれもどせる":{"variants":"つれもどせる/連れ戻せる"},"連れ戻せる":{"variants":"つれもどせる/連れ戻せる"},"つれる":{"variants":"つれる/吊れる/釣れる/連れる/攣れる"},"ツワブキ":{"variants":"ツワブキ/石蕗"},"石蕗":{"variants":"ツワブキ/石蕗"},"つんざく":{"variants":"つんざく/劈く"},"劈く":{"variants":"つんざく/劈く"},"づくり":{"variants":"づくり/作り/造り"},"付け":{"variants":"付/付け"},"付":{"variants":"付/付け"},"手合":{"variants":"手合/手合い"},"手合い":{"variants":"手合/手合い"},"手あか":{"variants":"手あか/手垢"},"手垢":{"variants":"手あか/手垢"},"手当たり":{"variants":"手当たり/手当り"},"手当り":{"variants":"手当たり/手当り"},"てあたりしだい":{"variants":"てあたりしだい/手当りしだい/手当り次第"},"手当りしだい":{"variants":"てあたりしだい/手当りしだい/手当り次第"},"手当り次第":{"variants":"てあたりしだい/手当りしだい/手当り次第"},"てあつい":{"variants":"てあつい/手あつい/手厚い"},"手あつい":{"variants":"てあつい/手あつい/手厚い"},"手厚い":{"variants":"てあつい/手あつい/手厚い"},"手あて":{"variants":"手あて/手当/手当て"},"手当":{"variants":"手あて/手当/手当て"},"手当て":{"variants":"手あて/手当/手当て"},"手あみ":{"variants":"手あみ/手編/手編み"},"手編":{"variants":"手あみ/手編/手編み"},"手編み":{"variants":"手あみ/手編/手編み"},"てあらい":{"variants":"てあらい/手荒い"},"手荒い":{"variants":"てあらい/手荒い"},"ていぎづける":{"variants":"ていぎづける/定義付ける"},"定義付ける":{"variants":"ていぎづける/定義付ける"},"ていさいぶる":{"variants":"ていさいぶる/体裁振る"},"体裁振る":{"variants":"ていさいぶる/体裁振る"},"てい身":{"variants":"てい身/挺身"},"挺身":{"variants":"てい身/挺身"},"ていする":{"variants":"ていする/呈する/挺する"},"ていたい":{"variants":"ていたい/手痛い"},"手痛い":{"variants":"ていたい/手痛い"},"てい談":{"variants":"てい談/鼎談"},"鼎談":{"variants":"てい談/鼎談"},"ていだん":{"variants":"ていだん/梯団"},"梯団":{"variants":"ていだん/梯団"},"手いっぱい":{"variants":"手いっぱい/手一杯"},"手一杯":{"variants":"手いっぱい/手一杯"},"亭々":{"variants":"亭々/亭亭"},"亭亭":{"variants":"亭々/亭亭"},"てい鉄":{"variants":"てい鉄/蹄鉄"},"蹄鉄":{"variants":"てい鉄/蹄鉄"},"ていねい":{"variants":"ていねい/丁寧/叮嚀"},"ていねん":{"variants":"ていねん/丁年/停年/定年/諦念"},"てい髪":{"variants":"てい髪/剃髪"},"剃髪":{"variants":"てい髪/剃髪"},"手植":{"variants":"手植/手植え"},"手植え":{"variants":"手植/手植え"},"手打":{"variants":"手打/手打ち"},"手打ち":{"variants":"手打/手打ち"},"手負":{"variants":"手負/手負い"},"手負い":{"variants":"手負/手負い"},"手おけ":{"variants":"手おけ/手桶"},"手桶":{"variants":"手おけ/手桶"},"て踊り":{"variants":"て踊り/手踊"},"手踊":{"variants":"て踊り/手踊"},"ておもい":{"variants":"ておもい/手重い"},"手重い":{"variants":"ておもい/手重い"},"手織":{"variants":"手織/手織り"},"手織り":{"variants":"手織/手織り"},"手かせ":{"variants":"手かせ/手械/手枷/手桎"},"てかてか":{"variants":"てかてか/テカテカ"},"テカテカ":{"variants":"てかてか/テカテカ"},"手がえし":{"variants":"手がえし/手返し"},"手返し":{"variants":"手がえし/手返し"},"手がかり":{"variants":"手がかり/手掛かり/手掛り/手懸り"},"手掛かり":{"variants":"手がかり/手掛かり/手掛り"},"手掛り":{"variants":"手がかり/手掛かり/手掛り"},"手がき":{"variants":"手がき/手描き"},"手描き":{"variants":"手がき/手描き"},"てがける":{"variants":"てがける/手がける/手掛ける/手懸ける"},"手がける":{"variants":"てがける/手がける/手掛ける/手懸ける"},"てがこむ":{"variants":"てがこむ/手が込む"},"手が込む":{"variants":"てがこむ/手が込む"},"てがたい":{"variants":"てがたい/手堅い"},"手堅い":{"variants":"てがたい/手堅い"},"てがるい":{"variants":"てがるい/手軽い"},"手軽い":{"variants":"てがるい/手軽い"},"てきぎ":{"variants":"てきぎ/適宜"},"適宜":{"variants":"てきぎ/適宜"},"てきす":{"variants":"てきす/敵す/適す"},"てきする":{"variants":"てきする/敵する/適する"},"滴々":{"variants":"滴々/滴滴"},"滴滴":{"variants":"滴々/滴滴"},"てきびしい":{"variants":"てきびしい/手厳しい"},"手厳しい":{"variants":"てきびしい/手厳しい"},"てきめん":{"variants":"てきめん/覿面"},"覿面":{"variants":"てきめん/覿面"},"手ぎわ":{"variants":"手ぎわ/手際"},"手際":{"variants":"手ぎわ/手際"},"てぐすね":{"variants":"てぐすね/手ぐすね"},"手ぐすね":{"variants":"てぐすね/手ぐすね"},"てこ":{"variants":"てこ/テコ/梃/梃子"},"テコ":{"variants":"てこ/テコ/梃/梃子"},"てこ入れ":{"variants":"てこ入れ/梃入れ"},"梃入れ":{"variants":"てこ入れ/梃入れ"},"てこずる":{"variants":"てこずる/手こずる/手古摺る"},"手こずる":{"variants":"てこずる/手こずる/手古摺る"},"手古摺る":{"variants":"てこずる/手こずる/手古摺る"},"手ごたえ":{"variants":"手ごたえ/手応え/手答え"},"手ごま":{"variants":"手ごま/手駒"},"手駒":{"variants":"手ごま/手駒"},"手ごめ":{"variants":"手ごめ/手込め"},"手込め":{"variants":"手ごめ/手込め"},"手ごろ":{"variants":"手ごろ/手頃"},"手頃":{"variants":"手ごろ/手頃"},"てごわい":{"variants":"てごわい/手ごわい"},"手ごわい":{"variants":"てごわい/手ごわい"},"手さぐり":{"variants":"手さぐり/手探り"},"手探り":{"variants":"手さぐり/手探り"},"手さげ":{"variants":"手さげ/手提/手提げ"},"手提":{"variants":"手さげ/手提/手提げ"},"手提げ":{"variants":"手さげ/手提/手提げ"},"手さばき":{"variants":"手さばき/手捌き"},"手捌き":{"variants":"手さばき/手捌き"},"手ざわり":{"variants":"手ざわり/手触り"},"手触り":{"variants":"手ざわり/手触り"},"手仕舞":{"variants":"手仕舞/手仕舞い"},"手仕舞い":{"variants":"手仕舞/手仕舞い"},"手すき":{"variants":"手すき/手隙/手漉き/手透き"},"手すり":{"variants":"手すり/手摺"},"手摺":{"variants":"手すり/手摺"},"てずから":{"variants":"てずから/手ずから"},"手ずから":{"variants":"てずから/手ずから"},"手だし":{"variants":"手だし/手出し"},"手出し":{"variants":"手だし/手出し"},"手だて":{"variants":"手だて/手立て"},"手立て":{"variants":"手だて/手立て"},"鉄火みそ":{"variants":"鉄火みそ/鉄火味噌"},"鉄火味噌":{"variants":"鉄火みそ/鉄火味噌"},"てっする":{"variants":"てっする/徹する/撤する"},"テッセン":{"variants":"テッセン/撤饌/鉄扇/鉄泉/鉄線"},"てっとうてつび":{"variants":"てっとうてつび/徹頭徹尾"},"徹頭徹尾":{"variants":"てっとうてつび/徹頭徹尾"},"てっとりばやい":{"variants":"てっとりばやい/手っとりばやい/手っとり早い/手っ取り早い/手取り早い"},"手っとりばやい":{"variants":"てっとりばやい/手っとりばやい/手っとり早い/手っ取り早い/手取り早い"},"手っとり早い":{"variants":"てっとりばやい/手っとりばやい/手っとり早い/手っ取り早い/手取り早い"},"手っ取り早い":{"variants":"てっとりばやい/手っとりばやい/手っとり早い/手っ取り早い/手取り早い"},"手取り早い":{"variants":"てっとりばやい/手っとりばやい/手っとり早い/手っ取り早い/手取り早い"},"てっぺん":{"variants":"てっぺん/鉄片/天辺"},"テッポウムシ":{"variants":"テッポウムシ/鉄砲虫"},"鉄砲虫":{"variants":"テッポウムシ/鉄砲虫"},"テッポウユリ":{"variants":"テッポウユリ/鉄砲百合"},"鉄砲百合":{"variants":"テッポウユリ/鉄砲百合"},"手つかず":{"variants":"手つかず/手付かず"},"手付かず":{"variants":"手つかず/手付かず"},"鉄かぶと":{"variants":"鉄かぶと/鉄兜"},"鉄兜":{"variants":"鉄かぶと/鉄兜"},"手つき":{"variants":"手つき/手付き"},"手付き":{"variants":"手つき/手付き"},"手付":{"variants":"手付/手付け"},"手付け":{"variants":"手付/手付け"},"てつだう":{"variants":"てつだう/手伝う"},"手伝う":{"variants":"てつだう/手伝う"},"てつだえる":{"variants":"てつだえる/手伝える"},"手伝える":{"variants":"てつだえる/手伝える"},"手続":{"variants":"手続/手続き"},"手続き":{"variants":"手続/手続き"},"手づくり":{"variants":"手づくり/手作り/手造り"},"手づまり":{"variants":"手づまり/手詰まり/手詰り"},"手詰まり":{"variants":"手づまり/手詰まり/手詰り"},"手詰り":{"variants":"手づまり/手詰まり/手詰り"},"手釣":{"variants":"手釣/手釣り"},"手釣り":{"variants":"手釣/手釣り"},"手づる":{"variants":"手づる/手蔓"},"手蔓":{"variants":"手づる/手蔓"},"ててなし子":{"variants":"ててなし子/父無し子"},"父無し子":{"variants":"ててなし子/父無し子"},"手並":{"variants":"手並/手並み"},"手並み":{"variants":"手並/手並み"},"てなれる":{"variants":"てなれる/手なれる/手慣れる/手馴れる"},"手なれる":{"variants":"てなれる/手なれる/手慣れる/手馴れる"},"手ぬかり":{"variants":"手ぬかり/手抜かり"},"手抜かり":{"variants":"手ぬかり/手抜かり"},"手ぬぐい":{"variants":"手ぬぐい/手拭/手拭い"},"手拭":{"variants":"手ぬぐい/手拭/手拭い"},"手拭い":{"variants":"手ぬぐい/手拭/手拭い"},"てぬるい":{"variants":"てぬるい/手緩い"},"手緩い":{"variants":"てぬるい/手緩い"},"手のうち":{"variants":"手のうち/手の内"},"手の内":{"variants":"手のうち/手の内"},"手のひら":{"variants":"手のひら/手の平"},"手の平":{"variants":"手のひら/手の平"},"手のもの":{"variants":"手のもの/手の者/手の物"},"手はず":{"variants":"手はず/手筈"},"手筈":{"variants":"手はず/手筈"},"てばしこい":{"variants":"てばしこい/手ばしこい"},"手ばしこい":{"variants":"てばしこい/手ばしこい"},"てばなす":{"variants":"てばなす/手放す"},"手放す":{"variants":"てばなす/手放す"},"てばなせる":{"variants":"てばなせる/手放せる"},"手放せる":{"variants":"てばなせる/手放せる"},"てばやい":{"variants":"てばやい/手早い/手速い"},"てひどい":{"variants":"てひどい/手ひどい/手酷い"},"手ひどい":{"variants":"てひどい/手ひどい/手酷い"},"手酷い":{"variants":"てひどい/手ひどい/手酷い"},"手控":{"variants":"手控/手控え"},"手控え":{"variants":"手控/手控え"},"てびかえる":{"variants":"てびかえる/手控える"},"手控える":{"variants":"てびかえる/手控える"},"手引":{"variants":"手引/手引き"},"手引き":{"variants":"手引/手引き"},"てびろい":{"variants":"てびろい/手広い"},"手広い":{"variants":"てびろい/手広い"},"手ふき":{"variants":"手ふき/手拭き"},"手拭き":{"variants":"手ふき/手拭き"},"手ぶくろ":{"variants":"手ぶくろ/手袋"},"手袋":{"variants":"手ぶくろ/手袋"},"手ほどき":{"variants":"手ほどき/手解き"},"手解き":{"variants":"手ほどき/手解き"},"手前みそ":{"variants":"手前みそ/手前味噌"},"手前味噌":{"variants":"手前みそ/手前味噌"},"てまどる":{"variants":"てまどる/手間どる/手間取る"},"手間どる":{"variants":"てまどる/手間どる/手間取る"},"手間取る":{"variants":"てまどる/手間どる/手間取る"},"手まね":{"variants":"手まね/手真似"},"手真似":{"variants":"手まね/手真似"},"手まねき":{"variants":"手まねき/手招き"},"手招き":{"variants":"手まねき/手招き"},"手間ひま":{"variants":"手間ひま/手間隙"},"手間隙":{"variants":"手間ひま/手間隙"},"てまめ":{"variants":"てまめ/手まめ"},"手まめ":{"variants":"てまめ/手まめ"},"手まり":{"variants":"手まり/手鞠/手毬"},"テマリバナ":{"variants":"テマリバナ/手鞠花/手毬花"},"手みやげ":{"variants":"手みやげ/手土産"},"手土産":{"variants":"手みやげ/手土産"},"てむかう":{"variants":"てむかう/手向かう"},"手向かう":{"variants":"てむかう/手向かう"},"てむかえる":{"variants":"てむかえる/手向かえる"},"手向かえる":{"variants":"てむかえる/手向かえる"},"手持":{"variants":"手持/手持ち"},"手持ち":{"variants":"手持/手持ち"},"手持ち無沙汰":{"variants":"手持ち無沙汰/手持無沙汰"},"手持無沙汰":{"variants":"手持ち無沙汰/手持無沙汰"},"手もと":{"variants":"手もと/手許/手元"},"テラ":{"variants":"テラ/寺"},"寺":{"variants":"テラ/寺"},"てらう":{"variants":"てらう/衒う"},"衒う":{"variants":"てらう/衒う"},"てらしあわせる":{"variants":"てらしあわせる/照らし合せる"},"照らし合せる":{"variants":"てらしあわせる/照らし合せる"},"てらす":{"variants":"てらす/照らす"},"照らす":{"variants":"てらす/照らす"},"てらせる":{"variants":"てらせる/照らせる"},"照らせる":{"variants":"てらせる/照らせる"},"寺詣":{"variants":"寺詣/寺詣で"},"寺詣で":{"variants":"寺詣/寺詣で"},"てりかえす":{"variants":"てりかえす/輝り返す/照り返す"},"てりかがやく":{"variants":"てりかがやく/照り輝く"},"照り輝く":{"variants":"てりかがやく/照り輝く"},"てりつける":{"variants":"てりつける/照りつける/照り付ける"},"照りつける":{"variants":"てりつける/照りつける/照り付ける"},"照り付ける":{"variants":"てりつける/照りつける/照り付ける"},"てりはえる":{"variants":"てりはえる/照りはえる/照り映える"},"照りはえる":{"variants":"てりはえる/照りはえる/照り映える"},"照り映える":{"variants":"てりはえる/照りはえる/照り映える"},"照焼":{"variants":"照焼/照焼き"},"照焼き":{"variants":"照焼/照焼き"},"てる":{"variants":"てる/輝る/照る"},"てれ":{"variants":"てれ/照れ"},"照れ":{"variants":"てれ/照れ"},"照れかくし":{"variants":"照れかくし/照れ隠し"},"照れ隠し":{"variants":"照れかくし/照れ隠し"},"てれくさい":{"variants":"てれくさい/照れくさい/照れ臭い/照臭い"},"照れくさい":{"variants":"てれくさい/照れくさい/照れ臭い/照臭い"},"照れ臭い":{"variants":"てれくさい/照れくさい/照れ臭い/照臭い"},"照臭い":{"variants":"てれくさい/照れくさい/照れ臭い/照臭い"},"てれる":{"variants":"てれる/照れる"},"照れる":{"variants":"てれる/照れる"},"手わざ":{"variants":"手わざ/手業"},"手業":{"variants":"手わざ/手業"},"手渡":{"variants":"手渡/手渡し"},"手渡し":{"variants":"手渡/手渡し"},"てわたす":{"variants":"てわたす/手渡す"},"手渡す":{"variants":"てわたす/手渡す"},"てわたせる":{"variants":"てわたせる/手渡せる"},"手渡せる":{"variants":"てわたせる/手渡せる"},"テン":{"variants":"テン/典/転/点/貂"},"天下とり":{"variants":"天下とり/天下取"},"天下取":{"variants":"天下とり/天下取"},"天下分けめ":{"variants":"天下分けめ/天下分け目"},"天下分け目":{"variants":"天下分けめ/天下分け目"},"てんかん":{"variants":"てんかん/癲癇"},"癲癇":{"variants":"てんかん/癲癇"},"てんき":{"variants":"てんき/天機/天気/転機/転帰"},"てんぐ":{"variants":"てんぐ/テング/天狗"},"テング":{"variants":"てんぐ/テング/天狗"},"天狗":{"variants":"てんぐ/テング/天狗"},"テングサ":{"variants":"テングサ/天草"},"天草":{"variants":"テングサ/天草"},"てん刻":{"variants":"てん刻/篆刻"},"篆刻":{"variants":"てん刻/篆刻"},"テンサイ":{"variants":"てん菜/テンサイ/天才/天災/天際/甜菜"},"甜菜":{"variants":"てん菜/テンサイ/甜菜"},"てん菜":{"variants":"てん菜/テンサイ/甜菜"},"天真らんまん":{"variants":"天真らんまん/天真爛漫"},"天真爛漫":{"variants":"天真らんまん/天真爛漫"},"テンジクアオイ":{"variants":"テンジクアオイ/天竺葵"},"天竺葵":{"variants":"テンジクアオイ/天竺葵"},"テンジクネズミ":{"variants":"テンジクネズミ/天竺鼠"},"天竺鼠":{"variants":"テンジクネズミ/天竺鼠"},"てんじる":{"variants":"てんじる/転じる/点じる"},"てんずる":{"variants":"てんずる/転ずる/点ずる"},"てんてこまい":{"variants":"てんてこまい/てんてこ舞い"},"てんてこ舞い":{"variants":"てんてこまい/てんてこ舞い"},"転転":{"variants":"転々/転転"},"転々":{"variants":"転々/転転"},"点々":{"variants":"点々/点点"},"点点":{"variants":"点々/点点"},"テントウムシ":{"variants":"テントウムシ/天道虫"},"天道虫":{"variants":"テントウムシ/天道虫"},"テントウムシダマシ":{"variants":"テントウムシダマシ/天道虫だまし"},"天道虫だまし":{"variants":"テントウムシダマシ/天道虫だまし"},"点取り虫":{"variants":"点取り虫/点取虫"},"点取虫":{"variants":"点取り虫/点取虫"},"天どん":{"variants":"天どん/天ドン/天丼"},"天ドン":{"variants":"天どん/天ドン/天丼"},"天丼":{"variants":"天どん/天ドン/天丼"},"テンナンショウ":{"variants":"テンナンショウ/天南星"},"天南星":{"variants":"テンナンショウ/天南星"},"天罰てきめん":{"variants":"天罰てきめん/天罰覿面"},"天罰覿面":{"variants":"天罰てきめん/天罰覿面"},"天びん":{"variants":"天びん/天秤"},"天秤":{"variants":"天びん/天秤"},"てんぷら":{"variants":"てんぷら/テンプラ/天ぷら/天麩羅"},"テンプラ":{"variants":"てんぷら/テンプラ/天ぷら/天麩羅"},"天ぷら":{"variants":"てんぷら/テンプラ/天ぷら/天麩羅"},"天麩羅":{"variants":"てんぷら/テンプラ/天ぷら/天麩羅"},"テンポ":{"variants":"テンポ/店舗"},"店舗":{"variants":"テンポ/店舗"},"てん末":{"variants":"てん末/顛末"},"顛末":{"variants":"てん末/顛末"},"で":{"variants":"で/デ"},"デ":{"variants":"で/デ"},"出会":{"variants":"出会/出会い"},"出合い":{"variants":"出合/出合い"},"出会い":{"variants":"出会/出会い"},"出合":{"variants":"出合/出合い"},"出合い頭":{"variants":"出合い頭/出合頭"},"出合頭":{"variants":"出合い頭/出合頭"},"であう":{"variants":"であう/出逢う/出会う/出合う"},"であえる":{"variants":"であえる/出会える/出合える"},"であるく":{"variants":"であるく/出歩く"},"出歩く":{"variants":"であるく/出歩く"},"であるける":{"variants":"であるける/出歩ける"},"出歩ける":{"variants":"であるける/出歩ける"},"出入り口":{"variants":"出入り口/出入口"},"出入口":{"variants":"出入り口/出入口"},"でおくれる":{"variants":"でおくれる/出遅れる"},"出遅れる":{"variants":"でおくれる/出遅れる"},"でかける":{"variants":"でかける/出かける/出掛ける"},"出かける":{"variants":"でかける/出かける/出掛ける"},"出掛ける":{"variants":"でかける/出かける/出掛ける"},"でかす":{"variants":"でかす/出来す"},"出来す":{"variants":"でかす/出来す"},"出がらし":{"variants":"出がらし/出涸らし"},"出涸らし":{"variants":"出がらし/出涸らし"},"出来あい":{"variants":"出来あい/出来合い"},"出来合い":{"variants":"出来あい/出来合い"},"できあう":{"variants":"できあう/出来合う"},"出来合う":{"variants":"できあう/出来合う"},"でき上がり":{"variants":"でき上がり/出来上がり/出来上り"},"出来上がり":{"variants":"でき上がり/出来上がり/出来上り"},"出来上り":{"variants":"でき上がり/出来上がり/出来上り"},"できあがる":{"variants":"できあがる/でき上がる/出来上がる"},"でき上がる":{"variants":"できあがる/でき上がる/出来上がる"},"出来上がる":{"variants":"できあがる/でき上がる/出来上がる"},"出来ごと":{"variants":"出来ごと/出来事"},"出来事":{"variants":"出来ごと/出来事"},"出来ばえ":{"variants":"出来ばえ/出来映え/出来栄え"},"できる":{"variants":"できる/出来る"},"出来る":{"variants":"できる/出来る"},"でくの坊":{"variants":"でくの坊/木偶の坊"},"木偶の坊":{"variants":"でくの坊/木偶の坊"},"でくわす":{"variants":"でくわす/出くわす/出会す/出食わす"},"出くわす":{"variants":"でくわす/出くわす/出会す/出食わす"},"出げいこ":{"variants":"出げいこ/出稽古"},"出稽古":{"variants":"出げいこ/出稽古"},"でさかる":{"variants":"でさかる/出盛る"},"出盛る":{"variants":"でさかる/出盛る"},"ｄｂ":{"variants":"ｄｂ/デシベル"},"デシベル":{"variants":"ｄｂ/デシベル"},"でしゃばる":{"variants":"でしゃばる/出しゃばる"},"出しゃばる":{"variants":"でしゃばる/出しゃばる"},"ｄｌ":{"variants":"ｄｌ/デシリットル"},"デシリットル":{"variants":"ｄｌ/デシリットル"},"ですぎる":{"variants":"ですぎる/出過ぎる"},"出過ぎる":{"variants":"ですぎる/出過ぎる"},"でずっぱり":{"variants":"でずっぱり/出ずっぱり"},"出ずっぱり":{"variants":"でずっぱり/出ずっぱり"},"でそろう":{"variants":"でそろう/出そろう/出揃う"},"出そろう":{"variants":"でそろう/出そろう/出揃う"},"出揃う":{"variants":"でそろう/出そろう/出揃う"},"出初":{"variants":"出初/出初め"},"出初め":{"variants":"出初/出初め"},"でたらめ":{"variants":"でたらめ/出鱈目"},"出鱈目":{"variants":"でたらめ/出鱈目"},"出々し":{"variants":"出々し/出だし/出出し"},"出だし":{"variants":"出々し/出だし/出出し"},"出出し":{"variants":"出々し/出だし/出出し"},"でっち":{"variants":"でっち/丁稚"},"丁稚":{"variants":"でっち/丁稚"},"でっちあげ":{"variants":"でっちあげ/でっち上げ/デッチ上げ"},"でっち上げ":{"variants":"でっちあげ/でっち上げ/デッチ上げ"},"デッチ上げ":{"variants":"でっちあげ/でっち上げ/デッチ上げ"},"でっちあげる":{"variants":"でっちあげる/でっち上げる/捏ち上げる"},"でっち上げる":{"variants":"でっちあげる/でっち上げる/捏ち上げる"},"捏ち上げる":{"variants":"でっちあげる/でっち上げる/捏ち上げる"},"でっ歯":{"variants":"でっ歯/出っ歯/出歯"},"出っ歯":{"variants":"でっ歯/出っ歯/出歯"},"出歯":{"variants":"でっ歯/出っ歯/出歯"},"でっぱる":{"variants":"でっぱる/出っぱる/出っ張る"},"出っぱる":{"variants":"でっぱる/出っぱる/出っ張る"},"出っ張る":{"variants":"でっぱる/出っぱる/出っ張る"},"でつくす":{"variants":"でつくす/出尽くす"},"出尽くす":{"variants":"でつくす/出尽くす"},"出づっぱり":{"variants":"出づっぱり/出突っぱり/出突っ張り"},"出突っぱり":{"variants":"出づっぱり/出突っぱり/出突っ張り"},"出突っ張り":{"variants":"出づっぱり/出突っぱり/出突っ張り"},"でなおす":{"variants":"でなおす/出直す"},"出直す":{"variants":"でなおす/出直す"},"でなおせる":{"variants":"でなおせる/出直せる"},"出直せる":{"variants":"でなおせる/出直せる"},"ではずれる":{"variants":"ではずれる/出外れる"},"出外れる":{"variants":"ではずれる/出外れる"},"ではらう":{"variants":"ではらう/出払う"},"出払う":{"variants":"ではらう/出払う"},"でばる":{"variants":"でばる/出張る"},"出張る":{"variants":"でばる/出張る"},"でまかせ":{"variants":"でまかせ/出任せ"},"出任せ":{"variants":"でまかせ/出任せ"},"でまわる":{"variants":"でまわる/出回る/出廻る"},"でむかえる":{"variants":"でむかえる/出迎える"},"出迎える":{"variants":"でむかえる/出迎える"},"でむく":{"variants":"でむく/出向く"},"出向く":{"variants":"でむく/出向く"},"でむける":{"variants":"でむける/出向ける"},"出向ける":{"variants":"でむける/出向ける"},"デメキン":{"variants":"デメキン/出目金"},"出目金":{"variants":"デメキン/出目金"},"でる":{"variants":"でる/出る"},"出る":{"variants":"でる/出る"},"田楽刺":{"variants":"田楽刺/田楽刺し"},"田楽刺し":{"variants":"田楽刺/田楽刺し"},"でんぐりがえる":{"variants":"でんぐりがえる/でんぐり返る"},"でんぐり返る":{"variants":"でんぐりがえる/でんぐり返る"},"でんせん":{"variants":"でんせん/電線/電閃"},"でんぶ":{"variants":"でんぶ/田麩/臀部"},"でんぷん":{"variants":"でんぷん/でん粉/澱粉"},"でん粉":{"variants":"でんぷん/でん粉/澱粉"},"澱粉":{"variants":"でんぷん/でん粉/澱粉"},"とい":{"variants":"とい/問/問い"},"問":{"variants":"とい/問/問い"},"問い":{"variants":"とい/問/問い"},"といあわす":{"variants":"といあわす/問い合わす"},"問い合わす":{"variants":"といあわす/問い合わす"},"問い合わせ":{"variants":"問い合わせ/問合せ"},"問合せ":{"variants":"問い合わせ/問合せ"},"といあわせる":{"variants":"といあわせる/問いあわせる/問い合せる/問い合わせる/問合せる"},"問いあわせる":{"variants":"といあわせる/問いあわせる/問い合せる/問い合わせる/問合せる"},"問い合せる":{"variants":"といあわせる/問いあわせる/問い合せる/問い合わせる/問合せる"},"問い合わせる":{"variants":"といあわせる/問いあわせる/問い合せる/問い合わせる/問合せる"},"問合せる":{"variants":"といあわせる/問いあわせる/問い合せる/問い合わせる/問合せる"},"といかえす":{"variants":"といかえす/問い返す/問返す"},"問い返す":{"variants":"といかえす/問い返す/問返す"},"問返す":{"variants":"といかえす/問い返す/問返す"},"といかける":{"variants":"といかける/問いかける/問い掛ける/問掛ける"},"問いかける":{"variants":"といかける/問いかける/問い掛ける/問掛ける"},"問い掛ける":{"variants":"といかける/問いかける/問い掛ける/問掛ける"},"問掛ける":{"variants":"といかける/問いかける/問い掛ける/問掛ける"},"といただす":{"variants":"といただす/問いただす/問い質す/問ただす"},"問いただす":{"variants":"といただす/問いただす/問い質す/問ただす"},"問い質す":{"variants":"といただす/問いただす/問い質す/問ただす"},"問ただす":{"variants":"といただす/問いただす/問い質す/問ただす"},"といただせる":{"variants":"といただせる/問いただせる"},"問いただせる":{"variants":"といただせる/問いただせる"},"といつめる":{"variants":"といつめる/問いつめる/問い詰める/問詰める"},"問いつめる":{"variants":"といつめる/問いつめる/問い詰める/問詰める"},"問い詰める":{"variants":"といつめる/問いつめる/問い詰める/問詰める"},"問詰める":{"variants":"といつめる/問いつめる/問い詰める/問詰める"},"とう":{"variants":"とう/問う"},"問う":{"variants":"とう/問う"},"トウ":{"variants":"トウ/登/党/唐/塔/投/棟/当/糖/籐/薹"},"籐いす":{"variants":"籐いす/籐椅子"},"籐椅子":{"variants":"籐いす/籐椅子"},"投かん":{"variants":"投かん/投函"},"投函":{"variants":"投かん/投函"},"トウガラシ":{"variants":"トウガラシ/唐がらし/唐芥子/唐辛子"},"唐がらし":{"variants":"トウガラシ/唐がらし/唐芥子/唐辛子"},"トウキビ":{"variants":"トウキビ/唐黍"},"唐黍":{"variants":"トウキビ/唐黍"},"トウギョ":{"variants":"トウギョ/闘魚"},"闘魚":{"variants":"トウギョ/闘魚"},"当ぎり":{"variants":"当ぎり/当限"},"当限":{"variants":"当ぎり/当限"},"トウゴマ":{"variants":"トウゴマ/唐胡麻"},"唐胡麻":{"variants":"トウゴマ/唐胡麻"},"搭載":{"variants":"とう載/搭載"},"登載":{"variants":"とう載/登載"},"とう載":{"variants":"とう載/登載/搭載"},"とうさん":{"variants":"とうさん/父さん"},"父さん":{"variants":"とうさん/父さん"},"当座しのぎ":{"variants":"当座しのぎ/当座凌ぎ"},"当座凌ぎ":{"variants":"当座しのぎ/当座凌ぎ"},"トウシミトンボ":{"variants":"トウシミトンボ/灯心蜻蛉"},"灯心蜻蛉":{"variants":"トウシミトンボ/灯心蜻蛉"},"島しょ":{"variants":"島しょ/島嶼"},"島嶼":{"variants":"島しょ/島嶼"},"トウシン":{"variants":"トウシン/刀心/刀身/投信/盗心/灯心/等親/等身/蕩心"},"トウシングサ":{"variants":"トウシングサ/灯心草"},"灯心草":{"variants":"トウシングサ/灯心草"},"とうじる":{"variants":"とうじる/投じる"},"投じる":{"variants":"とうじる/投じる"},"とうずる":{"variants":"とうずる/投ずる"},"投ずる":{"variants":"とうずる/投ずる"},"当世ふう":{"variants":"当世ふう/当世風"},"当世風":{"variants":"当世ふう/当世風"},"当せん":{"variants":"当せん/当選/当籤"},"当選":{"variants":"当せん/当選"},"当籤":{"variants":"当せん/当籤"},"とうてい":{"variants":"とうてい/到底"},"到底":{"variants":"とうてい/到底"},"投てき":{"variants":"投てき/投擲"},"投擲":{"variants":"投てき/投擲"},"トウテンコウ":{"variants":"トウテンコウ/東天紅"},"東天紅":{"variants":"トウテンコウ/東天紅"},"とうとう":{"variants":"とうとう/到頭"},"到頭":{"variants":"とうとう/到頭"},"蕩蕩":{"variants":"蕩々/蕩蕩"},"蕩々":{"variants":"蕩々/蕩蕩"},"滔々":{"variants":"滔々/滔滔"},"滔滔":{"variants":"滔々/滔滔"},"トウナ":{"variants":"トウナ/唐菜"},"唐菜":{"variants":"トウナ/唐菜"},"とうぶん":{"variants":"とうぶん/当分"},"当分":{"variants":"とうぶん/当分"},"トウホン":{"variants":"トウホン/唐本/藤本/謄本"},"トウボク":{"variants":"トウボク/倒木/唐墨"},"トウマル":{"variants":"トウマル/唐丸"},"唐丸":{"variants":"トウマル/唐丸"},"トウモロコシ":{"variants":"トウモロコシ/玉蜀黍"},"玉蜀黍":{"variants":"トウモロコシ/玉蜀黍"},"トウロウ":{"variants":"トウロウ/灯ろう/灯篭"},"灯ろう":{"variants":"トウロウ/灯ろう/灯篭"},"灯篭":{"variants":"トウロウ/灯ろう/灯篭"},"とえる":{"variants":"とえる/問える"},"問える":{"variants":"とえる/問える"},"とおい":{"variants":"とおい/遠い"},"遠い":{"variants":"とおい/遠い"},"とおざかる":{"variants":"とおざかる/遠ざかる"},"遠ざかる":{"variants":"とおざかる/遠ざかる"},"とおざける":{"variants":"とおざける/遠ざける"},"遠ざける":{"variants":"とおざける/遠ざける"},"とおす":{"variants":"とおす/通す/透す"},"とおせる":{"variants":"とおせる/通せる"},"通せる":{"variants":"とおせる/通せる"},"通せんぼう":{"variants":"通せんぼう/通せん坊"},"通せん坊":{"variants":"通せんぼう/通せん坊"},"とおのく":{"variants":"とおのく/遠のく"},"遠のく":{"variants":"とおのく/遠のく"},"とおのける":{"variants":"とおのける/遠退ける"},"遠退ける":{"variants":"とおのける/遠退ける"},"遠まわし":{"variants":"遠まわし/遠回し/遠廻し"},"とおり":{"variants":"とおり/通り"},"通り":{"variants":"どおり/通/通り"},"とおりかかる":{"variants":"とおりかかる/通りかかる/通り掛かる/通り掛る"},"通りかかる":{"variants":"とおりかかる/通りかかる/通り掛かる/通り掛る"},"通り掛かる":{"variants":"とおりかかる/通りかかる/通り掛かる/通り掛る"},"通り掛る":{"variants":"とおりかかる/通りかかる/通り掛かる/通り掛る"},"通りがけ":{"variants":"通りがけ/通り掛け"},"通り掛け":{"variants":"通りがけ/通り掛け"},"通りことば":{"variants":"通りことば/通り言葉/通り詞"},"とおりすぎる":{"variants":"とおりすぎる/通り過ぎる"},"通り過ぎる":{"variants":"とおりすぎる/通り過ぎる"},"とおりぬける":{"variants":"とおりぬける/通り抜ける"},"通り抜ける":{"variants":"とおりぬける/通り抜ける"},"通りみち":{"variants":"通りみち/通り道/通り路"},"とおる":{"variants":"とおる/通る/徹る/透る"},"とおれる":{"variants":"とおれる/通れる"},"通れる":{"variants":"とおれる/通れる"},"とかく":{"variants":"とかく/兎角"},"兎角":{"variants":"とかく/兎角"},"トカゲ":{"variants":"トカゲ/蜥蜴"},"蜥蜴":{"variants":"トカゲ/蜥蜴"},"とかす":{"variants":"とかす/解かす/融かす/溶かす/梳かす"},"とかせる":{"variants":"とかせる/溶かせる"},"溶かせる":{"variants":"とかせる/溶かせる"},"トがき":{"variants":"トがき/ト書/ト書き/卜書"},"ト書":{"variants":"トがき/ト書/ト書き/卜書"},"ト書き":{"variants":"トがき/ト書/ト書き/卜書"},"卜書":{"variants":"トがき/ト書/ト書き/卜書"},"とが人":{"variants":"とが人/科人/咎人"},"咎めだて":{"variants":"咎めだて/咎め立て/咎立て"},"咎め立て":{"variants":"咎めだて/咎め立て/咎立て"},"咎立て":{"variants":"咎めだて/咎め立て/咎立て"},"とがめる":{"variants":"とがめる/咎める"},"咎める":{"variants":"とがめる/咎める"},"とがらす":{"variants":"とがらす/尖らす"},"尖らす":{"variants":"とがらす/尖らす"},"とがる":{"variants":"とがる/尖る"},"尖る":{"variants":"とがる/尖る"},"トキ":{"variants":"トキ/斎/時/朱鷺/十寸/鴇"},"とき":{"variants":"とき/時"},"時":{"variants":"とき/時"},"ときあかす":{"variants":"ときあかす/解きあかす/解き明かす/解明かす/説き明かす/説明かす"},"解きあかす":{"variants":"ときあかす/解きあかす/解き明かす/解明かす"},"説明かす":{"variants":"ときあかす/説き明かす/説明かす"},"説き明かす":{"variants":"ときあかす/説き明かす/説明かす"},"解明かす":{"variants":"ときあかす/解きあかす/解き明かす/解明かす"},"解き明かす":{"variants":"ときあかす/解きあかす/解き明かす/解明かす"},"ときあるく":{"variants":"ときあるく/説きあるく"},"説きあるく":{"variants":"ときあるく/説きあるく"},"とき色":{"variants":"とき色/鴇色"},"鴇色":{"variants":"とき色/鴇色"},"ときおり":{"variants":"ときおり/時おり/時折"},"時おり":{"variants":"ときおり/時おり/時折"},"時折":{"variants":"ときおり/時おり/時折"},"ときたま":{"variants":"ときたま/時たま"},"時たま":{"variants":"ときたま/時たま"},"ときつける":{"variants":"ときつける/説きつける/説き付ける/説付ける"},"説きつける":{"variants":"ときつける/説きつける/説き付ける/説付ける"},"説き付ける":{"variants":"ときつける/説きつける/説き付ける/説付ける"},"説付ける":{"variants":"ときつける/説きつける/説き付ける/説付ける"},"ときどき":{"variants":"ときどき/時々/時時"},"時々":{"variants":"ときどき/時々/時時"},"時時":{"variants":"ときどき/時々/時時"},"ときには":{"variants":"ときには/時には"},"時には":{"variants":"ときには/時には"},"ときの声":{"variants":"ときの声/鯨波の声/鬨の声"},"ときはなす":{"variants":"ときはなす/解き放す/解き離す"},"ときはなつ":{"variants":"ときはなつ/解き放つ"},"解き放つ":{"variants":"ときはなつ/解き放つ"},"ときふせる":{"variants":"ときふせる/説き伏せる/説伏せる"},"説き伏せる":{"variants":"ときふせる/説き伏せる/説伏せる"},"説伏せる":{"variants":"ときふせる/説き伏せる/説伏せる"},"ときほぐす":{"variants":"ときほぐす/解きほぐす/溶きほぐす"},"ときめく":{"variants":"ときめく/時めく"},"時めく":{"variants":"ときめく/時めく"},"解きもの":{"variants":"解きもの/解き物"},"解き物":{"variants":"解きもの/解き物"},"研ぎ出し":{"variants":"研ぎ出し/研出し"},"研出し":{"variants":"研ぎ出し/研出し"},"研ぎもの":{"variants":"研ぎもの/研ぎ物"},"研ぎ物":{"variants":"研ぎもの/研ぎ物"},"とぎれる":{"variants":"とぎれる/途切れる"},"途切れる":{"variants":"とぎれる/途切れる"},"とく":{"variants":"とく/疾く"},"疾く":{"variants":"とく/疾く"},"得意げ":{"variants":"得意げ/得意気"},"得意気":{"variants":"得意げ/得意気"},"トクサ":{"variants":"トクサ/砥草/木賊"},"とくする":{"variants":"とくする/得する/督する"},"とくせいづける":{"variants":"とくせいづける/特性づける"},"特性づける":{"variants":"とくせいづける/特性づける"},"とくちょうづける":{"variants":"とくちょうづける/特徴付ける"},"特徴付ける":{"variants":"とくちょうづける/特徴付ける"},"とくと":{"variants":"とくと/篤と"},"篤と":{"variants":"とくと/篤と"},"得々":{"variants":"得々/得得"},"得得":{"variants":"得々/得得"},"とくに":{"variants":"とくに/特に"},"特に":{"variants":"とくに/特に"},"とくべつ":{"variants":"とくべつ/特別"},"特別":{"variants":"とくべつ/特別"},"とぐ":{"variants":"とぐ/研ぐ/磨ぐ"},"とぐろ":{"variants":"とぐろ/蜷局"},"蜷局":{"variants":"とぐろ/蜷局"},"とけあう":{"variants":"とけあう/解けあう/解け合う/解合う/溶けあう/溶け合う/溶合う"},"溶けあう":{"variants":"とけあう/溶けあう/溶け合う/溶合う"},"解け合う":{"variants":"とけあう/解けあう/解け合う/解合う"},"溶合う":{"variants":"とけあう/溶けあう/溶け合う/溶合う"},"解けあう":{"variants":"とけあう/解けあう/解け合う/解合う"},"溶け合う":{"variants":"とけあう/溶けあう/溶け合う/溶合う"},"解合う":{"variants":"とけあう/解けあう/解け合う/解合う"},"とけあえる":{"variants":"とけあえる/解け合える"},"解け合える":{"variants":"とけあえる/解け合える"},"とけこむ":{"variants":"とけこむ/とけ込む/溶け込む"},"とけ込む":{"variants":"とけこむ/とけ込む/溶け込む"},"溶け込む":{"variants":"とけこむ/とけ込む/溶け込む"},"とけこめる":{"variants":"とけこめる/とけ込める"},"とけ込める":{"variants":"とけこめる/とけ込める"},"とける":{"variants":"とける/釈ける/説ける/融ける/溶ける/熔ける"},"トケン":{"variants":"トケン/都県"},"都県":{"variants":"トケン/都県"},"とげ":{"variants":"とげ/トゲ/刺"},"トゲ":{"variants":"とげ/トゲ/刺"},"刺":{"variants":"とげ/トゲ/刺"},"トゲウオ":{"variants":"トゲウオ/棘魚"},"棘魚":{"variants":"トゲウオ/棘魚"},"とげだつ":{"variants":"とげだつ/刺立つ"},"刺立つ":{"variants":"とげだつ/刺立つ"},"とげとげしい":{"variants":"とげとげしい/トゲトゲしい/刺々しい/刺刺しい"},"トゲトゲしい":{"variants":"とげとげしい/トゲトゲしい/刺々しい/刺刺しい"},"刺々しい":{"variants":"とげとげしい/トゲトゲしい/刺々しい/刺刺しい"},"刺刺しい":{"variants":"とげとげしい/トゲトゲしい/刺々しい/刺刺しい"},"とげる":{"variants":"とげる/研げる/遂げる"},"とこずれ":{"variants":"とこずれ/床ずれ/床擦れ"},"床ずれ":{"variants":"とこずれ/床ずれ/床擦れ"},"床擦れ":{"variants":"とこずれ/床ずれ/床擦れ"},"とことこ":{"variants":"とことこ/トコトコ"},"トコトコ":{"variants":"とことこ/トコトコ"},"とことん":{"variants":"とことん/トコトン"},"トコトン":{"variants":"とことん/トコトン"},"トコナツ":{"variants":"トコナツ/常夏"},"常夏":{"variants":"トコナツ/常夏"},"床の間":{"variants":"床の間/床間"},"床間":{"variants":"床の間/床間"},"トコブシ":{"variants":"トコブシ/常節"},"常節":{"variants":"トコブシ/常節"},"床や":{"variants":"床や/床屋"},"床屋":{"variants":"床や/床屋"},"常世の国":{"variants":"常世の国/常世国"},"常世国":{"variants":"常世の国/常世国"},"ところ":{"variants":"ところ/所"},"所":{"variants":"ところ/所"},"所書":{"variants":"所書/所書き"},"所書き":{"variants":"所書/所書き"},"トコロテン":{"variants":"トコロテン/心太"},"心太":{"variants":"トコロテン/心太"},"トコロテングサ":{"variants":"トコロテングサ/心太草"},"心太草":{"variants":"トコロテングサ/心太草"},"ところどころ":{"variants":"ところどころ/処々/処処/所々/所所"},"所々":{"variants":"ところどころ/所々/所所"},"所所":{"variants":"ところどころ/所々/所所"},"トサイヌ":{"variants":"トサイヌ/土佐犬"},"土佐犬":{"variants":"トサイヌ/土佐犬"},"とざす":{"variants":"とざす/鎖す/閉ざす/閉す"},"閉ざす":{"variants":"とざす/閉ざす/閉す"},"閉す":{"variants":"とざす/閉ざす/閉す"},"年かさ":{"variants":"年かさ/年嵩"},"年嵩":{"variants":"年かさ/年嵩"},"としごろ":{"variants":"としごろ/年頃"},"年頃":{"variants":"としごろ/年頃"},"年取":{"variants":"年取/年取り"},"年取り":{"variants":"年取/年取り"},"としとる":{"variants":"としとる/年取る"},"年取る":{"variants":"としとる/年取る"},"年のうち":{"variants":"年のうち/年の内"},"年の内":{"variants":"年のうち/年の内"},"吐しゃ":{"variants":"吐しゃ/吐瀉"},"吐瀉":{"variants":"吐しゃ/吐瀉"},"年寄":{"variants":"年寄/年寄り"},"年寄り":{"variants":"年寄/年寄り"},"としよる":{"variants":"としよる/年寄る"},"年寄る":{"variants":"としよる/年寄る"},"とじ込み":{"variants":"とじ込み/綴込み"},"綴込み":{"variants":"とじ込み/綴込み"},"とじこむ":{"variants":"とじこむ/とじ込む/綴じ込む"},"とじ込む":{"variants":"とじこむ/とじ込む/綴じ込む"},"綴じ込む":{"variants":"とじこむ/とじ込む/綴じ込む"},"とじこめる":{"variants":"とじこめる/閉じこめる/閉じ込める/閉込める"},"閉じこめる":{"variants":"とじこめる/閉じこめる/閉じ込める/閉込める"},"閉じ込める":{"variants":"とじこめる/閉じこめる/閉じ込める/閉込める"},"閉込める":{"variants":"とじこめる/閉じこめる/閉じ込める/閉込める"},"とじこもる":{"variants":"とじこもる/閉じこもる/閉じ込もる/閉じ篭る"},"閉じこもる":{"variants":"とじこもる/閉じこもる/閉じ込もる/閉じ篭る"},"とじる":{"variants":"とじる/綴じる/閉じる"},"とそ":{"variants":"とそ/屠蘇"},"屠蘇":{"variants":"とそ/屠蘇"},"トタン":{"variants":"トタン/塗炭/途端"},"とたん":{"variants":"とたん/途端"},"途端":{"variants":"とたん/途端"},"とだえる":{"variants":"とだえる/跡絶える/途絶える"},"トチ":{"variants":"トチ/土地/栃/橡"},"とちの木":{"variants":"とちの木/トチノキ/栃の木/橡の木"},"トチノキ":{"variants":"とちの木/トチノキ/栃の木/橡の木"},"取っかかり":{"variants":"取っかかり/取っ掛り"},"取っ掛り":{"variants":"取っかかり/取っ掛り"},"取っくみあい":{"variants":"取っくみあい/取っ組み合い"},"取っ組み合い":{"variants":"取っくみあい/取っ組み合い"},"とっくむ":{"variants":"とっくむ/取っ組む"},"取っ組む":{"variants":"とっくむ/取っ組む"},"とっくめる":{"variants":"とっくめる/取っ組める"},"取っ組める":{"variants":"とっくめる/取っ組める"},"とっさ":{"variants":"とっさ/咄嗟"},"咄嗟":{"variants":"とっさ/咄嗟"},"とっちめる":{"variants":"とっちめる/取っちめる"},"取っちめる":{"variants":"とっちめる/取っちめる"},"取っつき":{"variants":"取っつき/取っ付き"},"取っ付き":{"variants":"取っつき/取っ付き"},"とっつく":{"variants":"とっつく/取っつく/取っ付く"},"取っつく":{"variants":"とっつく/取っつく/取っ付く"},"取っ付く":{"variants":"とっつく/取っつく/取っ付く"},"取っ手":{"variants":"取っ手/取手"},"取手":{"variants":"取っ手/取手"},"取っておき":{"variants":"取っておき/取って置き"},"取って置き":{"variants":"取っておき/取って置き"},"とってかえす":{"variants":"とってかえす/とって返す/取って返す"},"とって返す":{"variants":"とってかえす/とって返す/取って返す"},"取って返す":{"variants":"とってかえす/とって返す/取って返す"},"とっぴょうし":{"variants":"とっぴょうし/突拍子"},"突拍子":{"variants":"とっぴょうし/突拍子"},"とつぐ":{"variants":"とつぐ/嫁ぐ"},"嫁ぐ":{"variants":"とつぐ/嫁ぐ"},"吶々":{"variants":"吶々/吶吶"},"訥々":{"variants":"訥々/訥訥"},"訥訥":{"variants":"訥々/訥訥"},"吶吶":{"variants":"吶々/吶吶"},"とつレンズ":{"variants":"とつレンズ/凸レンズ"},"凸レンズ":{"variants":"とつレンズ/凸レンズ"},"ととのう":{"variants":"ととのう/整う/調う"},"ととのえなおす":{"variants":"ととのえなおす/整え直す"},"整え直す":{"variants":"ととのえなおす/整え直す"},"ととのえる":{"variants":"ととのえる/整える/調える"},"とともに":{"variants":"とともに/と共に"},"と共に":{"variants":"とともに/と共に"},"とどく":{"variants":"とどく/届く"},"届く":{"variants":"とどく/届く"},"届":{"variants":"届/届け"},"届け":{"variants":"届/届け"},"届け先":{"variants":"届け先/届先"},"届先":{"variants":"届け先/届先"},"届け出":{"variants":"届け出/届出"},"届出":{"variants":"届け出/届出"},"とどけでる":{"variants":"とどけでる/届けでる/届け出る/届出る"},"届けでる":{"variants":"とどけでる/届けでる/届け出る/届出る"},"届け出る":{"variants":"とどけでる/届けでる/届け出る/届出る"},"届出る":{"variants":"とどけでる/届けでる/届け出る/届出る"},"とどける":{"variants":"とどける/届ける"},"届ける":{"variants":"とどける/届ける"},"とどこおる":{"variants":"とどこおる/滞る"},"滞る":{"variants":"とどこおる/滞る"},"トドマツ":{"variants":"トドマツ/椴松"},"椴松":{"variants":"トドマツ/椴松"},"とどろかす":{"variants":"とどろかす/轟かす"},"轟かす":{"variants":"とどろかす/轟かす"},"とどろかせる":{"variants":"とどろかせる/轟かせる"},"轟かせる":{"variants":"とどろかせる/轟かせる"},"とどろく":{"variants":"とどろく/轟く"},"轟く":{"variants":"とどろく/轟く"},"となえる":{"variants":"となえる/唱える"},"唱える":{"variants":"となえる/唱える"},"トナカイ":{"variants":"トナカイ/馴鹿"},"馴鹿":{"variants":"トナカイ/馴鹿"},"となり":{"variants":"となり/隣"},"隣":{"variants":"となり/隣"},"となりあう":{"variants":"となりあう/隣合う"},"隣合う":{"variants":"となりあう/隣合う"},"となりあわす":{"variants":"となりあわす/隣り合わす/隣合わす"},"隣り合わす":{"variants":"となりあわす/隣り合わす/隣合わす"},"隣合わす":{"variants":"となりあわす/隣り合わす/隣合わす"},"隣合せ":{"variants":"隣合せ/隣合わせ"},"隣合わせ":{"variants":"隣合せ/隣合わせ"},"となりあわせる":{"variants":"となりあわせる/隣り合わせる/隣合わせる"},"隣り合わせる":{"variants":"となりあわせる/隣り合わせる/隣合わせる"},"隣合わせる":{"variants":"となりあわせる/隣り合わせる/隣合わせる"},"トネリコ":{"variants":"トネリコ/秦皮"},"秦皮":{"variants":"トネリコ/秦皮"},"とのこ":{"variants":"とのこ/砥の粉/砥粉"},"砥の粉":{"variants":"とのこ/砥の粉/砥粉"},"砥粉":{"variants":"とのこ/砥の粉/砥粉"},"殿さま":{"variants":"殿さま/殿様"},"殿様":{"variants":"殿さま/殿様"},"トノサマガエル":{"variants":"トノサマガエル/殿様蛙"},"殿様蛙":{"variants":"トノサマガエル/殿様蛙"},"とばく":{"variants":"とばく/賭博"},"賭博":{"variants":"とばく/賭博"},"とばす":{"variants":"とばす/飛ばす"},"飛ばす":{"variants":"とばす/飛ばす"},"とばせる":{"variants":"とばせる/飛ばせる"},"飛ばせる":{"variants":"とばせる/飛ばせる"},"とばっちり":{"variants":"とばっちり/トバっちり"},"トバっちり":{"variants":"とばっちり/トバっちり"},"飛び上がり":{"variants":"飛び上がり/飛上り"},"飛上り":{"variants":"飛び上がり/飛上り"},"とびあがる":{"variants":"とびあがる/飛び上がる"},"飛び上がる":{"variants":"とびあがる/飛び上がる"},"とびあがれる":{"variants":"とびあがれる/飛び上がれる"},"飛び上がれる":{"variants":"とびあがれる/飛び上がれる"},"とびあるく":{"variants":"とびあるく/飛び歩く/飛歩く"},"飛び歩く":{"variants":"とびあるく/飛び歩く/飛歩く"},"飛歩く":{"variants":"とびあるく/飛び歩く/飛歩く"},"飛び石":{"variants":"飛び石/飛石"},"飛石":{"variants":"飛び石/飛石"},"飛び板":{"variants":"飛び板/飛板"},"飛板":{"variants":"飛び板/飛板"},"飛び入り":{"variants":"飛び入り/飛入り"},"飛入り":{"variants":"飛び入り/飛入り"},"トビウオ":{"variants":"トビウオ/飛び魚/飛魚"},"飛び魚":{"variants":"トビウオ/飛び魚/飛魚"},"飛魚":{"variants":"トビウオ/飛び魚/飛魚"},"とびおりる":{"variants":"とびおりる/飛び下りる/飛び降りる/飛下りる/飛降りる"},"飛降りる":{"variants":"とびおりる/飛び降りる/飛降りる"},"飛下りる":{"variants":"とびおりる/飛び下りる/飛下りる"},"飛び降りる":{"variants":"とびおりる/飛び降りる/飛降りる"},"飛び下りる":{"variants":"とびおりる/飛び下りる/飛下りる"},"とびかう":{"variants":"とびかう/飛び交う/飛交う"},"飛び交う":{"variants":"とびかう/飛び交う/飛交う"},"飛交う":{"variants":"とびかう/飛び交う/飛交う"},"とびかかる":{"variants":"とびかかる/飛びかかる/飛び掛る"},"飛びかかる":{"variants":"とびかかる/飛びかかる/飛び掛る"},"飛び掛る":{"variants":"とびかかる/飛びかかる/飛び掛る"},"とびかかれる":{"variants":"とびかかれる/飛びかかれる"},"飛びかかれる":{"variants":"とびかかれる/飛びかかれる"},"飛び切り":{"variants":"飛び切り/飛切り"},"飛切り":{"variants":"飛び切り/飛切り"},"とびこえる":{"variants":"とびこえる/飛び越える"},"飛び越える":{"variants":"とびこえる/飛び越える"},"飛越":{"variants":"飛越/飛越し"},"飛越し":{"variants":"飛越/飛越し"},"とびこす":{"variants":"とびこす/跳び越す/飛び越す"},"とびこせる":{"variants":"とびこせる/飛び越せる"},"飛び越せる":{"variants":"とびこせる/飛び越せる"},"飛びこみ":{"variants":"飛びこみ/飛び込み/飛込み"},"飛び込み":{"variants":"飛びこみ/飛び込み/飛込み"},"飛込み":{"variants":"飛びこみ/飛び込み/飛込み"},"飛び込み台":{"variants":"飛び込み台/飛込み台/飛込台"},"飛込み台":{"variants":"飛び込み台/飛込み台/飛込台"},"飛込台":{"variants":"飛び込み台/飛込み台/飛込台"},"とびこむ":{"variants":"とびこむ/飛びこむ/飛び込む/飛込む"},"飛びこむ":{"variants":"とびこむ/飛びこむ/飛び込む/飛込む"},"飛び込む":{"variants":"とびこむ/飛びこむ/飛び込む/飛込む"},"飛込む":{"variants":"とびこむ/飛びこむ/飛び込む/飛込む"},"とびこめる":{"variants":"とびこめる/飛び込める"},"飛び込める":{"variants":"とびこめる/飛び込める"},"とび職":{"variants":"とび職/鳶職"},"鳶職":{"variants":"とび職/鳶職"},"とびたつ":{"variants":"とびたつ/飛びたつ/飛び立つ/飛立つ"},"飛びたつ":{"variants":"とびたつ/飛びたつ/飛び立つ/飛立つ"},"飛び立つ":{"variants":"とびたつ/飛びたつ/飛び立つ/飛立つ"},"飛立つ":{"variants":"とびたつ/飛びたつ/飛び立つ/飛立つ"},"とびたてる":{"variants":"とびたてる/飛び立てる"},"飛び立てる":{"variants":"とびたてる/飛び立てる"},"とびだす":{"variants":"とびだす/飛びだす/飛び出す/飛出す"},"飛びだす":{"variants":"とびだす/飛びだす/飛び出す/飛出す"},"飛び出す":{"variants":"とびだす/飛びだす/飛び出す/飛出す"},"飛出す":{"variants":"とびだす/飛びだす/飛び出す/飛出す"},"とびだせる":{"variants":"とびだせる/飛び出せる"},"飛び出せる":{"variants":"とびだせる/飛び出せる"},"飛び地":{"variants":"飛び地/飛地"},"飛地":{"variants":"飛び地/飛地"},"とびちがう":{"variants":"とびちがう/飛び違う/飛違う"},"飛び違う":{"variants":"とびちがう/飛び違う/飛違う"},"飛違う":{"variants":"とびちがう/飛び違う/飛違う"},"とびちる":{"variants":"とびちる/飛び散る/飛散る"},"飛び散る":{"variants":"とびちる/飛び散る/飛散る"},"飛散る":{"variants":"とびちる/飛び散る/飛散る"},"とびつく":{"variants":"とびつく/跳びつく/飛びつく/飛び付く/飛付く"},"飛び付く":{"variants":"とびつく/飛びつく/飛び付く/飛付く"},"飛付く":{"variants":"とびつく/飛びつく/飛び付く/飛付く"},"飛びつく":{"variants":"とびつく/飛びつく/飛び付く/飛付く"},"とびつける":{"variants":"とびつける/飛びつける"},"飛びつける":{"variants":"とびつける/飛びつける"},"とびでる":{"variants":"とびでる/とび出る/飛び出でる/飛び出る/飛出る"},"とび出る":{"variants":"とびでる/とび出る/飛び出でる/飛び出る/飛出る"},"飛び出でる":{"variants":"とびでる/とび出る/飛び出でる/飛び出る/飛出る"},"飛び出る":{"variants":"とびでる/とび出る/飛び出でる/飛び出る/飛出る"},"飛出る":{"variants":"とびでる/とび出る/飛び出でる/飛び出る/飛出る"},"とびとび":{"variants":"とびとび/飛び飛び"},"飛び飛び":{"variants":"とびとび/飛び飛び"},"飛び道具":{"variants":"飛び道具/飛道具"},"飛道具":{"variants":"飛び道具/飛道具"},"とびぬける":{"variants":"とびぬける/飛び抜ける"},"飛び抜ける":{"variants":"とびぬける/飛び抜ける"},"トビノウオ":{"variants":"トビノウオ/飛の魚"},"飛の魚":{"variants":"トビノウオ/飛の魚"},"とびのく":{"variants":"とびのく/飛び退く"},"飛び退く":{"variants":"とびのく/飛び退く"},"とびのる":{"variants":"とびのる/飛びのる/飛び乗る/飛乗る"},"飛びのる":{"variants":"とびのる/飛びのる/飛び乗る/飛乗る"},"飛び乗る":{"variants":"とびのる/飛びのる/飛び乗る/飛乗る"},"飛乗る":{"variants":"とびのる/飛びのる/飛び乗る/飛乗る"},"とびのれる":{"variants":"とびのれる/飛びのれる/飛び乗れる"},"飛びのれる":{"variants":"とびのれる/飛びのれる/飛び乗れる"},"飛び乗れる":{"variants":"とびのれる/飛びのれる/飛び乗れる"},"とびはなれる":{"variants":"とびはなれる/飛び離れる/飛離れる"},"飛び離れる":{"variants":"とびはなれる/飛び離れる/飛離れる"},"飛離れる":{"variants":"とびはなれる/飛び離れる/飛離れる"},"とびはねる":{"variants":"とびはねる/飛び跳ねる"},"飛び跳ねる":{"variants":"とびはねる/飛び跳ねる"},"跳箱":{"variants":"跳び箱/跳箱"},"飛箱":{"variants":"飛び箱/飛箱"},"跳び箱":{"variants":"跳び箱/跳箱"},"飛び箱":{"variants":"飛び箱/飛箱"},"とびまわる":{"variants":"とびまわる/飛びまわる/飛び回る/飛び廻る/飛回る/飛廻る"},"飛びまわる":{"variants":"とびまわる/飛びまわる/飛び回る/飛び廻る/飛回る/飛廻る"},"飛回る":{"variants":"とびまわる/飛びまわる/飛び回る/飛回る"},"飛廻る":{"variants":"とびまわる/飛びまわる/飛び廻る/飛廻る"},"飛び回る":{"variants":"とびまわる/飛びまわる/飛び回る/飛回る"},"飛び廻る":{"variants":"とびまわる/飛びまわる/飛び廻る/飛廻る"},"とびまわれる":{"variants":"とびまわれる/飛び回れる"},"飛び回れる":{"variants":"とびまわれる/飛び回れる"},"とびわたる":{"variants":"とびわたる/飛び渡る"},"飛び渡る":{"variants":"とびわたる/飛び渡る"},"とぶ":{"variants":"とぶ/跳ぶ/飛ぶ/翔ぶ"},"とべる":{"variants":"とべる/跳べる/飛べる"},"とぼける":{"variants":"とぼける/恍ける"},"恍ける":{"variants":"とぼける/恍ける"},"とまどい":{"variants":"とまどい/戸惑い"},"戸惑い":{"variants":"とまどい/戸惑い"},"とまどう":{"variants":"とまどう/戸惑う"},"戸惑う":{"variants":"とまどう/戸惑う"},"泊り":{"variants":"泊まり/泊り"},"泊まり":{"variants":"泊まり/泊り"},"泊まり掛け":{"variants":"泊まり掛け/泊りがけ/泊り掛け"},"泊りがけ":{"variants":"泊まり掛け/泊りがけ/泊り掛け"},"泊り掛け":{"variants":"泊まり掛け/泊りがけ/泊り掛け"},"とまり木":{"variants":"とまり木/止り木"},"止り木":{"variants":"とまり木/止り木"},"とまりこむ":{"variants":"とまりこむ/泊まり込む/泊り込む"},"泊まり込む":{"variants":"とまりこむ/泊まり込む/泊り込む"},"泊り込む":{"variants":"とまりこむ/泊まり込む/泊り込む"},"とまる":{"variants":"とまる/止まる/止る/停る/泊まる/泊る/留る"},"泊る":{"variants":"とまる/泊まる/泊る"},"泊まる":{"variants":"とまる/泊まる/泊る"},"止る":{"variants":"とまる/止まる/止る"},"止まる":{"variants":"とまる/止まる/止る"},"とまれる":{"variants":"とまれる/止まれる/泊まれる/留まれる"},"富くじ":{"variants":"富くじ/富籤"},"富籤":{"variants":"富くじ/富籤"},"とみに":{"variants":"とみに/頓に"},"頓に":{"variants":"とみに/頓に"},"とむ":{"variants":"とむ/富む"},"富む":{"variants":"とむ/富む"},"弔い合戦":{"variants":"弔い合戦/弔合戦"},"弔合戦":{"variants":"弔い合戦/弔合戦"},"とむらう":{"variants":"とむらう/弔う"},"弔う":{"variants":"とむらう/弔う"},"とむらえる":{"variants":"とむらえる/弔える"},"弔える":{"variants":"とむらえる/弔える"},"留置":{"variants":"留置/留置き"},"留置き":{"variants":"留置/留置き"},"とめおく":{"variants":"とめおく/留め置く/留置く"},"留め置く":{"variants":"とめおく/留め置く/留置く"},"留置く":{"variants":"とめおく/留め置く/留置く"},"止金":{"variants":"止め金/止金"},"止め金":{"variants":"止め金/止金"},"留め袖":{"variants":"留め袖/留袖"},"留袖":{"variants":"留め袖/留袖"},"留めだて":{"variants":"留めだて/留め立て/留立て"},"留め立て":{"variants":"留めだて/留め立て/留立て"},"留立て":{"variants":"留めだて/留め立て/留立て"},"とめど":{"variants":"とめど/止めど"},"止めど":{"variants":"とめど/止めど"},"とめゆく":{"variants":"とめゆく/求め行く/尋め行く"},"とめる":{"variants":"とめる/停める/泊める/富める"},"とも":{"variants":"とも/供/共/伴/友/艫/鞆"},"ともい":{"variants":"ともい/羨い/乏い"},"ともす":{"variants":"ともす/灯す"},"灯す":{"variants":"ともす/灯す"},"友だち":{"variants":"友だち/友達"},"友達":{"variants":"友だち/友達"},"友釣":{"variants":"友釣/友釣り"},"友釣り":{"variants":"友釣/友釣り"},"ともども":{"variants":"ともども/共々/共共"},"共々":{"variants":"ともども/共々/共共"},"共共":{"variants":"ともども/共々/共共"},"ともなう":{"variants":"ともなう/伴う"},"伴う":{"variants":"ともなう/伴う"},"ともなえる":{"variants":"ともなえる/伴える"},"伴える":{"variants":"ともなえる/伴える"},"ともに":{"variants":"ともに/共に"},"共に":{"variants":"ともに/共に"},"ともる":{"variants":"ともる/点る/灯る"},"トラ":{"variants":"トラ/虎/寅"},"トライ":{"variants":"トライ/渡来"},"渡来":{"variants":"トライ/渡来"},"とらえる":{"variants":"とらえる/捉える/捕える/捕らえる"},"捕らえる":{"variants":"とらえる/捕える/捕らえる"},"捕える":{"variants":"とらえる/捕える/捕らえる"},"トラツグミ":{"variants":"トラツグミ/虎鶫"},"虎鶫":{"variants":"トラツグミ/虎鶫"},"とら猫":{"variants":"とら猫/虎猫"},"虎猫":{"variants":"とら猫/虎猫"},"トラノオ":{"variants":"トラノオ/虎の尾"},"虎の尾":{"variants":"トラノオ/虎の尾"},"とらの巻":{"variants":"とらの巻/虎の巻"},"虎の巻":{"variants":"とらの巻/虎の巻"},"とらわれる":{"variants":"とらわれる/因われる/囚われる/捕らわれる/捕われる"},"捕らわれる":{"variants":"とらわれる/捕らわれる/捕われる"},"捕われる":{"variants":"とらわれる/捕らわれる/捕われる"},"とり":{"variants":"とり/採り"},"トリ":{"variants":"とり/トリ/鳥/酉/肚裏"},"採り":{"variants":"とり/採り"},"取り合い":{"variants":"取り合い/取合い"},"取合い":{"variants":"取り合い/取合い"},"とりあう":{"variants":"とりあう/取りあう/取り合う/取合う"},"取りあう":{"variants":"とりあう/取りあう/取り合う/取合う"},"取り合う":{"variants":"とりあう/取りあう/取り合う/取合う"},"取合う":{"variants":"とりあう/取りあう/取り合う/取合う"},"取りあえず":{"variants":"取りあえず/取り敢えず"},"取り敢えず":{"variants":"取りあえず/取り敢えず"},"とりあえる":{"variants":"とりあえる/取り合える"},"取り合える":{"variants":"とりあえる/取り合える"},"とりあげる":{"variants":"とりあげる/とり上げる/採りあげる/採り上げる/取りあげる/取り上げる/取上げる"},"とり上げる":{"variants":"とりあげる/とり上げる/採りあげる/採り上げる/取りあげる/取り上げる/取上げる"},"採りあげる":{"variants":"とりあげる/とり上げる/採りあげる/採り上げる"},"取り上げる":{"variants":"とりあげる/とり上げる/取りあげる/取り上げる/取上げる"},"取上げる":{"variants":"とりあげる/とり上げる/取りあげる/取り上げる/取上げる"},"取りあげる":{"variants":"とりあげる/とり上げる/取りあげる/取り上げる/取上げる"},"採り上げる":{"variants":"とりあげる/とり上げる/採りあげる/採り上げる"},"取り扱い":{"variants":"取り扱い/取扱/取扱い"},"取扱":{"variants":"取り扱い/取扱/取扱い"},"取扱い":{"variants":"取り扱い/取扱/取扱い"},"とりあつかう":{"variants":"とりあつかう/取りあつかう/取り扱う/取扱う"},"取りあつかう":{"variants":"とりあつかう/取りあつかう/取り扱う/取扱う"},"取り扱う":{"variants":"とりあつかう/取りあつかう/取り扱う/取扱う"},"取扱う":{"variants":"とりあつかう/取りあつかう/取り扱う/取扱う"},"とりあつかえる":{"variants":"とりあつかえる/取り扱える"},"取り扱える":{"variants":"とりあつかえる/取り扱える"},"とりあつめる":{"variants":"とりあつめる/取りあつめる/取り集める/取集める"},"取りあつめる":{"variants":"とりあつめる/取りあつめる/取り集める/取集める"},"取り集める":{"variants":"とりあつめる/取りあつめる/取り集める/取集める"},"取集める":{"variants":"とりあつめる/取りあつめる/取り集める/取集める"},"とりあわす":{"variants":"とりあわす/取り合わす"},"取り合わす":{"variants":"とりあわす/取り合わす"},"取り合わせ":{"variants":"取り合わせ/取合せ"},"取合せ":{"variants":"取り合わせ/取合せ"},"とりあわせる":{"variants":"とりあわせる/取りあわせる/取り合せる/取り合わせる/取合せる"},"取りあわせる":{"variants":"とりあわせる/取りあわせる/取り合せる/取り合わせる/取合せる"},"取り合せる":{"variants":"とりあわせる/取りあわせる/取り合せる/取り合わせる/取合せる"},"取り合わせる":{"variants":"とりあわせる/取りあわせる/取り合せる/取り合わせる/取合せる"},"取合せる":{"variants":"とりあわせる/取りあわせる/取り合せる/取り合わせる/取合せる"},"とりいそぎ":{"variants":"とりいそぎ/取り急ぎ"},"取り急ぎ":{"variants":"とりいそぎ/取り急ぎ"},"とりいる":{"variants":"とりいる/取り入る"},"取り入る":{"variants":"とりいる/取り入る"},"取りいれ":{"variants":"取りいれ/取り入れ/取入れ"},"取り入れ":{"variants":"取りいれ/取り入れ/取入れ"},"取入れ":{"variants":"取りいれ/取り入れ/取入れ"},"とりいれる":{"variants":"とりいれる/とり入れる/採り入れる/取り入れる/取入れる"},"とり入れる":{"variants":"とりいれる/とり入れる/採り入れる/取り入れる/取入れる"},"取り入れる":{"variants":"とりいれる/とり入れる/取り入れる/取入れる"},"取入れる":{"variants":"とりいれる/とり入れる/取り入れる/取入れる"},"鳥打ち帽":{"variants":"鳥打ち帽/鳥打帽"},"鳥打帽":{"variants":"鳥打ち帽/鳥打帽"},"取りえ":{"variants":"取りえ/取り柄/取柄"},"取り柄":{"variants":"取りえ/取り柄/取柄"},"取柄":{"variants":"取りえ/取り柄/取柄"},"鳥追":{"variants":"鳥追/鳥追い"},"鳥追い":{"variants":"鳥追/鳥追い"},"とりおく":{"variants":"とりおく/取り置く"},"取り置く":{"variants":"とりおく/取り置く"},"とりおこなう":{"variants":"とりおこなう/執り行う"},"執り行う":{"variants":"とりおこなう/執り行う"},"とりおこなえる":{"variants":"とりおこなえる/執り行える"},"執り行える":{"variants":"とりおこなえる/執り行える"},"とりおさえる":{"variants":"とりおさえる/取り押さえる/取り抑える/取抑える"},"取り抑える":{"variants":"とりおさえる/取り抑える/取抑える"},"取抑える":{"variants":"とりおさえる/取り抑える/取抑える"},"とりおとす":{"variants":"とりおとす/取り落す/取り落とす"},"取り落す":{"variants":"とりおとす/取り落す/取り落とす"},"取り落とす":{"variants":"とりおとす/取り落す/取り落とす"},"取り返し":{"variants":"取り返し/取返し"},"取返し":{"variants":"取り返し/取返し"},"とりかえす":{"variants":"とりかえす/取り返す/取返す"},"取り返す":{"variants":"とりかえす/取り返す/取返す"},"取返す":{"variants":"とりかえす/取り返す/取返す"},"とりかえせる":{"variants":"とりかえせる/取り返せる"},"取り返せる":{"variants":"とりかえせる/取り返せる"},"とりかえる":{"variants":"とりかえる/取りかえる/取り換える/取り替える/取替える"},"取りかえる":{"variants":"とりかえる/取りかえる/取り換える/取り替える/取替える"},"取り替える":{"variants":"とりかえる/取りかえる/取り替える/取替える"},"取替える":{"variants":"とりかえる/取りかえる/取り替える/取替える"},"とりかかる":{"variants":"とりかかる/取りかかる/取り掛かる/取り掛る"},"取りかかる":{"variants":"とりかかる/取りかかる/取り掛かる/取り掛る"},"取り掛かる":{"variants":"とりかかる/取りかかる/取り掛かる/取り掛る"},"取り掛る":{"variants":"とりかかる/取りかかる/取り掛かる/取り掛る"},"とりかこむ":{"variants":"とりかこむ/取り囲む/取囲む"},"取り囲む":{"variants":"とりかこむ/取り囲む/取囲む"},"取囲む":{"variants":"とりかこむ/取り囲む/取囲む"},"とりかこめる":{"variants":"とりかこめる/取り囲める"},"取り囲める":{"variants":"とりかこめる/取り囲める"},"鳥かご":{"variants":"鳥かご/鳥篭"},"鳥篭":{"variants":"鳥かご/鳥篭"},"とり方":{"variants":"とり方/捕方"},"捕方":{"variants":"とり方/捕方"},"とりかたづける":{"variants":"とりかたづける/取りかたづける/取り片付ける/取片付ける"},"取りかたづける":{"variants":"とりかたづける/取りかたづける/取り片付ける/取片付ける"},"取り片付ける":{"variants":"とりかたづける/取りかたづける/取り片付ける/取片付ける"},"取片付ける":{"variants":"とりかたづける/取りかたづける/取り片付ける/取片付ける"},"トリカブト":{"variants":"トリカブト/鳥兜"},"鳥兜":{"variants":"トリカブト/鳥兜"},"とりかわす":{"variants":"とりかわす/取り交す/取り交わす/取交す"},"取り交す":{"variants":"とりかわす/取り交す/取り交わす/取交す"},"取り交わす":{"variants":"とりかわす/取り交す/取り交わす/取交す"},"取交す":{"variants":"とりかわす/取り交す/取り交わす/取交す"},"とりかわせる":{"variants":"とりかわせる/取り交わせる"},"取り交わせる":{"variants":"とりかわせる/取り交わせる"},"とりきめる":{"variants":"とりきめる/取り極める/取り決める/取決める"},"取り決める":{"variants":"とりきめる/取り決める/取決める"},"取決める":{"variants":"とりきめる/取り決める/取決める"},"とりくずす":{"variants":"とりくずす/取り崩す/取崩す"},"取り崩す":{"variants":"とりくずす/取り崩す/取崩す"},"取崩す":{"variants":"とりくずす/取り崩す/取崩す"},"とりくずせる":{"variants":"とりくずせる/取り崩せる"},"取り崩せる":{"variants":"とりくずせる/取り崩せる"},"取り口":{"variants":"取り口/取口"},"取口":{"variants":"取り口/取口"},"取り組み":{"variants":"取り組み/取組"},"取組":{"variants":"取り組み/取組"},"とりくむ":{"variants":"とりくむ/取りくむ/取り組む/取組む"},"取りくむ":{"variants":"とりくむ/取りくむ/取り組む/取組む"},"取り組む":{"variants":"とりくむ/取りくむ/取り組む/取組む"},"取組む":{"variants":"とりくむ/取りくむ/取り組む/取組む"},"とりくめる":{"variants":"とりくめる/取り組める"},"取り組める":{"variants":"とりくめる/取り組める"},"取り消し":{"variants":"取り消し/取消/取消し"},"取消":{"variants":"取り消し/取消/取消し"},"取消し":{"variants":"取り消し/取消/取消し"},"とりけす":{"variants":"とりけす/取り消す/取消す"},"取り消す":{"variants":"とりけす/取り消す/取消す"},"取消す":{"variants":"とりけす/取り消す/取消す"},"とりけせる":{"variants":"とりけせる/取り消せる"},"取り消せる":{"variants":"とりけせる/取り消せる"},"とりこ":{"variants":"とりこ/取り粉/取粉/虜/擒"},"取り粉":{"variants":"とりこ/取り粉/取粉"},"取粉":{"variants":"とりこ/取り粉/取粉"},"取り越し苦労":{"variants":"取り越し苦労/取越苦労"},"取越苦労":{"variants":"取り越し苦労/取越苦労"},"とりこす":{"variants":"とりこす/取り越す/取越す"},"取り越す":{"variants":"とりこす/取り越す/取越す"},"取越す":{"variants":"とりこす/取り越す/取越す"},"とりこぼす":{"variants":"とりこぼす/取りこぼす/取り零す"},"取りこぼす":{"variants":"とりこぼす/取りこぼす/取り零す"},"取り零す":{"variants":"とりこぼす/取りこぼす/取り零す"},"取り込み":{"variants":"取り込み/取込み"},"取込み":{"variants":"取り込み/取込み"},"とりこむ":{"variants":"とりこむ/取りこむ/取り込む"},"取りこむ":{"variants":"とりこむ/取りこむ/取り込む"},"取り込む":{"variants":"とりこむ/取りこむ/取り込む"},"とりこめる":{"variants":"とりこめる/取りこめる/取り込める/取り篭める"},"取りこめる":{"variants":"とりこめる/取りこめる/取り込める/取り篭める"},"とりころす":{"variants":"とりころす/とり殺す/取り殺す/取殺す"},"とり殺す":{"variants":"とりころす/とり殺す/取り殺す/取殺す"},"取り殺す":{"variants":"とりころす/とり殺す/取り殺す/取殺す"},"取殺す":{"variants":"とりころす/とり殺す/取り殺す/取殺す"},"とりこわす":{"variants":"とりこわす/取り壊す/取り毀す/取壊す"},"取り壊す":{"variants":"とりこわす/取り壊す/取壊す"},"取壊す":{"variants":"とりこわす/取り壊す/取壊す"},"とりこわせる":{"variants":"とりこわせる/取り壊せる"},"取り壊せる":{"variants":"とりこわせる/取り壊せる"},"とりさげる":{"variants":"とりさげる/取り下げる/取下げる"},"取り下げる":{"variants":"とりさげる/取り下げる/取下げる"},"取下げる":{"variants":"とりさげる/取り下げる/取下げる"},"とりさばく":{"variants":"とりさばく/取りさばく/取り捌く"},"取りさばく":{"variants":"とりさばく/取りさばく/取り捌く"},"取り捌く":{"variants":"とりさばく/取りさばく/取り捌く"},"とりさる":{"variants":"とりさる/取り去る/取去る"},"取り去る":{"variants":"とりさる/取り去る/取去る"},"取去る":{"variants":"とりさる/取り去る/取去る"},"とりされる":{"variants":"とりされる/取り去れる"},"取り去れる":{"variants":"とりされる/取り去れる"},"取り沙汰":{"variants":"取り沙汰/取沙汰"},"取沙汰":{"variants":"取り沙汰/取沙汰"},"とりざたす":{"variants":"とりざたす/取りざたす"},"取りざたす":{"variants":"とりざたす/取りざたす"},"とりしきる":{"variants":"とりしきる/取りしきる/取り仕切る/取仕切る"},"取りしきる":{"variants":"とりしきる/取りしきる/取り仕切る/取仕切る"},"取り仕切る":{"variants":"とりしきる/取りしきる/取り仕切る/取仕切る"},"取仕切る":{"variants":"とりしきる/取りしきる/取り仕切る/取仕切る"},"とりしきれる":{"variants":"とりしきれる/取り仕切れる"},"取り仕切れる":{"variants":"とりしきれる/取り仕切れる"},"とりしずめる":{"variants":"とりしずめる/取り鎮める/取鎮める"},"取り鎮める":{"variants":"とりしずめる/取り鎮める/取鎮める"},"取鎮める":{"variants":"とりしずめる/取り鎮める/取鎮める"},"取り締まり":{"variants":"取り締まり/取締り"},"取締り":{"variants":"取り締まり/取締り"},"とりしまる":{"variants":"とりしまる/取りしまる/取り締まる/取り締る"},"取りしまる":{"variants":"とりしまる/取りしまる/取り締まる/取り締る"},"取り締まる":{"variants":"とりしまる/取りしまる/取り締まる/取り締る"},"取り締る":{"variants":"とりしまる/取りしまる/取り締まる/取り締る"},"とりしまれる":{"variants":"とりしまれる/取り締まれる"},"取り締まれる":{"variants":"とりしまれる/取り締まれる"},"取り調べ":{"variants":"取り調べ/取調/取調べ"},"取調":{"variants":"取り調べ/取調/取調べ"},"取調べ":{"variants":"取り調べ/取調/取調べ"},"とりしらべる":{"variants":"とりしらべる/取り調べる/取調べる"},"取り調べる":{"variants":"とりしらべる/取り調べる/取調べる"},"取調べる":{"variants":"とりしらべる/取り調べる/取調べる"},"とりすがる":{"variants":"とりすがる/取りすがる/取り縋る"},"取りすがる":{"variants":"とりすがる/取りすがる/取り縋る"},"取り縋る":{"variants":"とりすがる/取りすがる/取り縋る"},"とりすてる":{"variants":"とりすてる/取り捨てる/取捨てる"},"取り捨てる":{"variants":"とりすてる/取り捨てる/取捨てる"},"取捨てる":{"variants":"とりすてる/取り捨てる/取捨てる"},"とりすます":{"variants":"とりすます/取り澄ます/取澄ます"},"取り澄ます":{"variants":"とりすます/取り澄ます/取澄ます"},"取澄ます":{"variants":"とりすます/取り澄ます/取澄ます"},"とりそろう":{"variants":"とりそろう/取り揃う"},"取り揃う":{"variants":"とりそろう/取り揃う"},"とりそろえる":{"variants":"とりそろえる/取りそろえる/取り揃える/取揃える"},"取りそろえる":{"variants":"とりそろえる/取りそろえる/取り揃える/取揃える"},"取り揃える":{"variants":"とりそろえる/取りそろえる/取り揃える/取揃える"},"取揃える":{"variants":"とりそろえる/取りそろえる/取り揃える/取揃える"},"取りたて":{"variants":"取りたて/取り立て/取立/取立て"},"取り立て":{"variants":"取りたて/取り立て/取立/取立て"},"取立":{"variants":"取りたて/取り立て/取立/取立て"},"取立て":{"variants":"取りたて/取り立て/取立/取立て"},"とりたてる":{"variants":"とりたてる/取り立てる/取立てる"},"取り立てる":{"variants":"とりたてる/取り立てる/取立てる"},"取立てる":{"variants":"とりたてる/取り立てる/取立てる"},"取り高":{"variants":"取り高/取高"},"取高":{"variants":"取り高/取高"},"取り出し":{"variants":"取り出し/取出し"},"取出し":{"variants":"取り出し/取出し"},"とりだす":{"variants":"とりだす/取りだす/取り出す/取出す"},"取りだす":{"variants":"とりだす/取りだす/取り出す/取出す"},"取り出す":{"variants":"とりだす/取りだす/取り出す/取出す"},"取出す":{"variants":"とりだす/取りだす/取り出す/取出す"},"とりだせる":{"variants":"とりだせる/取り出せる"},"取り出せる":{"variants":"とりだせる/取り出せる"},"とりちがえる":{"variants":"とりちがえる/取り違える/取違える"},"取り違える":{"variants":"とりちがえる/取り違える/取違える"},"取違える":{"variants":"とりちがえる/取り違える/取違える"},"とりちらす":{"variants":"とりちらす/取り散らす/取散らす"},"取り散らす":{"variants":"とりちらす/取り散らす/取散らす"},"取散らす":{"variants":"とりちらす/取り散らす/取散らす"},"取り付き":{"variants":"取り付き/取付き"},"取付き":{"variants":"取り付き/取付き"},"取り次ぎ":{"variants":"取り次ぎ/取次"},"取次":{"variants":"取り次ぎ/取次"},"とりつく":{"variants":"とりつく/取りつく/取り付く"},"取りつく":{"variants":"とりつく/取りつく/取り付く"},"取り付く":{"variants":"とりつく/取りつく/取り付く"},"とりつくろう":{"variants":"とりつくろう/取りつくろう/取り繕う/取繕う"},"取りつくろう":{"variants":"とりつくろう/取りつくろう/取り繕う/取繕う"},"取り繕う":{"variants":"とりつくろう/取りつくろう/取り繕う/取繕う"},"取繕う":{"variants":"とりつくろう/取りつくろう/取り繕う/取繕う"},"とりつぐ":{"variants":"とりつぐ/取りつぐ/取り次ぐ/取次ぐ"},"取りつぐ":{"variants":"とりつぐ/取りつぐ/取り次ぐ/取次ぐ"},"取り次ぐ":{"variants":"とりつぐ/取りつぐ/取り次ぐ/取次ぐ"},"取次ぐ":{"variants":"とりつぐ/取りつぐ/取り次ぐ/取次ぐ"},"取り付け":{"variants":"取り付け/取付/取付け"},"取付":{"variants":"取り付け/取付/取付け"},"取付け":{"variants":"取り付け/取付/取付け"},"とりつける":{"variants":"とりつける/取りつける/取り付ける/取付ける"},"取りつける":{"variants":"とりつける/取りつける/取り付ける/取付ける"},"取り付ける":{"variants":"とりつける/取りつける/取り付ける/取付ける"},"取付ける":{"variants":"とりつける/取りつける/取り付ける/取付ける"},"とりつげる":{"variants":"とりつげる/取り次げる"},"取り次げる":{"variants":"とりつげる/取り次げる"},"とりで":{"variants":"とりで/砦"},"砦":{"variants":"とりで/砦"},"とりとめる":{"variants":"とりとめる/取りとめる/取り留める/取留める"},"取りとめる":{"variants":"とりとめる/取りとめる/取り留める/取留める"},"取り留める":{"variants":"とりとめる/取りとめる/取り留める/取留める"},"取留める":{"variants":"とりとめる/取りとめる/取り留める/取留める"},"取りどころ":{"variants":"取りどころ/取り所"},"取り所":{"variants":"取りどころ/取り所"},"とりなおす":{"variants":"とりなおす/取り直す/取直す"},"取り直す":{"variants":"とりなおす/取り直す/取直す"},"取直す":{"variants":"とりなおす/取り直す/取直す"},"とりなおせる":{"variants":"とりなおせる/取り直せる"},"取り直せる":{"variants":"とりなおせる/取り直せる"},"執り成し":{"variants":"執り成し/執成し"},"執成し":{"variants":"執り成し/執成し"},"とりなす":{"variants":"とりなす/とり成す/執り成す/執成す/取りなす"},"とり成す":{"variants":"とりなす/とり成す/執り成す/執成す/取りなす"},"執成す":{"variants":"とりなす/とり成す/執り成す/執成す"},"執り成す":{"variants":"とりなす/とり成す/執り成す/執成す"},"とりにがす":{"variants":"とりにがす/取り逃がす/取り逃す/取逃す"},"取り逃がす":{"variants":"とりにがす/取り逃がす/取り逃す/取逃す"},"取り逃す":{"variants":"とりにがす/取り逃がす/取り逃す/取逃す"},"取逃す":{"variants":"とりにがす/取り逃がす/取り逃す/取逃す"},"酉の市":{"variants":"酉の市/酉市"},"酉市":{"variants":"酉の市/酉市"},"とりのける":{"variants":"とりのける/取りのける"},"取りのける":{"variants":"とりのける/取りのける"},"とりのこす":{"variants":"とりのこす/取り残す"},"取り残す":{"variants":"とりのこす/取り残す"},"とりのぞく":{"variants":"とりのぞく/とり除く/取り除く"},"とり除く":{"variants":"とりのぞく/とり除く/取り除く"},"取り除く":{"variants":"とりのぞく/とり除く/取り除く"},"とりのぼせる":{"variants":"とりのぼせる/取り上せる/取上せる"},"取り上せる":{"variants":"とりのぼせる/取り上せる/取上せる"},"取上せる":{"variants":"とりのぼせる/取り上せる/取上せる"},"酉の待":{"variants":"酉の待/酉待"},"酉町":{"variants":"酉の町/酉町"},"酉の町":{"variants":"酉の町/酉町"},"酉待":{"variants":"酉の待/酉待"},"取り計らい":{"variants":"取り計らい/取計い"},"取計い":{"variants":"取り計らい/取計い"},"とりはからう":{"variants":"とりはからう/取りはからう/取り計らう/取計らう"},"取りはからう":{"variants":"とりはからう/取りはからう/取り計らう/取計らう"},"取り計らう":{"variants":"とりはからう/取りはからう/取り計らう/取計らう"},"取計らう":{"variants":"とりはからう/取りはからう/取り計らう/取計らう"},"とりはからえる":{"variants":"とりはからえる/取り計らえる"},"取り計らえる":{"variants":"とりはからえる/取り計らえる"},"とりはこぶ":{"variants":"とりはこぶ/取り運ぶ"},"取り運ぶ":{"variants":"とりはこぶ/取り運ぶ"},"とりはこべる":{"variants":"とりはこべる/取り運べる"},"取り運べる":{"variants":"とりはこべる/取り運べる"},"取り外し":{"variants":"取り外し/取外し"},"取外し":{"variants":"取り外し/取外し"},"とりはずす":{"variants":"とりはずす/取りはずす/取り外す/取外す"},"取りはずす":{"variants":"とりはずす/取りはずす/取り外す/取外す"},"取り外す":{"variants":"とりはずす/取りはずす/取り外す/取外す"},"取外す":{"variants":"とりはずす/取りはずす/取り外す/取外す"},"とりはずせる":{"variants":"とりはずせる/取り外せる"},"取り外せる":{"variants":"とりはずせる/取り外せる"},"とりはなす":{"variants":"とりはなす/取り離す/取離す"},"取り離す":{"variants":"とりはなす/取り離す/取離す"},"取離す":{"variants":"とりはなす/取り離す/取離す"},"とりはなせる":{"variants":"とりはなせる/取り離せる"},"取り離せる":{"variants":"とりはなせる/取り離せる"},"取り払い":{"variants":"取り払い/取払い"},"取払い":{"variants":"取り払い/取払い"},"とりはらう":{"variants":"とりはらう/取り払う/取払う"},"取り払う":{"variants":"とりはらう/取り払う/取払う"},"取払う":{"variants":"とりはらう/取り払う/取払う"},"取り灰":{"variants":"取り灰/取灰"},"取灰":{"variants":"取り灰/取灰"},"取り引":{"variants":"取り引/取り引き/取引"},"取り引き":{"variants":"取り引/取り引き/取引"},"取引":{"variants":"取り引/取り引き/取引"},"とりひしぐ":{"variants":"とりひしぐ/取り拉ぐ"},"取り拉ぐ":{"variants":"とりひしぐ/取り拉ぐ"},"とりひろげる":{"variants":"とりひろげる/取り広げる/取広げる"},"取り広げる":{"variants":"とりひろげる/取り広げる/取広げる"},"取広げる":{"variants":"とりひろげる/取り広げる/取広げる"},"取り分":{"variants":"取り分/取分"},"取分":{"variants":"取り分/取分"},"取り前":{"variants":"取り前/取前"},"取前":{"variants":"取り前/取前"},"取り巻き":{"variants":"取り巻き/取巻き"},"取巻き":{"variants":"取り巻き/取巻き"},"とりまぎれる":{"variants":"とりまぎれる/取り紛れる/取紛れる"},"取り紛れる":{"variants":"とりまぎれる/取り紛れる/取紛れる"},"取紛れる":{"variants":"とりまぎれる/取り紛れる/取紛れる"},"とりまく":{"variants":"とりまく/取りまく/取り巻く/取巻く"},"取りまく":{"variants":"とりまく/取りまく/取り巻く/取巻く"},"取り巻く":{"variants":"とりまく/取りまく/取り巻く/取巻く"},"取巻く":{"variants":"とりまく/取りまく/取り巻く/取巻く"},"とりまける":{"variants":"とりまける/取り巻ける"},"取り巻ける":{"variants":"とりまける/取り巻ける"},"とりまぜる":{"variants":"とりまぜる/取り混ぜる/取混ぜる"},"取り混ぜる":{"variants":"とりまぜる/取り混ぜる/取混ぜる"},"取混ぜる":{"variants":"とりまぜる/取り混ぜる/取混ぜる"},"とりまとめ":{"variants":"とりまとめ/取りまとめ"},"取りまとめ":{"variants":"とりまとめ/取りまとめ"},"とりまとめる":{"variants":"とりまとめる/取りまとめる/取り纏める"},"取りまとめる":{"variants":"とりまとめる/取りまとめる/取り纏める"},"取り纏める":{"variants":"とりまとめる/取りまとめる/取り纏める"},"とりまわす":{"variants":"とりまわす/取りまわす/取り回す/取り廻す/取回す/取廻す"},"取りまわす":{"variants":"とりまわす/取りまわす/取り回す/取り廻す/取回す/取廻す"},"取り回す":{"variants":"とりまわす/取りまわす/取り回す/取回す"},"取回す":{"variants":"とりまわす/取りまわす/取り回す/取回す"},"取り廻す":{"variants":"とりまわす/取りまわす/取り廻す/取廻す"},"取廻す":{"variants":"とりまわす/取りまわす/取り廻す/取廻す"},"とりみだす":{"variants":"とりみだす/取り乱す/取乱す"},"取り乱す":{"variants":"とりみだす/取り乱す/取乱す"},"取乱す":{"variants":"とりみだす/取り乱す/取乱す"},"とりむすぶ":{"variants":"とりむすぶ/取り結ぶ/取結ぶ"},"取り結ぶ":{"variants":"とりむすぶ/取り結ぶ/取結ぶ"},"取結ぶ":{"variants":"とりむすぶ/取り結ぶ/取結ぶ"},"とりむすべる":{"variants":"とりむすべる/取り結べる"},"取り結べる":{"variants":"とりむすべる/取り結べる"},"鳥黐":{"variants":"鳥もち/鳥黐"},"鳥もち":{"variants":"鳥もち/鳥黐"},"とりもつ":{"variants":"とりもつ/取もつ/取りもつ/取り持つ/取持つ"},"取もつ":{"variants":"とりもつ/取もつ/取りもつ/取り持つ/取持つ"},"取りもつ":{"variants":"とりもつ/取もつ/取りもつ/取り持つ/取持つ"},"取り持つ":{"variants":"とりもつ/取もつ/取りもつ/取り持つ/取持つ"},"取持つ":{"variants":"とりもつ/取もつ/取りもつ/取り持つ/取持つ"},"とりもてる":{"variants":"とりもてる/取りもてる/取り持てる"},"取りもてる":{"variants":"とりもてる/取りもてる/取り持てる"},"取り持てる":{"variants":"とりもてる/取りもてる/取り持てる"},"とりもどす":{"variants":"とりもどす/取り戻す/取戻す"},"取り戻す":{"variants":"とりもどす/取り戻す/取戻す"},"取戻す":{"variants":"とりもどす/取り戻す/取戻す"},"とりもどせる":{"variants":"とりもどせる/取り戻せる"},"取り戻せる":{"variants":"とりもどせる/取り戻せる"},"とりやめる":{"variants":"とりやめる/取りやめる/取止める"},"取りやめる":{"variants":"とりやめる/取りやめる/取止める"},"取止める":{"variants":"とりやめる/取りやめる/取止める"},"とりよせる":{"variants":"とりよせる/取り寄せる/取寄せる"},"取り寄せる":{"variants":"とりよせる/取り寄せる/取寄せる"},"取寄せる":{"variants":"とりよせる/取り寄せる/取寄せる"},"とりわけ":{"variants":"とりわけ/取り分け/取分け"},"取り分け":{"variants":"とりわけ/取り分け/取分け"},"取分け":{"variants":"とりわけ/取り分け/取分け"},"とりわける":{"variants":"とりわける/取り分ける/取分ける"},"取り分ける":{"variants":"とりわける/取り分ける/取分ける"},"取分ける":{"variants":"とりわける/取り分ける/取分ける"},"とる":{"variants":"とる/採る/撮る/執る/取る/盗る/捕る"},"トルコぶろ":{"variants":"トルコぶろ/トルコ風呂"},"トルコ風呂":{"variants":"トルコぶろ/トルコ風呂"},"トレード・マーク":{"variants":"トレード・マーク/トレードマーク"},"トレードマーク":{"variants":"トレード・マーク/トレードマーク"},"とれる":{"variants":"とれる/採れる/撮れる/取れる/捕れる"},"とろかす":{"variants":"とろかす/蕩かす"},"蕩かす":{"variants":"とろかす/蕩かす"},"とろける":{"variants":"とろける/蕩ける"},"蕩ける":{"variants":"とろける/蕩ける"},"とろり":{"variants":"とろり/トロリ"},"トロリ":{"variants":"とろり/トロリ"},"トロロイモ":{"variants":"トロロイモ/薯蕷芋"},"薯蕷芋":{"variants":"トロロイモ/薯蕷芋"},"とわず語り":{"variants":"とわず語り/問わずがたり/問わず語り"},"問わずがたり":{"variants":"とわず語り/問わずがたり/問わず語り"},"問わず語り":{"variants":"とわず語り/問わずがたり/問わず語り"},"トン":{"variants":"ｔ/トン/噸"},"噸":{"variants":"ｔ/トン/噸"},"ｔ":{"variants":"ｔ/トン/噸"},"トンカツ":{"variants":"トンカツ/豚カツ"},"豚カツ":{"variants":"トンカツ/豚カツ"},"トングム":{"variants":"トングム/通禁"},"通禁":{"variants":"トングム/通禁"},"とん挫":{"variants":"とん挫/頓挫"},"頓挫":{"variants":"とん挫/頓挫"},"とん汁":{"variants":"とん汁/豚汁"},"豚汁":{"variants":"とん汁/豚汁"},"とん走":{"variants":"とん走/遁走"},"遁走":{"variants":"とん走/遁走"},"とんちんかん":{"variants":"とんちんかん/頓珍漢"},"頓珍漢":{"variants":"とんちんかん/頓珍漢"},"とんとん拍子":{"variants":"とんとん拍子/トントン拍子"},"トントン拍子":{"variants":"とんとん拍子/トントン拍子"},"トンボ":{"variants":"トンボ/蜻蛉"},"蜻蛉":{"variants":"トンボ/蜻蛉"},"ど":{"variants":"ど/ド"},"ド":{"variants":"ど/ド"},"度合":{"variants":"度合/度合い"},"度合い":{"variants":"度合/度合い"},"ドウガメ":{"variants":"ドウガメ/胴龜"},"胴龜":{"variants":"ドウガメ/胴龜"},"洞くつ":{"variants":"洞くつ/洞窟"},"洞窟":{"variants":"洞くつ/洞窟"},"道具立":{"variants":"道具立/道具立て"},"道具立て":{"variants":"道具立/道具立て"},"どうける":{"variants":"どうける/道ける/道化ける"},"道ける":{"variants":"どうける/道ける/道化ける"},"道化ける":{"variants":"どうける/道ける/道化ける"},"同士打":{"variants":"同士打/同士打ち"},"同士打ち":{"variants":"同士打/同士打ち"},"どうじる":{"variants":"どうじる/動じる/同じる"},"どうずる":{"variants":"どうずる/動ずる/同ずる"},"同せい":{"variants":"同せい/同棲"},"同棲":{"variants":"同せい/同棲"},"銅たく":{"variants":"銅たく/銅鐸"},"銅鐸":{"variants":"銅たく/銅鐸"},"ドウダンツツジ":{"variants":"ドウダンツツジ/満天星"},"満天星":{"variants":"ドウダンツツジ/満天星"},"どうどう":{"variants":"どうどう/堂々/堂堂"},"堂々":{"variants":"堂々/堂堂"},"堂堂":{"variants":"堂々/堂堂"},"堂々めぐり":{"variants":"堂々めぐり/堂々回り/堂々巡り/堂堂回り/堂堂巡り"},"堂々巡り":{"variants":"堂々めぐり/堂々巡り/堂堂巡り"},"堂堂回り":{"variants":"堂々めぐり/堂々回り/堂堂回り"},"堂々回り":{"variants":"堂々めぐり/堂々回り/堂堂回り"},"堂堂巡り":{"variants":"堂々めぐり/堂々巡り/堂堂巡り"},"胴巻":{"variants":"胴巻/胴巻き"},"胴巻き":{"variants":"胴巻/胴巻き"},"胴まわり":{"variants":"胴まわり/胴回り/胴廻り"},"どう猛":{"variants":"どう猛/獰猛"},"獰猛":{"variants":"どう猛/獰猛"},"どおり":{"variants":"どおり/通/通り"},"どかす":{"variants":"どかす/退かす"},"退かす":{"variants":"どかす/退かす"},"ドカン":{"variants":"ドカン/土管"},"土管":{"variants":"ドカン/土管"},"ドクガ":{"variants":"ドクガ/毒牙/毒蛾"},"どくする":{"variants":"どくする/毒する"},"毒する":{"variants":"どくする/毒する"},"どくづく":{"variants":"どくづく/毒づく"},"毒づく":{"variants":"どくづく/毒づく"},"どくどくしい":{"variants":"どくどくしい/毒々しい/毒毒しい"},"毒々しい":{"variants":"どくどくしい/毒々しい/毒毒しい"},"毒毒しい":{"variants":"どくどくしい/毒々しい/毒毒しい"},"どしがたい":{"variants":"どしがたい/度しがたい/度し難い/度難い"},"度しがたい":{"variants":"どしがたい/度しがたい/度し難い/度難い"},"度し難い":{"variants":"どしがたい/度しがたい/度し難い/度難い"},"度難い":{"variants":"どしがたい/度しがたい/度し難い/度難い"},"どしゃ降り":{"variants":"どしゃ降り/土砂降り"},"土砂降り":{"variants":"どしゃ降り/土砂降り"},"ドジョウ":{"variants":"ドジョウ/泥鰌/土壌/鯲/鰌"},"ドジョウインゲン":{"variants":"ドジョウインゲン/泥鰌隠元"},"泥鰌隠元":{"variants":"ドジョウインゲン/泥鰌隠元"},"どすぐろい":{"variants":"どすぐろい/どす黒い"},"どす黒い":{"variants":"どすぐろい/どす黒い"},"どすんと":{"variants":"どすんと/ドスンと"},"ドスンと":{"variants":"どすんと/ドスンと"},"どだい":{"variants":"どだい/土台"},"土台":{"variants":"どだい/土台"},"どっしり":{"variants":"どっしり/ドッシリ"},"ドッシリ":{"variants":"どっしり/ドッシリ"},"どっちみち":{"variants":"どっちみち/どっち道"},"どっち道":{"variants":"どっちみち/どっち道"},"土手っ腹":{"variants":"土手っ腹/土手腹"},"土手腹":{"variants":"土手っ腹/土手腹"},"怒とう":{"variants":"怒とう/怒涛"},"怒涛":{"variants":"怒とう/怒涛"},"呶々":{"variants":"呶々/呶呶"},"呶呶":{"variants":"呶々/呶呶"},"都々逸":{"variants":"都々逸/都都逸"},"都都逸":{"variants":"都々逸/都都逸"},"土なべ":{"variants":"土なべ/土鍋"},"土鍋":{"variants":"土なべ/土鍋"},"どなりこむ":{"variants":"どなりこむ/怒鳴り込む"},"怒鳴り込む":{"variants":"どなりこむ/怒鳴り込む"},"どなりつける":{"variants":"どなりつける/怒鳴りつける"},"怒鳴りつける":{"variants":"どなりつける/怒鳴りつける"},"どなる":{"variants":"どなる/怒鳴る"},"怒鳴る":{"variants":"どなる/怒鳴る"},"どの":{"variants":"どの/殿"},"殿":{"variants":"どの/殿"},"土のう":{"variants":"土のう/土嚢"},"土嚢":{"variants":"土のう/土嚢"},"どのみち":{"variants":"どのみち/どの道"},"どの道":{"variants":"どのみち/どの道"},"ドバト":{"variants":"ドバト/土鳩/鴿"},"土俵入":{"variants":"土俵入/土俵入り"},"土俵入り":{"variants":"土俵入/土俵入り"},"ドブネズミ":{"variants":"ドブネズミ/溝鼠"},"溝鼠":{"variants":"ドブネズミ/溝鼠"},"どぶろく":{"variants":"どぶろく/獨酒"},"獨酒":{"variants":"どぶろく/獨酒"},"どまり":{"variants":"どまり/止まり"},"止まり":{"variants":"どまり/止まり"},"どもる":{"variants":"どもる/吃る"},"吃る":{"variants":"どもる/吃る"},"ドル":{"variants":"ドル/弗"},"弗":{"variants":"ドル/弗"},"どろくさい":{"variants":"どろくさい/泥くさい/泥臭い"},"泥くさい":{"variants":"どろくさい/泥くさい/泥臭い"},"泥臭い":{"variants":"どろくさい/泥くさい/泥臭い"},"どろどろ":{"variants":"どろどろ/ドロドロ"},"ドロドロ":{"variants":"どろどろ/ドロドロ"},"ドロノキ":{"variants":"ドロノキ/白楊"},"白楊":{"variants":"ドロノキ/白楊"},"どろぶかい":{"variants":"どろぶかい/泥深い"},"泥深い":{"variants":"どろぶかい/泥深い"},"泥まみれ":{"variants":"泥まみれ/泥塗れ"},"泥塗れ":{"variants":"泥まみれ/泥塗れ"},"どろんこ":{"variants":"どろんこ/泥んこ"},"泥んこ":{"variants":"どろんこ/泥んこ"},"どん":{"variants":"どん/ドン"},"ドン":{"variants":"どん/ドン"},"ドングリ":{"variants":"ドングリ/団栗"},"団栗":{"variants":"ドングリ/団栗"},"どんする":{"variants":"どんする/鈍する"},"鈍する":{"variants":"どんする/鈍する"},"どん底":{"variants":"どん底/ドン底"},"ドン底":{"variants":"どん底/ドン底"},"どんちょう":{"variants":"どんちょう/緞帳"},"緞帳":{"variants":"どんちょう/緞帳"},"どんどん":{"variants":"どんどん/ドンドン"},"ドンドン":{"variants":"どんどん/ドンドン"},"どんぶり":{"variants":"どんぶり/丼"},"丼":{"variants":"どんぶり/丼"},"どんぶり勘定":{"variants":"どんぶり勘定/丼勘定"},"丼勘定":{"variants":"どんぶり勘定/丼勘定"},"どん欲":{"variants":"どん欲/貪欲"},"貪欲":{"variants":"どん欲/貪欲"},"な":{"variants":"な/ナ"},"ナ":{"variants":"な/ナ"},"なぁ":{"variants":"なぁ/なァ"},"なァ":{"variants":"なぁ/なァ"},"なあなあ":{"variants":"なあなあ/ナアナア"},"ナアナア":{"variants":"なあなあ/ナアナア"},"ない":{"variants":"ない/無い"},"無い":{"variants":"ない/無い"},"ないがしろ":{"variants":"ないがしろ/蔑ろ"},"蔑ろ":{"variants":"ないがしろ/蔑ろ"},"ないし":{"variants":"ないし/乃至"},"乃至":{"variants":"ないし/乃至"},"ないしょ":{"variants":"ないしょ/内所/内緒"},"ないない":{"variants":"ないない/内々/内内"},"ないまぜる":{"variants":"ないまぜる/綯い交ぜる"},"綯い交ぜる":{"variants":"ないまぜる/綯い交ぜる"},"ないものねだり":{"variants":"ないものねだり/無いものねだり/無い物ねだり"},"無いものねだり":{"variants":"ないものねだり/無いものねだり/無い物ねだり"},"無い物ねだり":{"variants":"ないものねだり/無いものねだり/無い物ねだり"},"なう":{"variants":"なう/綯う"},"綯う":{"variants":"なう/綯う"},"なえる":{"variants":"なえる/萎える"},"萎える":{"variants":"なえる/萎える"},"なお":{"variants":"なお/尚/猶"},"尚":{"variants":"なお/尚"},"尚さら":{"variants":"尚さら/尚更"},"尚更":{"variants":"尚さら/尚更"},"なおす":{"variants":"なおす/直す"},"直す":{"variants":"なおす/直す"},"なおせる":{"variants":"なおせる/治せる/直せる"},"なおなお":{"variants":"なおなお/尚々/尚尚/猶々/猶猶"},"猶々":{"variants":"なおなお/猶々/猶猶"},"尚々":{"variants":"なおなお/尚々/尚尚"},"猶猶":{"variants":"なおなお/猶々/猶猶"},"尚尚":{"variants":"なおなお/尚々/尚尚"},"尚々書":{"variants":"尚々書/尚尚書"},"尚尚書":{"variants":"尚々書/尚尚書"},"なおも":{"variants":"なおも/尚も/猶も"},"なおる":{"variants":"なおる/治る/直る"},"なか":{"variants":"なか/中"},"仲":{"variants":"なか/仲"},"中":{"variants":"なか/中"},"中入":{"variants":"中入/中入り"},"中入り":{"variants":"中入/中入り"},"中おち":{"variants":"中おち/中落ち"},"中落ち":{"variants":"中おち/中落ち"},"中ぎり":{"variants":"中ぎり/中限"},"中限":{"variants":"中ぎり/中限"},"中ごろ":{"variants":"中ごろ/中頃"},"中頃":{"variants":"中ごろ/中頃"},"なかす":{"variants":"なかす/泣かす/鳴かす"},"なかせる":{"variants":"なかせる/泣かせる/鳴かせる"},"仲たがい":{"variants":"仲たがい/仲違い"},"仲違い":{"variants":"仲たがい/仲違い"},"なかだち":{"variants":"なかだち/仲立/媒"},"なかでも":{"variants":"なかでも/中でも"},"中でも":{"variants":"なかでも/中でも"},"なかば":{"variants":"なかば/半ば"},"半ば":{"variants":"なかば/半ば"},"仲間はずれ":{"variants":"仲間はずれ/仲間外れ"},"仲間外れ":{"variants":"仲間はずれ/仲間外れ"},"中休":{"variants":"中休/中休み"},"中休み":{"variants":"中休/中休み"},"なかよい":{"variants":"なかよい/仲良い"},"仲良い":{"variants":"なかよい/仲良い"},"仲よく":{"variants":"仲よく/仲良く"},"仲良く":{"variants":"仲よく/仲良く"},"なかよし":{"variants":"なかよし/仲よし/仲好し/仲良し"},"仲よし":{"variants":"なかよし/仲よし/仲好し/仲良し"},"ながい":{"variants":"ながい/永い/長い"},"ナガイモ":{"variants":"ナガイモ/長芋/長薯"},"ナガオドリ":{"variants":"ナガオドリ/長尾鶏"},"長尾鶏":{"variants":"ナガオドリ/長尾鶏"},"ながしいれる":{"variants":"ながしいれる/流し入れる"},"流し入れる":{"variants":"ながしいれる/流し入れる"},"ながしこむ":{"variants":"ながしこむ/流し込む"},"流し込む":{"variants":"ながしこむ/流し込む"},"ながしこめる":{"variants":"ながしこめる/流し込める"},"流し込める":{"variants":"ながしこめる/流し込める"},"ながす":{"variants":"ながす/流す"},"流す":{"variants":"ながす/流す"},"ナガスクジラ":{"variants":"ナガスクジラ/長須鯨"},"長須鯨":{"variants":"ナガスクジラ/長須鯨"},"ながせる":{"variants":"ながせる/流せる"},"流せる":{"variants":"ながせる/流せる"},"長そで":{"variants":"長そで/長袖"},"長袖":{"variants":"長そで/長袖"},"ながたらしい":{"variants":"ながたらしい/長たらしい"},"長たらしい":{"variants":"ながたらしい/長たらしい"},"ながなが":{"variants":"ながなが/長々/長長"},"長々":{"variants":"ながなが/長々/長長"},"長長":{"variants":"ながなが/長々/長長"},"長ばかま":{"variants":"長ばかま/長袴"},"長袴":{"variants":"長ばかま/長袴"},"ながびく":{"variants":"ながびく/長びく/長引く"},"長びく":{"variants":"ながびく/長びく/長引く"},"長引く":{"variants":"ながびく/長びく/長引く"},"ながめる":{"variants":"ながめる/眺める"},"眺める":{"variants":"ながめる/眺める"},"長もち":{"variants":"長もち/長持ち"},"長持ち":{"variants":"長もち/長持ち"},"ながらえる":{"variants":"ながらえる/永らえる/存える/長らえる"},"ながらく":{"variants":"ながらく/永らく/長らく"},"ながれあるく":{"variants":"ながれあるく/流れ歩く"},"流れ歩く":{"variants":"ながれあるく/流れ歩く"},"ながれおちる":{"variants":"ながれおちる/流れ落ちる"},"流れ落ちる":{"variants":"ながれおちる/流れ落ちる"},"ながれこむ":{"variants":"ながれこむ/流れ込む"},"流れ込む":{"variants":"ながれこむ/流れ込む"},"ながれだす":{"variants":"ながれだす/流れ出す"},"流れ出す":{"variants":"ながれだす/流れ出す"},"流れ弾":{"variants":"流れ弾/流弾"},"流弾":{"variants":"流れ弾/流弾"},"ながれつく":{"variants":"ながれつく/流れ着く"},"流れ着く":{"variants":"ながれつく/流れ着く"},"ながれつける":{"variants":"ながれつける/流れ着ける"},"流れ着ける":{"variants":"ながれつける/流れ着ける"},"ながれでる":{"variants":"ながれでる/流れ出る"},"流れ出る":{"variants":"ながれでる/流れ出る"},"ながれる":{"variants":"ながれる/流る/流れる"},"流る":{"variants":"ながれる/流る/流れる"},"流れる":{"variants":"ながれる/流る/流れる"},"なきあかす":{"variants":"なきあかす/泣き明かす/泣明かす"},"泣き明かす":{"variants":"なきあかす/泣き明かす/泣明かす"},"泣明かす":{"variants":"なきあかす/泣き明かす/泣明かす"},"泣き女":{"variants":"泣き女/泣女"},"泣女":{"variants":"泣き女/泣女"},"泣き顔":{"variants":"泣き顔/泣顔"},"泣顔":{"variants":"泣き顔/泣顔"},"亡き骸":{"variants":"亡き骸/亡骸"},"亡骸":{"variants":"亡き骸/亡骸"},"なきくずれる":{"variants":"なきくずれる/泣き崩れる/泣崩れる"},"泣き崩れる":{"variants":"なきくずれる/泣き崩れる/泣崩れる"},"泣崩れる":{"variants":"なきくずれる/泣き崩れる/泣崩れる"},"なきくらす":{"variants":"なきくらす/泣き暮す"},"泣き暮す":{"variants":"なきくらす/泣き暮す"},"なきこむ":{"variants":"なきこむ/泣き込む/泣込む"},"泣き込む":{"variants":"なきこむ/泣き込む/泣込む"},"泣込む":{"variants":"なきこむ/泣き込む/泣込む"},"なき声":{"variants":"なき声/泣き声/鳴き声"},"泣きごと":{"variants":"泣きごと/泣き言/泣言"},"泣き言":{"variants":"泣きごと/泣き言/泣言"},"泣言":{"variants":"泣きごと/泣き言/泣言"},"なきさけぶ":{"variants":"なきさけぶ/泣き叫ぶ"},"泣き叫ぶ":{"variants":"なきさけぶ/泣き叫ぶ"},"なきしきる":{"variants":"なきしきる/鳴きしきる/鳴き頻る"},"鳴きしきる":{"variants":"なきしきる/鳴きしきる/鳴き頻る"},"鳴き頻る":{"variants":"なきしきる/鳴きしきる/鳴き頻る"},"なきしずむ":{"variants":"なきしずむ/泣き沈む/泣沈む"},"泣き沈む":{"variants":"なきしずむ/泣き沈む/泣沈む"},"泣沈む":{"variants":"なきしずむ/泣き沈む/泣沈む"},"なきじゃくる":{"variants":"なきじゃくる/泣きじゃくる"},"泣きじゃくる":{"variants":"なきじゃくる/泣きじゃくる"},"なきつく":{"variants":"なきつく/泣きつく/泣き付く/泣付く"},"泣きつく":{"variants":"なきつく/泣きつく/泣き付く/泣付く"},"泣き付く":{"variants":"なきつく/泣きつく/泣き付く/泣付く"},"泣付く":{"variants":"なきつく/泣きつく/泣き付く/泣付く"},"泣きどころ":{"variants":"泣きどころ/泣き所"},"泣き所":{"variants":"泣きどころ/泣き所"},"なきぬれる":{"variants":"なきぬれる/泣きぬれる/泣き濡れる/泣濡れる"},"泣きぬれる":{"variants":"なきぬれる/泣きぬれる/泣き濡れる/泣濡れる"},"泣き濡れる":{"variants":"なきぬれる/泣きぬれる/泣き濡れる/泣濡れる"},"泣濡れる":{"variants":"なきぬれる/泣きぬれる/泣き濡れる/泣濡れる"},"なきはらす":{"variants":"なきはらす/泣きはらす/泣き腫らす/泣腫らす"},"泣きはらす":{"variants":"なきはらす/泣きはらす/泣き腫らす/泣腫らす"},"泣き腫らす":{"variants":"なきはらす/泣きはらす/泣き腫らす/泣腫らす"},"泣腫らす":{"variants":"なきはらす/泣きはらす/泣き腫らす/泣腫らす"},"なきふす":{"variants":"なきふす/泣き伏す"},"泣き伏す":{"variants":"なきふす/泣き伏す"},"なきふせる":{"variants":"なきふせる/泣き伏せる"},"泣き伏せる":{"variants":"なきふせる/泣き伏せる"},"なき虫":{"variants":"なき虫/泣き虫/鳴き虫"},"泣き寄り":{"variants":"泣き寄り/泣寄り"},"泣寄り":{"variants":"泣き寄り/泣寄り"},"泣き別れ":{"variants":"泣き別れ/泣別れ"},"泣別れ":{"variants":"泣き別れ/泣別れ"},"なきわめく":{"variants":"なきわめく/泣きわめく"},"泣きわめく":{"variants":"なきわめく/泣きわめく"},"ナギ":{"variants":"ナギ/竹柏/凪/薙/梛"},"なぎたおす":{"variants":"なぎたおす/なぎ倒す/薙ぎ倒す"},"なぎ倒す":{"variants":"なぎたおす/なぎ倒す/薙ぎ倒す"},"薙ぎ倒す":{"variants":"なぎたおす/なぎ倒す/薙ぎ倒す"},"ナギナタホオズキ":{"variants":"ナギナタホオズキ/長刀酸漿/薙刀酸漿"},"なぎはらう":{"variants":"なぎはらう/なぎ払う/薙ぎ払う"},"なぎ払う":{"variants":"なぎはらう/なぎ払う/薙ぎ払う"},"薙ぎ払う":{"variants":"なぎはらう/なぎ払う/薙ぎ払う"},"なぎふせる":{"variants":"なぎふせる/薙ぎ伏せる"},"薙ぎ伏せる":{"variants":"なぎふせる/薙ぎ伏せる"},"なく":{"variants":"なく/泣く/鳴く/哭く/啼く"},"なくす":{"variants":"なくす/亡くす/無くす"},"なくする":{"variants":"なくする/亡くする/無くする"},"なくなす":{"variants":"なくなす/亡くなす/無くなす"},"なくなる":{"variants":"なくなる/失くなる/亡くなる/無くなる"},"なぐ":{"variants":"なぐ/凪ぐ/薙ぐ/和ぐ"},"慰みもの":{"variants":"慰みもの/慰み物"},"慰み物":{"variants":"慰みもの/慰み物"},"なぐさむ":{"variants":"なぐさむ/慰む"},"慰む":{"variants":"なぐさむ/慰む"},"なぐさめる":{"variants":"なぐさめる/慰める"},"慰める":{"variants":"なぐさめる/慰める"},"なぐり込み":{"variants":"なぐり込み/殴り込み"},"殴り込み":{"variants":"なぐり込み/殴り込み"},"なぐりつける":{"variants":"なぐりつける/殴りつける/殴り付ける/撲りつける/撲り付ける"},"殴りつける":{"variants":"なぐりつける/殴りつける/殴り付ける"},"撲りつける":{"variants":"なぐりつける/撲りつける/撲り付ける"},"殴り付ける":{"variants":"なぐりつける/殴りつける/殴り付ける"},"撲り付ける":{"variants":"なぐりつける/撲りつける/撲り付ける"},"なぐりとばす":{"variants":"なぐりとばす/殴りとばす/殴り飛ばす/撲りとばす/撲り飛ばす"},"殴り飛ばす":{"variants":"なぐりとばす/殴りとばす/殴り飛ばす"},"殴りとばす":{"variants":"なぐりとばす/殴りとばす/殴り飛ばす"},"撲り飛ばす":{"variants":"なぐりとばす/撲りとばす/撲り飛ばす"},"撲りとばす":{"variants":"なぐりとばす/撲りとばす/撲り飛ばす"},"なぐる":{"variants":"なぐる/殴る/撲る"},"なぐれる":{"variants":"なぐれる/殴れる"},"殴れる":{"variants":"なぐれる/殴れる"},"なける":{"variants":"なける/泣ける/鳴ける"},"投げ入れ":{"variants":"投げ入れ/投入れ"},"投入れ":{"variants":"投げ入れ/投入れ"},"なげいれる":{"variants":"なげいれる/投げ入れる"},"投げ入れる":{"variants":"なげいれる/投げ入れる"},"なげうつ":{"variants":"なげうつ/抛つつ/擲つ"},"投げ売り":{"variants":"投げ売り/投売"},"投売":{"variants":"投げ売り/投売"},"なげかける":{"variants":"なげかける/投げかける/投げ掛ける"},"投げかける":{"variants":"なげかける/投げかける/投げ掛ける"},"投げ掛ける":{"variants":"なげかける/投げかける/投げ掛ける"},"なげかつ":{"variants":"なげかつ/投げ勝つ"},"投げ勝つ":{"variants":"なげかつ/投げ勝つ"},"なげかてる":{"variants":"なげかてる/投げ勝てる"},"投げ勝てる":{"variants":"なげかてる/投げ勝てる"},"なげかわしい":{"variants":"なげかわしい/嘆かわしい"},"嘆かわしい":{"variants":"なげかわしい/嘆かわしい"},"なげきあかす":{"variants":"なげきあかす/嘆き明かす"},"嘆き明かす":{"variants":"なげきあかす/嘆き明かす"},"なげきくらす":{"variants":"なげきくらす/嘆き暮す"},"嘆き暮す":{"variants":"なげきくらす/嘆き暮す"},"なげく":{"variants":"なげく/嘆く"},"嘆く":{"variants":"なげく/嘆く"},"投げ首":{"variants":"投げ首/投首"},"投首":{"variants":"投げ首/投首"},"なげこむ":{"variants":"なげこむ/投げこむ/投げ込む"},"投げこむ":{"variants":"なげこむ/投げこむ/投げ込む"},"投げ込む":{"variants":"なげこむ/投げこむ/投げ込む"},"なげこめる":{"variants":"なげこめる/投げ込める"},"投げ込める":{"variants":"なげこめる/投げ込める"},"なげし":{"variants":"なげし/長押"},"長押":{"variants":"なげし/長押"},"なげすてる":{"variants":"なげすてる/投げ棄てる/投げ捨てる/投棄てる/投捨てる"},"投げ棄てる":{"variants":"なげすてる/投げ棄てる/投棄てる"},"投捨てる":{"variants":"なげすてる/投げ捨てる/投捨てる"},"投げ捨てる":{"variants":"なげすてる/投げ捨てる/投捨てる"},"投棄てる":{"variants":"なげすてる/投げ棄てる/投棄てる"},"投げ銭":{"variants":"投げ銭/投銭"},"投銭":{"variants":"投げ銭/投銭"},"なげだす":{"variants":"なげだす/投げだす/投げ出す/投出す"},"投げだす":{"variants":"なげだす/投げだす/投げ出す/投出す"},"投げ出す":{"variants":"なげだす/投げだす/投げ出す/投出す"},"投出す":{"variants":"なげだす/投げだす/投げ出す/投出す"},"なげだせる":{"variants":"なげだせる/投げ出せる"},"投げ出せる":{"variants":"なげだせる/投げ出せる"},"なげつける":{"variants":"なげつける/投げつける/投げ付ける/投付ける"},"投げつける":{"variants":"なげつける/投げつける/投げ付ける/投付ける"},"投げ付ける":{"variants":"なげつける/投げつける/投げ付ける/投付ける"},"投付ける":{"variants":"なげつける/投げつける/投げ付ける/投付ける"},"なげとばす":{"variants":"なげとばす/投げ飛ばす"},"投げ飛ばす":{"variants":"なげとばす/投げ飛ばす"},"なげとばせる":{"variants":"なげとばせる/投げ飛ばせる"},"投げ飛ばせる":{"variants":"なげとばせる/投げ飛ばせる"},"投げもの":{"variants":"投げもの/投げ物/投物"},"投げ物":{"variants":"投げもの/投げ物/投物"},"投物":{"variants":"投げもの/投げ物/投物"},"投げやり":{"variants":"投げやり/投げ遣り"},"投げ遣り":{"variants":"投げやり/投げ遣り"},"なげる":{"variants":"なげる/投げる"},"投げる":{"variants":"なげる/投げる"},"なごむ":{"variants":"なごむ/和む"},"和む":{"variants":"なごむ/和む"},"なごめる":{"variants":"なごめる/和める"},"和める":{"variants":"なごめる/和める"},"なごり":{"variants":"なごり/名ごり/名残/名残り"},"名ごり":{"variants":"なごり/名ごり/名残/名残り"},"名残":{"variants":"なごり/名ごり/名残/名残り"},"名残り":{"variants":"なごり/名ごり/名残/名残り"},"なごりおしい":{"variants":"なごりおしい/名残惜しい"},"名残惜しい":{"variants":"なごりおしい/名残惜しい"},"名残の月":{"variants":"名残の月/名残月"},"名残月":{"variants":"名残の月/名残月"},"なさけ":{"variants":"なさけ/情け"},"情け":{"variants":"なさけ/情け"},"なさけない":{"variants":"なさけない/情けない/情ない"},"情けない":{"variants":"なさけない/情けない/情ない"},"情ない":{"variants":"なさけない/情けない/情ない"},"なさけぶかい":{"variants":"なさけぶかい/情け深い/情深い"},"情け深い":{"variants":"なさけぶかい/情け深い/情深い"},"情深い":{"variants":"なさけぶかい/情け深い/情深い"},"なさぬ仲":{"variants":"なさぬ仲/生さぬ仲"},"生さぬ仲":{"variants":"なさぬ仲/生さぬ仲"},"なざす":{"variants":"なざす/名指す"},"名指す":{"variants":"なざす/名指す"},"なし":{"variants":"なし/無し"},"ナシ":{"variants":"なし/ナシ/梨"},"梨":{"variants":"なし/ナシ/梨"},"無し":{"variants":"なし/無し"},"ナシウリ":{"variants":"ナシウリ/梨瓜"},"梨瓜":{"variants":"ナシウリ/梨瓜"},"なしくずし":{"variants":"なしくずし/なし崩し/済し崩し"},"なし崩し":{"variants":"なしくずし/なし崩し/済し崩し"},"済し崩し":{"variants":"なしくずし/なし崩し/済し崩し"},"なしとげる":{"variants":"なしとげる/為し遂げる/成し遂げる"},"ナシのつぶて":{"variants":"ナシのつぶて/梨の礫"},"梨の礫":{"variants":"ナシのつぶて/梨の礫"},"なじみ":{"variants":"なじみ/馴染/馴染み"},"馴染":{"variants":"なじみ/馴染/馴染み"},"馴染み":{"variants":"なじみ/馴染/馴染み"},"なじむ":{"variants":"なじむ/馴染む"},"馴染む":{"variants":"なじむ/馴染む"},"なじめる":{"variants":"なじめる/馴染める"},"馴染める":{"variants":"なじめる/馴染める"},"なす":{"variants":"なす/為す/済す/成す/生す"},"ナス":{"variants":"ナス/茄"},"茄":{"variants":"ナス/茄"},"なすりつける":{"variants":"なすりつける/なすり付ける"},"なすり付ける":{"variants":"なすりつける/なすり付ける"},"ナズナ":{"variants":"ナズナ/薺"},"薺":{"variants":"ナズナ/薺"},"なずむ":{"variants":"なずむ/泥む"},"泥む":{"variants":"なずむ/泥む"},"なぜ":{"variants":"なぜ/何故"},"何故":{"variants":"なぜ/何故"},"なぜか":{"variants":"なぜか/何故か"},"何故か":{"variants":"なぜか/何故か"},"なぜる":{"variants":"なぜる/撫ぜる"},"撫ぜる":{"variants":"なぜる/撫ぜる"},"なぞ":{"variants":"なぞ/ナゾ/謎"},"何ぞ":{"variants":"なぞ/何ぞ"},"ナゾ":{"variants":"なぞ/ナゾ/謎"},"謎":{"variants":"なぞ/ナゾ/謎"},"なぞなぞ":{"variants":"なぞなぞ/謎々/謎謎"},"謎々":{"variants":"なぞなぞ/謎々/謎謎"},"謎謎":{"variants":"なぞなぞ/謎々/謎謎"},"なたね油":{"variants":"なたね油/菜種油"},"菜種油":{"variants":"なたね油/菜種油"},"ナタマメ":{"variants":"ナタマメ/鉈豆"},"鉈豆":{"variants":"ナタマメ/鉈豆"},"ナタマメギセル":{"variants":"ナタマメギセル/鉈豆煙管"},"鉈豆煙管":{"variants":"ナタマメギセル/鉈豆煙管"},"なだかい":{"variants":"なだかい/名高い"},"名高い":{"variants":"なだかい/名高い"},"なだめる":{"variants":"なだめる/宥める"},"宥める":{"variants":"なだめる/宥める"},"なだれこむ":{"variants":"なだれこむ/なだれ込む/雪崩込む"},"なだれ込む":{"variants":"なだれこむ/なだれ込む/雪崩込む"},"雪崩込む":{"variants":"なだれこむ/なだれ込む/雪崩込む"},"菜っぱ":{"variants":"菜っぱ/菜っ葉"},"菜っ葉":{"variants":"菜っぱ/菜っ葉"},"なつ印":{"variants":"なつ印/捺印"},"捺印":{"variants":"なつ印/捺印"},"なつかしい":{"variants":"なつかしい/懐かしい/懐しい"},"懐かしい":{"variants":"なつかしい/懐かしい/懐しい"},"懐しい":{"variants":"なつかしい/懐かしい/懐しい"},"なつかしむ":{"variants":"なつかしむ/懐かしむ"},"懐かしむ":{"variants":"なつかしむ/懐かしむ"},"なつける":{"variants":"なつける/懐ける"},"懐ける":{"variants":"なつける/懐ける"},"夏ばて":{"variants":"夏ばて/夏バテ"},"夏バテ":{"variants":"夏ばて/夏バテ"},"ナツミカン":{"variants":"ナツミカン/夏みかん/夏蜜柑"},"夏みかん":{"variants":"ナツミカン/夏みかん/夏蜜柑"},"夏蜜柑":{"variants":"ナツミカン/夏みかん/夏蜜柑"},"ナツメ":{"variants":"ナツメ/棗"},"棗":{"variants":"ナツメ/棗"},"なつめく":{"variants":"なつめく/夏めく"},"夏めく":{"variants":"なつめく/夏めく"},"ナツメヤシ":{"variants":"ナツメヤシ/棗椰子"},"棗椰子":{"variants":"ナツメヤシ/棗椰子"},"夏もの":{"variants":"夏もの/夏物"},"夏物":{"variants":"夏もの/夏物"},"夏やすみ":{"variants":"夏やすみ/夏休/夏休み"},"夏休":{"variants":"夏やすみ/夏休/夏休み"},"夏休み":{"variants":"夏やすみ/夏休/夏休み"},"夏やせ":{"variants":"夏やせ/夏痩せ"},"夏痩せ":{"variants":"夏やせ/夏痩せ"},"名付":{"variants":"名付/名付け"},"名付け":{"variants":"名付/名付け"},"名付け親":{"variants":"名付け親/名付親"},"名付親":{"variants":"名付け親/名付親"},"なづける":{"variants":"なづける/名づける/名付ける"},"名づける":{"variants":"なづける/名づける/名付ける"},"名付ける":{"variants":"なづける/名づける/名付ける"},"なであげる":{"variants":"なであげる/なで上げる"},"なで上げる":{"variants":"なであげる/なで上げる"},"なでおろす":{"variants":"なでおろす/なで下ろす"},"なで下ろす":{"variants":"なでおろす/なで下ろす"},"なで肩":{"variants":"なで肩/撫で肩"},"撫で肩":{"variants":"なで肩/撫で肩"},"撫斬り":{"variants":"なで斬り/撫で斬り/撫斬り"},"なで斬り":{"variants":"なで斬り/撫で斬り/撫斬り"},"撫で斬り":{"variants":"なで斬り/撫で斬り/撫斬り"},"ナデシコ":{"variants":"ナデシコ/撫子/瞿麦"},"なでつける":{"variants":"なでつける/撫でつける/撫で付ける"},"撫でつける":{"variants":"なでつける/撫でつける/撫で付ける"},"撫で付ける":{"variants":"なでつける/撫でつける/撫で付ける"},"なでる":{"variants":"なでる/撫でる"},"撫でる":{"variants":"なでる/撫でる"},"７":{"variants":"７/七"},"七":{"variants":"７/七"},"七色唐がらし":{"variants":"七色唐がらし/七色唐辛子"},"七色唐辛子":{"variants":"七色唐がらし/七色唐辛子"},"ナナカマド":{"variants":"ナナカマド/七竃"},"七竃":{"variants":"ナナカマド/七竃"},"七草粥":{"variants":"七草がゆ/七草粥"},"七草がゆ":{"variants":"七草がゆ/七草粥"},"７つ":{"variants":"７つ/七つ"},"七つ":{"variants":"７つ/七つ"},"七つ道具":{"variants":"七つ道具/七道具"},"七道具":{"variants":"七つ道具/七道具"},"七光":{"variants":"七光/七光り"},"七光り":{"variants":"七光/七光り"},"七ふしぎ":{"variants":"七ふしぎ/七不思議"},"七不思議":{"variants":"七ふしぎ/七不思議"},"ななめ":{"variants":"ななめ/斜め"},"斜め":{"variants":"ななめ/斜め"},"なにかと":{"variants":"なにかと/何かと/何彼と"},"何かと":{"variants":"なにかと/何かと/何彼と"},"何彼と":{"variants":"なにかと/何かと/何彼と"},"なにがな":{"variants":"なにがな/何がな"},"何がな":{"variants":"なにがな/何がな"},"なにがなし":{"variants":"なにがなし/何がなし"},"何がなし":{"variants":"なにがなし/何がなし"},"なにげない":{"variants":"なにげない/何気ない/何気無い"},"何気ない":{"variants":"なにげない/何気ない/何気無い"},"何気無い":{"variants":"なにげない/何気ない/何気無い"},"なにごころない":{"variants":"なにごころない/何心無い"},"何心無い":{"variants":"なにごころない/何心無い"},"何ごと":{"variants":"何ごと/何事"},"何事":{"variants":"何ごと/何事"},"なにさま":{"variants":"なにさま/何様"},"何様":{"variants":"なにさま/何様"},"なにしろ":{"variants":"なにしろ/何しろ"},"何しろ":{"variants":"なにしろ/何しろ"},"なにせ":{"variants":"なにせ/何せ"},"何せ":{"variants":"なにせ/何せ"},"なにとぞ":{"variants":"なにとぞ/何とぞ/何卒"},"何とぞ":{"variants":"なにとぞ/何とぞ/何卒"},"何卒":{"variants":"なにとぞ/何とぞ/何卒"},"なにとて":{"variants":"なにとて/何とて"},"何とて":{"variants":"なにとて/何とて"},"なにぶん":{"variants":"なにぶん/何分"},"何分":{"variants":"なにぶん/何分"},"なにもかも":{"variants":"なにもかも/何もかも"},"何もかも":{"variants":"なにもかも/何もかも"},"何もの":{"variants":"何もの/何者"},"何者":{"variants":"何もの/何者"},"なにやら":{"variants":"なにやら/何やら"},"何やら":{"variants":"なにやら/何やら"},"ナノハナ":{"variants":"ナノハナ/菜の花/菜花"},"菜の花":{"variants":"ナノハナ/菜の花/菜花"},"菜花":{"variants":"ナノハナ/菜の花/菜花"},"名のり":{"variants":"名のり/名乗/名乗り"},"名乗":{"variants":"名のり/名乗/名乗り"},"名乗り":{"variants":"名のり/名乗/名乗り"},"なのりでる":{"variants":"なのりでる/名乗り出る"},"名乗り出る":{"variants":"なのりでる/名乗り出る"},"なのる":{"variants":"なのる/名乗る"},"名乗る":{"variants":"なのる/名乗る"},"なびかす":{"variants":"なびかす/靡かす"},"靡かす":{"variants":"なびかす/靡かす"},"なびく":{"variants":"なびく/靡く"},"靡く":{"variants":"なびく/靡く"},"なぶり殺し":{"variants":"なぶり殺し/嬲り殺し"},"嬲り殺し":{"variants":"なぶり殺し/嬲り殺し"},"嬲りもの":{"variants":"嬲りもの/嬲り物"},"嬲り物":{"variants":"嬲りもの/嬲り物"},"なぶる":{"variants":"なぶる/嬲る"},"嬲る":{"variants":"なぶる/嬲る"},"なべ":{"variants":"なべ/ナベ/鍋"},"ナベ":{"variants":"なべ/ナベ/鍋"},"鍋":{"variants":"なべ/ナベ/鍋"},"なベかえる":{"variants":"なベかえる/並べ換える"},"並べ換える":{"variants":"なベかえる/並べ換える"},"ナベヅル":{"variants":"ナベヅル/鍋鶴/鍋鉉"},"なべて":{"variants":"なべて/並べて"},"並べて":{"variants":"なべて/並べて"},"鍋もの":{"variants":"鍋もの/鍋物"},"鍋物":{"variants":"鍋もの/鍋物"},"ナマ":{"variants":"ナマ/生"},"生":{"variants":"ナマ/生"},"生揚":{"variants":"生揚/生揚げ"},"生揚げ":{"variants":"生揚/生揚げ"},"なまあたたかい":{"variants":"なまあたたかい/生暖かい"},"生暖かい":{"variants":"なまあたたかい/生暖かい"},"なまあたらしい":{"variants":"なまあたらしい/生新しい"},"生新しい":{"variants":"なまあたらしい/生新しい"},"ナマイキ":{"variants":"ナマイキ/生意気"},"生意気":{"variants":"ナマイキ/生意気"},"なまぐさい":{"variants":"なまぐさい/生臭い/腥い"},"なまけ者":{"variants":"なまけ者/ナマケモノ/怠けもの/怠け者"},"ナマケモノ":{"variants":"なまけ者/ナマケモノ/怠けもの/怠け者"},"怠けもの":{"variants":"なまけ者/ナマケモノ/怠けもの/怠け者"},"怠け者":{"variants":"なまけ者/ナマケモノ/怠けもの/怠け者"},"なまける":{"variants":"なまける/怠ける"},"怠ける":{"variants":"なまける/怠ける"},"なまこ":{"variants":"なまこ/ナマコ/海鼠"},"ナマコ":{"variants":"なまこ/ナマコ/海鼠"},"海鼠":{"variants":"なまこ/ナマコ/海鼠"},"ナマズ":{"variants":"ナマズ/癜/鯰"},"なまっちろい":{"variants":"なまっちろい/なまっ白い/生っちろい/生っ白い"},"なまっ白い":{"variants":"なまっちろい/なまっ白い/生っちろい/生っ白い"},"生っちろい":{"variants":"なまっちろい/なまっ白い/生っちろい/生っ白い"},"生っ白い":{"variants":"なまっちろい/なまっ白い/生っちろい/生っ白い"},"生つば":{"variants":"生つば/生唾"},"生唾":{"variants":"生つば/生唾"},"なまなか":{"variants":"なまなか/生半"},"生半":{"variants":"なまなか/生半"},"なまなましい":{"variants":"なまなましい/生々しい/生生しい"},"生々しい":{"variants":"なまなましい/生々しい/生生しい"},"生生しい":{"variants":"なまなましい/生々しい/生生しい"},"なまぬるい":{"variants":"なまぬるい/生ぬるい/生温い"},"生ぬるい":{"variants":"なまぬるい/生ぬるい/生温い"},"生温い":{"variants":"なまぬるい/生ぬるい/生温い"},"なまやさしい":{"variants":"なまやさしい/生易しい"},"生易しい":{"variants":"なまやさしい/生易しい"},"なまり":{"variants":"なまり/鉛/訛/訛り"},"訛り":{"variants":"なまり/訛/訛り"},"訛":{"variants":"なまり/訛/訛り"},"なまる":{"variants":"なまる/訛る"},"訛る":{"variants":"なまる/訛る"},"並":{"variants":"並/並み"},"並み":{"variants":"なみ/並み"},"なみ":{"variants":"なみ/並み"},"なみいる":{"variants":"なみいる/並みいる/並み居る/並居る"},"並みいる":{"variants":"なみいる/並みいる/並み居る/並居る"},"並み居る":{"variants":"なみいる/並みいる/並み居る/並居る"},"並居る":{"variants":"なみいる/並みいる/並み居る/並居る"},"波打ちぎわ":{"variants":"波打ちぎわ/波打ち際"},"波打ち際":{"variants":"波打ちぎわ/波打ち際"},"なみうつ":{"variants":"なみうつ/波うつ/波打つ"},"波うつ":{"variants":"なみうつ/波うつ/波打つ"},"波打つ":{"variants":"なみうつ/波うつ/波打つ"},"なみする":{"variants":"なみする/蔑する"},"蔑する":{"variants":"なみする/蔑する"},"並み大抵":{"variants":"並み大抵/並大抵"},"並大抵":{"variants":"並み大抵/並大抵"},"なみだぐましい":{"variants":"なみだぐましい/涙ぐましい"},"涙ぐましい":{"variants":"なみだぐましい/涙ぐましい"},"なみだぐむ":{"variants":"なみだぐむ/涙ぐむ"},"涙ぐむ":{"variants":"なみだぐむ/涙ぐむ"},"なみだする":{"variants":"なみだする/涙する"},"涙する":{"variants":"なみだする/涙する"},"なみだつ":{"variants":"なみだつ/波立つ"},"波立つ":{"variants":"なみだつ/波立つ"},"なみだもろい":{"variants":"なみだもろい/涙脆い"},"涙脆い":{"variants":"なみだもろい/涙脆い"},"並々":{"variants":"並々/並並"},"並並":{"variants":"並々/並並"},"波のり":{"variants":"波のり/波乗り"},"波乗り":{"variants":"波のり/波乗り"},"なみはずれる":{"variants":"なみはずれる/並外れる"},"並外れる":{"variants":"なみはずれる/並外れる"},"なむ":{"variants":"なむ/南無"},"南無":{"variants":"なむ/南無"},"ナメクジ":{"variants":"ナメクジ/蛞蝓"},"蛞蝓":{"variants":"ナメクジ/蛞蝓"},"ナメコ":{"variants":"ナメコ/滑子"},"滑子":{"variants":"ナメコ/滑子"},"なめし革":{"variants":"なめし革/鞣し革/鞣革"},"鞣し革":{"variants":"なめし革/鞣し革/鞣革"},"鞣革":{"variants":"なめし革/鞣し革/鞣革"},"なめす":{"variants":"なめす/鞣す"},"鞣す":{"variants":"なめす/鞣す"},"なめずる":{"variants":"なめずる/舐めずる"},"舐めずる":{"variants":"なめずる/舐めずる"},"なめる":{"variants":"なめる/嘗める/甜める/舐める"},"なやましい":{"variants":"なやましい/悩ましい"},"悩ましい":{"variants":"なやましい/悩ましい"},"なやます":{"variants":"なやます/悩ます"},"悩ます":{"variants":"なやます/悩ます"},"なやみぬく":{"variants":"なやみぬく/悩み抜く"},"悩み抜く":{"variants":"なやみぬく/悩み抜く"},"なやむ":{"variants":"なやむ/悩む"},"悩む":{"variants":"なやむ/悩む"},"ナラ":{"variants":"ナラ/楢"},"楢":{"variants":"ナラ/楢"},"ならい":{"variants":"ならい/習い"},"習い":{"variants":"ならい/習い"},"ならう":{"variants":"ならう/習う/倣う"},"ならえる":{"variants":"ならえる/習える"},"習える":{"variants":"ならえる/習える"},"ならく":{"variants":"ならく/奈落"},"奈落":{"variants":"ならく/奈落"},"ならす":{"variants":"ならす/慣す/慣らす/均す/生らす/馴す/馴らす/鳴らす"},"慣らす":{"variants":"ならす/慣す/慣らす"},"慣す":{"variants":"ならす/慣す/慣らす"},"馴らす":{"variants":"ならす/馴す/馴らす"},"馴す":{"variants":"ならす/馴す/馴らす"},"ならせる":{"variants":"ならせる/慣らせる/鳴らせる"},"奈良漬":{"variants":"奈良漬/奈良漬け"},"奈良漬け":{"variants":"奈良漬/奈良漬け"},"ならびたつ":{"variants":"ならびたつ/並び立つ"},"並び立つ":{"variants":"ならびたつ/並び立つ"},"ならびたてる":{"variants":"ならびたてる/並び立てる"},"並び立てる":{"variants":"ならびたてる/並び立てる"},"ならびない":{"variants":"ならびない/並びない/並び無い/並無い"},"並びない":{"variants":"ならびない/並びない/並び無い/並無い"},"並び無い":{"variants":"ならびない/並びない/並び無い/並無い"},"並無い":{"variants":"ならびない/並びない/並び無い/並無い"},"ならびに":{"variants":"ならびに/並びに"},"並びに":{"variants":"ならびに/並びに"},"ならぶ":{"variants":"ならぶ/陳ぶ/並ぶ/列ぶ"},"並べかえ":{"variants":"並べかえ/並べ換え"},"並べ換え":{"variants":"並べかえ/並べ換え"},"ならべたてる":{"variants":"ならべたてる/並べたてる/並べ立てる"},"並べたてる":{"variants":"ならべたてる/並べたてる/並べ立てる"},"並べ立てる":{"variants":"ならべたてる/並べたてる/並べ立てる"},"ならべる":{"variants":"ならべる/並べる/列べる"},"ならわす":{"variants":"ならわす/慣わす/習わす"},"ならわせる":{"variants":"ならわせる/慣わせる/習わせる"},"なり":{"variants":"なり/鳴り"},"鳴り":{"variants":"なり/鳴り"},"なりあがる":{"variants":"なりあがる/成り上がる"},"成り上がる":{"variants":"なりあがる/成り上がる"},"なりかわる":{"variants":"なりかわる/なり変わる/成り代る/成り代わる/成り変わる"},"成り代る":{"variants":"なりかわる/成り代る/成り代わる"},"成り代わる":{"variants":"なりかわる/成り代る/成り代わる"},"成り変わる":{"variants":"なりかわる/なり変わる/成り変わる"},"なり変わる":{"variants":"なりかわる/なり変わる/成り変わる"},"成り金":{"variants":"成り金/成金"},"成金":{"variants":"成り金/成金"},"なりさがる":{"variants":"なりさがる/成り下がる"},"成り下がる":{"variants":"なりさがる/成り下がる"},"なりさがれる":{"variants":"なりさがれる/成り下がれる"},"成り下がれる":{"variants":"なりさがれる/成り下がれる"},"なりすます":{"variants":"なりすます/成りすます/成り済ます"},"成りすます":{"variants":"なりすます/成りすます/成り済ます"},"成り済ます":{"variants":"なりすます/成りすます/成り済ます"},"成り立ち":{"variants":"成り立ち/成立ち"},"成立ち":{"variants":"成り立ち/成立ち"},"なりたつ":{"variants":"なりたつ/成りたつ/成り立つ/成立つ"},"成りたつ":{"variants":"なりたつ/成りたつ/成り立つ/成立つ"},"成り立つ":{"variants":"なりたつ/成りたつ/成り立つ/成立つ"},"成立つ":{"variants":"なりたつ/成りたつ/成り立つ/成立つ"},"なりだす":{"variants":"なりだす/鳴りだす/鳴り出す"},"鳴りだす":{"variants":"なりだす/鳴りだす/鳴り出す"},"鳴り出す":{"variants":"なりだす/鳴りだす/鳴り出す"},"なりひびく":{"variants":"なりひびく/鳴り響く"},"鳴り響く":{"variants":"なりひびく/鳴り響く"},"なりふり":{"variants":"なりふり/形振り"},"形振り":{"variants":"なりふり/形振り"},"鳴り物":{"variants":"鳴り物/鳴物"},"鳴物":{"variants":"鳴り物/鳴物"},"鳴り物入り":{"variants":"鳴り物入り/鳴物入"},"鳴物入":{"variants":"鳴り物入り/鳴物入"},"成りゆき":{"variants":"成りゆき/成り行き/成行き"},"成り行き":{"variants":"成りゆき/成り行き/成行き"},"成行き":{"variants":"成りゆき/成り行き/成行き"},"なりわたる":{"variants":"なりわたる/鳴りわたる/鳴り渡る"},"鳴りわたる":{"variants":"なりわたる/鳴りわたる/鳴り渡る"},"鳴り渡る":{"variants":"なりわたる/鳴りわたる/鳴り渡る"},"なる":{"variants":"なる/為る/成る/生る/鳴る"},"なれあい":{"variants":"なれあい/なれ合い"},"なれ合い":{"variants":"なれあい/なれ合い"},"なれあう":{"variants":"なれあう/なれ合う/馴れあう/馴れ合う"},"なれ合う":{"variants":"なれあう/なれ合う/馴れあう/馴れ合う"},"馴れあう":{"variants":"なれあう/なれ合う/馴れあう/馴れ合う"},"馴れ合う":{"variants":"なれあう/なれ合う/馴れあう/馴れ合う"},"なれ初め":{"variants":"なれ初め/馴れ初め/馴初め"},"馴れ初め":{"variants":"なれ初め/馴れ初め/馴初め"},"馴初め":{"variants":"なれ初め/馴れ初め/馴初め"},"なれなれしい":{"variants":"なれなれしい/馴れなれしい/馴れ馴れしい"},"馴れなれしい":{"variants":"なれなれしい/馴れなれしい/馴れ馴れしい"},"馴れ馴れしい":{"variants":"なれなれしい/馴れなれしい/馴れ馴れしい"},"なれる":{"variants":"なれる/慣れる/成れる/馴れる/狎れる"},"縄付":{"variants":"縄付/縄付き"},"縄付き":{"variants":"縄付/縄付き"},"縄のれん":{"variants":"縄のれん/縄暖簾"},"縄暖簾":{"variants":"縄のれん/縄暖簾"},"縄ばしご":{"variants":"縄ばしご/縄梯子"},"縄梯子":{"variants":"縄ばしご/縄梯子"},"縄張":{"variants":"縄張/縄張り"},"縄張り":{"variants":"縄張/縄張り"},"ナンキンネズミ":{"variants":"ナンキンネズミ/南京鼠"},"南京鼠":{"variants":"ナンキンネズミ/南京鼠"},"ナンキンムシ":{"variants":"ナンキンムシ/南京虫"},"南京虫":{"variants":"ナンキンムシ/南京虫"},"難くせ":{"variants":"難くせ/難癖"},"難癖":{"variants":"難くせ/難癖"},"軟膏":{"variants":"軟こう/軟膏"},"軟こう":{"variants":"軟こう/軟膏/軟鋼"},"軟鋼":{"variants":"軟こう/軟鋼"},"なんこつ":{"variants":"なんこつ/軟骨"},"軟骨":{"variants":"なんこつ/軟骨"},"なんずる":{"variants":"なんずる/難ずる"},"難ずる":{"variants":"なんずる/難ずる"},"なんだか":{"variants":"なんだか/何だか"},"何だか":{"variants":"なんだか/何だか"},"なんだかんだ":{"variants":"なんだかんだ/何だかんだ"},"何だかんだ":{"variants":"なんだかんだ/何だかんだ"},"ナンテン":{"variants":"ナンテン/南天/難点"},"なんで":{"variants":"なんで/何で"},"何で":{"variants":"なんで/何で"},"なんでも":{"variants":"なんでも/何でも"},"何でも":{"variants":"なんでも/何でも"},"なんと":{"variants":"なんと/何と"},"何と":{"variants":"なんと/何と"},"なんとか":{"variants":"なんとか/何とか"},"何とか":{"variants":"なんとか/何とか"},"なんとも":{"variants":"なんとも/何とも"},"何とも":{"variants":"なんとも/何とも"},"なんど":{"variants":"なんど/納戸"},"納戸":{"variants":"なんど/納戸"},"なんなく":{"variants":"なんなく/難なく/難無く"},"難なく":{"variants":"なんなく/難なく/難無く"},"難無く":{"variants":"なんなく/難なく/難無く"},"喃々":{"variants":"喃々/喃喃"},"喃喃":{"variants":"喃々/喃喃"},"なんなんとする":{"variants":"なんなんとする/垂んとする"},"垂んとする":{"variants":"なんなんとする/垂んとする"},"なんのかんの":{"variants":"なんのかんの/何のかんの"},"何のかんの":{"variants":"なんのかんの/何のかんの"},"南ばん":{"variants":"南ばん/南蛮"},"南蛮":{"variants":"南ばん/南蛮"},"なんびと":{"variants":"なんびと/何びと"},"何びと":{"variants":"なんびと/何びと"},"なんら":{"variants":"なんら/何ら/何等"},"何ら":{"variants":"なんら/何ら/何等"},"何等":{"variants":"なんら/何ら/何等"},"なんらかの":{"variants":"なんらかの/何らかの"},"何らかの":{"variants":"なんらかの/何らかの"},"２":{"variants":"２/二"},"二":{"variants":"２/二"},"ＮＩＥＳ":{"variants":"ＮＩＥＳ/ニーズ"},"ニーズ":{"variants":"ＮＩＥＳ/ニーズ"},"似合":{"variants":"似合/似合い"},"似合い":{"variants":"似合/似合い"},"にあう":{"variants":"にあう/似合う"},"似合う":{"variants":"にあう/似合う"},"にあがる":{"variants":"にあがる/煮上がる"},"煮上がる":{"variants":"にあがる/煮上がる"},"にあたって":{"variants":"にあたって/に当たって"},"に当たって":{"variants":"にあたって/に当たって"},"にあたり":{"variants":"にあたり/に当たり"},"に当たり":{"variants":"にあたり/に当たり"},"にあたる":{"variants":"にあたる/に当たる"},"に当たる":{"variants":"にあたる/に当たる"},"にあわしい":{"variants":"にあわしい/似合しい"},"似合しい":{"variants":"にあわしい/似合しい"},"にいにい蝉":{"variants":"にいにい蝉/ニイニイゼミ"},"ニイニイゼミ":{"variants":"にいにい蝉/ニイニイゼミ"},"にえかえる":{"variants":"にえかえる/煮え返る"},"煮え返る":{"variants":"にえかえる/煮え返る"},"にえくりかえる":{"variants":"にえくりかえる/煮えくりかえる/煮えくり返る/煮え繰り返る"},"煮えくりかえる":{"variants":"にえくりかえる/煮えくりかえる/煮えくり返る/煮え繰り返る"},"煮えくり返る":{"variants":"にえくりかえる/煮えくりかえる/煮えくり返る/煮え繰り返る"},"煮え繰り返る":{"variants":"にえくりかえる/煮えくりかえる/煮えくり返る/煮え繰り返る"},"にえたぎる":{"variants":"にえたぎる/煮えたぎる/煮え滾る"},"煮えたぎる":{"variants":"にえたぎる/煮えたぎる/煮え滾る"},"煮え滾る":{"variants":"にえたぎる/煮えたぎる/煮え滾る"},"にえたつ":{"variants":"にえたつ/煮えたつ/煮え立つ"},"煮えたつ":{"variants":"にえたつ/煮えたつ/煮え立つ"},"煮え立つ":{"variants":"にえたつ/煮えたつ/煮え立つ"},"にえる":{"variants":"にえる/煮える"},"煮える":{"variants":"にえる/煮える"},"ニオ":{"variants":"ニオ/鳰"},"鳰":{"variants":"ニオ/鳰"},"におい":{"variants":"におい/臭/臭い/匂/匂い"},"匂い":{"variants":"におい/匂/匂い"},"臭":{"variants":"におい/臭/臭い"},"匂":{"variants":"におい/匂/匂い"},"におい袋":{"variants":"におい袋/匂袋"},"匂袋":{"variants":"におい袋/匂袋"},"におう":{"variants":"におう/臭う/匂う"},"仁王立ち":{"variants":"仁王立/仁王立ち"},"仁王立":{"variants":"仁王立/仁王立ち"},"におわす":{"variants":"におわす/臭わす/匂わす"},"におわせる":{"variants":"におわせる/臭わせる/匂わせる"},"ニカメイガ":{"variants":"ニカメイガ/二化螟蛾"},"二化螟蛾":{"variants":"ニカメイガ/二化螟蛾"},"ニカメイチュウ":{"variants":"ニカメイチュウ/二化螟虫"},"二化螟虫":{"variants":"ニカメイチュウ/二化螟虫"},"にかよう":{"variants":"にかよう/似かよう/似通う"},"似かよう":{"variants":"にかよう/似かよう/似通う"},"似通う":{"variants":"にかよう/似かよう/似通う"},"にがい":{"variants":"にがい/ニガい/苦い"},"ニガい":{"variants":"にがい/ニガい/苦い"},"苦い":{"variants":"にがい/ニガい/苦い"},"ニガウリ":{"variants":"ニガウリ/苦瓜"},"苦瓜":{"variants":"ニガウリ/苦瓜"},"にがす":{"variants":"にがす/逃がす"},"逃がす":{"variants":"にがす/逃がす"},"２月":{"variants":"２月/二月"},"二月":{"variants":"２月/二月"},"にがにがしい":{"variants":"にがにがしい/苦々しい/苦苦しい"},"苦々しい":{"variants":"にがにがしい/苦々しい/苦苦しい"},"苦苦しい":{"variants":"にがにがしい/苦々しい/苦苦しい"},"にがみばしる":{"variants":"にがみばしる/苦みばしる"},"苦みばしる":{"variants":"にがみばしる/苦みばしる"},"ニガ虫":{"variants":"ニガ虫/苦虫"},"苦虫":{"variants":"ニガ虫/苦虫"},"にがりきる":{"variants":"にがりきる/苦りきる/苦り切る"},"苦りきる":{"variants":"にがりきる/苦りきる/苦り切る"},"苦り切る":{"variants":"にがりきる/苦りきる/苦り切る"},"ニガ笑い":{"variants":"ニガ笑い/苦笑い"},"苦笑い":{"variants":"ニガ笑い/苦笑い"},"ニキビ":{"variants":"ニキビ/面皰"},"面皰":{"variants":"ニキビ/面皰"},"にぎにぎしい":{"variants":"にぎにぎしい/賑々しい/賑賑しい"},"賑々しい":{"variants":"にぎにぎしい/賑々しい/賑賑しい"},"賑賑しい":{"variants":"にぎにぎしい/賑々しい/賑賑しい"},"にぎやか":{"variants":"にぎやか/賑やか"},"賑やか":{"variants":"にぎやか/賑やか"},"にぎやかす":{"variants":"にぎやかす/賑やかす"},"賑やかす":{"variants":"にぎやかす/賑やかす"},"握りこぶし":{"variants":"握りこぶし/握り拳"},"握り拳":{"variants":"握りこぶし/握り拳"},"にぎりしめる":{"variants":"にぎりしめる/握りしめる/握り締める"},"握りしめる":{"variants":"にぎりしめる/握りしめる/握り締める"},"握り締める":{"variants":"にぎりしめる/握りしめる/握り締める"},"握り鮨":{"variants":"握り鮨/握鮨"},"握鮨":{"variants":"握り鮨/握鮨"},"にぎりつぶす":{"variants":"にぎりつぶす/握りつぶす/握り潰す"},"握りつぶす":{"variants":"にぎりつぶす/握りつぶす/握り潰す"},"握り潰す":{"variants":"にぎりつぶす/握りつぶす/握り潰す"},"にぎりつぶせる":{"variants":"にぎりつぶせる/握りつぶせる"},"握りつぶせる":{"variants":"にぎりつぶせる/握りつぶせる"},"にぎり飯":{"variants":"にぎり飯/握り飯/握飯"},"握り飯":{"variants":"にぎり飯/握り飯/握飯"},"握飯":{"variants":"にぎり飯/握り飯/握飯"},"にぎる":{"variants":"にぎる/握る"},"握る":{"variants":"にぎる/握る"},"にぎれる":{"variants":"にぎれる/握れる"},"握れる":{"variants":"にぎれる/握れる"},"にぎわい":{"variants":"にぎわい/賑/賑わい"},"賑":{"variants":"にぎわい/賑/賑わい"},"賑わい":{"variants":"にぎわい/賑/賑わい"},"にぎわう":{"variants":"にぎわう/賑わう"},"賑わう":{"variants":"にぎわう/賑わう"},"にぎわしい":{"variants":"にぎわしい/賑わしい"},"賑わしい":{"variants":"にぎわしい/賑わしい"},"にぎわす":{"variants":"にぎわす/賑わす"},"賑わす":{"variants":"にぎわす/賑わす"},"にぎわせる":{"variants":"にぎわせる/賑わせる"},"賑わせる":{"variants":"にぎわせる/賑わせる"},"にぎわわす":{"variants":"にぎわわす/賑わわす"},"賑わわす":{"variants":"にぎわわす/賑わわす"},"にくい":{"variants":"にくい/憎い"},"憎い":{"variants":"にくい/憎い"},"ニクガ":{"variants":"ニクガ/肉芽"},"肉芽":{"variants":"ニクガ/肉芽"},"にくがる":{"variants":"にくがる/憎がる"},"憎がる":{"variants":"にくがる/憎がる"},"肉しゅ":{"variants":"肉しゅ/肉腫"},"肉腫":{"variants":"肉しゅ/肉腫"},"ニクズク":{"variants":"ニクズク/肉ずく"},"肉ずく":{"variants":"ニクズク/肉ずく"},"にくたらしい":{"variants":"にくたらしい/憎たらしい"},"憎たらしい":{"variants":"にくたらしい/憎たらしい"},"にくにくしい":{"variants":"にくにくしい/憎々しい/憎憎しい"},"憎々しい":{"variants":"にくにくしい/憎々しい/憎憎しい"},"憎憎しい":{"variants":"にくにくしい/憎々しい/憎憎しい"},"肉ばなれ":{"variants":"肉ばなれ/肉離れ"},"肉離れ":{"variants":"肉ばなれ/肉離れ"},"にくまれる":{"variants":"にくまれる/憎まれる"},"憎まれる":{"variants":"にくまれる/憎まれる"},"にくむ":{"variants":"にくむ/憎む"},"憎む":{"variants":"にくむ/憎む"},"にくめる":{"variants":"にくめる/憎める"},"憎める":{"variants":"にくめる/憎める"},"にくらしい":{"variants":"にくらしい/憎らしい"},"憎らしい":{"variants":"にくらしい/憎らしい"},"にげうせる":{"variants":"にげうせる/逃げ失せる"},"逃げ失せる":{"variants":"にげうせる/逃げ失せる"},"にげかえる":{"variants":"にげかえる/逃げ帰る"},"逃げ帰る":{"variants":"にげかえる/逃げ帰る"},"逃げ口":{"variants":"逃げ口/逃口"},"逃口":{"variants":"逃げ口/逃口"},"逃げ口上":{"variants":"逃げ口上/逃口上"},"逃口上":{"variants":"逃げ口上/逃口上"},"逃げことば":{"variants":"逃げことば/逃げ言葉/逃言葉"},"逃げ言葉":{"variants":"逃げことば/逃げ言葉/逃言葉"},"逃言葉":{"variants":"逃げことば/逃げ言葉/逃言葉"},"にげこむ":{"variants":"にげこむ/逃げ込む"},"逃げ込む":{"variants":"にげこむ/逃げ込む"},"にげこめる":{"variants":"にげこめる/逃げ込める"},"逃げ込める":{"variants":"にげこめる/逃げ込める"},"逃げ支度":{"variants":"逃げ支度/逃支度"},"逃支度":{"variants":"逃げ支度/逃支度"},"にげだす":{"variants":"にげだす/逃げだす/逃げ出す"},"逃げだす":{"variants":"にげだす/逃げだす/逃げ出す"},"逃げ出す":{"variants":"にげだす/逃げだす/逃げ出す"},"にげだせる":{"variants":"にげだせる/逃げ出せる"},"逃げ出せる":{"variants":"にげだせる/逃げ出せる"},"にげない":{"variants":"にげない/似気無い"},"似気無い":{"variants":"にげない/似気無い"},"にげのびる":{"variants":"にげのびる/逃げのびる/逃げ延びる/逃延びる"},"逃げのびる":{"variants":"にげのびる/逃げのびる/逃げ延びる/逃延びる"},"逃げ延びる":{"variants":"にげのびる/逃げのびる/逃げ延びる/逃延びる"},"逃延びる":{"variants":"にげのびる/逃げのびる/逃げ延びる/逃延びる"},"逃げ場":{"variants":"逃げ場/逃場"},"逃場":{"variants":"逃げ場/逃場"},"にげまどう":{"variants":"にげまどう/逃げまどう/逃げ惑う"},"逃げまどう":{"variants":"にげまどう/逃げまどう/逃げ惑う"},"逃げ惑う":{"variants":"にげまどう/逃げまどう/逃げ惑う"},"にげまわる":{"variants":"にげまわる/逃げ回る"},"逃げ回る":{"variants":"にげまわる/逃げ回る"},"にげまわれる":{"variants":"にげまわれる/逃げ回れる"},"逃げ回れる":{"variants":"にげまわれる/逃げ回れる"},"逃げ水":{"variants":"逃げ水/逃水"},"逃水":{"variants":"逃げ水/逃水"},"逃げ道":{"variants":"逃げ道/逃道"},"逃道":{"variants":"逃げ道/逃道"},"にげる":{"variants":"にげる/逃げる"},"逃げる":{"variants":"にげる/逃げる"},"煮こみ":{"variants":"煮こみ/煮込み"},"煮込み":{"variants":"煮こみ/煮込み"},"にこむ":{"variants":"にこむ/煮込む"},"煮込む":{"variants":"にこむ/煮込む"},"にこめる":{"variants":"にこめる/煮込める"},"煮込める":{"variants":"にこめる/煮込める"},"にごす":{"variants":"にごす/濁す"},"濁す":{"variants":"にごす/濁す"},"にごせる":{"variants":"にごせる/濁せる"},"濁せる":{"variants":"にごせる/濁せる"},"にごらす":{"variants":"にごらす/濁らす"},"濁らす":{"variants":"にごらす/濁らす"},"にごらせる":{"variants":"にごらせる/濁らせる"},"濁らせる":{"variants":"にごらせる/濁らせる"},"にごり江":{"variants":"にごり江/濁江"},"濁江":{"variants":"にごり江/濁江"},"にごり酒":{"variants":"にごり酒/濁酒"},"濁酒":{"variants":"にごり酒/濁酒"},"にごる":{"variants":"にごる/濁る"},"濁る":{"variants":"にごる/濁る"},"荷さばき":{"variants":"荷さばき/荷捌"},"荷捌":{"variants":"荷さばき/荷捌"},"にし":{"variants":"にし/ニシ/西/二死/螺"},"ニシ":{"variants":"にし/ニシ/西/二死/螺"},"にしき絵":{"variants":"にしき絵/錦絵"},"錦絵":{"variants":"にしき絵/錦絵"},"ニシキギ":{"variants":"ニシキギ/錦木"},"錦木":{"variants":"ニシキギ/錦木"},"ニシキゴイ":{"variants":"ニシキゴイ/錦鯉"},"錦鯉":{"variants":"ニシキゴイ/錦鯉"},"ニシキヘビ":{"variants":"ニシキヘビ/錦蛇"},"錦蛇":{"variants":"ニシキヘビ/錦蛇"},"煮染":{"variants":"煮染/煮染め"},"煮染め":{"variants":"煮染/煮染め"},"にしめる":{"variants":"にしめる/煮染める"},"煮染める":{"variants":"にしめる/煮染める"},"ニシン":{"variants":"ニシン/二伸/鯡"},"ニジマス":{"variants":"ニジマス/虹鱒"},"虹鱒":{"variants":"ニジマス/虹鱒"},"にじみでる":{"variants":"にじみでる/にじみ出る"},"にじみ出る":{"variants":"にじみでる/にじみ出る"},"にじむ":{"variants":"にじむ/滲む"},"滲む":{"variants":"にじむ/滲む"},"にじり口":{"variants":"にじり口/躙口"},"躙口":{"variants":"にじり口/躙口"},"にじりよる":{"variants":"にじりよる/にじり寄る/躙り寄る"},"にじり寄る":{"variants":"にじりよる/にじり寄る/躙り寄る"},"躙り寄る":{"variants":"にじりよる/にじり寄る/躙り寄る"},"ニセ":{"variants":"ニセ/贋/偽"},"偽":{"variants":"ニセ/偽"},"偽もの":{"variants":"偽もの/偽者"},"偽者":{"variants":"偽もの/偽者"},"にせる":{"variants":"にせる/似せる"},"似せる":{"variants":"にせる/似せる"},"にたいして":{"variants":"にたいして/に対して"},"に対して":{"variants":"にたいして/に対して"},"にたいする":{"variants":"にたいする/に対する"},"に対する":{"variants":"にたいする/に対する"},"煮たき":{"variants":"煮たき/煮炊き"},"煮炊き":{"variants":"煮たき/煮炊き"},"にたつ":{"variants":"にたつ/煮立つ"},"煮立つ":{"variants":"にたつ/煮立つ"},"にたてる":{"variants":"にたてる/煮立てる"},"煮立てる":{"variants":"にたてる/煮立てる"},"ニッケイ":{"variants":"ニッケイ/肉桂/日系/日計"},"ニッパやし":{"variants":"ニッパやし/ニッパヤシ/ニッパ椰子"},"ニッパヤシ":{"variants":"ニッパやし/ニッパヤシ/ニッパ椰子"},"ニッパ椰子":{"variants":"ニッパやし/ニッパヤシ/ニッパ椰子"},"につかわしい":{"variants":"につかわしい/似つかわしい"},"似つかわしい":{"variants":"につかわしい/似つかわしい"},"につく":{"variants":"につく/似つく"},"似つく":{"variants":"につく/似つく"},"煮付":{"variants":"煮付/煮付け"},"煮付け":{"variants":"煮付/煮付け"},"につける":{"variants":"につける/煮つける/煮付ける"},"煮つける":{"variants":"につける/煮つける/煮付ける"},"煮付ける":{"variants":"につける/煮つける/煮付ける"},"につまる":{"variants":"につまる/煮詰まる/煮詰る"},"煮詰まる":{"variants":"につまる/煮詰まる/煮詰る"},"煮詰る":{"variants":"につまる/煮詰まる/煮詰る"},"につめる":{"variants":"につめる/煮つめる/煮詰める"},"煮つめる":{"variants":"につめる/煮つめる/煮詰める"},"煮詰める":{"variants":"につめる/煮つめる/煮詰める"},"荷づくり":{"variants":"荷づくり/荷造り"},"荷造り":{"variants":"荷づくり/荷造り"},"荷作り":{"variants":"荷作/荷作り"},"荷作":{"variants":"荷作/荷作り"},"になう":{"variants":"になう/荷なう/担う"},"になえる":{"variants":"になえる/担える"},"担える":{"variants":"になえる/担える"},"二の酉":{"variants":"二の酉/二酉"},"二酉":{"variants":"二の酉/二酉"},"二の舞":{"variants":"二の舞/二の舞い"},"二の舞い":{"variants":"二の舞/二の舞い"},"二番せんじ":{"variants":"二番せんじ/二番煎じ"},"二番煎じ":{"variants":"二番せんじ/二番煎じ"},"にふくめる":{"variants":"にふくめる/煮含める"},"煮含める":{"variants":"にふくめる/煮含める"},"ニマイガイ":{"variants":"ニマイガイ/二枚貝"},"二枚貝":{"variants":"ニマイガイ/二枚貝"},"煮もの":{"variants":"煮もの/煮物"},"煮物":{"variants":"煮もの/煮物"},"ＮＥＷ":{"variants":"ＮＥＷ/Ｎｅｗ/ニュー/Νｅｗ"},"Ｎｅｗ":{"variants":"ＮＥＷ/Ｎｅｗ/ニュー/Νｅｗ"},"ニュー":{"variants":"ＮＥＷ/Ｎｅｗ/ニュー/Νｅｗ"},"Νｅｗ":{"variants":"ＮＥＷ/Ｎｅｗ/ニュー/Νｅｗ"},"ＮＥＷＳ":{"variants":"ＮＥＷＳ/にゅーす/ニュース"},"にゅーす":{"variants":"ＮＥＷＳ/にゅーす/ニュース"},"ニュース":{"variants":"ＮＥＷＳ/にゅーす/ニュース"},"乳がん":{"variants":"乳がん/乳ガン/乳癌"},"乳ガン":{"variants":"乳がん/乳ガン/乳癌"},"乳癌":{"variants":"乳がん/乳ガン/乳癌"},"ニュウコウ":{"variants":"ニュウコウ/乳香"},"乳香":{"variants":"ニュウコウ/乳香"},"にゅうじょう":{"variants":"にゅうじょう/乳状"},"乳状":{"variants":"にゅうじょう/乳状"},"乳せん":{"variants":"乳せん/乳腺"},"乳腺":{"variants":"乳せん/乳腺"},"ニュウナイスズメ":{"variants":"ニュウナイスズメ/入内雀"},"入内雀":{"variants":"ニュウナイスズメ/入内雀"},"女護が島":{"variants":"女護が島/女護島"},"女護島":{"variants":"女護が島/女護島"},"ニラ":{"variants":"ニラ/韮"},"韮":{"variants":"ニラ/韮"},"にらみあう":{"variants":"にらみあう/にらみ合う/睨みあう/睨み合う"},"にらみ合う":{"variants":"にらみあう/にらみ合う/睨みあう/睨み合う"},"睨みあう":{"variants":"にらみあう/にらみ合う/睨みあう/睨み合う"},"睨み合う":{"variants":"にらみあう/にらみ合う/睨みあう/睨み合う"},"にらみあわす":{"variants":"にらみあわす/にらみ合わす"},"にらみ合わす":{"variants":"にらみあわす/にらみ合わす"},"にらみあわせる":{"variants":"にらみあわせる/にらみ合せる/睨みあわせる/睨み合せる"},"にらみ合せる":{"variants":"にらみあわせる/にらみ合せる/睨みあわせる/睨み合せる"},"睨みあわせる":{"variants":"にらみあわせる/にらみ合せる/睨みあわせる/睨み合せる"},"睨み合せる":{"variants":"にらみあわせる/にらみ合せる/睨みあわせる/睨み合せる"},"にらみつける":{"variants":"にらみつける/睨みつける/睨み付ける"},"睨みつける":{"variants":"にらみつける/睨みつける/睨み付ける"},"睨み付ける":{"variants":"にらみつける/睨みつける/睨み付ける"},"にらむ":{"variants":"にらむ/睨む"},"睨む":{"variants":"にらむ/睨む"},"にる":{"variants":"にる/似る/煮る"},"ニレ":{"variants":"ニレ/楡"},"楡":{"variants":"ニレ/楡"},"ニワウメ":{"variants":"ニワウメ/庭梅"},"庭梅":{"variants":"ニワウメ/庭梅"},"にわか":{"variants":"にわか/俄"},"俄":{"variants":"にわか/俄"},"ニワゼキショウ":{"variants":"ニワゼキショウ/庭石菖"},"庭石菖":{"variants":"ニワゼキショウ/庭石菖"},"ニワタタキ":{"variants":"ニワタタキ/庭叩き"},"庭叩き":{"variants":"ニワタタキ/庭叩き"},"ニワトコ":{"variants":"ニワトコ/接骨木"},"接骨木":{"variants":"ニワトコ/接骨木"},"人気もの":{"variants":"人気もの/人気者"},"人気者":{"variants":"人気もの/人気者"},"人形遣":{"variants":"人形遣/人形遣い"},"人形遣い":{"variants":"人形遣/人形遣い"},"人間並":{"variants":"人間並/人間並み"},"人間並み":{"variants":"人間並/人間並み"},"にんげんらしい":{"variants":"にんげんらしい/人間らしい"},"人間らしい":{"variants":"にんげんらしい/人間らしい"},"人間わざ":{"variants":"人間わざ/人間業"},"人間業":{"variants":"人間わざ/人間業"},"にんじる":{"variants":"にんじる/任じる"},"任じる":{"variants":"にんじる/任じる"},"にんじん":{"variants":"にんじん/ニンジン/人参"},"ニンジン":{"variants":"にんじん/ニンジン/人参"},"人参":{"variants":"にんじん/ニンジン/人参"},"人相書":{"variants":"人相書/人相書き"},"人相書き":{"variants":"人相書/人相書き"},"にんにく":{"variants":"にんにく/ニンニク/大蒜/忍辱"},"ニンニク":{"variants":"にんにく/ニンニク/大蒜/忍辱"},"ぬいあげる":{"variants":"ぬいあげる/縫い上げる/縫上げる"},"縫い上げる":{"variants":"ぬいあげる/縫い上げる/縫上げる"},"縫上げる":{"variants":"ぬいあげる/縫い上げる/縫上げる"},"ぬいあわす":{"variants":"ぬいあわす/縫い合わす"},"縫い合わす":{"variants":"ぬいあわす/縫い合わす"},"ぬいあわせる":{"variants":"ぬいあわせる/縫い合わせる"},"縫い合わせる":{"variants":"ぬいあわせる/縫い合わせる"},"縫い糸":{"variants":"縫い糸/縫糸"},"縫糸":{"variants":"縫い糸/縫糸"},"ぬいぐるみ":{"variants":"ぬいぐるみ/縫いぐるみ"},"縫いぐるみ":{"variants":"ぬいぐるみ/縫いぐるみ"},"ぬいこむ":{"variants":"ぬいこむ/縫い込む"},"縫い込む":{"variants":"ぬいこむ/縫い込む"},"ぬいこめる":{"variants":"ぬいこめる/縫い込める"},"縫い込める":{"variants":"ぬいこめる/縫い込める"},"縫い代":{"variants":"縫い代/縫代"},"縫代":{"variants":"縫い代/縫代"},"ぬいつける":{"variants":"ぬいつける/縫いつける"},"縫いつける":{"variants":"ぬいつける/縫いつける"},"縫い取り":{"variants":"縫い取り/縫取り"},"縫取り":{"variants":"縫い取り/縫取り"},"縫い目":{"variants":"縫い目/縫目"},"縫目":{"variants":"縫い目/縫目"},"縫い物":{"variants":"縫い物/縫物"},"縫物":{"variants":"縫い物/縫物"},"ぬう":{"variants":"ぬう/縫う"},"縫う":{"variants":"ぬう/縫う"},"ヌエ":{"variants":"ヌエ/鵺"},"鵺":{"variants":"ヌエ/鵺"},"ぬえる":{"variants":"ぬえる/縫える"},"縫える":{"variants":"ぬえる/縫える"},"ぬかす":{"variants":"ぬかす/吐かす/抜かす"},"ぬかづく":{"variants":"ぬかづく/額づく"},"額づく":{"variants":"ぬかづく/額づく"},"糠漬":{"variants":"糠漬/糠漬け"},"糠漬け":{"variants":"糠漬/糠漬け"},"ぬか星":{"variants":"ぬか星/糠星"},"糠星":{"variants":"ぬか星/糠星"},"ぬかる":{"variants":"ぬかる/抜かる"},"抜かる":{"variants":"ぬかる/抜かる"},"ぬがす":{"variants":"ぬがす/脱がす"},"脱がす":{"variants":"ぬがす/脱がす"},"ぬがせる":{"variants":"ぬがせる/脱がせる"},"脱がせる":{"variants":"ぬがせる/脱がせる"},"ぬき":{"variants":"ぬき/緯/貫/抜き"},"抜き足":{"variants":"抜き足/抜足"},"抜足":{"variants":"抜き足/抜足"},"ぬきあわせる":{"variants":"ぬきあわせる/抜き合せる/抜合せる"},"抜き合せる":{"variants":"ぬきあわせる/抜き合せる/抜合せる"},"抜合せる":{"variants":"ぬきあわせる/抜き合せる/抜合せる"},"抜き糸":{"variants":"抜き糸/抜糸"},"抜糸":{"variants":"抜き糸/抜糸"},"抜き打ち":{"variants":"抜き打ち/抜打ち"},"抜打ち":{"variants":"抜き打ち/抜打ち"},"抜き刷り":{"variants":"抜き刷り/抜刷"},"抜刷":{"variants":"抜き刷り/抜刷"},"ぬきだす":{"variants":"ぬきだす/抜きだす/抜き出す/抜出す"},"抜きだす":{"variants":"ぬきだす/抜きだす/抜き出す/抜出す"},"抜き出す":{"variants":"ぬきだす/抜きだす/抜き出す/抜出す"},"抜出す":{"variants":"ぬきだす/抜きだす/抜き出す/抜出す"},"ぬきだせる":{"variants":"ぬきだせる/抜き出せる"},"抜き出せる":{"variants":"ぬきだせる/抜き出せる"},"ぬきつらねる":{"variants":"ぬきつらねる/抜き連ねる/抜連ねる"},"抜き連ねる":{"variants":"ぬきつらねる/抜き連ねる/抜連ねる"},"抜連ねる":{"variants":"ぬきつらねる/抜き連ねる/抜連ねる"},"抜き手":{"variants":"抜き手/抜手"},"抜手":{"variants":"抜き手/抜手"},"ぬきとる":{"variants":"ぬきとる/抜きとる/抜き取る/抜取る"},"抜きとる":{"variants":"ぬきとる/抜きとる/抜き取る/抜取る"},"抜き取る":{"variants":"ぬきとる/抜きとる/抜き取る/抜取る"},"抜取る":{"variants":"ぬきとる/抜きとる/抜き取る/抜取る"},"ぬきとれる":{"variants":"ぬきとれる/抜き取れる"},"抜き取れる":{"variants":"ぬきとれる/抜き取れる"},"ぬきはなつ":{"variants":"ぬきはなつ/抜き放つ/抜放つ"},"抜き放つ":{"variants":"ぬきはなつ/抜き放つ/抜放つ"},"抜放つ":{"variants":"ぬきはなつ/抜き放つ/抜放つ"},"ぬきんでる":{"variants":"ぬきんでる/抽んでる/擢んでる/抜きんでる/抜きん出る"},"抜きん出る":{"variants":"ぬきんでる/抜きんでる/抜きん出る"},"抜きんでる":{"variants":"ぬきんでる/抜きんでる/抜きん出る"},"ぬぎすてる":{"variants":"ぬぎすてる/脱ぎ捨てる/脱捨てる"},"脱ぎ捨てる":{"variants":"ぬぎすてる/脱ぎ捨てる/脱捨てる"},"脱捨てる":{"variants":"ぬぎすてる/脱ぎ捨てる/脱捨てる"},"ぬく":{"variants":"ぬく/抜く"},"抜く":{"variants":"ぬく/抜く"},"ぬくもり":{"variants":"ぬくもり/温もり"},"温もり":{"variants":"ぬくもり/温もり"},"ぬくもる":{"variants":"ぬくもる/温もる"},"温もる":{"variants":"ぬくもる/温もる"},"ぬぐ":{"variants":"ぬぐ/脱ぐ"},"脱ぐ":{"variants":"ぬぐ/脱ぐ"},"ぬぐいさる":{"variants":"ぬぐいさる/ぬぐい去る"},"ぬぐい去る":{"variants":"ぬぐいさる/ぬぐい去る"},"ぬぐいされる":{"variants":"ぬぐいされる/ぬぐい去れる"},"ぬぐい去れる":{"variants":"ぬぐいされる/ぬぐい去れる"},"ぬぐいとる":{"variants":"ぬぐいとる/ぬぐい取る"},"ぬぐい取る":{"variants":"ぬぐいとる/ぬぐい取る"},"ぬぐう":{"variants":"ぬぐう/拭う"},"拭う":{"variants":"ぬぐう/拭う"},"ぬぐえる":{"variants":"ぬぐえる/拭える"},"拭える":{"variants":"ぬぐえる/拭える"},"ぬけあがる":{"variants":"ぬけあがる/抜けあがる"},"抜けあがる":{"variants":"ぬけあがる/抜けあがる"},"抜け穴":{"variants":"抜け穴/抜穴"},"抜穴":{"variants":"抜け穴/抜穴"},"抜けがけ":{"variants":"抜けがけ/抜駆け"},"抜駆け":{"variants":"抜けがけ/抜駆け"},"ぬけ殻":{"variants":"ぬけ殻/脱殻/抜け殻/抜殻"},"抜け殻":{"variants":"ぬけ殻/抜け殻/抜殻"},"抜殻":{"variants":"ぬけ殻/抜け殻/抜殻"},"抜け毛":{"variants":"抜け毛/抜毛"},"抜毛":{"variants":"抜け毛/抜毛"},"ぬけだす":{"variants":"ぬけだす/抜け出す"},"抜け出す":{"variants":"ぬけだす/抜け出す"},"ぬけだせる":{"variants":"ぬけだせる/抜け出せる"},"抜け出せる":{"variants":"ぬけだせる/抜け出せる"},"ぬけでる":{"variants":"ぬけでる/抜けでる/抜け出る"},"抜けでる":{"variants":"ぬけでる/抜けでる/抜け出る"},"抜け出る":{"variants":"ぬけでる/抜けでる/抜け出る"},"抜け道":{"variants":"抜け道/抜道"},"抜道":{"variants":"抜け道/抜道"},"抜け目":{"variants":"抜け目/抜目"},"抜目":{"variants":"抜け目/抜目"},"ぬける":{"variants":"ぬける/抜ける"},"抜ける":{"variants":"ぬける/抜ける"},"ぬげる":{"variants":"ぬげる/脱げる"},"脱げる":{"variants":"ぬげる/脱げる"},"ぬすみだす":{"variants":"ぬすみだす/盗み出す"},"盗み出す":{"variants":"ぬすみだす/盗み出す"},"ぬすみだせる":{"variants":"ぬすみだせる/盗み出せる"},"盗み出せる":{"variants":"ぬすみだせる/盗み出せる"},"ぬすむ":{"variants":"ぬすむ/盗む"},"盗む":{"variants":"ぬすむ/盗む"},"ぬすめる":{"variants":"ぬすめる/盗める"},"盗める":{"variants":"ぬすめる/盗める"},"ぬらす":{"variants":"ぬらす/濡らす"},"濡らす":{"variants":"ぬらす/濡らす"},"塗":{"variants":"塗/塗り"},"塗り":{"variants":"塗/塗り"},"塗り絵":{"variants":"塗り絵/塗絵"},"塗絵":{"variants":"塗り絵/塗絵"},"塗り薬":{"variants":"塗り薬/塗薬"},"塗薬":{"variants":"塗り薬/塗薬"},"ぬりたくる":{"variants":"ぬりたくる/塗りたくる"},"塗りたくる":{"variants":"ぬりたくる/塗りたくる"},"塗りたて":{"variants":"塗りたて/塗立"},"塗立":{"variants":"塗りたて/塗立"},"ぬりたてる":{"variants":"ぬりたてる/塗り立てる/塗立てる"},"塗り立てる":{"variants":"ぬりたてる/塗り立てる/塗立てる"},"塗立てる":{"variants":"ぬりたてる/塗り立てる/塗立てる"},"ぬりつける":{"variants":"ぬりつける/塗りつける/塗り付ける/塗付ける"},"塗りつける":{"variants":"ぬりつける/塗りつける/塗り付ける/塗付ける"},"塗り付ける":{"variants":"ぬりつける/塗りつける/塗り付ける/塗付ける"},"塗付ける":{"variants":"ぬりつける/塗りつける/塗り付ける/塗付ける"},"ぬりつぶす":{"variants":"ぬりつぶす/塗りつぶす/塗り潰す"},"塗りつぶす":{"variants":"ぬりつぶす/塗りつぶす/塗り潰す"},"塗り潰す":{"variants":"ぬりつぶす/塗りつぶす/塗り潰す"},"ぬりつぶせる":{"variants":"ぬりつぶせる/塗りつぶせる"},"塗りつぶせる":{"variants":"ぬりつぶせる/塗りつぶせる"},"ぬる":{"variants":"ぬる/塗る"},"塗る":{"variants":"ぬる/塗る"},"ヌルデ":{"variants":"ヌルデ/白膠木"},"白膠木":{"variants":"ヌルデ/白膠木"},"ぬるぬる":{"variants":"ぬるぬる/ヌルヌル"},"ヌルヌル":{"variants":"ぬるぬる/ヌルヌル"},"ぬるま湯":{"variants":"ぬるま湯/微温湯"},"微温湯":{"variants":"ぬるま湯/微温湯"},"ぬるむ":{"variants":"ぬるむ/温む"},"温む":{"variants":"ぬるむ/温む"},"濡れ縁":{"variants":"濡れ縁/濡縁"},"濡縁":{"variants":"濡れ縁/濡縁"},"濡れ衣":{"variants":"濡れ衣/濡衣"},"濡衣":{"variants":"濡れ衣/濡衣"},"濡れ事":{"variants":"濡れ事/濡事"},"濡事":{"variants":"濡れ事/濡事"},"ぬれそぼつ":{"variants":"ぬれそぼつ/濡れそぼつ"},"濡れそぼつ":{"variants":"ぬれそぼつ/濡れそぼつ"},"ぬれ手":{"variants":"ぬれ手/濡手"},"濡手":{"variants":"ぬれ手/濡手"},"濡れ場":{"variants":"濡れ場/濡場"},"濡場":{"variants":"濡れ場/濡場"},"ぬれる":{"variants":"ぬれる/濡れる"},"濡れる":{"variants":"ぬれる/濡れる"},"ね":{"variants":"ね/ネ"},"ネ":{"variants":"ね/ネ"},"ネイモ":{"variants":"ネイモ/根芋"},"根芋":{"variants":"ネイモ/根芋"},"寝入りばな":{"variants":"寝入りばな/寝入り端"},"寝入り端":{"variants":"寝入りばな/寝入り端"},"ねいる":{"variants":"ねいる/寝入る"},"寝入る":{"variants":"ねいる/寝入る"},"値うち":{"variants":"値うち/値打/値打ち"},"値打":{"variants":"値うち/値打/値打ち"},"値打ち":{"variants":"値うち/値打/値打ち"},"ねぇ":{"variants":"ねぇ/ねェ"},"ねェ":{"variants":"ねぇ/ねェ"},"ねえ":{"variants":"ねえ/ねエ"},"ねエ":{"variants":"ねえ/ねエ"},"ねかしつける":{"variants":"ねかしつける/寝かしつける/寝かし付ける"},"寝かしつける":{"variants":"ねかしつける/寝かしつける/寝かし付ける"},"寝かし付ける":{"variants":"ねかしつける/寝かしつける/寝かし付ける"},"ねかす":{"variants":"ねかす/寝かす"},"寝かす":{"variants":"ねかす/寝かす"},"ねかせる":{"variants":"ねかせる/寝かせる"},"寝かせる":{"variants":"ねかせる/寝かせる"},"ねから":{"variants":"ねから/根から"},"根から":{"variants":"ねから/根から"},"願いごと":{"variants":"願いごと/願い事/願事"},"願い事":{"variants":"願いごと/願い事/願事"},"願事":{"variants":"願いごと/願い事/願事"},"ねがいさげる":{"variants":"ねがいさげる/願い下げる"},"願い下げる":{"variants":"ねがいさげる/願い下げる"},"願い出る":{"variants":"ねがいでる/願い出る/願出る"},"ねがいでる":{"variants":"ねがいでる/願い出る/願出る"},"願出る":{"variants":"ねがいでる/願い出る/願出る"},"ねがう":{"variants":"ねがう/願う"},"願う":{"variants":"ねがう/願う"},"ねがえる":{"variants":"ねがえる/寝返る"},"願える":{"variants":"ねがえる/願える"},"寝返る":{"variants":"ねがえる/寝返る"},"ねがわくは":{"variants":"ねがわくは/願わくは"},"願わくは":{"variants":"ねがわくは/願わくは"},"ねがわしい":{"variants":"ねがわしい/願わしい"},"願わしい":{"variants":"ねがわしい/願わしい"},"ネキリムシ":{"variants":"ネキリムシ/根切り虫/根切虫"},"根切り虫":{"variants":"ネキリムシ/根切り虫/根切虫"},"根切虫":{"variants":"ネキリムシ/根切り虫/根切虫"},"ねぎ":{"variants":"ねぎ/ネギ/禰宜/葱"},"ネギ":{"variants":"ねぎ/ネギ/禰宜/葱"},"祈ぎごと":{"variants":"祈ぎごと/祈ぎ事"},"祈ぎ事":{"variants":"祈ぎごと/祈ぎ事"},"ねぎらう":{"variants":"ねぎらう/労う/犒う"},"ねぎる":{"variants":"ねぎる/値切る"},"値切る":{"variants":"ねぎる/値切る"},"ねぎれる":{"variants":"ねぎれる/値切れる"},"値切れる":{"variants":"ねぎれる/値切れる"},"ネクタイどめ":{"variants":"ネクタイどめ/ネクタイ止/ネクタイ止め"},"ネクタイ止":{"variants":"ネクタイどめ/ネクタイ止/ネクタイ止め"},"ネクタイ止め":{"variants":"ネクタイどめ/ネクタイ止/ネクタイ止め"},"ねぐ":{"variants":"ねぐ/祈ぐ"},"祈ぐ":{"variants":"ねぐ/祈ぐ"},"ねぐる":{"variants":"ねぐる/ネグる"},"ネグる":{"variants":"ねぐる/ネグる"},"ねぐるしい":{"variants":"ねぐるしい/寝苦しい"},"寝苦しい":{"variants":"ねぐるしい/寝苦しい"},"ネコ":{"variants":"ネコ/猫"},"猫":{"variants":"ネコ/猫"},"猫かぶり":{"variants":"猫かぶり/猫被り"},"猫被り":{"variants":"猫かぶり/猫被り"},"ネコジャラシ":{"variants":"ネコジャラシ/猫じゃらし"},"猫じゃらし":{"variants":"ネコジャラシ/猫じゃらし"},"ねこそぎ":{"variants":"ねこそぎ/根こそぎ"},"根こそぎ":{"variants":"ねこそぎ/根こそぎ"},"ねこなで声":{"variants":"ねこなで声/猫なで声/猫撫で声"},"猫なで声":{"variants":"ねこなで声/猫なで声/猫撫で声"},"猫撫で声":{"variants":"ねこなで声/猫なで声/猫撫で声"},"ねこむ":{"variants":"ねこむ/寝込む"},"寝込む":{"variants":"ねこむ/寝込む"},"ネコヤナギ":{"variants":"ネコヤナギ/猫柳"},"猫柳":{"variants":"ネコヤナギ/猫柳"},"ねころがる":{"variants":"ねころがる/寝転がる"},"寝転がる":{"variants":"ねころがる/寝転がる"},"ねころぶ":{"variants":"ねころぶ/寝ころぶ/寝転ぶ"},"寝ころぶ":{"variants":"ねころぶ/寝ころぶ/寝転ぶ"},"寝転ぶ":{"variants":"ねころぶ/寝ころぶ/寝転ぶ"},"ねころべる":{"variants":"ねころべる/寝ころべる"},"寝ころべる":{"variants":"ねころべる/寝ころべる"},"ねざす":{"variants":"ねざす/根ざす/根差す"},"根ざす":{"variants":"ねざす/根ざす/根差す"},"根差す":{"variants":"ねざす/根ざす/根差す"},"ねしずまる":{"variants":"ねしずまる/寝静まる"},"寝静まる":{"variants":"ねしずまる/寝静まる"},"ねじ":{"variants":"ねじ/ネジ/捻子/螺子/捩子"},"ネジ":{"variants":"ねじ/ネジ/捻子/螺子/捩子"},"ねじあう":{"variants":"ねじあう/ねじ合う/捩じ合う"},"ねじ合う":{"variants":"ねじあう/ねじ合う/捩じ合う"},"捩じ合う":{"variants":"ねじあう/ねじ合う/捩じ合う"},"ねじあげる":{"variants":"ねじあげる/ねじ上げる/捩じ上げる"},"ねじ上げる":{"variants":"ねじあげる/ねじ上げる/捩じ上げる"},"捩じ上げる":{"variants":"ねじあげる/ねじ上げる/捩じ上げる"},"ねじ切り":{"variants":"ねじ切り/螺子切"},"螺子切":{"variants":"ねじ切り/螺子切"},"ねじきる":{"variants":"ねじきる/ねじ切る/捩じ切る"},"ねじ切る":{"variants":"ねじきる/ねじ切る/捩じ切る"},"捩じ切る":{"variants":"ねじきる/ねじ切る/捩じ切る"},"ネジクギ":{"variants":"ネジクギ/螺子釘"},"螺子釘":{"variants":"ネジクギ/螺子釘"},"ねじくれる":{"variants":"ねじくれる/捻くれる/捻じくれる/拗くれる/拗じくれる/捩くれる/捩じくれる"},"拗じくれる":{"variants":"ねじくれる/拗くれる/拗じくれる"},"拗くれる":{"variants":"ねじくれる/拗くれる/拗じくれる"},"捻じくれる":{"variants":"ねじくれる/捻くれる/捻じくれる"},"捩じくれる":{"variants":"ねじくれる/捩くれる/捩じくれる"},"捻くれる":{"variants":"ねじくれる/捻くれる/捻じくれる"},"捩くれる":{"variants":"ねじくれる/捩くれる/捩じくれる"},"ねじける":{"variants":"ねじける/拗ける"},"拗ける":{"variants":"ねじける/拗ける"},"ねじこむ":{"variants":"ねじこむ/ねじ込む/捩じこむ/捩じ込む"},"ねじ込む":{"variants":"ねじこむ/ねじ込む/捩じこむ/捩じ込む"},"捩じこむ":{"variants":"ねじこむ/ねじ込む/捩じこむ/捩じ込む"},"捩じ込む":{"variants":"ねじこむ/ねじ込む/捩じこむ/捩じ込む"},"ねじこめる":{"variants":"ねじこめる/ねじ込める"},"ねじ込める":{"variants":"ねじこめる/ねじ込める"},"ネジバナ":{"variants":"ネジバナ/捩花"},"捩花":{"variants":"ネジバナ/捩花"},"ねじふせる":{"variants":"ねじふせる/ねじ伏せる/捩じ伏せる"},"ねじ伏せる":{"variants":"ねじふせる/ねじ伏せる/捩じ伏せる"},"捩じ伏せる":{"variants":"ねじふせる/ねじ伏せる/捩じ伏せる"},"ねじまげる":{"variants":"ねじまげる/ねじ曲げる"},"ねじ曲げる":{"variants":"ねじまげる/ねじ曲げる"},"ねじむける":{"variants":"ねじむける/ねじ向ける/捩じ向ける"},"ねじ向ける":{"variants":"ねじむける/ねじ向ける/捩じ向ける"},"捩じ向ける":{"variants":"ねじむける/ねじ向ける/捩じ向ける"},"根締":{"variants":"根締/根締め"},"根締め":{"variants":"根締/根締め"},"音締":{"variants":"音締/音締め"},"音締め":{"variants":"音締/音締め"},"ねじり鉢巻":{"variants":"ねじり鉢巻/捩り鉢巻"},"捩り鉢巻":{"variants":"ねじり鉢巻/捩り鉢巻"},"ねじる":{"variants":"ねじる/捻じる/拗じる/拗る/捩じる"},"拗る":{"variants":"ねじる/拗じる/拗る"},"拗じる":{"variants":"ねじる/拗じる/拗る"},"ねすごす":{"variants":"ねすごす/寝過ごす/寝過す"},"寝過ごす":{"variants":"ねすごす/寝過ごす/寝過す"},"寝過す":{"variants":"ねすごす/寝過ごす/寝過す"},"ネズミ":{"variants":"ネズミ/鼠"},"鼠":{"variants":"ネズミ/鼠"},"ねずみ色":{"variants":"ねずみ色/鼠色"},"鼠色":{"variants":"ねずみ色/鼠色"},"ねずみ算":{"variants":"ねずみ算/鼠算"},"鼠算":{"variants":"ねずみ算/鼠算"},"ねせる":{"variants":"ねせる/寝せる"},"寝せる":{"variants":"ねせる/寝せる"},"ねそびれる":{"variants":"ねそびれる/寝そびれる"},"寝そびれる":{"variants":"ねそびれる/寝そびれる"},"ねそべる":{"variants":"ねそべる/寝そべる"},"寝そべる":{"variants":"ねそべる/寝そべる"},"ねたましい":{"variants":"ねたましい/妬ましい"},"妬ましい":{"variants":"ねたましい/妬ましい"},"ねたむ":{"variants":"ねたむ/妬む"},"妬む":{"variants":"ねたむ/妬む"},"ねだる":{"variants":"ねだる/強請る"},"強請る":{"variants":"ねだる/強請る"},"ねちがえる":{"variants":"ねちがえる/寝違える"},"寝違える":{"variants":"ねちがえる/寝違える"},"ＮＥＴ":{"variants":"ＮＥＴ/ネット"},"ネット":{"variants":"ＮＥＴ/ネット"},"ねつく":{"variants":"ねつく/寝つく/寝付く"},"寝つく":{"variants":"ねつく/寝つく/寝付く"},"寝付く":{"variants":"ねつく/寝つく/寝付く"},"根付":{"variants":"根付/根付け"},"根付け":{"variants":"根付/根付け"},"ねつける":{"variants":"ねつける/寝つける/寝付ける"},"寝つける":{"variants":"ねつける/寝つける/寝付ける"},"寝付ける":{"variants":"ねつける/寝つける/寝付ける"},"ねつ造":{"variants":"ねつ造/捏造"},"捏造":{"variants":"ねつ造/捏造"},"ねつっぽい":{"variants":"ねつっぽい/熱っぽい"},"熱っぽい":{"variants":"ねつっぽい/熱っぽい"},"ねづく":{"variants":"ねづく/根づく"},"根づく":{"variants":"ねづく/根づく"},"ねづよい":{"variants":"ねづよい/根づよい/根強い"},"根づよい":{"variants":"ねづよい/根づよい/根強い"},"根強い":{"variants":"ねづよい/根づよい/根強い"},"ねとぼける":{"variants":"ねとぼける/寝とぼける"},"寝とぼける":{"variants":"ねとぼける/寝とぼける"},"ねとる":{"variants":"ねとる/寝取る"},"寝取る":{"variants":"ねとる/寝取る"},"根無し草":{"variants":"根無し草/根無草"},"根無草":{"variants":"根無し草/根無草"},"子の日":{"variants":"子の日/子日"},"子日":{"variants":"子の日/子日"},"ねばい":{"variants":"ねばい/粘い"},"粘い":{"variants":"ねばい/粘い"},"ねばっこい":{"variants":"ねばっこい/粘っこい"},"粘っこい":{"variants":"ねばっこい/粘っこい"},"ねばつく":{"variants":"ねばつく/粘つく/粘着く"},"粘つく":{"variants":"ねばつく/粘つく/粘着く"},"粘着く":{"variants":"ねばつく/粘つく/粘着く"},"ねばねば":{"variants":"ねばねば/ネバネバ"},"ネバネバ":{"variants":"ねばねば/ネバネバ"},"粘りけ":{"variants":"粘りけ/粘り気"},"粘り気":{"variants":"粘りけ/粘り気"},"ねばりづよい":{"variants":"ねばりづよい/ねばり強い/粘り強い/粘強い"},"ねばり強い":{"variants":"ねばりづよい/ねばり強い/粘り強い/粘強い"},"粘り強い":{"variants":"ねばりづよい/ねばり強い/粘り強い/粘強い"},"粘強い":{"variants":"ねばりづよい/ねばり強い/粘り強い/粘強い"},"ねばりぬく":{"variants":"ねばりぬく/粘り抜く"},"粘り抜く":{"variants":"ねばりぬく/粘り抜く"},"ねばりぬける":{"variants":"ねばりぬける/粘り抜ける"},"粘り抜ける":{"variants":"ねばりぬける/粘り抜ける"},"ねばる":{"variants":"ねばる/粘る"},"粘る":{"variants":"ねばる/粘る"},"ねぶかい":{"variants":"ねぶかい/根深い"},"根深い":{"variants":"ねぶかい/根深い"},"寝ぶくろ":{"variants":"寝ぶくろ/寝袋"},"寝袋":{"variants":"寝ぶくろ/寝袋"},"ねぶる":{"variants":"ねぶる/舐る"},"舐る":{"variants":"ねぶる/舐る"},"ねぼける":{"variants":"ねぼける/寝ぼける"},"寝ぼける":{"variants":"ねぼける/寝ぼける"},"寝待の月":{"variants":"寝待の月/寝待月"},"寝待月":{"variants":"寝待の月/寝待月"},"根まわし":{"variants":"根まわし/根回し"},"根回し":{"variants":"根まわし/根回し"},"ねむい":{"variants":"ねむい/眠い"},"眠い":{"variants":"ねむい/眠い"},"眠け":{"variants":"眠け/眠気"},"眠気":{"variants":"眠け/眠気"},"眠け覚まし":{"variants":"眠け覚まし/眠気ざまし/眠気覚し"},"眠気ざまし":{"variants":"眠け覚まし/眠気ざまし/眠気覚し"},"眠気覚し":{"variants":"眠け覚まし/眠気ざまし/眠気覚し"},"ねむたい":{"variants":"ねむたい/眠たい"},"眠たい":{"variants":"ねむたい/眠たい"},"ねむらす":{"variants":"ねむらす/眠らす"},"眠らす":{"variants":"ねむらす/眠らす"},"ねむらせる":{"variants":"ねむらせる/眠らせる"},"眠らせる":{"variants":"ねむらせる/眠らせる"},"ネムリグサ":{"variants":"ネムリグサ/眠草"},"眠草":{"variants":"ネムリグサ/眠草"},"眠りぐすり":{"variants":"眠りぐすり/眠り薬"},"眠り薬":{"variants":"眠りぐすり/眠り薬"},"ねむりこける":{"variants":"ねむりこける/眠りこける"},"眠りこける":{"variants":"ねむりこける/眠りこける"},"ねむりこむ":{"variants":"ねむりこむ/眠りこむ/眠り込む"},"眠りこむ":{"variants":"ねむりこむ/眠りこむ/眠り込む"},"眠り込む":{"variants":"ねむりこむ/眠りこむ/眠り込む"},"ねむる":{"variants":"ねむる/睡る/眠る"},"ねむれる":{"variants":"ねむれる/眠れる"},"眠れる":{"variants":"ねむれる/眠れる"},"ねめる":{"variants":"ねめる/睨める"},"睨める":{"variants":"ねめる/睨める"},"ねらいうつ":{"variants":"ねらいうつ/ねらい打つ/狙い打つ"},"ねらい打つ":{"variants":"ねらいうつ/ねらい打つ/狙い打つ"},"狙い打つ":{"variants":"ねらいうつ/ねらい打つ/狙い打つ"},"ねらいうてる":{"variants":"ねらいうてる/ねらい打てる"},"ねらい打てる":{"variants":"ねらいうてる/ねらい打てる"},"ねらう":{"variants":"ねらう/狙う"},"狙う":{"variants":"ねらう/狙う"},"ねらえる":{"variants":"ねらえる/狙える"},"狙える":{"variants":"ねらえる/狙える"},"ねらわれる":{"variants":"ねらわれる/狙われる"},"狙われる":{"variants":"ねらわれる/狙われる"},"練り":{"variants":"練/練り"},"練":{"variants":"練/練り"},"ねりあげる":{"variants":"ねりあげる/練り上げる"},"練り上げる":{"variants":"ねりあげる/練り上げる"},"ねりあるく":{"variants":"ねりあるく/練り歩く/練歩く"},"練り歩く":{"variants":"ねりあるく/練り歩く/練歩く"},"練歩く":{"variants":"ねりあるく/練り歩く/練歩く"},"ねりあわす":{"variants":"ねりあわす/練り合わす"},"練り合わす":{"variants":"ねりあわす/練り合わす"},"ねりあわせる":{"variants":"ねりあわせる/ねり合せる/煉りあわせる/煉り合せる/練りあわせる/練り合せる/練り合わせる"},"ねり合せる":{"variants":"ねりあわせる/ねり合せる/煉りあわせる/煉り合せる/練りあわせる/練り合せる/練り合わせる"},"練りあわせる":{"variants":"ねりあわせる/ねり合せる/練りあわせる/練り合せる/練り合わせる"},"煉り合せる":{"variants":"ねりあわせる/ねり合せる/煉りあわせる/煉り合せる"},"練り合せる":{"variants":"ねりあわせる/ねり合せる/練りあわせる/練り合せる/練り合わせる"},"練り合わせる":{"variants":"ねりあわせる/ねり合せる/練りあわせる/練り合せる/練り合わせる"},"煉りあわせる":{"variants":"ねりあわせる/ねり合せる/煉りあわせる/煉り合せる"},"練り製品":{"variants":"練り製品/練製品"},"練製品":{"variants":"練り製品/練製品"},"ねりなおす":{"variants":"ねりなおす/練り直す/練直す"},"練り直す":{"variants":"ねりなおす/練り直す/練直す"},"練直す":{"variants":"ねりなおす/練り直す/練直す"},"ねりなおせる":{"variants":"ねりなおせる/練り直せる"},"練り直せる":{"variants":"ねりなおせる/練り直せる"},"練りもの":{"variants":"練りもの/練り物/練物"},"練り物":{"variants":"練りもの/練り物/練物"},"練物":{"variants":"練りもの/練り物/練物"},"ねる":{"variants":"ねる/煉る/練る/錬る"},"寝る":{"variants":"ねる/寝る"},"ねれる":{"variants":"ねれる/煉れる/練れる/錬れる"},"ねわすれる":{"variants":"ねわすれる/寝忘れる"},"寝忘れる":{"variants":"ねわすれる/寝忘れる"},"ねんざ":{"variants":"ねんざ/ねん挫/捻挫"},"ねん挫":{"variants":"ねんざ/ねん挫/捻挫"},"捻挫":{"variants":"ねんざ/ねん挫/捻挫"},"ねん出":{"variants":"ねん出/捻出/拈出"},"ねんじる":{"variants":"ねんじる/念じる"},"念じる":{"variants":"ねんじる/念じる"},"ねんずる":{"variants":"ねんずる/念ずる"},"念ずる":{"variants":"ねんずる/念ずる"},"ねんねん":{"variants":"ねんねん/年年"},"年年":{"variants":"年々/年年"},"念々":{"variants":"念々/念念"},"念念":{"variants":"念々/念念"},"年々":{"variants":"年々/年年"},"ねんねんさいさい":{"variants":"ねんねんさいさい/年年歳歳"},"年年歳歳":{"variants":"ねんねんさいさい/年年歳歳"},"ねんらい":{"variants":"ねんらい/年来"},"年来":{"variants":"ねんらい/年来"},"の":{"variants":"の/ノ/之"},"ノ":{"variants":"の/ノ/之"},"ＮＯ":{"variants":"ＮＯ/ノー"},"ノー":{"variants":"ＮＯ/ノー"},"ノイバラ":{"variants":"ノイバラ/野茨"},"野茨":{"variants":"ノイバラ/野茨"},"脳いっ血":{"variants":"脳いっ血/脳溢血"},"脳溢血":{"variants":"脳いっ血/脳溢血"},"能書":{"variants":"能書/能書き"},"能書き":{"variants":"能書/能書き"},"脳こうそく":{"variants":"脳こうそく/脳硬塞"},"脳硬塞":{"variants":"脳こうそく/脳硬塞"},"脳しゅよう":{"variants":"脳しゅよう/脳腫瘍"},"脳腫瘍":{"variants":"脳しゅよう/脳腫瘍"},"脳しんとう":{"variants":"脳しんとう/脳震とう/脳震盪"},"脳震とう":{"variants":"脳しんとう/脳震とう/脳震盪"},"脳震盪":{"variants":"脳しんとう/脳震とう/脳震盪"},"ノウゼンカズラ":{"variants":"ノウゼンカズラ/凌霄花"},"凌霄花":{"variants":"ノウゼンカズラ/凌霄花"},"嚢胞":{"variants":"のう胞/嚢胞"},"のう胞":{"variants":"のう胞/嚢胞"},"脳みそ":{"variants":"脳みそ/脳味噌"},"脳味噌":{"variants":"脳みそ/脳味噌"},"のがせる":{"variants":"のがせる/逃せる"},"逃せる":{"variants":"のがせる/逃せる"},"のがれる":{"variants":"のがれる/逃れる"},"逃れる":{"variants":"のがれる/逃れる"},"ノキシノブ":{"variants":"ノキシノブ/軒忍"},"軒忍":{"variants":"ノキシノブ/軒忍"},"軒並":{"variants":"軒並/軒並み"},"軒並み":{"variants":"軒並/軒並み"},"のけぞる":{"variants":"のけぞる/のけ反る/仰け反る"},"のけ反る":{"variants":"のけぞる/のけ反る/仰け反る"},"仰け反る":{"variants":"のけぞる/のけ反る/仰け反る"},"のけ者":{"variants":"のけ者/除けもの/除け者"},"除けもの":{"variants":"のけ者/除けもの/除け者"},"除け者":{"variants":"のけ者/除けもの/除け者"},"のこす":{"variants":"のこす/遺す/残す"},"のこせる":{"variants":"のこせる/残せる"},"残せる":{"variants":"のこせる/残せる"},"のこのこ":{"variants":"のこのこ/ノコノコ"},"ノコノコ":{"variants":"のこのこ/ノコノコ"},"のこらず":{"variants":"のこらず/残らず"},"残らず":{"variants":"のこらず/残らず"},"のこりおおい":{"variants":"のこりおおい/残り多い/残多い"},"残り多い":{"variants":"のこりおおい/残り多い/残多い"},"残多い":{"variants":"のこりおおい/残り多い/残多い"},"のこりおしい":{"variants":"のこりおしい/残り惜しい/残惜しい"},"残り惜しい":{"variants":"のこりおしい/残り惜しい/残惜しい"},"残惜しい":{"variants":"のこりおしい/残り惜しい/残惜しい"},"残りもの":{"variants":"残りもの/残り物"},"残り物":{"variants":"残りもの/残り物"},"のこる":{"variants":"のこる/遺る/残る"},"のこれる":{"variants":"のこれる/残れる"},"残れる":{"variants":"のこれる/残れる"},"野ざらし":{"variants":"野ざらし/野晒"},"野晒":{"variants":"野ざらし/野晒"},"のしあがる":{"variants":"のしあがる/のし上がる/伸し上がる"},"のし上がる":{"variants":"のしあがる/のし上がる/伸し上がる"},"伸し上がる":{"variants":"のしあがる/のし上がる/伸し上がる"},"のしあがれる":{"variants":"のしあがれる/のし上がれる"},"のし上がれる":{"variants":"のしあがれる/のし上がれる"},"のしあるく":{"variants":"のしあるく/のし歩く/伸し歩く"},"のし歩く":{"variants":"のしあるく/のし歩く/伸し歩く"},"伸し歩く":{"variants":"のしあるく/のし歩く/伸し歩く"},"のしかかる":{"variants":"のしかかる/伸し掛る"},"伸し掛る":{"variants":"のしかかる/伸し掛る"},"のし紙":{"variants":"のし紙/熨斗紙"},"熨斗紙":{"variants":"のし紙/熨斗紙"},"のし袋":{"variants":"のし袋/熨斗袋"},"熨斗袋":{"variants":"のし袋/熨斗袋"},"のし餅":{"variants":"のし餅/伸し餅"},"伸し餅":{"variants":"のし餅/伸し餅"},"のす":{"variants":"のす/熨す"},"熨す":{"variants":"のす/熨す"},"のせる":{"variants":"のせる/載せる/乗せる"},"のぞきこむ":{"variants":"のぞきこむ/のぞき込む"},"のぞき込む":{"variants":"のぞきこむ/のぞき込む"},"のぞきこめる":{"variants":"のぞきこめる/のぞき込める"},"のぞき込める":{"variants":"のぞきこめる/のぞき込める"},"のぞく":{"variants":"のぞく/除く/覗く"},"のぞける":{"variants":"のぞける/覗ける"},"覗ける":{"variants":"のぞける/覗ける"},"のぞましい":{"variants":"のぞましい/望ましい"},"望ましい":{"variants":"のぞましい/望ましい"},"のぞみ":{"variants":"のぞみ/望み"},"望み":{"variants":"のぞみ/望み"},"のぞむ":{"variants":"のぞむ/望む/臨む"},"のぞめる":{"variants":"のぞめる/挑める/望める/臨める"},"のたまう":{"variants":"のたまう/宣う/曰う"},"野垂れ死に":{"variants":"野垂れ死に/野垂死"},"野垂死":{"variants":"野垂れ死に/野垂死"},"野だて":{"variants":"野だて/野点"},"野点":{"variants":"野だて/野点"},"のちほど":{"variants":"のちほど/後ほど/後程"},"後ほど":{"variants":"のちほど/後ほど/後程"},"後程":{"variants":"のちほど/後ほど/後程"},"のっかる":{"variants":"のっかる/載っかる/乗っかる"},"のっける":{"variants":"のっける/載っける/乗っける"},"のっとる":{"variants":"のっとる/乗っ取る/乗取る/則る/法る"},"乗っ取る":{"variants":"のっとる/乗っ取る/乗取る"},"乗取る":{"variants":"のっとる/乗っ取る/乗取る"},"のっとれる":{"variants":"のっとれる/乗っ取れる"},"乗っ取れる":{"variants":"のっとれる/乗っ取れる"},"のっぴき":{"variants":"のっぴき/退っ引き"},"退っ引き":{"variants":"のっぴき/退っ引き"},"野天ぶろ":{"variants":"野天ぶろ/野天風呂"},"野天風呂":{"variants":"野天ぶろ/野天風呂"},"のど":{"variants":"のど/ノド/喉"},"ノド":{"variants":"のど/ノド/喉"},"喉":{"variants":"のど/ノド/喉"},"のどか":{"variants":"のどか/長閑"},"長閑":{"variants":"のどか/長閑"},"のどけい":{"variants":"のどけい/長閑けい"},"長閑けい":{"variants":"のどけい/長閑けい"},"のど笛":{"variants":"のど笛/喉笛"},"喉笛":{"variants":"のど笛/喉笛"},"のど元":{"variants":"のど元/喉元"},"喉元":{"variants":"のど元/喉元"},"のど輪":{"variants":"のど輪/喉輪"},"喉輪":{"variants":"のど輪/喉輪"},"ノネズミ":{"variants":"ノネズミ/野ねずみ/野鼠"},"野ねずみ":{"variants":"ノネズミ/野ねずみ/野鼠"},"野鼠":{"variants":"ノネズミ/野ねずみ/野鼠"},"ののしる":{"variants":"ののしる/罵る"},"罵る":{"variants":"ののしる/罵る"},"のばす":{"variants":"のばす/延す/延ばす/伸ばす"},"延す":{"variants":"のばす/延す/延ばす"},"延ばす":{"variants":"のばす/延す/延ばす"},"のばせる":{"variants":"のばせる/延ばせる/伸ばせる"},"ノバラ":{"variants":"ノバラ/野ばら/野薔薇"},"野ばら":{"variants":"ノバラ/野ばら/野薔薇"},"野薔薇":{"variants":"ノバラ/野ばら/野薔薇"},"のびあがる":{"variants":"のびあがる/伸び上がる"},"伸び上がる":{"variants":"のびあがる/伸び上がる"},"のびあがれる":{"variants":"のびあがれる/伸び上がれる"},"伸び上がれる":{"variants":"のびあがれる/伸び上がれる"},"のびなやむ":{"variants":"のびなやむ/伸び悩む"},"伸び悩む":{"variants":"のびなやむ/伸び悩む"},"延びのび":{"variants":"延びのび/延び延び"},"延び延び":{"variants":"のびのび/延び延び"},"のびのび":{"variants":"のびのび/延び延び"},"伸び伸び":{"variants":"伸びのび/伸び伸び"},"伸びのび":{"variants":"伸びのび/伸び伸び"},"のびやか":{"variants":"のびやか/伸びやか"},"伸びやか":{"variants":"のびやか/伸びやか"},"のびゆく":{"variants":"のびゆく/伸びゆく"},"伸びゆく":{"variants":"のびゆく/伸びゆく"},"のびる":{"variants":"のびる/延びる/伸びる"},"ノビル":{"variants":"ノビル/野蒜"},"野蒜":{"variants":"ノビル/野蒜"},"のぶとい":{"variants":"のぶとい/野太い"},"野太い":{"variants":"のぶとい/野太い"},"延べ":{"variants":"延/延べ"},"延":{"variants":"延/延べ"},"延べ人員":{"variants":"延べ人員/延人員"},"延人員":{"variants":"延べ人員/延人員"},"延べ日数":{"variants":"延べ日数/延日数"},"延日数":{"variants":"延べ日数/延日数"},"のべる":{"variants":"のべる/延べる/述べる/伸べる/陳べる"},"のぼせあがる":{"variants":"のぼせあがる/のぼせ上がる"},"のぼせ上がる":{"variants":"のぼせあがる/のぼせ上がる"},"のぼせる":{"variants":"のぼせる/逆上せる/上せる"},"のぼり":{"variants":"のぼり/昇り/登り/幟"},"のぼり坂":{"variants":"のぼり坂/上り坂"},"上り坂":{"variants":"のぼり坂/上り坂"},"のぼりつめる":{"variants":"のぼりつめる/上り詰める/登りつめる/登り詰める"},"登り詰める":{"variants":"のぼりつめる/登りつめる/登り詰める"},"登りつめる":{"variants":"のぼりつめる/登りつめる/登り詰める"},"のぼる":{"variants":"のぼる/昇る/上る/登る"},"のぼれる":{"variants":"のぼれる/昇れる/上れる/登れる"},"のます":{"variants":"のます/飲ます"},"飲ます":{"variants":"のます/飲ます"},"のみ":{"variants":"のみ/ノミ/蚤/鑿"},"ノミ":{"variants":"のみ/ノミ/蚤/鑿"},"のみあかす":{"variants":"のみあかす/飲み明かす/飲明かす/呑み明かす/呑明かす"},"飲明かす":{"variants":"のみあかす/飲み明かす/飲明かす"},"飲み明かす":{"variants":"のみあかす/飲み明かす/飲明かす"},"呑明かす":{"variants":"のみあかす/呑み明かす/呑明かす"},"呑み明かす":{"variants":"のみあかす/呑み明かす/呑明かす"},"飲み食い":{"variants":"飲み食い/飲食い"},"飲食い":{"variants":"飲み食い/飲食い"},"のみくだす":{"variants":"のみくだす/飲み下す/飲下す"},"飲み下す":{"variants":"のみくだす/飲み下す/飲下す"},"飲下す":{"variants":"のみくだす/飲み下す/飲下す"},"呑み込み":{"variants":"呑みこみ/呑み込み/呑込み"},"呑みこみ":{"variants":"呑みこみ/呑み込み/呑込み"},"飲込み":{"variants":"飲みこみ/飲み込み/飲込み"},"飲み込み":{"variants":"飲みこみ/飲み込み/飲込み"},"飲みこみ":{"variants":"飲みこみ/飲み込み/飲込み"},"呑込み":{"variants":"呑みこみ/呑み込み/呑込み"},"のみこむ":{"variants":"のみこむ/のみ込む/飲みこむ/飲み込む/飲込む/呑みこむ/呑み込む"},"のみ込む":{"variants":"のみこむ/のみ込む/飲みこむ/飲み込む/飲込む/呑みこむ/呑み込む"},"呑み込む":{"variants":"のみこむ/のみ込む/呑みこむ/呑み込む"},"呑みこむ":{"variants":"のみこむ/のみ込む/呑みこむ/呑み込む"},"飲込む":{"variants":"のみこむ/のみ込む/飲みこむ/飲み込む/飲込む"},"飲み込む":{"variants":"のみこむ/のみ込む/飲みこむ/飲み込む/飲込む"},"飲みこむ":{"variants":"のみこむ/のみ込む/飲みこむ/飲み込む/飲込む"},"のみこめる":{"variants":"のみこめる/飲み込める/呑み込める"},"飲み代":{"variants":"飲み代/飲代"},"飲代":{"variants":"飲み代/飲代"},"飲み助":{"variants":"飲み助/飲助"},"飲助":{"variants":"飲み助/飲助"},"のみつぶす":{"variants":"のみつぶす/飲みつぶす/飲み潰す/飲潰す/呑みつぶす/呑み潰す"},"呑み潰す":{"variants":"のみつぶす/呑みつぶす/呑み潰す"},"呑みつぶす":{"variants":"のみつぶす/呑みつぶす/呑み潰す"},"飲潰す":{"variants":"のみつぶす/飲みつぶす/飲み潰す/飲潰す"},"飲み潰す":{"variants":"のみつぶす/飲みつぶす/飲み潰す/飲潰す"},"飲みつぶす":{"variants":"のみつぶす/飲みつぶす/飲み潰す/飲潰す"},"のみつぶれる":{"variants":"のみつぶれる/飲みつぶれる/飲み潰れる/呑みつぶれる/呑み潰れる"},"呑み潰れる":{"variants":"のみつぶれる/呑みつぶれる/呑み潰れる"},"呑みつぶれる":{"variants":"のみつぶれる/呑みつぶれる/呑み潰れる"},"飲み潰れる":{"variants":"のみつぶれる/飲みつぶれる/飲み潰れる"},"飲みつぶれる":{"variants":"のみつぶれる/飲みつぶれる/飲み潰れる"},"のみの市":{"variants":"のみの市/蚤の市"},"蚤の市":{"variants":"のみの市/蚤の市"},"のみほす":{"variants":"のみほす/飲みほす/飲み乾す/飲み干す/飲干す"},"飲みほす":{"variants":"のみほす/飲みほす/飲み乾す/飲み干す/飲干す"},"飲み干す":{"variants":"のみほす/飲みほす/飲み干す/飲干す"},"飲干す":{"variants":"のみほす/飲みほす/飲み干す/飲干す"},"のみほせる":{"variants":"のみほせる/飲み干せる"},"飲み干せる":{"variants":"のみほせる/飲み干せる"},"のみまわす":{"variants":"のみまわす/飲みまわす/飲み回す/飲回す"},"飲みまわす":{"variants":"のみまわす/飲みまわす/飲み回す/飲回す"},"飲み回す":{"variants":"のみまわす/飲みまわす/飲み回す/飲回す"},"飲回す":{"variants":"のみまわす/飲みまわす/飲み回す/飲回す"},"飲みもの":{"variants":"飲みもの/飲み物/飲物"},"飲み物":{"variants":"飲みもの/飲み物/飲物"},"飲物":{"variants":"飲みもの/飲み物/飲物"},"飲み屋":{"variants":"飲み屋/飲屋"},"呑屋":{"variants":"呑み屋/呑屋"},"呑み屋":{"variants":"呑み屋/呑屋"},"飲屋":{"variants":"飲み屋/飲屋"},"のむ":{"variants":"のむ/飲む/呑む"},"のめりこむ":{"variants":"のめりこむ/のめり込む"},"のめり込む":{"variants":"のめりこむ/のめり込む"},"のめる":{"variants":"のめる/飲める/呑める"},"のら犬":{"variants":"のら犬/野良犬"},"野良犬":{"variants":"のら犬/野良犬"},"野良ねこ":{"variants":"野良ねこ/野良猫"},"野良猫":{"variants":"野良ねこ/野良猫"},"のり":{"variants":"のり/ノリ/海苔/糊/乗り"},"ノリ":{"variants":"のり/ノリ/海苔/糊/乗り"},"乗り合い":{"variants":"乗り合い/乗合"},"乗合":{"variants":"乗り合い/乗合"},"のりあげる":{"variants":"のりあげる/乗り上げる/乗上げる"},"乗り上げる":{"variants":"のりあげる/乗り上げる/乗上げる"},"乗上げる":{"variants":"のりあげる/乗り上げる/乗上げる"},"のりあわす":{"variants":"のりあわす/乗り合わす"},"乗り合わす":{"variants":"のりあわす/乗り合わす"},"のりあわせる":{"variants":"のりあわせる/乗り合せる/乗り合わせる/乗合せる"},"乗り合せる":{"variants":"のりあわせる/乗り合せる/乗り合わせる/乗合せる"},"乗り合わせる":{"variants":"のりあわせる/乗り合せる/乗り合わせる/乗合せる"},"乗合せる":{"variants":"のりあわせる/乗り合せる/乗り合わせる/乗合せる"},"のりいれる":{"variants":"のりいれる/乗り入れる/乗入れる"},"乗り入れる":{"variants":"のりいれる/乗り入れる/乗入れる"},"乗入れる":{"variants":"のりいれる/乗り入れる/乗入れる"},"のりうつる":{"variants":"のりうつる/乗り移る/乗移る"},"乗り移る":{"variants":"のりうつる/乗り移る/乗移る"},"乗移る":{"variants":"のりうつる/乗り移る/乗移る"},"のりおくれる":{"variants":"のりおくれる/乗り後れる/乗り遅れる/乗後れる/乗遅れる"},"乗り後れる":{"variants":"のりおくれる/乗り後れる/乗後れる"},"乗遅れる":{"variants":"のりおくれる/乗り遅れる/乗遅れる"},"乗後れる":{"variants":"のりおくれる/乗り後れる/乗後れる"},"乗り遅れる":{"variants":"のりおくれる/乗り遅れる/乗遅れる"},"乗りかえ":{"variants":"乗りかえ/乗り換え/乗換"},"乗り換え":{"variants":"乗りかえ/乗り換え/乗換"},"乗換":{"variants":"乗りかえ/乗り換え/乗換"},"のりかえる":{"variants":"のりかえる/乗りかえる/乗り換える/乗換える"},"乗りかえる":{"variants":"のりかえる/乗りかえる/乗り換える/乗換える"},"乗り換える":{"variants":"のりかえる/乗りかえる/乗り換える/乗換える"},"乗換える":{"variants":"のりかえる/乗りかえる/乗り換える/乗換える"},"のりかかる":{"variants":"のりかかる/乗りかかる/乗り掛かる/乗り掛る"},"乗りかかる":{"variants":"のりかかる/乗りかかる/乗り掛かる/乗り掛る"},"乗り掛かる":{"variants":"のりかかる/乗りかかる/乗り掛かる/乗り掛る"},"乗り掛る":{"variants":"のりかかる/乗りかかる/乗り掛かる/乗り掛る"},"のりかける":{"variants":"のりかける/乗りかける/乗り掛ける/乗掛ける"},"乗りかける":{"variants":"のりかける/乗りかける/乗り掛ける/乗掛ける"},"乗り掛ける":{"variants":"のりかける/乗りかける/乗り掛ける/乗掛ける"},"乗掛ける":{"variants":"のりかける/乗りかける/乗り掛ける/乗掛ける"},"のりきる":{"variants":"のりきる/乗りきる/乗り切る/乗切る"},"乗りきる":{"variants":"のりきる/乗りきる/乗り切る/乗切る"},"乗り切る":{"variants":"のりきる/乗りきる/乗り切る/乗切る"},"乗切る":{"variants":"のりきる/乗りきる/乗り切る/乗切る"},"のりきれる":{"variants":"のりきれる/乗り切れる"},"乗り切れる":{"variants":"のりきれる/乗り切れる"},"のりくむ":{"variants":"のりくむ/乗り組む/乗組む"},"乗り組む":{"variants":"のりくむ/乗り組む/乗組む"},"乗組む":{"variants":"のりくむ/乗り組む/乗組む"},"のりくめる":{"variants":"のりくめる/乗り組める"},"乗り組める":{"variants":"のりくめる/乗り組める"},"のりこえる":{"variants":"のりこえる/乗りこえる/乗り越える/乗越える"},"乗りこえる":{"variants":"のりこえる/乗りこえる/乗り越える/乗越える"},"乗り越える":{"variants":"のりこえる/乗りこえる/乗り越える/乗越える"},"乗越える":{"variants":"のりこえる/乗りこえる/乗り越える/乗越える"},"のりこす":{"variants":"のりこす/乗り越す/乗越す"},"乗り越す":{"variants":"のりこす/乗り越す/乗越す"},"乗越す":{"variants":"のりこす/乗り越す/乗越す"},"のりこせる":{"variants":"のりこせる/乗り越せる"},"乗り越せる":{"variants":"のりこせる/乗り越せる"},"のりこなす":{"variants":"のりこなす/乗りこなす"},"乗りこなす":{"variants":"のりこなす/乗りこなす"},"のりこなせる":{"variants":"のりこなせる/乗りこなせる"},"乗りこなせる":{"variants":"のりこなせる/乗りこなせる"},"のりこむ":{"variants":"のりこむ/乗りこむ/乗り込む/乗込む"},"乗りこむ":{"variants":"のりこむ/乗りこむ/乗り込む/乗込む"},"乗り込む":{"variants":"のりこむ/乗りこむ/乗り込む/乗込む"},"乗込む":{"variants":"のりこむ/乗りこむ/乗り込む/乗込む"},"のりこめる":{"variants":"のりこめる/乗り込める"},"乗り込める":{"variants":"のりこめる/乗り込める"},"糊しろ":{"variants":"糊しろ/糊代"},"糊代":{"variants":"糊しろ/糊代"},"のりすごす":{"variants":"のりすごす/乗り過ごす"},"乗り過ごす":{"variants":"のりすごす/乗り過ごす"},"のりすすめる":{"variants":"のりすすめる/乗り進める"},"乗り進める":{"variants":"のりすすめる/乗り進める"},"のりすてる":{"variants":"のりすてる/乗り捨てる/乗捨てる"},"乗り捨てる":{"variants":"のりすてる/乗り捨てる/乗捨てる"},"乗捨てる":{"variants":"のりすてる/乗り捨てる/乗捨てる"},"のりする":{"variants":"のりする/糊する"},"糊する":{"variants":"のりする/糊する"},"のりだす":{"variants":"のりだす/のり出す/乗りだす/乗り出す/乗出す"},"のり出す":{"variants":"のりだす/のり出す/乗りだす/乗り出す/乗出す"},"乗りだす":{"variants":"のりだす/のり出す/乗りだす/乗り出す/乗出す"},"乗り出す":{"variants":"のりだす/のり出す/乗りだす/乗り出す/乗出す"},"乗出す":{"variants":"のりだす/のり出す/乗りだす/乗り出す/乗出す"},"のりだせる":{"variants":"のりだせる/のり出せる/乗り出せる"},"のり出せる":{"variants":"のりだせる/のり出せる/乗り出せる"},"乗り出せる":{"variants":"のりだせる/のり出せる/乗り出せる"},"のりつぐ":{"variants":"のりつぐ/乗り継ぐ"},"乗り継ぐ":{"variants":"のりつぐ/乗り継ぐ"},"のりつける":{"variants":"のりつける/乗りつける/乗り付ける/乗付ける"},"乗りつける":{"variants":"のりつける/乗りつける/乗り付ける/乗付ける"},"乗り付ける":{"variants":"のりつける/乗りつける/乗り付ける/乗付ける"},"乗付ける":{"variants":"のりつける/乗りつける/乗り付ける/乗付ける"},"のりつげる":{"variants":"のりつげる/乗り継げる"},"乗り継げる":{"variants":"のりつげる/乗り継げる"},"乗り手":{"variants":"乗り手/乗手"},"乗手":{"variants":"乗り手/乗手"},"のりとおす":{"variants":"のりとおす/乗り通す"},"乗り通す":{"variants":"のりとおす/乗り通す"},"乗り逃げ":{"variants":"乗り逃げ/乗逃げ"},"乗逃げ":{"variants":"乗り逃げ/乗逃げ"},"のりはずす":{"variants":"のりはずす/乗りはずす/乗り外す/乗外す"},"乗りはずす":{"variants":"のりはずす/乗りはずす/乗り外す/乗外す"},"乗り外す":{"variants":"のりはずす/乗りはずす/乗り外す/乗外す"},"乗外す":{"variants":"のりはずす/乗りはずす/乗り外す/乗外す"},"乗り場":{"variants":"乗り場/乗場"},"乗場":{"variants":"乗り場/乗場"},"ノリ巻き":{"variants":"ノリ巻き/海苔巻"},"海苔巻":{"variants":"ノリ巻き/海苔巻"},"のりまわす":{"variants":"のりまわす/乗りまわす/乗り回す/乗回す"},"乗りまわす":{"variants":"のりまわす/乗りまわす/乗り回す/乗回す"},"乗り回す":{"variants":"のりまわす/乗りまわす/乗り回す/乗回す"},"乗回す":{"variants":"のりまわす/乗りまわす/乗り回す/乗回す"},"のりまわせる":{"variants":"のりまわせる/乗り回せる"},"乗り回せる":{"variants":"のりまわせる/乗り回せる"},"のりもの":{"variants":"のりもの/乗り物/乗物"},"乗り物":{"variants":"のりもの/乗り物/乗物"},"乗物":{"variants":"のりもの/乗り物/乗物"},"のる":{"variants":"のる/載る/乗る/宣る"},"のれる":{"variants":"のれる/乗れる"},"乗れる":{"variants":"のれる/乗れる"},"のれん":{"variants":"のれん/暖簾"},"暖簾":{"variants":"のれん/暖簾"},"のろう":{"variants":"のろう/詛う"},"詛う":{"variants":"のろう/詛う"},"のろける":{"variants":"のろける/惚気ける"},"惚気ける":{"variants":"のろける/惚気ける"},"のろのろ":{"variants":"のろのろ/ノロノロ"},"ノロノロ":{"variants":"のろのろ/ノロノロ"},"のろわしい":{"variants":"のろわしい/呪わしい"},"呪わしい":{"variants":"のろわしい/呪わしい"},"のんき":{"variants":"のんき/暢気/呑気"},"飲兵衛":{"variants":"飲んべえ/飲ん兵衛/飲兵衛"},"飲ん兵衛":{"variants":"飲んべえ/飲ん兵衛/飲兵衛"},"飲んべえ":{"variants":"飲んべえ/飲ん兵衛/飲兵衛"},"はあ":{"variants":"はあ/ハア"},"ハア":{"variants":"はあ/ハア"},"ハアリ":{"variants":"ハアリ/羽蟻"},"羽蟻":{"variants":"ハアリ/羽蟻"},"ハイ":{"variants":"ハイ/灰/敗/肺/胚"},"はいいる":{"variants":"はいいる/這入る"},"這入る":{"variants":"はいいる/這入る"},"はいかい":{"variants":"はいかい/徘徊"},"徘徊":{"variants":"はいかい/徘徊"},"俳諧":{"variants":"俳かい/俳諧"},"俳かい":{"variants":"俳かい/俳諧"},"胚芽":{"variants":"はい芽/胚芽"},"はい芽":{"variants":"はい芽/胚芽"},"肺がん":{"variants":"肺がん/肺癌"},"肺癌":{"variants":"肺がん/肺癌"},"肺気しゅ":{"variants":"肺気しゅ/肺気腫"},"肺気腫":{"variants":"肺気しゅ/肺気腫"},"ハイギョ":{"variants":"ハイギョ/肺魚"},"肺魚":{"variants":"ハイギョ/肺魚"},"ハイク":{"variants":"ハイク/俳句"},"俳句":{"variants":"ハイク/俳句"},"はいす":{"variants":"はいす/排す/配す"},"はいする":{"variants":"はいする/廃する/拝する/排する/配する"},"はいずる":{"variants":"はいずる/這いずる"},"這いずる":{"variants":"はいずる/這いずる"},"排せつ":{"variants":"排せつ/排泄"},"排泄":{"variants":"排せつ/排泄"},"肺せん":{"variants":"肺せん/肺尖"},"肺尖":{"variants":"肺せん/肺尖"},"配ぜん":{"variants":"配ぜん/配膳"},"配膳":{"variants":"配ぜん/配膳"},"はいだす":{"variants":"はいだす/這いだす/這い出す"},"這いだす":{"variants":"はいだす/這いだす/這い出す"},"這い出す":{"variants":"はいだす/這いだす/這い出す"},"はいつくばう":{"variants":"はいつくばう/這いつくばう/這い蹲う"},"這いつくばう":{"variants":"はいつくばう/這いつくばう/這い蹲う"},"這い蹲う":{"variants":"はいつくばう/這いつくばう/這い蹲う"},"はいでる":{"variants":"はいでる/這出る"},"這出る":{"variants":"はいでる/這出る"},"ハイマツ":{"variants":"ハイマツ/這松"},"這松":{"variants":"ハイマツ/這松"},"はいまつわる":{"variants":"はいまつわる/這いまつわる/這い纏る"},"這いまつわる":{"variants":"はいまつわる/這いまつわる/這い纏る"},"這い纏る":{"variants":"はいまつわる/這いまつわる/這い纏る"},"はいりきる":{"variants":"はいりきる/入り切る"},"入り切る":{"variants":"はいりきる/入り切る"},"はいりこむ":{"variants":"はいりこむ/入りこむ"},"入りこむ":{"variants":"はいりこむ/入りこむ"},"はいりこめる":{"variants":"はいりこめる/入り込める"},"入り込める":{"variants":"はいりこめる/入り込める"},"はう":{"variants":"はう/這う"},"這う":{"variants":"はう/這う"},"ハエ":{"variants":"ハエ/映え/栄え/蝿/蠅"},"生えぎわ":{"variants":"生えぎわ/生え際"},"生え際":{"variants":"生えぎわ/生え際"},"ハエジゴク":{"variants":"ハエジゴク/蝿地獄"},"蝿地獄":{"variants":"ハエジゴク/蝿地獄"},"ハエトリグサ":{"variants":"ハエトリグサ/蝿取草"},"蝿取草":{"variants":"ハエトリグサ/蝿取草"},"はえ縄":{"variants":"はえ縄/延縄"},"延縄":{"variants":"はえ縄/延縄"},"はえぬき":{"variants":"はえぬき/はえ抜き/生えぬき/生え抜き"},"はえ抜き":{"variants":"はえぬき/はえ抜き/生えぬき/生え抜き"},"生えぬき":{"variants":"はえぬき/はえ抜き/生えぬき/生え抜き"},"生え抜き":{"variants":"はえぬき/はえ抜き/生えぬき/生え抜き"},"はえる":{"variants":"はえる/映える/生える/這える"},"ハオウジュ":{"variants":"ハオウジュ/覇王樹"},"覇王樹":{"variants":"ハオウジュ/覇王樹"},"羽織":{"variants":"羽織/羽織り"},"羽織り":{"variants":"羽織/羽織り"},"はおる":{"variants":"はおる/羽織る"},"羽織る":{"variants":"はおる/羽織る"},"はかす":{"variants":"はかす/捌かす"},"捌かす":{"variants":"はかす/捌かす"},"はかどる":{"variants":"はかどる/捗る"},"捗る":{"variants":"はかどる/捗る"},"はかない":{"variants":"はかない/果敢ない/儚い"},"はかなむ":{"variants":"はかなむ/儚む"},"儚む":{"variants":"はかなむ/儚む"},"はかばかしい":{"variants":"はかばかしい/捗々しい/捗捗しい"},"捗々しい":{"variants":"はかばかしい/捗々しい/捗捗しい"},"捗捗しい":{"variants":"はかばかしい/捗々しい/捗捗しい"},"はかま":{"variants":"はかま/袴"},"袴":{"variants":"はかま/袴"},"はからう":{"variants":"はからう/計らう"},"計らう":{"variants":"はからう/計らう"},"はからえる":{"variants":"はからえる/計らえる"},"計らえる":{"variants":"はからえる/計らえる"},"はかりこむ":{"variants":"はかりこむ/量りこむ/量り込む"},"量りこむ":{"variants":"はかりこむ/量りこむ/量り込む"},"量り込む":{"variants":"はかりこむ/量りこむ/量り込む"},"はかる":{"variants":"はかる/計る/諮る/図る/測る/謀る/量る"},"はかれる":{"variants":"はかれる/計れる/諮れる/図れる/測れる/謀れる/量れる"},"羽交い締め":{"variants":"羽交い締め/羽交締め"},"羽交締め":{"variants":"羽交い締め/羽交締め"},"はがき":{"variants":"はがき/ハガキ/葉書"},"ハガキ":{"variants":"はがき/ハガキ/葉書"},"葉書":{"variants":"はがき/ハガキ/葉書"},"はがす":{"variants":"はがす/剥す"},"剥す":{"variants":"はがす/剥す"},"はがせる":{"variants":"はがせる/剥せる"},"剥せる":{"variants":"はがせる/剥せる"},"はがゆい":{"variants":"はがゆい/歯がゆい/歯痒い"},"歯がゆい":{"variants":"はがゆい/歯がゆい/歯痒い"},"歯痒い":{"variants":"はがゆい/歯がゆい/歯痒い"},"はがれる":{"variants":"はがれる/剥がれる"},"剥がれる":{"variants":"はがれる/剥がれる"},"吐きけ":{"variants":"吐きけ/吐き気/吐気"},"吐き気":{"variants":"吐きけ/吐き気/吐気"},"吐気":{"variants":"吐きけ/吐き気/吐気"},"掃きそうじ":{"variants":"掃きそうじ/掃き掃除"},"掃き掃除":{"variants":"掃きそうじ/掃き掃除"},"はきだす":{"variants":"はきだす/はき出す/掃きだす/掃き出す/掃出す/吐きだす/吐き出す/吐出す"},"はき出す":{"variants":"はきだす/はき出す/掃きだす/掃き出す/掃出す/吐きだす/吐き出す/吐出す"},"掃きだす":{"variants":"はきだす/はき出す/掃きだす/掃き出す/掃出す"},"吐出す":{"variants":"はきだす/はき出す/吐きだす/吐き出す/吐出す"},"吐き出す":{"variants":"はきだす/はき出す/吐きだす/吐き出す/吐出す"},"掃出す":{"variants":"はきだす/はき出す/掃きだす/掃き出す/掃出す"},"掃き出す":{"variants":"はきだす/はき出す/掃きだす/掃き出す/掃出す"},"吐きだす":{"variants":"はきだす/はき出す/吐きだす/吐き出す/吐出す"},"はきだせる":{"variants":"はきだせる/吐き出せる"},"吐き出せる":{"variants":"はきだせる/吐き出せる"},"はきだめ":{"variants":"はきだめ/掃き溜め/掃溜め"},"掃き溜め":{"variants":"はきだめ/掃き溜め/掃溜め"},"掃溜め":{"variants":"はきだめ/掃き溜め/掃溜め"},"はきちがえる":{"variants":"はきちがえる/はき違える/履き違える/履違える"},"はき違える":{"variants":"はきちがえる/はき違える/履き違える/履違える"},"履き違える":{"variants":"はきちがえる/はき違える/履き違える/履違える"},"履違える":{"variants":"はきちがえる/はき違える/履き違える/履違える"},"はきはき":{"variants":"はきはき/ハキハキ"},"ハキハキ":{"variants":"はきはき/ハキハキ"},"はき物":{"variants":"はき物/履き物/履物"},"履き物":{"variants":"はき物/履き物/履物"},"履物":{"variants":"はき物/履き物/履物"},"ハギ":{"variants":"ハギ/接ぎ/矧/萩"},"はぎあわす":{"variants":"はぎあわす/はぎ合わす/接ぎ合わす"},"はぎ合わす":{"variants":"はぎあわす/はぎ合わす/接ぎ合わす"},"接ぎ合わす":{"variants":"はぎあわす/はぎ合わす/接ぎ合わす"},"はぎあわせる":{"variants":"はぎあわせる/はぎ合せる/接ぎ合せる/接ぎ合わせる"},"はぎ合せる":{"variants":"はぎあわせる/はぎ合せる/接ぎ合せる/接ぎ合わせる"},"接ぎ合せる":{"variants":"はぎあわせる/はぎ合せる/接ぎ合せる/接ぎ合わせる"},"接ぎ合わせる":{"variants":"はぎあわせる/はぎ合せる/接ぎ合せる/接ぎ合わせる"},"はぎとる":{"variants":"はぎとる/はぎ取る"},"はぎ取る":{"variants":"はぎとる/はぎ取る"},"はぎとれる":{"variants":"はぎとれる/はぎ取れる"},"はぎ取れる":{"variants":"はぎとれる/はぎ取れる"},"はく":{"variants":"はく/穿く/掃く/吐く/履く/佩く"},"ハク":{"variants":"ハク/伯/箔"},"ハクサイ":{"variants":"ハクサイ/白菜"},"白菜":{"variants":"ハクサイ/白菜"},"はくす":{"variants":"はくす/博す"},"博す":{"variants":"はくす/博す"},"はくする":{"variants":"はくする/博する"},"博する":{"variants":"はくする/博する"},"はく製":{"variants":"はく製/剥製"},"剥製":{"variants":"はく製/剥製"},"白せん":{"variants":"白せん/白扇/白線/白癬"},"はくだつ":{"variants":"はくだつ/はく奪/剥奪/剥脱"},"剥奪":{"variants":"はくだつ/はく奪/剥奪"},"はく奪":{"variants":"はくだつ/はく奪/剥奪"},"ハクチョウ":{"variants":"ハクチョウ/白丁/白鳥"},"ハクトウ":{"variants":"ハクトウ/白桃/白頭"},"ハクトウオウ":{"variants":"ハクトウオウ/白頭翁"},"白頭翁":{"variants":"ハクトウオウ/白頭翁"},"はく票":{"variants":"はく票/白票"},"白票":{"variants":"はく票/白票"},"ハクヨウ":{"variants":"ハクヨウ/舶用"},"舶用":{"variants":"ハクヨウ/舶用"},"はく落":{"variants":"はく落/剥落"},"剥落":{"variants":"はく落/剥落"},"はく離":{"variants":"はく離/剥離"},"剥離":{"variants":"はく離/剥離"},"はくり":{"variants":"はくり/薄利"},"薄利":{"variants":"はくり/薄利"},"はぐ":{"variants":"はぐ/矧ぐ/剥ぐ"},"歯ぐき":{"variants":"歯ぐき/歯茎"},"歯茎":{"variants":"歯ぐき/歯茎"},"はぐくむ":{"variants":"はぐくむ/育くむ/育む"},"育くむ":{"variants":"はぐくむ/育くむ/育む"},"育む":{"variants":"はぐくむ/育くむ/育む"},"はぐくめる":{"variants":"はぐくめる/育める"},"育める":{"variants":"はぐくめる/育める"},"はけ":{"variants":"はけ/刷毛/捌け"},"はけ口":{"variants":"はけ口/捌けぐち"},"捌けぐち":{"variants":"はけ口/捌けぐち"},"はける":{"variants":"はける/掃ける/吐ける/噴ける/履ける"},"はげあがる":{"variants":"はげあがる/はげ上がる"},"はげ上がる":{"variants":"はげあがる/はげ上がる"},"はげ頭":{"variants":"はげ頭/禿頭"},"禿頭":{"variants":"はげ頭/禿頭"},"ハゲイトウ":{"variants":"ハゲイトウ/葉鶏頭"},"葉鶏頭":{"variants":"ハゲイトウ/葉鶏頭"},"はげおちる":{"variants":"はげおちる/はげ落ちる"},"はげ落ちる":{"variants":"はげおちる/はげ落ちる"},"はげしい":{"variants":"はげしい/激しい/烈しい"},"ハゲタカ":{"variants":"ハゲタカ/禿鷹"},"禿鷹":{"variants":"ハゲタカ/禿鷹"},"はげます":{"variants":"はげます/励ます"},"励ます":{"variants":"はげます/励ます"},"はげませる":{"variants":"はげませる/励ませる"},"励ませる":{"variants":"はげませる/励ませる"},"はげむ":{"variants":"はげむ/励む"},"励む":{"variants":"はげむ/励む"},"はげ山":{"variants":"はげ山/禿山"},"禿山":{"variants":"はげ山/禿山"},"はげる":{"variants":"はげる/禿げる/矧げる/剥げる"},"ハゲワシ":{"variants":"ハゲワシ/禿鷲"},"禿鷲":{"variants":"ハゲワシ/禿鷲"},"箱書":{"variants":"箱書/箱書き"},"箱書き":{"variants":"箱書/箱書き"},"はこびこむ":{"variants":"はこびこむ/運び込む"},"運び込む":{"variants":"はこびこむ/運び込む"},"はこびこめる":{"variants":"はこびこめる/運び込める"},"運び込める":{"variants":"はこびこめる/運び込める"},"はこびだす":{"variants":"はこびだす/運び出す"},"運び出す":{"variants":"はこびだす/運び出す"},"はこびだせる":{"variants":"はこびだせる/運び出せる"},"運び出せる":{"variants":"はこびだせる/運び出せる"},"はこぶ":{"variants":"はこぶ/運ぶ"},"運ぶ":{"variants":"はこぶ/運ぶ"},"ハコベ":{"variants":"ハコベ/繁縷"},"繁縷":{"variants":"ハコベ/繁縷"},"はこべる":{"variants":"はこべる/運べる"},"運べる":{"variants":"はこべる/運べる"},"ハコヤナギ":{"variants":"ハコヤナギ/箱柳"},"箱柳":{"variants":"ハコヤナギ/箱柳"},"歯ごたえ":{"variants":"歯ごたえ/歯応え"},"歯応え":{"variants":"歯ごたえ/歯応え"},"はさ":{"variants":"はさ/稲架"},"稲架":{"variants":"はさ/稲架"},"はさまる":{"variants":"はさまる/挟まる"},"挟まる":{"variants":"はさまる/挟まる"},"ハサミ":{"variants":"ハサミ/鋏"},"鋏":{"variants":"ハサミ/鋏"},"はさみ撃ち":{"variants":"はさみ撃ち/挟み撃ち/挟撃ち"},"挟み撃ち":{"variants":"はさみ撃ち/挟み撃ち/挟撃ち"},"挟撃ち":{"variants":"はさみ撃ち/挟み撃ち/挟撃ち"},"はさみきる":{"variants":"はさみきる/はさみ切る/挟み切る"},"はさみ切る":{"variants":"はさみきる/はさみ切る/挟み切る"},"挟み切る":{"variants":"はさみきる/はさみ切る/挟み切る"},"はさみこむ":{"variants":"はさみこむ/挟み込む"},"挟み込む":{"variants":"はさみこむ/挟み込む"},"はさみこめる":{"variants":"はさみこめる/挟み込める"},"挟み込める":{"variants":"はさみこめる/挟み込める"},"はさみ将棋":{"variants":"はさみ将棋/挟み将棋"},"挟み将棋":{"variants":"はさみ将棋/挟み将棋"},"はさむ":{"variants":"はさむ/ハサむ/剪む/夾む/挾む/鋏む"},"ハサむ":{"variants":"はさむ/ハサむ/剪む/夾む/挾む/鋏む"},"はさめる":{"variants":"はさめる/挟める/夾める/鋏める"},"はざま":{"variants":"はざま/はざ間/狭間/迫間/硲"},"はざ間":{"variants":"はざま/はざ間/狭間/迫間"},"迫間":{"variants":"はざま/はざ間/迫間"},"狭間":{"variants":"はざま/はざ間/狭間"},"はし":{"variants":"はし/橋/箸"},"はしか":{"variants":"はしか/麻疹"},"麻疹":{"variants":"はしか/麻疹"},"橋懸":{"variants":"橋懸/橋懸り"},"橋懸り":{"variants":"橋懸/橋懸り"},"はしくれ":{"variants":"はしくれ/端くれ"},"端くれ":{"variants":"はしくれ/端くれ"},"はしけ":{"variants":"はしけ/艀"},"艀":{"variants":"はしけ/艀"},"橋げた":{"variants":"橋げた/橋桁"},"橋桁":{"variants":"橋げた/橋桁"},"はしご":{"variants":"はしご/梯/梯子"},"はしご酒":{"variants":"はしご酒/梯子酒/梯酒"},"はしご段":{"variants":"はしご段/梯子段/梯段"},"はしご乗り":{"variants":"はしご乗り/梯子乗り/梯乗り"},"はした金":{"variants":"はした金/端金"},"端金":{"variants":"はした金/端金"},"橋詰":{"variants":"橋詰/橋詰め"},"橋詰め":{"variants":"橋詰/橋詰め"},"はしなく":{"variants":"はしなく/端無く"},"端無く":{"variants":"はしなく/端無く"},"はしなくも":{"variants":"はしなくも/端無くも"},"端無くも":{"variants":"はしなくも/端無くも"},"端々":{"variants":"端々/端端"},"端端":{"variants":"端々/端端"},"ハシバミ":{"variants":"ハシバミ/榛"},"榛":{"variants":"ハシバミ/榛"},"はしょる":{"variants":"はしょる/端折る"},"端折る":{"variants":"はしょる/端折る"},"はしょれる":{"variants":"はしょれる/端折れる"},"端折れる":{"variants":"はしょれる/端折れる"},"はしらす":{"variants":"はしらす/走らす"},"走らす":{"variants":"はしらす/走らす"},"はしりこむ":{"variants":"はしりこむ/走り込む"},"走り込む":{"variants":"はしりこむ/走り込む"},"はしりこめる":{"variants":"はしりこめる/走り込める"},"走り込める":{"variants":"はしりこめる/走り込める"},"はしりさる":{"variants":"はしりさる/走り去る"},"走り去る":{"variants":"はしりさる/走り去る"},"走り高跳び":{"variants":"走り高跳び/走高跳"},"走高跳":{"variants":"走り高跳び/走高跳"},"はしりだす":{"variants":"はしりだす/走り出す"},"走り出す":{"variants":"はしりだす/走り出す"},"はしりだせる":{"variants":"はしりだせる/走り出せる"},"走り出せる":{"variants":"はしりだせる/走り出せる"},"はしりでる":{"variants":"はしりでる/走りでる/走り出る"},"走りでる":{"variants":"はしりでる/走りでる/走り出る"},"走り出る":{"variants":"はしりでる/走りでる/走り出る"},"はしりぬく":{"variants":"はしりぬく/走り抜く"},"走り抜く":{"variants":"はしりぬく/走り抜く"},"はしりぬける":{"variants":"はしりぬける/走り抜ける"},"走り抜ける":{"variants":"はしりぬける/走り抜ける"},"走幅跳":{"variants":"走り幅跳び/走幅跳"},"走り幅跳び":{"variants":"走り幅跳び/走幅跳"},"はしりまわる":{"variants":"はしりまわる/走り回る"},"走り回る":{"variants":"はしりまわる/走り回る"},"はしりまわれる":{"variants":"はしりまわれる/走り回れる"},"走り回れる":{"variants":"はしりまわれる/走り回れる"},"はしる":{"variants":"はしる/走る"},"走る":{"variants":"はしる/走る"},"はしれる":{"variants":"はしれる/走れる"},"走れる":{"variants":"はしれる/走れる"},"ハジ":{"variants":"ハジ/恥"},"恥":{"variants":"ハジ/恥"},"はじいる":{"variants":"はじいる/恥じ入る/恥入る"},"恥じ入る":{"variants":"はじいる/恥じ入る/恥入る"},"恥入る":{"variants":"はじいる/恥じ入る/恥入る"},"はじきかえす":{"variants":"はじきかえす/はじき返す/弾き返す"},"はじき返す":{"variants":"はじきかえす/はじき返す/弾き返す"},"弾き返す":{"variants":"はじきかえす/はじき返す/弾き返す"},"はじきかえせる":{"variants":"はじきかえせる/弾き返せる"},"弾き返せる":{"variants":"はじきかえせる/弾き返せる"},"はじきだす":{"variants":"はじきだす/はじき出す/弾き出す"},"はじき出す":{"variants":"はじきだす/はじき出す/弾き出す"},"弾き出す":{"variants":"はじきだす/はじき出す/弾き出す"},"はじきだせる":{"variants":"はじきだせる/はじき出せる/弾き出せる"},"はじき出せる":{"variants":"はじきだせる/はじき出せる/弾き出せる"},"弾き出せる":{"variants":"はじきだせる/はじき出せる/弾き出せる"},"恥さらし":{"variants":"恥さらし/恥曝し"},"恥曝し":{"variants":"恥さらし/恥曝し"},"はじまる":{"variants":"はじまる/始まる"},"始まる":{"variants":"はじまる/始まる"},"はじめ":{"variants":"はじめ/始め/初め"},"初め":{"variants":"はじめ/初め"},"はじめて":{"variants":"はじめて/始めて/初めて"},"はじめる":{"variants":"はじめる/始める"},"始める":{"variants":"はじめる/始める"},"はじらう":{"variants":"はじらう/恥じらう/羞じらう"},"ハジラミ":{"variants":"ハジラミ/羽虱"},"羽虱":{"variants":"ハジラミ/羽虱"},"はじる":{"variants":"はじる/恥じる"},"恥じる":{"variants":"はじる/恥じる"},"ハス":{"variants":"ハス/斜"},"斜":{"variants":"ハス/斜"},"はす交い":{"variants":"はす交い/斜かい/斜交い"},"斜かい":{"variants":"はす交い/斜かい/斜交い"},"斜交い":{"variants":"はす交い/斜かい/斜交い"},"蓮っぱ":{"variants":"蓮っぱ/蓮っ葉/蓮葉"},"蓮っ葉":{"variants":"蓮っぱ/蓮っ葉/蓮葉"},"蓮葉":{"variants":"蓮っぱ/蓮っ葉/蓮葉"},"はする":{"variants":"はする/派する"},"派する":{"variants":"はする/派する"},"はず":{"variants":"はず/筈"},"筈":{"variants":"はず/筈"},"はずかしい":{"variants":"はずかしい/恥しい/恥ずかしい"},"恥しい":{"variants":"はずかしい/恥しい/恥ずかしい"},"恥ずかしい":{"variants":"はずかしい/恥しい/恥ずかしい"},"はずかしめる":{"variants":"はずかしめる/辱める"},"辱める":{"variants":"はずかしめる/辱める"},"はずす":{"variants":"はずす/外す"},"外す":{"variants":"はずす/外す"},"はずせる":{"variants":"はずせる/外せる"},"外せる":{"variants":"はずせる/外せる"},"はずみ車":{"variants":"はずみ車/勢車/弾みぐるま/弾み車"},"弾みぐるま":{"variants":"はずみ車/弾みぐるま/弾み車"},"弾み車":{"variants":"はずみ車/弾みぐるま/弾み車"},"はずむ":{"variants":"はずむ/弾む"},"弾む":{"variants":"はずむ/弾む"},"はずれ":{"variants":"はずれ/ハズレ/外れ/葉ずれ/葉擦れ"},"ハズレ":{"variants":"はずれ/ハズレ/外れ/葉ずれ/葉擦れ"},"葉ずれ":{"variants":"はずれ/ハズレ/葉ずれ/葉擦れ"},"葉擦れ":{"variants":"はずれ/ハズレ/葉ずれ/葉擦れ"},"はずれる":{"variants":"はずれる/外れる"},"外れる":{"variants":"はずれる/外れる"},"はせさんずる":{"variants":"はせさんずる/はせ参ずる/馳せ参ずる"},"はせ参ずる":{"variants":"はせさんずる/はせ参ずる/馳せ参ずる"},"馳せ参ずる":{"variants":"はせさんずる/はせ参ずる/馳せ参ずる"},"はせる":{"variants":"はせる/馳せる"},"馳せる":{"variants":"はせる/馳せる"},"ハゼ":{"variants":"ハゼ/沙魚/櫨/鯊"},"ハゼウルシ":{"variants":"ハゼウルシ/黄櫨漆"},"黄櫨漆":{"variants":"ハゼウルシ/黄櫨漆"},"はぜる":{"variants":"はぜる/爆ぜる"},"爆ぜる":{"variants":"はぜる/爆ぜる"},"はた":{"variants":"はた/将"},"将":{"variants":"はた/将"},"ハタオリ":{"variants":"ハタオリ/機織/機織り"},"機織":{"variants":"ハタオリ/機織/機織り"},"機織り":{"variants":"ハタオリ/機織/機織り"},"ハタオリムシ":{"variants":"ハタオリムシ/機織虫"},"機織虫":{"variants":"ハタオリムシ/機織虫"},"畑ちがい":{"variants":"畑ちがい/畑違い"},"畑違い":{"variants":"畑ちがい/畑違い"},"はたける":{"variants":"はたける/叩ける"},"叩ける":{"variants":"はたける/叩ける"},"旗指し物":{"variants":"旗指し物/旗指物"},"旗指物":{"variants":"旗指し物/旗指物"},"果し合い":{"variants":"果し合い/果たし合い"},"果たし合い":{"variants":"果し合い/果たし合い"},"はたし状":{"variants":"はたし状/果し状"},"果し状":{"variants":"はたし状/果し状"},"はたして":{"variants":"はたして/果して/果たして"},"果して":{"variants":"はたして/果して/果たして"},"果たして":{"variants":"はたして/果して/果たして"},"はたす":{"variants":"はたす/果す/果たす"},"果す":{"variants":"はたす/果す/果たす"},"果たす":{"variants":"はたす/果す/果たす"},"はたせる":{"variants":"はたせる/果たせる"},"果たせる":{"variants":"はたせる/果たせる"},"ハタハタ":{"variants":"ハタハタ/鰰"},"鰰":{"variants":"ハタハタ/鰰"},"葉たばこ":{"variants":"葉たばこ/葉煙草"},"葉煙草":{"variants":"葉たばこ/葉煙草"},"はた目":{"variants":"はた目/傍目"},"傍目":{"variants":"はた目/傍目"},"旗持":{"variants":"旗持/旗持ち"},"旗持ち":{"variants":"旗持/旗持ち"},"はたらかす":{"variants":"はたらかす/働かす"},"働かす":{"variants":"はたらかす/働かす"},"はたらかせる":{"variants":"はたらかせる/働かせる"},"働かせる":{"variants":"はたらかせる/働かせる"},"はたらき":{"variants":"はたらき/働き"},"働き":{"variants":"はたらき/働き"},"ハタラキアリ":{"variants":"ハタラキアリ/働き蟻"},"働き蟻":{"variants":"ハタラキアリ/働き蟻"},"働きかけ":{"variants":"働きかけ/働き掛け"},"働き掛け":{"variants":"働きかけ/働き掛け"},"はたらきかける":{"variants":"はたらきかける/働きかける/働き掛ける"},"働きかける":{"variants":"はたらきかける/働きかける/働き掛ける"},"働き掛ける":{"variants":"はたらきかける/働きかける/働き掛ける"},"ハタラキバチ":{"variants":"ハタラキバチ/働きバチ/働き蜂"},"働きバチ":{"variants":"ハタラキバチ/働きバチ/働き蜂"},"働き蜂":{"variants":"ハタラキバチ/働きバチ/働き蜂"},"働きもの":{"variants":"働きもの/働き者"},"働き者":{"variants":"働きもの/働き者"},"はたらく":{"variants":"はたらく/働く"},"働く":{"variants":"はたらく/働く"},"はたらける":{"variants":"はたらける/働ける"},"働ける":{"variants":"はたらける/働ける"},"破たん":{"variants":"破たん/破綻"},"破綻":{"variants":"破たん/破綻"},"ハタンキョウ":{"variants":"ハタンキョウ/巴旦杏"},"巴旦杏":{"variants":"ハタンキョウ/巴旦杏"},"肌あい":{"variants":"肌あい/肌合/肌合い"},"肌合":{"variants":"肌あい/肌合/肌合い"},"肌合い":{"variants":"肌あい/肌合/肌合い"},"はだか麦":{"variants":"はだか麦/ハダカムギ/裸麦"},"ハダカムギ":{"variants":"はだか麦/ハダカムギ/裸麦"},"裸麦":{"variants":"はだか麦/ハダカムギ/裸麦"},"ハダカムシ":{"variants":"ハダカムシ/裸虫"},"裸虫":{"variants":"ハダカムシ/裸虫"},"肌触り":{"variants":"肌触り/肌触わり"},"肌触わり":{"variants":"肌触り/肌触わり"},"はだし":{"variants":"はだし/ハダシ/裸足/跣"},"ハダシ":{"variants":"はだし/ハダシ/裸足/跣"},"ハチ":{"variants":"ハチ/鉢/蜂"},"８":{"variants":"８/八"},"八":{"variants":"８/八"},"はち合わせ":{"variants":"はち合わせ/ハチ合わせ/鉢合せ"},"ハチ合わせ":{"variants":"はち合わせ/ハチ合わせ/鉢合せ"},"鉢合せ":{"variants":"はち合わせ/ハチ合わせ/鉢合せ"},"鉢植":{"variants":"鉢植/鉢植え"},"鉢植え":{"variants":"鉢植/鉢植え"},"８月":{"variants":"８月/八月"},"八月":{"variants":"８月/八月"},"はちきれる":{"variants":"はちきれる/はち切れる"},"はち切れる":{"variants":"はちきれる/はち切れる"},"ハチク":{"variants":"ハチク/淡竹/破竹"},"鉢たたき":{"variants":"鉢たたき/鉢叩"},"鉢叩":{"variants":"鉢たたき/鉢叩"},"ハチドリ":{"variants":"ハチドリ/蜂鳥"},"蜂鳥":{"variants":"ハチドリ/蜂鳥"},"はちの巣":{"variants":"はちの巣/蜂の巣"},"蜂の巣":{"variants":"はちの巣/蜂の巣"},"はちまき":{"variants":"はちまき/鉢まき/鉢巻"},"鉢まき":{"variants":"はちまき/鉢まき/鉢巻"},"鉢巻":{"variants":"はちまき/鉢まき/鉢巻"},"はちまん":{"variants":"はちまん/八幡"},"八幡":{"variants":"はちまん/八幡"},"はちみつ":{"variants":"はちみつ/蜂蜜"},"蜂蜜":{"variants":"はちみつ/蜂蜜"},"８ミリ":{"variants":"８ミリ/八ミリ"},"八ミリ":{"variants":"８ミリ/八ミリ"},"八面六ぴ":{"variants":"八面六ぴ/八面六臂"},"八面六臂":{"variants":"八面六ぴ/八面六臂"},"はちゅう類":{"variants":"はちゅう類/は虫類/ハチュウルイ/ハチュウ類/爬虫類"},"は虫類":{"variants":"はちゅう類/は虫類/ハチュウルイ/ハチュウ類/爬虫類"},"ハチュウルイ":{"variants":"はちゅう類/は虫類/ハチュウルイ/ハチュウ類/爬虫類"},"ハチュウ類":{"variants":"はちゅう類/は虫類/ハチュウルイ/ハチュウ類/爬虫類"},"爬虫類":{"variants":"はちゅう類/は虫類/ハチュウルイ/ハチュウ類/爬虫類"},"ハッカ":{"variants":"ハッカ/薄荷"},"薄荷":{"variants":"ハッカ/薄荷"},"ハッカセイ":{"variants":"ハッカセイ/薄荷精"},"薄荷精":{"variants":"ハッカセイ/薄荷精"},"ハッカノウ":{"variants":"ハッカノウ/薄荷脳"},"薄荷脳":{"variants":"ハッカノウ/薄荷脳"},"ハッカユ":{"variants":"ハッカユ/薄荷油"},"薄荷油":{"variants":"ハッカユ/薄荷油"},"はっきり":{"variants":"はっきり/ハッキリ"},"ハッキリ":{"variants":"はっきり/ハッキリ"},"はっけ":{"variants":"はっけ/八卦"},"八卦":{"variants":"はっけ/八卦"},"ハッサク":{"variants":"ハッサク/八朔"},"八朔":{"variants":"ハッサク/八朔"},"発しん":{"variants":"発しん/発信/発振/発進"},"はっする":{"variants":"はっする/発する"},"発する":{"variants":"はっする/発する"},"ハッパ":{"variants":"ハッパ/発破/葉っぱ"},"ハッピ":{"variants":"ハッピ/法被"},"法被":{"variants":"ハッピ/法被"},"ハツカネズミ":{"variants":"ハツカネズミ/二十日鼠"},"二十日鼠":{"variants":"ハツカネズミ/二十日鼠"},"発がん":{"variants":"発がん/発ガン/発癌"},"発ガン":{"variants":"発がん/発ガン/発癌"},"発癌":{"variants":"発がん/発ガン/発癌"},"はつ恋":{"variants":"はつ恋/初恋"},"初恋":{"variants":"はつ恋/初恋"},"ハツタケ":{"variants":"ハツタケ/初茸"},"初茸":{"variants":"ハツタケ/初茸"},"初日の出":{"variants":"初日の出/初日出"},"初日出":{"variants":"初日の出/初日出"},"初もうで":{"variants":"初もうで/初詣"},"初詣":{"variants":"初もうで/初詣"},"初もの":{"variants":"初もの/初物"},"初物":{"variants":"初もの/初物"},"はつらつ":{"variants":"はつらつ/溌剌/溌溂"},"はて":{"variants":"はて/果/果て"},"ハテ":{"variants":"はて/ハテ"},"果":{"variants":"はて/果/果て"},"果て":{"variants":"はて/果/果て"},"はてる":{"variants":"はてる/果てる"},"果てる":{"variants":"はてる/果てる"},"ハト":{"variants":"ハト/鳩"},"鳩":{"variants":"ハト/鳩"},"波とう":{"variants":"波とう/波涛"},"波涛":{"variants":"波とう/波涛"},"はとうしょく":{"variants":"はとうしょく/把頭飾"},"把頭飾":{"variants":"はとうしょく/把頭飾"},"ハトムギ":{"variants":"ハトムギ/鳩麦"},"鳩麦":{"variants":"ハトムギ/鳩麦"},"花かご":{"variants":"花かご/花篭"},"花篭":{"variants":"花かご/花篭"},"鼻かぜ":{"variants":"鼻かぜ/鼻風邪"},"鼻風邪":{"variants":"鼻かぜ/鼻風邪"},"花かんざし":{"variants":"花かんざし/花簪"},"花簪":{"variants":"花かんざし/花簪"},"花がつお":{"variants":"花がつお/花鰹"},"花鰹":{"variants":"花がつお/花鰹"},"鼻くそ":{"variants":"鼻くそ/鼻糞/鼻屎"},"鼻ぐすり":{"variants":"鼻ぐすり/鼻薬"},"鼻薬":{"variants":"鼻ぐすり/鼻薬"},"花ぐもり":{"variants":"花ぐもり/花曇/花曇り"},"花曇":{"variants":"花ぐもり/花曇/花曇り"},"花曇り":{"variants":"花ぐもり/花曇/花曇り"},"花ことば":{"variants":"花ことば/花言葉"},"花言葉":{"variants":"花ことば/花言葉"},"花ごよみ":{"variants":"花ごよみ/花暦"},"花暦":{"variants":"花ごよみ/花暦"},"はなし":{"variants":"はなし/噺"},"噺":{"variants":"はなし/噺"},"話し合い":{"variants":"話し合い/話合い"},"話合い":{"variants":"話し合い/話合い"},"はなしあう":{"variants":"はなしあう/話し合う"},"話し合う":{"variants":"はなしあう/話し合う"},"はなしあえる":{"variants":"はなしあえる/話し合える"},"話し合える":{"variants":"はなしあえる/話し合える"},"はなし家":{"variants":"はなし家/噺家/咄家"},"はなしかける":{"variants":"はなしかける/話しかける/話し掛ける"},"話しかける":{"variants":"はなしかける/話しかける/話し掛ける"},"話し掛ける":{"variants":"はなしかける/話しかける/話し掛ける"},"話しことば":{"variants":"話しことば/話し言葉/話言葉"},"話し言葉":{"variants":"話しことば/話し言葉/話言葉"},"話言葉":{"variants":"話しことば/話し言葉/話言葉"},"はなしこむ":{"variants":"はなしこむ/話しこむ/話し込む"},"話しこむ":{"variants":"はなしこむ/話しこむ/話し込む"},"話し込む":{"variants":"はなしこむ/話しこむ/話し込む"},"はなしだす":{"variants":"はなしだす/話し出す"},"話し出す":{"variants":"はなしだす/話し出す"},"ハナショウブ":{"variants":"ハナショウブ/花しょうぶ"},"花しょうぶ":{"variants":"ハナショウブ/花しょうぶ"},"はなじろむ":{"variants":"はなじろむ/鼻白む"},"鼻白む":{"variants":"はなじろむ/鼻白む"},"はなす":{"variants":"はなす/離す/話す"},"ハナズオウ":{"variants":"ハナズオウ/花蘇芳"},"花蘇芳":{"variants":"ハナズオウ/花蘇芳"},"はなせる":{"variants":"はなせる/放せる/離せる/話せる"},"鼻高々":{"variants":"鼻高々/鼻高高"},"鼻高高":{"variants":"鼻高々/鼻高高"},"花だより":{"variants":"花だより/花便り"},"花便り":{"variants":"花だより/花便り"},"鼻っつら":{"variants":"鼻っつら/鼻っ面"},"鼻っ面":{"variants":"鼻っつら/鼻っ面"},"鼻っぱしら":{"variants":"鼻っぱしら/鼻っ柱"},"鼻っ柱":{"variants":"鼻っぱしら/鼻っ柱"},"はなつ":{"variants":"はなつ/放つ"},"放つ":{"variants":"はなつ/放つ"},"鼻つまみ":{"variants":"鼻つまみ/鼻摘み"},"鼻摘み":{"variants":"鼻つまみ/鼻摘み"},"花づくし":{"variants":"花づくし/花尽し"},"花尽し":{"variants":"花づくし/花尽し"},"花どき":{"variants":"花どき/花時"},"花時":{"variants":"花どき/花時"},"はなはだ":{"variants":"はなはだ/甚だ"},"甚だ":{"variants":"はなはだ/甚だ"},"はなはだしい":{"variants":"はなはだしい/甚だしい"},"甚だしい":{"variants":"はなはだしい/甚だしい"},"はなばなしい":{"variants":"はなばなしい/花々しい/花花しい/華々しい/華華しい"},"花花しい":{"variants":"はなばなしい/花々しい/花花しい"},"花々しい":{"variants":"はなばなしい/花々しい/花花しい"},"華々しい":{"variants":"はなばなしい/華々しい/華華しい"},"華華しい":{"variants":"はなばなしい/華々しい/華華しい"},"花ふぶき":{"variants":"花ふぶき/花吹雪"},"花吹雪":{"variants":"花ふぶき/花吹雪"},"花祭":{"variants":"花祭/花祭り"},"花祭り":{"variants":"花祭/花祭り"},"ハナミズキ":{"variants":"ハナミズキ/花水木"},"花水木":{"variants":"ハナミズキ/花水木"},"はなやか":{"variants":"はなやか/花やか/華やか"},"はなやぐ":{"variants":"はなやぐ/花やぐ/華やぐ"},"ハナヤサイ":{"variants":"ハナヤサイ/花椰菜"},"花椰菜":{"variants":"ハナヤサイ/花椰菜"},"花やしき":{"variants":"花やしき/花屋敷"},"花屋敷":{"variants":"花やしき/花屋敷"},"歯ならび":{"variants":"歯ならび/歯並び"},"歯並び":{"variants":"歯ならび/歯並び"},"離ればなれ":{"variants":"離ればなれ/離れ離れ"},"離れ離れ":{"variants":"離ればなれ/離れ離れ"},"はなれる":{"variants":"はなれる/放れる/離れる"},"はにわ":{"variants":"はにわ/埴輪"},"埴輪":{"variants":"はにわ/埴輪"},"ハネ":{"variants":"ハネ/羽根/跳ね/撥ね"},"はねあがる":{"variants":"はねあがる/はね上がる/ハネ上がる/跳ねあがる/跳ね上がる/跳上がる"},"はね上がる":{"variants":"はねあがる/はね上がる/ハネ上がる/跳ねあがる/跳ね上がる/跳上がる"},"ハネ上がる":{"variants":"はねあがる/はね上がる/ハネ上がる/跳ねあがる/跳ね上がる/跳上がる"},"跳ねあがる":{"variants":"はねあがる/はね上がる/ハネ上がる/跳ねあがる/跳ね上がる/跳上がる"},"跳ね上がる":{"variants":"はねあがる/はね上がる/ハネ上がる/跳ねあがる/跳ね上がる/跳上がる"},"跳上がる":{"variants":"はねあがる/はね上がる/ハネ上がる/跳ねあがる/跳ね上がる/跳上がる"},"はねあげる":{"variants":"はねあげる/はね上げる"},"はね上げる":{"variants":"はねあげる/はね上げる"},"はねかえす":{"variants":"はねかえす/はね返す/跳ね返す"},"はね返す":{"variants":"はねかえす/はね返す/跳ね返す"},"跳ね返す":{"variants":"はねかえす/はね返す/跳ね返す"},"はねかえせる":{"variants":"はねかえせる/跳ね返せる"},"跳ね返せる":{"variants":"はねかえせる/跳ね返せる"},"はね返り":{"variants":"はね返り/跳ねかえり/跳ね返り"},"跳ねかえり":{"variants":"はね返り/跳ねかえり/跳ね返り"},"跳ね返り":{"variants":"はね返り/跳ねかえり/跳ね返り"},"はねかえる":{"variants":"はねかえる/はね返る/跳ね返る"},"はね返る":{"variants":"はねかえる/はね返る/跳ね返る"},"跳ね返る":{"variants":"はねかえる/はね返る/跳ね返る"},"はねかす":{"variants":"はねかす/跳ねかす"},"跳ねかす":{"variants":"はねかす/跳ねかす"},"はねだす":{"variants":"はねだす/ハネ出す/跳ね出す"},"ハネ出す":{"variants":"はねだす/ハネ出す/跳ね出す"},"跳ね出す":{"variants":"はねだす/ハネ出す/跳ね出す"},"はねっ返り":{"variants":"はねっ返り/跳ねっかえり/跳ねっ返り"},"跳ねっかえり":{"variants":"はねっ返り/跳ねっかえり/跳ねっ返り"},"跳ねっ返り":{"variants":"はねっ返り/跳ねっかえり/跳ねっ返り"},"はねつける":{"variants":"はねつける/撥ねつける/撥ね付ける"},"撥ねつける":{"variants":"はねつける/撥ねつける/撥ね付ける"},"撥ね付ける":{"variants":"はねつける/撥ねつける/撥ね付ける"},"撥ねつるべ":{"variants":"撥ねつるべ/撥ね釣瓶"},"撥ね釣瓶":{"variants":"撥ねつるべ/撥ね釣瓶"},"はねのける":{"variants":"はねのける/跳ねのける/跳ね除ける"},"跳ねのける":{"variants":"はねのける/跳ねのける/跳ね除ける"},"跳ね除ける":{"variants":"はねのける/跳ねのける/跳ね除ける"},"はね橋":{"variants":"はね橋/跳ね橋"},"跳ね橋":{"variants":"はね橋/跳ね橋"},"はねる":{"variants":"はねる/跳ねる/撥ねる"},"ハハコグサ":{"variants":"ハハコグサ/母子草"},"母子草":{"variants":"ハハコグサ/母子草"},"母もの":{"variants":"母もの/母物"},"母物":{"variants":"母もの/母物"},"はばかり様":{"variants":"はばかり様/憚り様"},"憚り様":{"variants":"はばかり様/憚り様"},"はばかりながら":{"variants":"はばかりながら/憚りながら"},"憚りながら":{"variants":"はばかりながら/憚りながら"},"はばたく":{"variants":"はばたく/羽ばたく"},"羽ばたく":{"variants":"はばたく/羽ばたく"},"はばたける":{"variants":"はばたける/羽ばたける"},"羽ばたける":{"variants":"はばたける/羽ばたける"},"幅跳":{"variants":"幅跳/幅跳び"},"幅跳び":{"variants":"幅跳/幅跳び"},"幅ひろ":{"variants":"幅ひろ/幅広"},"幅広":{"variants":"幅ひろ/幅広"},"はばひろい":{"variants":"はばひろい/幅広い"},"幅広い":{"variants":"はばひろい/幅広い"},"はばむ":{"variants":"はばむ/阻む/沮む"},"はばめる":{"variants":"はばめる/阻める"},"阻める":{"variants":"はばめる/阻める"},"はびこる":{"variants":"はびこる/蔓延る"},"蔓延る":{"variants":"はびこる/蔓延る"},"ハブ":{"variants":"ハブ/波布"},"波布":{"variants":"ハブ/波布"},"はぶく":{"variants":"はぶく/省く"},"省く":{"variants":"はぶく/省く"},"はぶける":{"variants":"はぶける/省ける"},"省ける":{"variants":"はぶける/省ける"},"ハブソウ":{"variants":"ハブソウ/波布草"},"波布草":{"variants":"ハブソウ/波布草"},"ハブラシ":{"variants":"ハブラシ/歯ブラシ"},"歯ブラシ":{"variants":"ハブラシ/歯ブラシ"},"はべる":{"variants":"はべる/侍る"},"侍る":{"variants":"はべる/侍る"},"はべれる":{"variants":"はべれる/侍れる"},"侍れる":{"variants":"はべれる/侍れる"},"ハボタン":{"variants":"ハボタン/葉ぼたん/葉牡丹"},"葉ぼたん":{"variants":"ハボタン/葉ぼたん/葉牡丹"},"葉牡丹":{"variants":"ハボタン/葉ぼたん/葉牡丹"},"ハマ":{"variants":"ハマ/浜/濱"},"ハマオモト":{"variants":"ハマオモト/浜万年青"},"浜万年青":{"variants":"ハマオモト/浜万年青"},"ハマグリ":{"variants":"ハマグリ/蛤"},"蛤":{"variants":"ハマグリ/蛤"},"ハマダラカ":{"variants":"ハマダラカ/羽斑蚊"},"羽斑蚊":{"variants":"ハマダラカ/羽斑蚊"},"ハマボウフウ":{"variants":"ハマボウフウ/浜防風"},"浜防風":{"variants":"ハマボウフウ/浜防風"},"ハマユウ":{"variants":"ハマユウ/浜ゆう/浜木綿"},"浜ゆう":{"variants":"ハマユウ/浜ゆう/浜木綿"},"浜木綿":{"variants":"ハマユウ/浜ゆう/浜木綿"},"はまり役":{"variants":"はまり役/嵌り役"},"嵌り役":{"variants":"はまり役/嵌り役"},"はまる":{"variants":"はまる/ハマる/填る/嵌る"},"ハマる":{"variants":"はまる/ハマる/填る/嵌る"},"歯みがき":{"variants":"歯みがき/歯磨き"},"歯磨き":{"variants":"歯みがき/歯磨き"},"ハミガキ":{"variants":"ハミガキ/歯磨"},"歯磨":{"variants":"ハミガキ/歯磨"},"はみだす":{"variants":"はみだす/はみ出す/食み出す"},"はみ出す":{"variants":"はみだす/はみ出す/食み出す"},"食み出す":{"variants":"はみだす/はみ出す/食み出す"},"はみでる":{"variants":"はみでる/はみ出る/食み出でる"},"はみ出る":{"variants":"はみでる/はみ出る/食み出でる"},"はむ":{"variants":"はむ/食む"},"食む":{"variants":"はむ/食む"},"はむかう":{"variants":"はむかう/歯向かう/刃向かう"},"はむかえる":{"variants":"はむかえる/刃向かえる"},"刃向かえる":{"variants":"はむかえる/刃向かえる"},"ハムシ":{"variants":"ハムシ/羽虫/葉虫"},"はめ":{"variants":"はめ/羽目"},"羽目":{"variants":"はめ/羽目"},"はめ板":{"variants":"はめ板/羽目板"},"羽目板":{"variants":"はめ板/羽目板"},"はめ込み":{"variants":"はめ込み/嵌め込み"},"嵌め込み":{"variants":"はめ込み/嵌め込み"},"はめこむ":{"variants":"はめこむ/はめ込む/填め込む/嵌め込む"},"はめ込む":{"variants":"はめこむ/はめ込む/填め込む/嵌め込む"},"はめこめる":{"variants":"はめこめる/はめ込める"},"はめ込める":{"variants":"はめこめる/はめ込める"},"はめる":{"variants":"はめる/填める/嵌める"},"ハモ":{"variants":"ハモ/鱧"},"鱧":{"variants":"ハモ/鱧"},"はや":{"variants":"はや/早"},"早":{"variants":"はや/早"},"ハヤ":{"variants":"ハヤ/早/鮠"},"はやい":{"variants":"はやい/早い/速い"},"早生まれ":{"variants":"早生まれ/早生れ"},"早生れ":{"variants":"早生まれ/早生れ"},"早変り":{"variants":"早変り/早変わり"},"早変わり":{"variants":"早変り/早変わり"},"はやしたてる":{"variants":"はやしたてる/はやし立てる"},"はやし立てる":{"variants":"はやしたてる/はやし立てる"},"はやす":{"variants":"はやす/生やす/囃す"},"はやばや":{"variants":"はやばや/早早"},"ハヤブサ":{"variants":"ハヤブサ/隼"},"隼":{"variants":"ハヤブサ/隼"},"はやまる":{"variants":"はやまる/早まる/速まる"},"はやめる":{"variants":"はやめる/早める/速める"},"はやらす":{"variants":"はやらす/流行らす"},"流行らす":{"variants":"はやらす/流行らす"},"はやり気":{"variants":"はやり気/逸り気"},"逸り気":{"variants":"はやり気/逸り気"},"はやる":{"variants":"はやる/ハヤる/逸る/流行る"},"ハヤる":{"variants":"はやる/ハヤる/逸る/流行る"},"早わかり":{"variants":"早わかり/早分かり/早分り"},"早分かり":{"variants":"早わかり/早分かり/早分り"},"早分り":{"variants":"早わかり/早分かり/早分り"},"早わざ":{"variants":"早わざ/早業"},"早業":{"variants":"早わざ/早業"},"はよう":{"variants":"はよう/早う"},"早う":{"variants":"はよう/早う"},"ハラ":{"variants":"ハラ/原/腹"},"腹あて":{"variants":"腹あて/腹当て"},"腹当て":{"variants":"腹あて/腹当て"},"腹合せ":{"variants":"腹合せ/腹合わせ"},"腹合わせ":{"variants":"腹合せ/腹合わせ"},"はらいきよめる":{"variants":"はらいきよめる/祓い清める"},"祓い清める":{"variants":"はらいきよめる/祓い清める"},"払い込み":{"variants":"払い込み/払込"},"払込":{"variants":"払い込み/払込"},"はらいこむ":{"variants":"はらいこむ/払いこむ/払い込む/払込む"},"払いこむ":{"variants":"はらいこむ/払いこむ/払い込む/払込む"},"払い込む":{"variants":"はらいこむ/払いこむ/払い込む/払込む"},"払込む":{"variants":"はらいこむ/払いこむ/払い込む/払込む"},"はらいこめる":{"variants":"はらいこめる/払い込める"},"払い込める":{"variants":"はらいこめる/払い込める"},"はらいさげる":{"variants":"はらいさげる/払い下げる"},"払い下げる":{"variants":"はらいさげる/払い下げる"},"腹いせ":{"variants":"腹いせ/腹癒せ"},"腹癒せ":{"variants":"腹いせ/腹癒せ"},"払いだし":{"variants":"払いだし/払い出し/払出し"},"払い出し":{"variants":"払いだし/払い出し/払出し"},"払出し":{"variants":"払いだし/払い出し/払出し"},"はらいだす":{"variants":"はらいだす/払い出す"},"払い出す":{"variants":"はらいだす/払い出す"},"はらいだせる":{"variants":"はらいだせる/払い出せる"},"払い出せる":{"variants":"はらいだせる/払い出せる"},"はらいっぱい":{"variants":"はらいっぱい/腹いっぱい/腹一杯"},"腹いっぱい":{"variants":"はらいっぱい/腹いっぱい/腹一杯"},"腹一杯":{"variants":"はらいっぱい/腹いっぱい/腹一杯"},"はらいのける":{"variants":"はらいのける/払いのける/払い除ける"},"払いのける":{"variants":"はらいのける/払いのける/払い除ける"},"払い除ける":{"variants":"はらいのける/払いのける/払い除ける"},"払い戻し":{"variants":"払い戻し/払戻し"},"払戻し":{"variants":"払い戻し/払戻し"},"はらいもどす":{"variants":"はらいもどす/払いもどす/払い戻す/払戻す"},"払いもどす":{"variants":"はらいもどす/払いもどす/払い戻す/払戻す"},"払い戻す":{"variants":"はらいもどす/払いもどす/払い戻す/払戻す"},"払戻す":{"variants":"はらいもどす/払いもどす/払い戻す/払戻す"},"はらいもどせる":{"variants":"はらいもどせる/払い戻せる"},"払い戻せる":{"variants":"はらいもどせる/払い戻せる"},"払いもの":{"variants":"払いもの/払い物"},"払い物":{"variants":"払いもの/払い物"},"はらう":{"variants":"はらう/払う/祓う"},"はらえる":{"variants":"はらえる/払える"},"払える":{"variants":"はらえる/払える"},"腹がけ":{"variants":"腹がけ/腹掛け"},"腹掛け":{"variants":"腹がけ/腹掛け"},"腹切":{"variants":"腹切/腹切り"},"腹切り":{"variants":"腹切/腹切り"},"はらぎたない":{"variants":"はらぎたない/腹穢い"},"腹穢い":{"variants":"はらぎたない/腹穢い"},"はらぐろい":{"variants":"はらぐろい/腹黒い"},"腹黒い":{"variants":"はらぐろい/腹黒い"},"腹ごしらえ":{"variants":"腹ごしらえ/腹拵え"},"腹拵え":{"variants":"腹ごしらえ/腹拵え"},"ハラごなし":{"variants":"ハラごなし/腹ごなし"},"腹ごなし":{"variants":"ハラごなし/腹ごなし"},"はらす":{"variants":"はらす/腫らす/晴らす"},"はらせる":{"variants":"はらせる/晴らせる"},"晴らせる":{"variants":"はらせる/晴らせる"},"はらだたしい":{"variants":"はらだたしい/腹立たしい"},"腹立たしい":{"variants":"はらだたしい/腹立たしい"},"はらだつ":{"variants":"はらだつ/腹立つ"},"腹立つ":{"variants":"はらだつ/腹立つ"},"腹つづみ":{"variants":"腹つづみ/腹鼓"},"腹鼓":{"variants":"腹つづみ/腹鼓"},"腹づもり":{"variants":"腹づもり/腹積もり"},"腹積もり":{"variants":"腹づもり/腹積もり"},"腹ばい":{"variants":"腹ばい/腹這い"},"腹這い":{"variants":"腹ばい/腹這い"},"腹巻":{"variants":"腹巻/腹巻き"},"腹巻き":{"variants":"腹巻/腹巻き"},"はらむ":{"variants":"はらむ/孕む"},"孕む":{"variants":"はらむ/孕む"},"ハラン":{"variants":"ハラン/波乱/波瀾/葉蘭"},"はり":{"variants":"はり/ハリ/針/張/張り/玻璃/鍼"},"ハリ":{"variants":"はり/ハリ/針/張/張り/玻璃/鍼"},"張り":{"variants":"ばり/張り"},"張":{"variants":"はり/ハリ/張/張り"},"張りあい":{"variants":"張りあい/張合い"},"張合い":{"variants":"張りあい/張合い"},"はりあう":{"variants":"はりあう/はり合う/張り合う/張合う"},"はり合う":{"variants":"はりあう/はり合う/張り合う/張合う"},"張り合う":{"variants":"はりあう/はり合う/張り合う/張合う"},"張合う":{"variants":"はりあう/はり合う/張り合う/張合う"},"はりあえる":{"variants":"はりあえる/張り合える"},"張り合える":{"variants":"はりあえる/張り合える"},"はりあげる":{"variants":"はりあげる/張り上げる/張上げる"},"張り上げる":{"variants":"はりあげる/張り上げる/張上げる"},"張上げる":{"variants":"はりあげる/張り上げる/張上げる"},"はりあわす":{"variants":"はりあわす/張り合わす"},"張り合わす":{"variants":"はりあわす/張り合わす"},"はりあわせる":{"variants":"はりあわせる/張り合わせる"},"張り合わせる":{"variants":"はりあわせる/張り合わせる"},"張り板":{"variants":"張り板/張板"},"張板":{"variants":"張り板/張板"},"ハリエンジュ":{"variants":"ハリエンジュ/針槐"},"針槐":{"variants":"ハリエンジュ/針槐"},"張り扇":{"variants":"張り扇/張扇"},"張扇":{"variants":"張り扇/張扇"},"張りかえ":{"variants":"張りかえ/張替え"},"張替え":{"variants":"張りかえ/張替え"},"はりかえる":{"variants":"はりかえる/張り替える"},"張り替える":{"variants":"はりかえる/張り替える"},"貼り紙":{"variants":"貼り紙/貼紙"},"貼紙":{"variants":"貼り紙/貼紙"},"張り紙":{"variants":"張り紙/張紙"},"張紙":{"variants":"張り紙/張紙"},"はりきる":{"variants":"はりきる/張りきる/張り切る/張切る"},"張りきる":{"variants":"はりきる/張りきる/張り切る/張切る"},"張り切る":{"variants":"はりきる/張りきる/張り切る/張切る"},"張切る":{"variants":"はりきる/張りきる/張り切る/張切る"},"はりきれる":{"variants":"はりきれる/張り切れる"},"張り切れる":{"variants":"はりきれる/張り切れる"},"張り子":{"variants":"張り子/張子"},"張子":{"variants":"張り子/張子"},"はりこむ":{"variants":"はりこむ/張り込む"},"張り込む":{"variants":"はりこむ/張り込む"},"はりさける":{"variants":"はりさける/張り裂ける/張裂ける"},"張り裂ける":{"variants":"はりさける/張り裂ける/張裂ける"},"張裂ける":{"variants":"はりさける/張り裂ける/張裂ける"},"はりたおす":{"variants":"はりたおす/ハリたおす/張り倒す/張倒す"},"ハリたおす":{"variants":"はりたおす/ハリたおす/張り倒す/張倒す"},"張り倒す":{"variants":"はりたおす/ハリたおす/張り倒す/張倒す"},"張倒す":{"variants":"はりたおす/ハリたおす/張り倒す/張倒す"},"張り出し":{"variants":"張り出し/張出し"},"張出し":{"variants":"張り出し/張出し"},"はりだす":{"variants":"はりだす/張り出す"},"張り出す":{"variants":"はりだす/張り出す"},"はりだせる":{"variants":"はりだせる/張り出せる"},"張り出せる":{"variants":"はりだせる/張り出せる"},"はりつく":{"variants":"はりつく/張りつく/張り付く"},"張りつく":{"variants":"はりつく/張りつく/張り付く"},"張り付く":{"variants":"はりつく/張りつく/張り付く"},"はりつける":{"variants":"はりつける/張りつける/張り付ける/張付ける"},"張りつける":{"variants":"はりつける/張りつける/張り付ける/張付ける"},"張り付ける":{"variants":"はりつける/張りつける/張り付ける/張付ける"},"張付ける":{"variants":"はりつける/張りつける/張り付ける/張付ける"},"はりつめる":{"variants":"はりつめる/張りつめる/張り詰める/張詰める"},"張りつめる":{"variants":"はりつめる/張りつめる/張り詰める/張詰める"},"張り詰める":{"variants":"はりつめる/張りつめる/張り詰める/張詰める"},"張詰める":{"variants":"はりつめる/張りつめる/張り詰める/張詰める"},"張り手":{"variants":"張り手/張手"},"張手":{"variants":"張り手/張手"},"はりとばす":{"variants":"はりとばす/張りとばす/張り飛ばす/張飛ばす"},"張りとばす":{"variants":"はりとばす/張りとばす/張り飛ばす/張飛ばす"},"張り飛ばす":{"variants":"はりとばす/張りとばす/張り飛ばす/張飛ばす"},"張飛ばす":{"variants":"はりとばす/張りとばす/張り飛ばす/張飛ばす"},"ハリネズミ":{"variants":"ハリネズミ/針鼠"},"針鼠":{"variants":"ハリネズミ/針鼠"},"貼りまぜ":{"variants":"貼りまぜ/貼り雑ぜ"},"貼り雑ぜ":{"variants":"貼りまぜ/貼り雑ぜ"},"張りまぜ":{"variants":"張りまぜ/張り混ぜ"},"張り混ぜ":{"variants":"張りまぜ/張り混ぜ"},"はりまわす":{"variants":"はりまわす/張り回す/張回す"},"張り回す":{"variants":"はりまわす/張り回す/張回す"},"張回す":{"variants":"はりまわす/張り回す/張回す"},"はりめぐらす":{"variants":"はりめぐらす/張り巡らす"},"張り巡らす":{"variants":"はりめぐらす/張り巡らす"},"はりめぐらせる":{"variants":"はりめぐらせる/張りめぐらせる/張り巡らせる"},"張りめぐらせる":{"variants":"はりめぐらせる/張りめぐらせる/張り巡らせる"},"張り巡らせる":{"variants":"はりめぐらせる/張りめぐらせる/張り巡らせる"},"はる":{"variants":"はる/張る/貼る"},"はるか":{"variants":"はるか/遥か"},"遥か":{"variants":"はるか/遥か"},"はるかに":{"variants":"はるかに/遥かに"},"遥かに":{"variants":"はるかに/遥かに"},"春がすみ":{"variants":"春がすみ/春霞"},"春霞":{"variants":"春がすみ/春霞"},"春さき":{"variants":"春さき/春先"},"春先":{"variants":"春さき/春先"},"ハルゼミ":{"variants":"ハルゼミ/春蝉"},"春蝉":{"variants":"ハルゼミ/春蝉"},"春告げ鳥":{"variants":"春告げ鳥/春告鳥"},"春告鳥":{"variants":"春告げ鳥/春告鳥"},"はるばる":{"variants":"はるばる/遥々"},"遥々":{"variants":"はるばる/遥々"},"はるめく":{"variants":"はるめく/春めく"},"春めく":{"variants":"はるめく/春めく"},"春もの":{"variants":"春もの/春物"},"春物":{"variants":"春もの/春物"},"晴れ":{"variants":"晴/晴れ"},"晴":{"variants":"晴/晴れ"},"はれあがる":{"variants":"はれあがる/腫れ上がる/晴れ上がる"},"はれがましい":{"variants":"はれがましい/晴がましい"},"晴がましい":{"variants":"はれがましい/晴がましい"},"晴れ着":{"variants":"晴れ着/晴着"},"晴着":{"variants":"晴れ着/晴着"},"晴れ姿":{"variants":"晴れ姿/晴姿"},"晴姿":{"variants":"晴れ姿/晴姿"},"晴々":{"variants":"晴々/晴れ晴れ/晴晴"},"晴れ晴れ":{"variants":"晴々/晴れ晴れ/晴晴"},"晴晴":{"variants":"晴々/晴れ晴れ/晴晴"},"はれぼったい":{"variants":"はれぼったい/腫れぼったい"},"腫れぼったい":{"variants":"はれぼったい/腫れぼったい"},"晴れ間":{"variants":"晴れ間/晴間"},"晴間":{"variants":"晴れ間/晴間"},"はれ物":{"variants":"はれ物/腫れ物"},"腫れ物":{"variants":"はれ物/腫れ物"},"晴やか":{"variants":"晴やか/晴れやか"},"晴れやか":{"variants":"晴やか/晴れやか"},"はれる":{"variants":"はれる/腫れる/晴れる/張れる/貼れる"},"はれわたる":{"variants":"はれわたる/晴れわたる/晴れ渡る/晴渡る"},"晴れわたる":{"variants":"はれわたる/晴れわたる/晴れ渡る/晴渡る"},"晴れ渡る":{"variants":"はれわたる/晴れわたる/晴れ渡る/晴渡る"},"晴渡る":{"variants":"はれわたる/晴れわたる/晴れ渡る/晴渡る"},"はんがんびいき":{"variants":"はんがんびいき/判官びいき/判官贔屓"},"判官びいき":{"variants":"はんがんびいき/判官びいき/判官贔屓"},"判官贔屓":{"variants":"はんがんびいき/判官びいき/判官贔屓"},"はんこん":{"variants":"はんこん/瘢痕"},"瘢痕":{"variants":"はんこん/瘢痕"},"飯ごう":{"variants":"飯ごう/飯盒"},"飯盒":{"variants":"飯ごう/飯盒"},"ハンザキ":{"variants":"ハンザキ/半裂"},"半裂":{"variants":"ハンザキ/半裂"},"はんじる":{"variants":"はんじる/判じる"},"判じる":{"variants":"はんじる/判じる"},"反すう":{"variants":"反すう/反芻"},"反芻":{"variants":"反すう/反芻"},"はんする":{"variants":"はんする/反する"},"反する":{"variants":"はんする/反する"},"はんずる":{"variants":"はんずる/判ずる"},"判ずる":{"variants":"はんずる/判ずる"},"半そで":{"variants":"半そで/半袖"},"半袖":{"variants":"半そで/半袖"},"はんだ":{"variants":"はんだ/ハンダ"},"ハンダ":{"variants":"はんだ/ハンダ"},"範疇":{"variants":"範ちゅう/範疇"},"範ちゅう":{"variants":"範ちゅう/範疇"},"判取り帳":{"variants":"判取り帳/判取帳"},"判取帳":{"variants":"判取り帳/判取帳"},"半どん":{"variants":"半どん/半ドン"},"半ドン":{"variants":"半どん/半ドン"},"ハンノキ":{"variants":"ハンノキ/榛の木/榛木"},"榛の木":{"variants":"ハンノキ/榛の木/榛木"},"榛木":{"variants":"ハンノキ/榛の木/榛木"},"半々":{"variants":"半々/半半"},"半半":{"variants":"半々/半半"},"反ばく":{"variants":"反ばく/反駁"},"反駁":{"variants":"反ばく/反駁"},"ハンプウシ":{"variants":"ハンプウシ/半風子"},"半風子":{"variants":"ハンプウシ/半風子"},"ハンミョウ":{"variants":"ハンミョウ/斑猫"},"斑猫":{"variants":"ハンミョウ/斑猫"},"はんめん":{"variants":"はんめん/反面"},"反面":{"variants":"はんめん/反面"},"はん用":{"variants":"はん用/汎用/繁用"},"はんらん":{"variants":"はんらん/反乱/叛乱/氾濫"},"伴りょ":{"variants":"伴りょ/伴侶"},"伴侶":{"variants":"伴りょ/伴侶"},"ばあさん":{"variants":"ばあさん/婆さん"},"婆さん":{"variants":"ばあさん/婆さん"},"場当たり":{"variants":"場当たり/場当り"},"場当り":{"variants":"場当たり/場当り"},"ばあちゃん":{"variants":"ばあちゃん/婆ちゃん"},"婆ちゃん":{"variants":"ばあちゃん/婆ちゃん"},"バイ":{"variants":"バイ/倍"},"倍":{"variants":"バイ/倍"},"ばい煙":{"variants":"ばい煙/煤煙"},"煤煙":{"variants":"ばい煙/煤煙"},"ばい菌":{"variants":"ばい菌/バイキン/バイ菌/黴菌"},"バイキン":{"variants":"ばい菌/バイキン/バイ菌/黴菌"},"バイ菌":{"variants":"ばい菌/バイキン/バイ菌/黴菌"},"黴菌":{"variants":"ばい菌/バイキン/バイ菌/黴菌"},"ばいする":{"variants":"ばいする/倍する"},"倍する":{"variants":"ばいする/倍する"},"バイバイ":{"variants":"バイバイ/倍々"},"倍々":{"variants":"バイバイ/倍々"},"買べん":{"variants":"買べん/買弁"},"買弁":{"variants":"買べん/買弁"},"ばか":{"variants":"ばか/バカ/莫迦"},"バカ":{"variants":"ばか/バカ/莫迦"},"莫迦":{"variants":"ばか/バカ/莫迦"},"バカガイ":{"variants":"バカガイ/馬鹿貝"},"馬鹿貝":{"variants":"バカガイ/馬鹿貝"},"ばかくさい":{"variants":"ばかくさい/馬鹿臭い"},"馬鹿臭い":{"variants":"ばかくさい/馬鹿臭い"},"ばかげる":{"variants":"ばかげる/バカげる/馬鹿げる"},"バカげる":{"variants":"ばかげる/バカげる/馬鹿げる"},"馬鹿げる":{"variants":"ばかげる/バカげる/馬鹿げる"},"ばか騒ぎ":{"variants":"ばか騒ぎ/馬鹿騒ぎ"},"馬鹿騒ぎ":{"variants":"ばか騒ぎ/馬鹿騒ぎ"},"ばかす":{"variants":"ばかす/化かす"},"化かす":{"variants":"ばかす/化かす"},"ばかせる":{"variants":"ばかせる/化かせる"},"化かせる":{"variants":"ばかせる/化かせる"},"ばか力":{"variants":"ばか力/馬鹿力"},"馬鹿力":{"variants":"ばか力/馬鹿力"},"ばかばかしい":{"variants":"ばかばかしい/バカバカしい/馬鹿馬鹿しい"},"バカバカしい":{"variants":"ばかばかしい/バカバカしい/馬鹿馬鹿しい"},"馬鹿馬鹿しい":{"variants":"ばかばかしい/バカバカしい/馬鹿馬鹿しい"},"ばからしい":{"variants":"ばからしい/馬鹿らしい"},"馬鹿らしい":{"variants":"ばからしい/馬鹿らしい"},"バク":{"variants":"バク/獏/貘"},"ばく進":{"variants":"ばく進/驀進"},"驀進":{"variants":"ばく進/驀進"},"ばくする":{"variants":"ばくする/縛する/駁する"},"ばく然":{"variants":"ばく然/漠然"},"漠然":{"variants":"ばく然/漠然"},"ばく大":{"variants":"ばく大/莫大"},"莫大":{"variants":"ばく大/莫大"},"博打々ち":{"variants":"博打々ち/博打打ち"},"博打打ち":{"variants":"博打々ち/博打打ち"},"漠々":{"variants":"漠々/漠漠"},"漠漠":{"variants":"漠々/漠漠"},"バグ":{"variants":"バグ/馬具"},"馬具":{"variants":"バグ/馬具"},"化け物":{"variants":"化け物/化物"},"化物":{"variants":"化け物/化物"},"ばける":{"variants":"ばける/化ける"},"化ける":{"variants":"ばける/化ける"},"バショウ":{"variants":"バショウ/芭蕉"},"芭蕉":{"variants":"バショウ/芭蕉"},"場所ふさぎ":{"variants":"場所ふさぎ/場所塞ぎ"},"場所塞ぎ":{"variants":"場所ふさぎ/場所塞ぎ"},"ば声":{"variants":"ば声/罵声"},"罵声":{"variants":"ば声/罵声"},"ばたくさい":{"variants":"ばたくさい/ばた臭い/バタくさい/バタ臭い"},"ばた臭い":{"variants":"ばたくさい/ばた臭い/バタくさい/バタ臭い"},"バタくさい":{"variants":"ばたくさい/ばた臭い/バタくさい/バタ臭い"},"バタ臭い":{"variants":"ばたくさい/ばた臭い/バタくさい/バタ臭い"},"罰当たり":{"variants":"罰当たり/罰当り"},"罰当り":{"variants":"罰当たり/罰当り"},"バッケン":{"variants":"バッケン/抜剣"},"抜剣":{"variants":"バッケン/抜剣"},"ばっこ":{"variants":"ばっこ/跋扈"},"跋扈":{"variants":"ばっこ/跋扈"},"ばっする":{"variants":"ばっする/罰する"},"罰する":{"variants":"ばっする/罰する"},"バッタ":{"variants":"バッタ/飛蝗"},"飛蝗":{"variants":"バッタ/飛蝗"},"抜てき":{"variants":"抜てき/抜擢"},"抜擢":{"variants":"抜てき/抜擢"},"バツ":{"variants":"バツ/閥/跋"},"ば倒":{"variants":"ば倒/罵倒"},"罵倒":{"variants":"ば倒/罵倒"},"場なれ":{"variants":"場なれ/場馴れ"},"場馴れ":{"variants":"場なれ/場馴れ"},"ババ":{"variants":"ババ/婆/馬場"},"バラ":{"variants":"バラ/薔薇"},"薔薇":{"variants":"バラ/薔薇"},"ばら色":{"variants":"ばら色/薔薇色"},"薔薇色":{"variants":"ばら色/薔薇色"},"ばらつき":{"variants":"ばらつき/バラツキ"},"バラツキ":{"variants":"ばらつき/バラツキ"},"ばらつく":{"variants":"ばらつく/バラつく"},"バラつく":{"variants":"ばらつく/バラつく"},"ばらばら":{"variants":"ばらばら/バラバラ"},"バラバラ":{"variants":"ばらばら/バラバラ"},"ばらまき":{"variants":"ばらまき/バラマキ"},"バラマキ":{"variants":"ばらまき/バラマキ"},"ばらまく":{"variants":"ばらまく/ばら蒔く"},"ばら蒔く":{"variants":"ばらまく/ばら蒔く"},"バラモン":{"variants":"バラモン/婆羅門"},"婆羅門":{"variants":"バラモン/婆羅門"},"ばり":{"variants":"ばり/張り"},"ばりばり":{"variants":"ばりばり/バリバリ"},"バリバリ":{"variants":"ばりばり/バリバリ"},"ばん":{"variants":"ばん/万"},"万":{"variants":"ばん/万"},"バン":{"variants":"バン/晩/盤/鷭"},"ばん回":{"variants":"ばん回/挽回"},"挽回":{"variants":"ばん回/挽回"},"バンカラ":{"variants":"バンカラ/蛮カラ"},"蛮カラ":{"variants":"バンカラ/蛮カラ"},"晩さん":{"variants":"晩さん/晩餐"},"晩餐":{"variants":"晩さん/晩餐"},"バンザイ":{"variants":"バンザイ/万才/万歳"},"晩しゃく":{"variants":"晩しゃく/晩酌"},"晩酌":{"variants":"晩しゃく/晩酌"},"バンショウ":{"variants":"バンショウ/晩鐘/蕃椒/万象/万障"},"ばんばん":{"variants":"ばんばん/バンバン/万万"},"バンバン":{"variants":"ばんばん/バンバン/万万"},"万万":{"variants":"ばんばん/バンバン/万万"},"万々歳":{"variants":"万々歳/万万歳"},"万万歳":{"variants":"万々歳/万万歳"},"バンプ":{"variants":"バンプ/万夫"},"万夫":{"variants":"バンプ/万夫"},"％":{"variants":"％/パーセント"},"パーセント":{"variants":"％/パーセント"},"ぱくぱく":{"variants":"ぱくぱく/パクパク"},"パクパク":{"variants":"ぱくぱく/パクパク"},"ぱさぱさ":{"variants":"ぱさぱさ/パサパサ"},"パサパサ":{"variants":"ぱさぱさ/パサパサ"},"ｐａ":{"variants":"ｐａ/パスカル"},"パスカル":{"variants":"ｐａ/パスカル"},"ぱたり":{"variants":"ぱたり/パタリ"},"パタリ":{"variants":"ぱたり/パタリ"},"ぱらぱら":{"variants":"ぱらぱら/パラパラ"},"パラパラ":{"variants":"ぱらぱら/パラパラ"},"ぱりぱり":{"variants":"ぱりぱり/パリパリ"},"パリパリ":{"variants":"ぱりぱり/パリパリ"},"パンの木":{"variants":"パンの木/パンノキ"},"パンノキ":{"variants":"パンの木/パンノキ"},"ひあがる":{"variants":"ひあがる/乾上がる/干上がる"},"日当たり":{"variants":"日当たり/日当り"},"日当り":{"variants":"日当たり/日当り"},"火あぶり":{"variants":"火あぶり/火炙り/火焙り"},"ひいき目":{"variants":"ひいき目/贔屓目"},"贔屓目":{"variants":"ひいき目/贔屓目"},"ひいでる":{"variants":"ひいでる/秀でる"},"秀でる":{"variants":"ひいでる/秀でる"},"ひいばあさん":{"variants":"ひいばあさん/曾祖母さん"},"曾祖母さん":{"variants":"ひいばあさん/曾祖母さん"},"ヒイラギ":{"variants":"ヒイラギ/柊"},"柊":{"variants":"ヒイラギ/柊"},"ひいん":{"variants":"ひいん/悲引"},"悲引":{"variants":"ひいん/悲引"},"火打":{"variants":"火打/火打ち"},"火打ち":{"variants":"火打/火打ち"},"火打ち石":{"variants":"火打ち石/火打石"},"火打石":{"variants":"火打ち石/火打石"},"ヒエ":{"variants":"ヒエ/稗/冷え"},"ひえこむ":{"variants":"ひえこむ/冷えこむ/冷え込む"},"冷えこむ":{"variants":"ひえこむ/冷えこむ/冷え込む"},"冷え込む":{"variants":"ひえこむ/冷えこむ/冷え込む"},"冷え性":{"variants":"冷え性/冷性"},"冷性":{"variants":"冷え性/冷性"},"ひえる":{"variants":"ひえる/冷える"},"冷える":{"variants":"ひえる/冷える"},"ヒオウギ":{"variants":"ヒオウギ/桧扇"},"桧扇":{"variants":"ヒオウギ/桧扇"},"火おけ":{"variants":"火おけ/火桶"},"火桶":{"variants":"火おけ/火桶"},"控":{"variants":"控/控え"},"控え":{"variants":"控/控え"},"控え室":{"variants":"控え室/控室"},"控室":{"variants":"控え室/控室"},"控えめ":{"variants":"控えめ/控え目/控目"},"控え目":{"variants":"控えめ/控え目/控目"},"控目":{"variants":"控えめ/控え目/控目"},"ひかえる":{"variants":"ひかえる/控える"},"控える":{"variants":"ひかえる/控える"},"ひかくてき":{"variants":"ひかくてき/比較的"},"比較的":{"variants":"ひかくてき/比較的"},"ヒカゲノカズラ":{"variants":"ヒカゲノカズラ/石松/日蔭の葛"},"火かげん":{"variants":"火かげん/火加減"},"火加減":{"variants":"火かげん/火加減"},"ひかす":{"variants":"ひかす/落籍す"},"落籍す":{"variants":"ひかす/落籍す"},"ひからす":{"variants":"ひからす/光らす"},"光らす":{"variants":"ひからす/光らす"},"ひからびる":{"variants":"ひからびる/乾涸びる/干からびる/干枯らびる/干涸らびる"},"干枯らびる":{"variants":"ひからびる/干からびる/干枯らびる"},"干涸らびる":{"variants":"ひからびる/干からびる/干涸らびる"},"干からびる":{"variants":"ひからびる/干からびる/干枯らびる/干涸らびる"},"ヒカリゴケ":{"variants":"ヒカリゴケ/光蘚"},"光蘚":{"variants":"ヒカリゴケ/光蘚"},"光りもの":{"variants":"光りもの/光り物"},"光り物":{"variants":"光りもの/光り物"},"ひかる":{"variants":"ひかる/光る"},"光る":{"variants":"ひかる/光る"},"ひかれ者":{"variants":"ひかれ者/引かれもの/引かれ者"},"引かれもの":{"variants":"ひかれ者/引かれもの/引かれ者"},"引かれ者":{"variants":"ひかれ者/引かれもの/引かれ者"},"ヒガイ":{"variants":"ヒガイ/被害/鰉"},"日掛":{"variants":"日掛/日掛け"},"日掛け":{"variants":"日掛/日掛け"},"ひがし":{"variants":"ひがし/乾菓子/干菓子"},"ひがみ根性":{"variants":"ひがみ根性/僻み根性"},"僻み根性":{"variants":"ひがみ根性/僻み根性"},"ひがむ":{"variants":"ひがむ/僻む"},"僻む":{"variants":"ひがむ/僻む"},"ヒガラ":{"variants":"ヒガラ/日雀/日柄"},"ヒガンザクラ":{"variants":"ヒガンザクラ/彼岸桜"},"彼岸桜":{"variants":"ヒガンザクラ/彼岸桜"},"ヒガンバナ":{"variants":"ヒガンバナ/彼岸花"},"彼岸花":{"variants":"ヒガンバナ/彼岸花"},"ヒキ":{"variants":"ヒキ/引き/悲喜"},"引き合い":{"variants":"引き合い/引合/引合い"},"引合":{"variants":"引き合い/引合/引合い"},"引合い":{"variants":"引き合い/引合/引合い"},"ひきあう":{"variants":"ひきあう/引き合う/引合う"},"引き合う":{"variants":"ひきあう/引き合う/引合う"},"引合う":{"variants":"ひきあう/引き合う/引合う"},"ひきあえる":{"variants":"ひきあえる/引き合える"},"引き合える":{"variants":"ひきあえる/引き合える"},"引き上げ":{"variants":"引き上げ/引上げ"},"引上げ":{"variants":"引き上げ/引上げ"},"ひきあげる":{"variants":"ひきあげる/引きあげる/引き上げる/引き揚げる"},"引きあげる":{"variants":"ひきあげる/引きあげる/引き上げる/引き揚げる"},"引き当て":{"variants":"引き当て/引当/引当て"},"引当":{"variants":"引き当て/引当/引当て"},"引当て":{"variants":"引き当て/引当/引当て"},"ひきあてる":{"variants":"ひきあてる/引き当てる/引当てる"},"引き当てる":{"variants":"ひきあてる/引き当てる/引当てる"},"引当てる":{"variants":"ひきあてる/引き当てる/引当てる"},"ひきあわす":{"variants":"ひきあわす/引き合わす"},"引き合わす":{"variants":"ひきあわす/引き合わす"},"ひきあわせる":{"variants":"ひきあわせる/引き合せる/引合せる"},"引き合せる":{"variants":"ひきあわせる/引き合せる/引合せる"},"引合せる":{"variants":"ひきあわせる/引き合せる/引合せる"},"ひきいる":{"variants":"ひきいる/率いる"},"率いる":{"variants":"ひきいる/率いる"},"ひきいれる":{"variants":"ひきいれる/引き入れる/引入れる"},"引き入れる":{"variants":"ひきいれる/引き入れる/引入れる"},"引入れる":{"variants":"ひきいれる/引き入れる/引入れる"},"引き受け":{"variants":"引き受け/引受/引受け"},"引受":{"variants":"引き受け/引受/引受け"},"引受け":{"variants":"引き受け/引受/引受け"},"ひきうける":{"variants":"ひきうける/引き受ける/引受ける"},"引き受ける":{"variants":"ひきうける/引き受ける/引受ける"},"引受ける":{"variants":"ひきうける/引き受ける/引受ける"},"ひきおこす":{"variants":"ひきおこす/引きおこす/引き起こす/引き起す"},"引きおこす":{"variants":"ひきおこす/引きおこす/引き起こす/引き起す"},"引き起こす":{"variants":"ひきおこす/引きおこす/引き起こす/引き起す"},"引き起す":{"variants":"ひきおこす/引きおこす/引き起こす/引き起す"},"ひきおとす":{"variants":"ひきおとす/引き落とす"},"引き落とす":{"variants":"ひきおとす/引き落とす"},"ひきおとせる":{"variants":"ひきおとせる/引き落とせる"},"引き落とせる":{"variants":"ひきおとせる/引き落とせる"},"ひきおろす":{"variants":"ひきおろす/引き下ろす/引き降ろす"},"ひきおろせる":{"variants":"ひきおろせる/引き下ろせる/引き降ろせる"},"引き換え":{"variants":"引き換え/引換"},"引換":{"variants":"引き換え/引換"},"引き返し":{"variants":"引き返し/引返し"},"引返し":{"variants":"引き返し/引返し"},"ひきかえす":{"variants":"ひきかえす/引きかえす/引き返す/引返す"},"引きかえす":{"variants":"ひきかえす/引きかえす/引き返す/引返す"},"引き返す":{"variants":"ひきかえす/引きかえす/引き返す/引返す"},"引返す":{"variants":"ひきかえす/引きかえす/引き返す/引返す"},"ひきかえせる":{"variants":"ひきかえせる/引き返せる"},"引き返せる":{"variants":"ひきかえせる/引き返せる"},"ひきかえる":{"variants":"ひきかえる/引き換える/引き替える/引換える/引替える"},"引き替える":{"variants":"ひきかえる/引き替える/引替える"},"引換える":{"variants":"ひきかえる/引き換える/引換える"},"引き換える":{"variants":"ひきかえる/引き換える/引換える"},"引替える":{"variants":"ひきかえる/引き替える/引替える"},"ヒキガエル":{"variants":"ヒキガエル/蟾蜍"},"蟾蜍":{"variants":"ヒキガエル/蟾蜍"},"引き菓子":{"variants":"引き菓子/引菓子"},"引菓子":{"variants":"引き菓子/引菓子"},"弾きがたり":{"variants":"弾きがたり/弾き語り"},"弾き語り":{"variants":"弾きがたり/弾き語り"},"引金":{"variants":"引き金/引金"},"引き金":{"variants":"引き金/引金"},"引きぎわ":{"variants":"引きぎわ/引き際/引際"},"引き際":{"variants":"引きぎわ/引き際/引際"},"引際":{"variants":"引きぎわ/引き際/引際"},"ひきぐする":{"variants":"ひきぐする/引き具する/引具する"},"引き具する":{"variants":"ひきぐする/引き具する/引具する"},"引具する":{"variants":"ひきぐする/引き具する/引具する"},"ひきこむ":{"variants":"ひきこむ/ひき込む/引き込む/引込む"},"ひき込む":{"variants":"ひきこむ/ひき込む/引き込む/引込む"},"引き込む":{"variants":"ひきこむ/ひき込む/引き込む/引込む"},"引込む":{"variants":"ひきこむ/ひき込む/引き込む/引込む"},"ひきこめる":{"variants":"ひきこめる/引き込める"},"引き込める":{"variants":"ひきこめる/引き込める"},"ひきこもる":{"variants":"ひきこもる/引き篭る"},"引き篭る":{"variants":"ひきこもる/引き篭る"},"ひきころす":{"variants":"ひきころす/ひき殺す/轢き殺す"},"ひき殺す":{"variants":"ひきころす/ひき殺す/轢き殺す"},"轢き殺す":{"variants":"ひきころす/ひき殺す/轢き殺す"},"ひきさがる":{"variants":"ひきさがる/引き下がる/引下がる"},"引き下がる":{"variants":"ひきさがる/引き下がる/引下がる"},"引下がる":{"variants":"ひきさがる/引き下がる/引下がる"},"ひきさく":{"variants":"ひきさく/引きさく/引き裂く/引裂く"},"引きさく":{"variants":"ひきさく/引きさく/引き裂く/引裂く"},"引き裂く":{"variants":"ひきさく/引きさく/引き裂く/引裂く"},"引裂く":{"variants":"ひきさく/引きさく/引き裂く/引裂く"},"ひきさける":{"variants":"ひきさける/引き裂ける"},"引き裂ける":{"variants":"ひきさける/引き裂ける"},"引き下げ":{"variants":"引き下げ/引下げ"},"引下げ":{"variants":"引き下げ/引下げ"},"ひきさげる":{"variants":"ひきさげる/引き下げる/引下げる"},"引き下げる":{"variants":"ひきさげる/引き下げる/引下げる"},"引下げる":{"variants":"ひきさげる/引き下げる/引下げる"},"ひきさる":{"variants":"ひきさる/引き去る/引去る"},"引き去る":{"variants":"ひきさる/引き去る/引去る"},"引去る":{"variants":"ひきさる/引き去る/引去る"},"引き算":{"variants":"引き算/引算"},"引算":{"variants":"引き算/引算"},"ひき潮":{"variants":"ひき潮/引き潮/引潮"},"引き潮":{"variants":"ひき潮/引き潮/引潮"},"引潮":{"variants":"ひき潮/引き潮/引潮"},"ひきしぼる":{"variants":"ひきしぼる/引きしぼる/引き絞る/引絞る"},"引きしぼる":{"variants":"ひきしぼる/引きしぼる/引き絞る/引絞る"},"引き絞る":{"variants":"ひきしぼる/引きしぼる/引き絞る/引絞る"},"引絞る":{"variants":"ひきしぼる/引きしぼる/引き絞る/引絞る"},"ひきしぼれる":{"variants":"ひきしぼれる/引き絞れる"},"引き絞れる":{"variants":"ひきしぼれる/引き絞れる"},"ひきしまる":{"variants":"ひきしまる/引き締まる/引き締る"},"引き締まる":{"variants":"ひきしまる/引き締まる/引き締る"},"引き締る":{"variants":"ひきしまる/引き締まる/引き締る"},"ひきしめる":{"variants":"ひきしめる/引きしめる/引き締める/引締める"},"引きしめる":{"variants":"ひきしめる/引きしめる/引き締める/引締める"},"引き締める":{"variants":"ひきしめる/引きしめる/引き締める/引締める"},"引締める":{"variants":"ひきしめる/引きしめる/引き締める/引締める"},"ひきずりこむ":{"variants":"ひきずりこむ/引きずりこむ/引きずり込む/引き摺り込む"},"引きずりこむ":{"variants":"ひきずりこむ/引きずりこむ/引きずり込む/引き摺り込む"},"引きずり込む":{"variants":"ひきずりこむ/引きずりこむ/引きずり込む/引き摺り込む"},"引き摺り込む":{"variants":"ひきずりこむ/引きずりこむ/引きずり込む/引き摺り込む"},"ひきずりこめる":{"variants":"ひきずりこめる/引きずり込める"},"引きずり込める":{"variants":"ひきずりこめる/引きずり込める"},"ひきずりだす":{"variants":"ひきずりだす/引きずり出す"},"引きずり出す":{"variants":"ひきずりだす/引きずり出す"},"ひきずりだせる":{"variants":"ひきずりだせる/引きずり出せる"},"引きずり出せる":{"variants":"ひきずりだせる/引きずり出せる"},"ひきずりまわす":{"variants":"ひきずりまわす/引きずり回す"},"引きずり回す":{"variants":"ひきずりまわす/引きずり回す"},"ひきずりまわせる":{"variants":"ひきずりまわせる/引きずり回せる"},"引きずり回せる":{"variants":"ひきずりまわせる/引きずり回せる"},"ひきずる":{"variants":"ひきずる/引きずる/引き摺る"},"引きずる":{"variants":"ひきずる/引きずる/引き摺る"},"引き摺る":{"variants":"ひきずる/引きずる/引き摺る"},"ひきたつ":{"variants":"ひきたつ/引き立つ"},"引き立つ":{"variants":"ひきたつ/引き立つ"},"引き立て":{"variants":"引き立て/引立て"},"引立て":{"variants":"引き立て/引立て"},"ひきたて役":{"variants":"ひきたて役/引立て役/引立役"},"引立て役":{"variants":"ひきたて役/引立て役/引立役"},"引立役":{"variants":"ひきたて役/引立て役/引立役"},"ひきたてる":{"variants":"ひきたてる/引きたてる/引き立てる/引立てる"},"引きたてる":{"variants":"ひきたてる/引きたてる/引き立てる/引立てる"},"引き立てる":{"variants":"ひきたてる/引きたてる/引き立てる/引立てる"},"引立てる":{"variants":"ひきたてる/引きたてる/引き立てる/引立てる"},"引き出し":{"variants":"引き出し/引出し"},"引出し":{"variants":"引き出し/引出し"},"ひきだす":{"variants":"ひきだす/引きだす/引き出す/引出す"},"引きだす":{"variants":"ひきだす/引きだす/引き出す/引出す"},"引き出す":{"variants":"ひきだす/引きだす/引き出す/引出す"},"引出す":{"variants":"ひきだす/引きだす/引き出す/引出す"},"ひきだせる":{"variants":"ひきだせる/引き出せる"},"引き出せる":{"variants":"ひきだせる/引き出せる"},"ひきちぎる":{"variants":"ひきちぎる/引きちぎる"},"引きちぎる":{"variants":"ひきちぎる/引きちぎる"},"ひきちぎれる":{"variants":"ひきちぎれる/引きちぎれる"},"引きちぎれる":{"variants":"ひきちぎれる/引きちぎれる"},"挽茶":{"variants":"挽き茶/挽茶"},"挽き茶":{"variants":"挽き茶/挽茶"},"引き継ぎ":{"variants":"引き継ぎ/引継/引継ぎ"},"引継":{"variants":"引き継ぎ/引継/引継ぎ"},"引継ぎ":{"variants":"引き継ぎ/引継/引継ぎ"},"ひきつくろう":{"variants":"ひきつくろう/引き繕う"},"引き繕う":{"variants":"ひきつくろう/引き繕う"},"ひきつぐ":{"variants":"ひきつぐ/引き継ぐ/引継ぐ"},"引き継ぐ":{"variants":"ひきつぐ/引き継ぐ/引継ぐ"},"引継ぐ":{"variants":"ひきつぐ/引き継ぐ/引継ぐ"},"引きつけ":{"variants":"引きつけ/引付け"},"引付け":{"variants":"引きつけ/引付け"},"ひきつける":{"variants":"ひきつける/引きつける/引き付ける"},"引きつける":{"variants":"ひきつける/引きつける/引き付ける"},"引き付ける":{"variants":"ひきつける/引きつける/引き付ける"},"ひきつげる":{"variants":"ひきつげる/引き継げる"},"引き継げる":{"variants":"ひきつげる/引き継げる"},"ひきつづき":{"variants":"ひきつづき/引き続き/引続き"},"引き続き":{"variants":"ひきつづき/引き続き/引続き"},"引続き":{"variants":"ひきつづき/引き続き/引続き"},"ひきつづく":{"variants":"ひきつづく/引き続く"},"引き続く":{"variants":"ひきつづく/引き続く"},"ひきつづける":{"variants":"ひきつづける/引き続ける"},"引き続ける":{"variants":"ひきつづける/引き続ける"},"ひきつる":{"variants":"ひきつる/引き攣る"},"引き攣る":{"variants":"ひきつる/引き攣る"},"ひきつれる":{"variants":"ひきつれる/引き連れる/引き攣れる/引連れる/引攣れる"},"引連れる":{"variants":"ひきつれる/引き連れる/引連れる"},"引き連れる":{"variants":"ひきつれる/引き連れる/引連れる"},"引攣れる":{"variants":"ひきつれる/引き攣れる/引攣れる"},"引き攣れる":{"variants":"ひきつれる/引き攣れる/引攣れる"},"引き出物":{"variants":"引き出物/引出物"},"引出物":{"variants":"引き出物/引出物"},"ひきとめる":{"variants":"ひきとめる/引き止める/引き留める/引止める/引留める"},"引止める":{"variants":"ひきとめる/引き止める/引止める"},"引き止める":{"variants":"ひきとめる/引き止める/引止める"},"引留める":{"variants":"ひきとめる/引き留める/引留める"},"引き留める":{"variants":"ひきとめる/引き留める/引留める"},"ひきとる":{"variants":"ひきとる/引き取る"},"引き取る":{"variants":"ひきとる/引き取る"},"ひきとれる":{"variants":"ひきとれる/引き取れる"},"引き取れる":{"variants":"ひきとれる/引き取れる"},"引き戸":{"variants":"引き戸/引戸"},"引戸":{"variants":"引き戸/引戸"},"ひき肉":{"variants":"ひき肉/挽き肉/挽肉"},"挽き肉":{"variants":"ひき肉/挽き肉/挽肉"},"挽肉":{"variants":"ひき肉/挽き肉/挽肉"},"轢き逃げ":{"variants":"轢き逃げ/轢逃げ"},"轢逃げ":{"variants":"轢き逃げ/轢逃げ"},"引き抜き":{"variants":"引き抜き/引抜き"},"引抜き":{"variants":"引き抜き/引抜き"},"ひきぬく":{"variants":"ひきぬく/引き抜く/引抜く"},"引き抜く":{"variants":"ひきぬく/引き抜く/引抜く"},"引抜く":{"variants":"ひきぬく/引き抜く/引抜く"},"ひきぬける":{"variants":"ひきぬける/引き抜ける"},"引き抜ける":{"variants":"ひきぬける/引き抜ける"},"ひきのける":{"variants":"ひきのける/引き退ける"},"引き退ける":{"variants":"ひきのける/引き退ける"},"引伸し":{"variants":"引き伸ばし/引伸し"},"引き伸ばし":{"variants":"引き伸ばし/引伸し"},"引延し":{"variants":"引き延ばし/引延し"},"引き延ばし":{"variants":"引き延ばし/引延し"},"ひきのばす":{"variants":"ひきのばす/引き延ばす/引き伸ばす"},"ひきのばせる":{"variants":"ひきのばせる/引き延ばせる/引き伸ばせる"},"ひきはなす":{"variants":"ひきはなす/引き離す/引離す"},"引き離す":{"variants":"ひきはなす/引き離す/引離す"},"引離す":{"variants":"ひきはなす/引き離す/引離す"},"ひきはなせる":{"variants":"ひきはなせる/引き離せる"},"引き離せる":{"variants":"ひきはなせる/引き離せる"},"ひきはらう":{"variants":"ひきはらう/引き払う/引払う"},"引き払う":{"variants":"ひきはらう/引き払う/引払う"},"引払う":{"variants":"ひきはらう/引き払う/引払う"},"引き窓":{"variants":"引き窓/引窓"},"引窓":{"variants":"引き窓/引窓"},"引き回し":{"variants":"引き回し/引回し"},"引回し":{"variants":"引き回し/引回し"},"ひきまわす":{"variants":"ひきまわす/引き回す/引回す"},"引き回す":{"variants":"ひきまわす/引き回す/引回す"},"引回す":{"variants":"ひきまわす/引き回す/引回す"},"ひきもどす":{"variants":"ひきもどす/引き戻す"},"引き戻す":{"variants":"ひきもどす/引き戻す"},"ひきもどせる":{"variants":"ひきもどせる/引き戻せる"},"引き戻せる":{"variants":"ひきもどせる/引き戻せる"},"引き物":{"variants":"引き物/引物"},"引物":{"variants":"引き物/引物"},"ひきょう":{"variants":"ひきょう/卑怯"},"卑怯":{"variants":"ひきょう/卑怯"},"ひきよせる":{"variants":"ひきよせる/引き寄せる"},"引き寄せる":{"variants":"ひきよせる/引き寄せる"},"引き分け":{"variants":"引き分け/引分"},"引分":{"variants":"引き分け/引分"},"ひきわける":{"variants":"ひきわける/引き分ける"},"引き分ける":{"variants":"ひきわける/引き分ける"},"引き渡し":{"variants":"引き渡し/引渡し"},"引渡し":{"variants":"引き渡し/引渡し"},"ひきわたす":{"variants":"ひきわたす/引き渡す/引渡す"},"引き渡す":{"variants":"ひきわたす/引き渡す/引渡す"},"引渡す":{"variants":"ひきわたす/引き渡す/引渡す"},"ひきわたせる":{"variants":"ひきわたせる/引き渡せる"},"引き渡せる":{"variants":"ひきわたせる/引き渡せる"},"ひき割り":{"variants":"ひき割り/挽割り/碾割り"},"ひく":{"variants":"ひく/引く/曳く/牽く/索く/惹く/挽く/曵く/碾く/轢く"},"ひくい":{"variants":"ひくい/低い"},"低い":{"variants":"ひくい/低い"},"ヒクイドリ":{"variants":"ヒクイドリ/火食鳥"},"火食鳥":{"variants":"ヒクイドリ/火食鳥"},"引く手あまた":{"variants":"引く手あまた/引く手数多"},"引く手数多":{"variants":"引く手あまた/引く手数多"},"ひくまる":{"variants":"ひくまる/低まる"},"低まる":{"variants":"ひくまる/低まる"},"ひくめる":{"variants":"ひくめる/低める"},"低める":{"variants":"ひくめる/低める"},"ヒグマ":{"variants":"ヒグマ/羆"},"羆":{"variants":"ヒグマ/羆"},"ヒグラシ":{"variants":"ヒグラシ/茅蜩/日暮し"},"日暮":{"variants":"日暮/日暮れ"},"日暮れ":{"variants":"日暮/日暮れ"},"ひけ":{"variants":"ひけ/引け"},"引け":{"variants":"ひけ/引け"},"引けぎわ":{"variants":"引けぎわ/引け際"},"引け際":{"variants":"引けぎわ/引け際"},"退けぎわ":{"variants":"退けぎわ/退け際"},"退け際":{"variants":"退けぎわ/退け際"},"火消":{"variants":"火消/火消し"},"火消し":{"variants":"火消/火消し"},"秘けつ":{"variants":"秘けつ/秘結"},"秘結":{"variants":"秘けつ/秘結"},"引けめ":{"variants":"引けめ/引け目"},"引け目":{"variants":"引けめ/引け目"},"ひける":{"variants":"ひける/引ける/曳ける/牽ける/惹ける/曵ける"},"ヒゲ":{"variants":"ヒゲ/髭/髯/鬚"},"ひこうき雲":{"variants":"ひこうき雲/飛行機雲"},"飛行機雲":{"variants":"ひこうき雲/飛行機雲"},"ひ骨":{"variants":"ひ骨/腓骨"},"腓骨":{"variants":"ひ骨/腓骨"},"ヒゴイ":{"variants":"ヒゴイ/緋鯉"},"緋鯉":{"variants":"ヒゴイ/緋鯉"},"日ごろ":{"variants":"日ごろ/日頃"},"日頃":{"variants":"日ごろ/日頃"},"久方ぶり":{"variants":"久方ぶり/久方振り"},"久方振り":{"variants":"久方ぶり/久方振り"},"ひさぐ":{"variants":"ひさぐ/鬻ぐ"},"鬻ぐ":{"variants":"ひさぐ/鬻ぐ"},"ひさし":{"variants":"ひさし/裳層/庇/廂"},"ひさしい":{"variants":"ひさしい/久しい"},"久しい":{"variants":"ひさしい/久しい"},"久しぶり":{"variants":"久しぶり/久し振り"},"久し振り":{"variants":"久しぶり/久し振り"},"久々":{"variants":"久々/久びさ/久久"},"久びさ":{"variants":"久々/久びさ/久久"},"久久":{"variants":"久々/久びさ/久久"},"ひざ":{"variants":"ひざ/ヒザ/膝"},"ヒザ":{"variants":"ひざ/ヒザ/膝"},"膝":{"variants":"ひざ/ヒザ/膝"},"ひざ掛け":{"variants":"ひざ掛け/膝掛け"},"膝掛け":{"variants":"ひざ掛け/膝掛け"},"ひざ小僧":{"variants":"ひざ小僧/膝小僧"},"膝小僧":{"variants":"ひざ小僧/膝小僧"},"陽ざし":{"variants":"日差し/日射し/陽ざし/陽射し"},"陽射し":{"variants":"日差し/日射し/陽ざし/陽射し"},"ひざ詰め":{"variants":"ひざ詰め/膝詰め"},"膝詰め":{"variants":"ひざ詰め/膝詰め"},"ひざ枕":{"variants":"ひざ枕/膝枕"},"膝枕":{"variants":"ひざ枕/膝枕"},"ひざまずく":{"variants":"ひざまずく/跪く"},"跪く":{"variants":"ひざまずく/跪く"},"ひざ元":{"variants":"ひざ元/膝元"},"膝元":{"variants":"ひざ元/膝元"},"ヒシ":{"variants":"ヒシ/彼此/皮脂/秘史/菱"},"ひし形":{"variants":"ひし形/菱形"},"菱形":{"variants":"ひし形/菱形"},"ひしぐ":{"variants":"ひしぐ/拉ぐ"},"拉ぐ":{"variants":"ひしぐ/拉ぐ"},"ひしげる":{"variants":"ひしげる/拉げる"},"拉げる":{"variants":"ひしげる/拉げる"},"ひしひし":{"variants":"ひしひし/ヒシヒシ"},"ヒシヒシ":{"variants":"ひしひし/ヒシヒシ"},"ひしめきあう":{"variants":"ひしめきあう/ひしめき合う"},"ひしめき合う":{"variants":"ひしめきあう/ひしめき合う"},"ひしめく":{"variants":"ひしめく/犇めく"},"犇めく":{"variants":"ひしめく/犇めく"},"ひしょう":{"variants":"ひしょう/費消/飛しょう/飛翔"},"飛翔":{"variants":"ひしょう/飛しょう/飛翔"},"飛しょう":{"variants":"ひしょう/飛しょう/飛翔"},"ヒシンケイ":{"variants":"ヒシンケイ/皮針形"},"皮針形":{"variants":"ヒシンケイ/皮針形"},"ひじ":{"variants":"ひじ/ヒジ/肱/非時/肘/臂"},"ヒジ":{"variants":"ひじ/ヒジ/肱/非時/肘/臂"},"ひじ掛け":{"variants":"ひじ掛け/肘掛け"},"肘掛け":{"variants":"ひじ掛け/肘掛け"},"ひじき":{"variants":"ひじき/ヒジキ/鹿尾菜/肘木"},"ヒジキ":{"variants":"ひじき/ヒジキ/鹿尾菜/肘木"},"ひじ鉄":{"variants":"ひじ鉄/肘鉄"},"肘鉄":{"variants":"ひじ鉄/肘鉄"},"ひす":{"variants":"ひす/比す/秘す"},"ひする":{"variants":"ひする/比する/秘する"},"ひ素":{"variants":"ひ素/ヒ素/砒素"},"ヒ素":{"variants":"ひ素/ヒ素/砒素"},"砒素":{"variants":"ひ素/ヒ素/砒素"},"悲そう":{"variants":"悲そう/悲壮/悲愴"},"悲愴":{"variants":"悲そう/悲愴"},"悲壮":{"variants":"悲そう/悲壮"},"ひそか":{"variants":"ひそか/窃か/秘か/密か"},"ひそひそ":{"variants":"ひそひそ/ヒソヒソ"},"ヒソヒソ":{"variants":"ひそひそ/ヒソヒソ"},"ひそまる":{"variants":"ひそまる/潜まる"},"潜まる":{"variants":"ひそまる/潜まる"},"ひそみ":{"variants":"ひそみ/顰"},"顰":{"variants":"ひそみ/顰"},"ひそむ":{"variants":"ひそむ/潜む"},"潜む":{"variants":"ひそむ/潜む"},"ひそめる":{"variants":"ひそめる/潜める"},"潜める":{"variants":"ひそめる/潜める"},"ひ臓":{"variants":"ひ臓/脾臓"},"脾臓":{"variants":"ひ臓/脾臓"},"秘蔵っ子":{"variants":"秘蔵っ子/秘蔵子"},"秘蔵子":{"variants":"秘蔵っ子/秘蔵子"},"ひぞる":{"variants":"ひぞる/乾反る"},"乾反る":{"variants":"ひぞる/乾反る"},"ひた押し":{"variants":"ひた押し/直押し"},"直押し":{"variants":"ひた押し/直押し"},"ひたかくし":{"variants":"ひたかくし/ひた隠し"},"ひた隠し":{"variants":"ひたかくし/ひた隠し"},"ヒタキ":{"variants":"ヒタキ/鶲"},"鶲":{"variants":"ヒタキ/鶲"},"ひたし物":{"variants":"ひたし物/浸しもの/浸し物"},"浸しもの":{"variants":"ひたし物/浸しもの/浸し物"},"浸し物":{"variants":"ひたし物/浸しもの/浸し物"},"ひたす":{"variants":"ひたす/浸す"},"浸す":{"variants":"ひたす/浸す"},"ひた走り":{"variants":"ひた走り/直走り"},"直走り":{"variants":"ひた走り/直走り"},"ひたひた":{"variants":"ひたひた/ヒタヒタ"},"ヒタヒタ":{"variants":"ひたひた/ヒタヒタ"},"ひたる":{"variants":"ひたる/浸る"},"浸る":{"variants":"ひたる/浸る"},"ひだ":{"variants":"ひだ/襞"},"襞":{"variants":"ひだ/襞"},"火ダネ":{"variants":"火ダネ/火種"},"火種":{"variants":"火ダネ/火種"},"日だまり":{"variants":"日だまり/日溜まり/日溜り"},"日溜まり":{"variants":"日だまり/日溜まり/日溜り"},"日溜り":{"variants":"日だまり/日溜まり/日溜り"},"ひだり":{"variants":"ひだり/左"},"左":{"variants":"ひだり/左"},"左うちわ":{"variants":"左うちわ/左団扇"},"左団扇":{"variants":"左うちわ/左団扇"},"左きき":{"variants":"左きき/左利き"},"左利き":{"variants":"左きき/左利き"},"ひっかえす":{"variants":"ひっかえす/引っ返す"},"引っ返す":{"variants":"ひっかえす/引っ返す"},"引っ掛かり":{"variants":"引っ掛かり/引掛り"},"引掛り":{"variants":"引っ掛かり/引掛り"},"ひっかかる":{"variants":"ひっかかる/引っかかる/引っ掛かる/引っ掛る"},"引っかかる":{"variants":"ひっかかる/引っかかる/引っ掛かる/引っ掛る"},"引っ掛かる":{"variants":"ひっかかる/引っかかる/引っ掛かる/引っ掛る"},"引っ掛る":{"variants":"ひっかかる/引っかかる/引っ掛かる/引っ掛る"},"ひっかく":{"variants":"ひっかく/ひっ掻く/引っかく/引っ掻く/引掻く"},"ひっ掻く":{"variants":"ひっかく/ひっ掻く/引っかく/引っ掻く/引掻く"},"引っかく":{"variants":"ひっかく/ひっ掻く/引っかく/引っ掻く/引掻く"},"引っ掻く":{"variants":"ひっかく/ひっ掻く/引っかく/引っ掻く/引掻く"},"引掻く":{"variants":"ひっかく/ひっ掻く/引っかく/引っ掻く/引掻く"},"ひっかける":{"variants":"ひっかける/引っかける/引っ掛ける"},"引っかける":{"variants":"ひっかける/引っかける/引っ掛ける"},"引っ掛ける":{"variants":"ひっかける/引っかける/引っ掛ける"},"ひっかつぐ":{"variants":"ひっかつぐ/ひっ担ぐ/引っ担ぐ"},"ひっ担ぐ":{"variants":"ひっかつぐ/ひっ担ぐ/引っ担ぐ"},"引っ担ぐ":{"variants":"ひっかつぐ/ひっ担ぐ/引っ担ぐ"},"ひっかぶる":{"variants":"ひっかぶる/ひっ被る/引っ被る"},"ひっ被る":{"variants":"ひっかぶる/ひっ被る/引っ被る"},"引っ被る":{"variants":"ひっかぶる/ひっ被る/引っ被る"},"ひっきょう":{"variants":"ひっきょう/畢竟"},"畢竟":{"variants":"ひっきょう/畢竟"},"ひっきょうするに":{"variants":"ひっきょうするに/畢竟するに"},"畢竟するに":{"variants":"ひっきょうするに/畢竟するに"},"ひっきりなし":{"variants":"ひっきりなし/ひっきり無し/引切りなし/引切り無し"},"ひっきり無し":{"variants":"ひっきりなし/ひっきり無し/引切りなし/引切り無し"},"引切りなし":{"variants":"ひっきりなし/ひっきり無し/引切りなし/引切り無し"},"引切り無し":{"variants":"ひっきりなし/ひっきり無し/引切りなし/引切り無し"},"ひっくくる":{"variants":"ひっくくる/ひっ括る/引っくくる/引っ括る"},"ひっ括る":{"variants":"ひっくくる/ひっ括る/引っくくる/引っ括る"},"引っくくる":{"variants":"ひっくくる/ひっ括る/引っくくる/引っ括る"},"引っ括る":{"variants":"ひっくくる/ひっ括る/引っくくる/引っ括る"},"ひっくりかえす":{"variants":"ひっくりかえす/ひっくり返す/引っくり返す/引っ繰り返す"},"ひっくり返す":{"variants":"ひっくりかえす/ひっくり返す/引っくり返す/引っ繰り返す"},"引っくり返す":{"variants":"ひっくりかえす/ひっくり返す/引っくり返す/引っ繰り返す"},"引っ繰り返す":{"variants":"ひっくりかえす/ひっくり返す/引っくり返す/引っ繰り返す"},"ひっくりかえせる":{"variants":"ひっくりかえせる/ひっくり返せる"},"ひっくり返せる":{"variants":"ひっくりかえせる/ひっくり返せる"},"ひっくりかえる":{"variants":"ひっくりかえる/ひっくり返る/引っ繰り返る"},"ひっくり返る":{"variants":"ひっくりかえる/ひっくり返る/引っ繰り返る"},"引っ繰り返る":{"variants":"ひっくりかえる/ひっくり返る/引っ繰り返る"},"ひっくりかえれる":{"variants":"ひっくりかえれる/ひっくり返れる"},"ひっくり返れる":{"variants":"ひっくりかえれる/ひっくり返れる"},"ひっくるめる":{"variants":"ひっくるめる/引っ括める"},"引っ括める":{"variants":"ひっくるめる/引っ括める"},"引っ越し":{"variants":"引っ越し/引越し"},"引越し":{"variants":"引っ越し/引越し"},"ひっこす":{"variants":"ひっこす/引っ越す/引越す"},"引っ越す":{"variants":"ひっこす/引っ越す/引越す"},"引越す":{"variants":"ひっこす/引っ越す/引越す"},"ひっこせる":{"variants":"ひっこせる/引っ越せる"},"引っ越せる":{"variants":"ひっこせる/引っ越せる"},"ひっこぬく":{"variants":"ひっこぬく/ひっこ抜く/引っこぬく/引っこ抜く"},"ひっこ抜く":{"variants":"ひっこぬく/ひっこ抜く/引っこぬく/引っこ抜く"},"引っこぬく":{"variants":"ひっこぬく/ひっこ抜く/引っこぬく/引っこ抜く"},"引っこ抜く":{"variants":"ひっこぬく/ひっこ抜く/引っこぬく/引っこ抜く"},"引っこみ":{"variants":"引っこみ/引っ込み/引込み"},"引っ込み":{"variants":"引っこみ/引っ込み/引込み"},"引込み":{"variants":"引っこみ/引っ込み/引込み"},"引っ込み思案":{"variants":"引っ込み思案/引込み思案"},"引込み思案":{"variants":"引っ込み思案/引込み思案"},"ひっこむ":{"variants":"ひっこむ/引っ込む"},"引っ込む":{"variants":"ひっこむ/引っ込む"},"ひっこめる":{"variants":"ひっこめる/ひっ込める/引っこめる/引っ込める"},"ひっ込める":{"variants":"ひっこめる/ひっ込める/引っこめる/引っ込める"},"引っこめる":{"variants":"ひっこめる/ひっ込める/引っこめる/引っ込める"},"引っ込める":{"variants":"ひっこめる/ひっ込める/引っこめる/引っ込める"},"ひっこもる":{"variants":"ひっこもる/ひっ篭る/引っ篭る"},"ひっ篭る":{"variants":"ひっこもる/ひっ篭る/引っ篭る"},"引っ篭る":{"variants":"ひっこもる/ひっ篭る/引っ篭る"},"ひっさげる":{"variants":"ひっさげる/ひっ提げる/引っさげる/引っ下げる/引っ提げる"},"引っさげる":{"variants":"ひっさげる/ひっ提げる/引っさげる/引っ下げる/引っ提げる"},"ひっ提げる":{"variants":"ひっさげる/ひっ提げる/引っさげる/引っ提げる"},"引っ提げる":{"variants":"ひっさげる/ひっ提げる/引っさげる/引っ提げる"},"ひったてる":{"variants":"ひったてる/引っ立てる"},"引っ立てる":{"variants":"ひったてる/引っ立てる"},"ひっつかむ":{"variants":"ひっつかむ/ひっ掴む/引っつかむ/引っ掴む"},"ひっ掴む":{"variants":"ひっつかむ/ひっ掴む/引っつかむ/引っ掴む"},"引っつかむ":{"variants":"ひっつかむ/ひっ掴む/引っつかむ/引っ掴む"},"引っ掴む":{"variants":"ひっつかむ/ひっ掴む/引っつかむ/引っ掴む"},"ひっつく":{"variants":"ひっつく/引っ付く"},"引っ付く":{"variants":"ひっつく/引っ付く"},"引っつめ":{"variants":"引っつめ/引っ詰め"},"引っ詰め":{"variants":"引っつめ/引っ詰め"},"ヒット・エンド・ラン":{"variants":"ヒット・エンド・ラン/ヒットエンドラン"},"ヒットエンドラン":{"variants":"ヒット・エンド・ラン/ヒットエンドラン"},"ひっとらえる":{"variants":"ひっとらえる/引っ捕える"},"引っ捕える":{"variants":"ひっとらえる/引っ捕える"},"ひっぱがす":{"variants":"ひっぱがす/引っ剥がす"},"引っ剥がす":{"variants":"ひっぱがす/引っ剥がす"},"ひっ迫":{"variants":"ひっ迫/逼迫"},"逼迫":{"variants":"ひっ迫/逼迫"},"ひっぱたく":{"variants":"ひっぱたく/引っぱたく"},"引っぱたく":{"variants":"ひっぱたく/引っぱたく"},"引っ張りだこ":{"variants":"引っ張りだこ/引張りだこ/引張り凧"},"引張りだこ":{"variants":"引っ張りだこ/引張りだこ/引張り凧"},"引張り凧":{"variants":"引っ張りだこ/引張りだこ/引張り凧"},"ひっぱる":{"variants":"ひっぱる/引っぱる/引っ張る/引張る"},"引っぱる":{"variants":"ひっぱる/引っぱる/引っ張る/引張る"},"引っ張る":{"variants":"ひっぱる/引っぱる/引っ張る/引張る"},"引張る":{"variants":"ひっぱる/引っぱる/引っ張る/引張る"},"ひっぱれる":{"variants":"ひっぱれる/引っ張れる"},"引っ張れる":{"variants":"ひっぱれる/引っ張れる"},"ヒップ":{"variants":"ヒップ/匹夫"},"匹夫":{"variants":"ヒップ/匹夫"},"火付":{"variants":"火付/火付き"},"火付き":{"variants":"火付/火付き"},"ひつぎ":{"variants":"ひつぎ/日嗣/柩"},"ヒツジ":{"variants":"ヒツジ/未/羊"},"ヒツジグサ":{"variants":"ヒツジグサ/未草"},"未草":{"variants":"ヒツジグサ/未草"},"日照り雨":{"variants":"日照り雨/日照雨"},"日照雨":{"variants":"日照り雨/日照雨"},"ひと":{"variants":"ひと/ヒト/人/匪徒/費途"},"ヒト":{"variants":"ひと/ヒト/人/匪徒/費途"},"ひと足":{"variants":"ひと足/一足"},"一足":{"variants":"ひと足/一足"},"ひと汗":{"variants":"ひと汗/一汗"},"一汗":{"variants":"ひと汗/一汗"},"人当たり":{"variants":"人当たり/人当り"},"人当り":{"variants":"人当たり/人当り"},"ひと雨":{"variants":"ひと雨/一雨"},"一雨":{"variants":"ひと雨/一雨"},"ひと泡":{"variants":"ひと泡/一泡"},"一泡":{"variants":"ひと泡/一泡"},"ひと息":{"variants":"ひと息/一息"},"一息":{"variants":"ひと息/一息"},"ひといちばい":{"variants":"ひといちばい/人一倍"},"人一倍":{"variants":"ひといちばい/人一倍"},"ひとえに":{"variants":"ひとえに/偏に"},"偏に":{"variants":"ひとえに/偏に"},"ひと抱え":{"variants":"ひと抱え/一抱え"},"一抱え":{"variants":"ひと抱え/一抱え"},"ひとかたならず":{"variants":"ひとかたならず/一方ならず"},"一方ならず":{"variants":"ひとかたならず/一方ならず"},"ひと皮":{"variants":"ひと皮/一皮"},"一皮":{"variants":"ひと皮/一皮"},"ひとかわむく":{"variants":"ひとかわむく/一皮むく/一皮剥く"},"一皮むく":{"variants":"ひとかわむく/一皮むく/一皮剥く"},"一皮剥く":{"variants":"ひとかわむく/一皮むく/一皮剥く"},"ひとかわむける":{"variants":"ひとかわむける/一皮むける/一皮剥ける"},"一皮むける":{"variants":"ひとかわむける/一皮むける/一皮剥ける"},"一皮剥ける":{"variants":"ひとかわむける/一皮むける/一皮剥ける"},"ひとがましい":{"variants":"ひとがましい/人がましい"},"人がましい":{"variants":"ひとがましい/人がましい"},"人がら":{"variants":"人がら/人柄"},"人柄":{"variants":"人がら/人柄"},"人斬り庖丁":{"variants":"人斬り庖丁/人斬庖丁"},"人斬庖丁":{"variants":"人斬り庖丁/人斬庖丁"},"ひときわ":{"variants":"ひときわ/一際"},"一際":{"variants":"ひときわ/一際"},"ひとくさい":{"variants":"ひとくさい/人臭い"},"人臭い":{"variants":"ひとくさい/人臭い"},"ひと癖":{"variants":"ひと癖/一癖"},"一癖":{"variants":"ひと癖/一癖"},"ひとくち":{"variants":"ひとくち/ひと口/一口"},"ひと口":{"variants":"ひとくち/ひと口/一口"},"一口":{"variants":"ひとくち/ひと口/一口"},"ひとこと":{"variants":"ひとこと/ひと言/一言"},"ひと言":{"variants":"ひとこと/ひと言/一言"},"一言":{"variants":"ひとこと/ひと言/一言"},"一こま":{"variants":"一こま/一齣"},"一齣":{"variants":"一こま/一齣"},"ひところ":{"variants":"ひところ/ひと頃/一頃"},"ひと頃":{"variants":"ひところ/ひと頃/一頃"},"一頃":{"variants":"ひところ/ひと頃/一頃"},"ひとごと":{"variants":"ひとごと/ひと事"},"ひと事":{"variants":"ひとごと/ひと事"},"人ごみ":{"variants":"人ごみ/人込み/人混み"},"ひとさし指":{"variants":"ひとさし指/人さし指/人差し指/人差指/人指しゆび/人指し指"},"人さし指":{"variants":"ひとさし指/人さし指/人差し指/人差指/人指しゆび/人指し指"},"人差指":{"variants":"ひとさし指/人さし指/人差し指/人差指"},"人指しゆび":{"variants":"ひとさし指/人さし指/人指しゆび/人指し指"},"人指し指":{"variants":"ひとさし指/人さし指/人指しゆび/人指し指"},"人差し指":{"variants":"ひとさし指/人さし指/人差し指/人差指"},"人さま":{"variants":"人さま/人様"},"人様":{"variants":"人さま/人様"},"人さらい":{"variants":"人さらい/人攫い"},"人攫い":{"variants":"人さらい/人攫い"},"ひとしい":{"variants":"ひとしい/均しい/等しい"},"ひとしお":{"variants":"ひとしお/一しお/一入"},"一しお":{"variants":"ひとしお/一しお/一入"},"一入":{"variants":"ひとしお/一しお/一入"},"ひとしきり":{"variants":"ひとしきり/一頻り"},"一頻り":{"variants":"ひとしきり/一頻り"},"ひとしれず":{"variants":"ひとしれず/人知れず"},"人知れず":{"variants":"ひとしれず/人知れず"},"ひとすじ":{"variants":"ひとすじ/一すじ/一筋"},"一すじ":{"variants":"一すじ/一筋"},"一筋":{"variants":"一すじ/一筋"},"ひと筋縄":{"variants":"ひと筋縄/一筋縄"},"一筋縄":{"variants":"ひと筋縄/一筋縄"},"ひとたび":{"variants":"ひとたび/ひと度"},"ひと度":{"variants":"ひとたび/ひと度"},"ひとっ飛び":{"variants":"ひとっ飛び/一飛び"},"一飛び":{"variants":"ひとっ飛び/一飛び"},"１つ":{"variants":"１つ/一つ"},"一つ":{"variants":"１つ/一つ"},"ひとつ穴":{"variants":"ひとつ穴/一つあな/一つ穴"},"一つあな":{"variants":"ひとつ穴/一つあな/一つ穴"},"一つ穴":{"variants":"ひとつ穴/一つあな/一つ穴"},"ひとつ覚え":{"variants":"ひとつ覚え/一つ覚え"},"一つ覚え":{"variants":"ひとつ覚え/一つ覚え"},"ひとつ話":{"variants":"ひとつ話/一つばなし/一つ話"},"一つばなし":{"variants":"ひとつ話/一つばなし/一つ話"},"一つ話":{"variants":"ひとつ話/一つばなし/一つ話"},"ひとつひとつ":{"variants":"ひとつひとつ/一つひとつ/一つ一つ"},"一つひとつ":{"variants":"ひとつひとつ/一つひとつ/一つ一つ"},"一つ一つ":{"variants":"ひとつひとつ/一つひとつ/一つ一つ"},"ひとつぶ":{"variants":"ひとつぶ/ひと粒"},"ひと粒":{"variants":"ひとつぶ/ひと粒"},"ひとつ身":{"variants":"ひとつ身/一つ身"},"一つ身":{"variants":"ひとつ身/一つ身"},"人付きあい":{"variants":"人付きあい/人付き合い/人付合い"},"人付き合い":{"variants":"人付きあい/人付き合い/人付合い"},"人付合い":{"variants":"人付きあい/人付き合い/人付合い"},"人づて":{"variants":"人づて/人伝"},"人伝":{"variants":"人づて/人伝"},"ヒトデ":{"variants":"ヒトデ/海星/人手/人出"},"ひととき":{"variants":"ひととき/ひと時"},"ひと時":{"variants":"ひととき/ひと時"},"人なつこい":{"variants":"人なつこい/人懐こい"},"人懐こい":{"variants":"人なつこい/人懐こい"},"ひとなつっこい":{"variants":"ひとなつっこい/人懐っこい"},"人懐っこい":{"variants":"ひとなつっこい/人懐っこい"},"人並":{"variants":"人並/人並み"},"人並み":{"variants":"人並/人並み"},"ひとはたあげる":{"variants":"ひとはたあげる/一旗揚げる"},"一旗揚げる":{"variants":"ひとはたあげる/一旗揚げる"},"ひと肌":{"variants":"ひと肌/一肌/人肌"},"人肌":{"variants":"ひと肌/人肌"},"一肌":{"variants":"ひと肌/一肌"},"ひとはだぬぐ":{"variants":"ひとはだぬぐ/一肌脱ぐ"},"一肌脱ぐ":{"variants":"ひとはだぬぐ/一肌脱ぐ"},"ひと花":{"variants":"ひと花/一花"},"一花":{"variants":"ひと花/一花"},"ひとはなさかせる":{"variants":"ひとはなさかせる/一花咲かせる"},"一花咲かせる":{"variants":"ひとはなさかせる/一花咲かせる"},"ひと晩":{"variants":"ひと晩/一晩"},"一晩":{"variants":"ひと晩/一晩"},"人々":{"variants":"人々/人びと/人人"},"人びと":{"variants":"人々/人びと/人人"},"人人":{"variants":"人々/人びと/人人"},"人まかせ":{"variants":"人まかせ/人任せ"},"人任せ":{"variants":"人まかせ/人任せ"},"ひと幕":{"variants":"ひと幕/一幕"},"一幕":{"variants":"ひと幕/一幕"},"ひとまず":{"variants":"ひとまず/一先ず"},"一先ず":{"variants":"ひとまず/一先ず"},"人待ち顔":{"variants":"人待ち顔/人待顔"},"人待顔":{"variants":"人待ち顔/人待顔"},"人まね":{"variants":"人まね/人真似"},"人真似":{"variants":"人まね/人真似"},"ひと回り":{"variants":"ひと回り/一回り"},"一回り":{"variants":"ひと回り/一回り"},"ひとみ":{"variants":"ひとみ/瞳"},"瞳":{"variants":"ひとみ/瞳"},"ひと昔":{"variants":"ひと昔/一昔"},"一昔":{"variants":"ひと昔/一昔"},"ひと目":{"variants":"ひと目/一目"},"人目":{"variants":"ひと目/人目"},"一目":{"variants":"ひと目/一目"},"ひとめぼれ":{"variants":"ひとめぼれ/一目ボレ"},"一目ボレ":{"variants":"ひとめぼれ/一目ボレ"},"ひと役":{"variants":"ひと役/一役"},"一役":{"variants":"ひと役/一役"},"ひと山":{"variants":"ひと山/一山/人山"},"ひとり":{"variants":"ひとり/一人/火採り/火取り/独り"},"ひとり歩き":{"variants":"ひとり歩き/独り歩き"},"独り歩き":{"variants":"ひとり歩き/独り歩き"},"ひとり案内":{"variants":"ひとり案内/独り案内"},"独り案内":{"variants":"ひとり案内/独り案内"},"ひとり暮し":{"variants":"ひとり暮し/一人暮らし"},"一人暮らし":{"variants":"ひとり暮し/一人暮らし"},"独り暮らし":{"variants":"独り暮し/独り暮らし"},"独り暮し":{"variants":"独り暮し/独り暮らし"},"ひとりごつ":{"variants":"ひとりごつ/独りごつ"},"独りごつ":{"variants":"ひとりごつ/独りごつ"},"独り言":{"variants":"独り言/独言"},"独言":{"variants":"独り言/独言"},"ヒトリシズカ":{"variants":"ヒトリシズカ/一人静"},"一人静":{"variants":"ヒトリシズカ/一人静"},"ひとり占め":{"variants":"ひとり占め/一人占め/独り占め"},"ひとり立ち":{"variants":"ひとり立ち/独り立ち"},"独り立ち":{"variants":"ひとり立ち/独り立ち"},"ひとりっ子":{"variants":"ひとりっ子/一人っ子/一人子/独りっ子"},"一人子":{"variants":"ひとりっ子/一人っ子/一人子"},"一人っ子":{"variants":"ひとりっ子/一人っ子/一人子"},"ひとりでに":{"variants":"ひとりでに/独りでに"},"独りでに":{"variants":"ひとりでに/独りでに"},"ひとり者":{"variants":"ひとり者/独りもの/独り者"},"独りもの":{"variants":"ひとり者/独りもの/独り者"},"独り者":{"variants":"ひとり者/独りもの/独り者"},"独りよがり":{"variants":"独りよがり/独り善がり"},"独り善がり":{"variants":"独りよがり/独り善がり"},"ひどる":{"variants":"ひどる/火取る"},"火取る":{"variants":"ひどる/火取る"},"ひな":{"variants":"ひな/ヒナ/鄙"},"ヒナ":{"variants":"ひな/ヒナ/鄙"},"鄙":{"variants":"ひな/ヒナ/鄙"},"ヒナギク":{"variants":"ヒナギク/雛菊"},"雛菊":{"variants":"ヒナギク/雛菊"},"ヒナゲシ":{"variants":"ヒナゲシ/雛罌粟"},"雛罌粟":{"variants":"ヒナゲシ/雛罌粟"},"日なた":{"variants":"日なた/日向"},"日向":{"variants":"日なた/日向"},"ひなたくさい":{"variants":"ひなたくさい/日向臭い"},"日向臭い":{"variants":"ひなたくさい/日向臭い"},"日なたぼっこ":{"variants":"日なたぼっこ/日向ぼっこ"},"日向ぼっこ":{"variants":"日なたぼっこ/日向ぼっこ"},"ひな壇":{"variants":"ひな壇/雛壇"},"雛壇":{"variants":"ひな壇/雛壇"},"ひな鳥":{"variants":"ひな鳥/雛鳥"},"雛鳥":{"variants":"ひな鳥/雛鳥"},"ひな人形":{"variants":"ひな人形/雛人形"},"雛人形":{"variants":"ひな人形/雛人形"},"ひなの節句":{"variants":"ひなの節句/雛の節句/雛節句"},"雛の節句":{"variants":"ひなの節句/雛の節句/雛節句"},"雛節句":{"variants":"ひなの節句/雛の節句/雛節句"},"ひなびる":{"variants":"ひなびる/鄙びる"},"鄙びる":{"variants":"ひなびる/鄙びる"},"ひな祭り":{"variants":"ひな祭り/雛まつり/雛祭"},"雛まつり":{"variants":"ひな祭り/雛まつり/雛祭"},"雛祭":{"variants":"ひな祭り/雛まつり/雛祭"},"日並":{"variants":"日並/日並み"},"日並み":{"variants":"日並/日並み"},"ひにくる":{"variants":"ひにくる/皮肉る"},"皮肉る":{"variants":"ひにくる/皮肉る"},"日にち":{"variants":"日にち/日日"},"日日":{"variants":"日々/日日"},"ひにひに":{"variants":"ひにひに/日に日に"},"日に日に":{"variants":"ひにひに/日に日に"},"ひねり":{"variants":"ひねり/捻り"},"捻り":{"variants":"ひねり/捻り"},"ひねりだす":{"variants":"ひねりだす/ひねり出す/捻り出す"},"ひねり出す":{"variants":"ひねりだす/ひねり出す/捻り出す"},"捻り出す":{"variants":"ひねりだす/ひねり出す/捻り出す"},"ひねりまわす":{"variants":"ひねりまわす/ひねり回す/捻り回す"},"ひねり回す":{"variants":"ひねりまわす/ひねり回す/捻り回す"},"捻り回す":{"variants":"ひねりまわす/ひねり回す/捻り回す"},"ひねる":{"variants":"ひねる/ヒネる"},"ヒネる":{"variants":"ひねる/ヒネる"},"ひのき":{"variants":"ひのき/ヒノキ/桧/檜"},"ヒノキ":{"variants":"ひのき/ヒノキ/桧/檜"},"ひのき舞台":{"variants":"ひのき舞台/桧舞台"},"桧舞台":{"variants":"ひのき舞台/桧舞台"},"火の見やぐら":{"variants":"火の見やぐら/火の見櫓"},"火の見櫓":{"variants":"火の見やぐら/火の見櫓"},"ヒバ":{"variants":"ヒバ/乾葉/干葉/桧葉"},"被ばく":{"variants":"被ばく/被曝/被爆"},"ヒバリ":{"variants":"ヒバリ/雲雀"},"雲雀":{"variants":"ヒバリ/雲雀"},"ひひ":{"variants":"ひひ/比比"},"比比":{"variants":"ひひ/比比"},"ヒヒ":{"variants":"ヒヒ/狒々/狒狒/霏々/霏霏"},"狒狒":{"variants":"ヒヒ/狒々/狒狒"},"霏霏":{"variants":"ヒヒ/霏々/霏霏"},"狒々":{"variants":"ヒヒ/狒々/狒狒"},"霏々":{"variants":"ヒヒ/霏々/霏霏"},"ひび":{"variants":"ひび/ヒビ/罅"},"ヒビ":{"variants":"ひび/ヒビ/罅"},"罅":{"variants":"ひび/ヒビ/罅"},"日々":{"variants":"日々/日日"},"ひびかす":{"variants":"ひびかす/響かす"},"響かす":{"variants":"ひびかす/響かす"},"響":{"variants":"響/響き"},"響き":{"variants":"響/響き"},"ひびきわたる":{"variants":"ひびきわたる/響きわたる"},"響きわたる":{"variants":"ひびきわたる/響きわたる"},"ひびく":{"variants":"ひびく/響く"},"響く":{"variants":"ひびく/響く"},"ひびわれる":{"variants":"ひびわれる/ひび割れる/罅割れる"},"ひび割れる":{"variants":"ひびわれる/ひび割れる/罅割れる"},"罅割れる":{"variants":"ひびわれる/ひび割れる/罅割れる"},"皮膚":{"variants":"皮ふ/皮膚"},"皮ふ":{"variants":"皮ふ/皮膚"},"火ぶた":{"variants":"火ぶた/火蓋"},"火蓋":{"variants":"火ぶた/火蓋"},"干乾":{"variants":"干乾/干乾し"},"日干し":{"variants":"日干/日干し"},"日乾し":{"variants":"日乾/日乾し"},"日干":{"variants":"日干/日干し"},"日乾":{"variants":"日乾/日乾し"},"干乾し":{"variants":"干乾/干乾し"},"ひま":{"variants":"ひま/ヒマ/蓖麻"},"ヒマ":{"variants":"ひま/ヒマ/蓖麻"},"蓖麻":{"variants":"ひま/ヒマ/蓖麻"},"ひまし油":{"variants":"ひまし油/蓖麻子油"},"蓖麻子油":{"variants":"ひまし油/蓖麻子油"},"日待":{"variants":"日待/日待ち"},"日待ち":{"variants":"日待/日待ち"},"暇つぶし":{"variants":"暇つぶし/暇潰し"},"暇潰し":{"variants":"暇つぶし/暇潰し"},"火まつり":{"variants":"火まつり/火祭"},"火祭":{"variants":"火まつり/火祭"},"隙々":{"variants":"隙々/隙隙"},"隙隙":{"variants":"隙々/隙隙"},"暇々":{"variants":"暇々/暇暇"},"暇暇":{"variants":"暇々/暇暇"},"ヒマラヤすぎ":{"variants":"ヒマラヤすぎ/ヒマラヤスギ/ヒマラヤ杉"},"ヒマラヤスギ":{"variants":"ヒマラヤすぎ/ヒマラヤスギ/ヒマラヤ杉"},"ヒマラヤ杉":{"variants":"ヒマラヤすぎ/ヒマラヤスギ/ヒマラヤ杉"},"ひまわり":{"variants":"ひまわり/ヒマワリ/向日葵"},"ヒマワリ":{"variants":"ひまわり/ヒマワリ/向日葵"},"向日葵":{"variants":"ひまわり/ヒマワリ/向日葵"},"ヒメコマツ":{"variants":"ヒメコマツ/姫小松"},"姫小松":{"variants":"ヒメコマツ/姫小松"},"ヒメマス":{"variants":"ヒメマス/姫鱒"},"姫鱒":{"variants":"ヒメマス/姫鱒"},"ヒメユリ":{"variants":"ヒメユリ/姫百合"},"姫百合":{"variants":"ヒメユリ/姫百合"},"ひめる":{"variants":"ひめる/秘める"},"秘める":{"variants":"ひめる/秘める"},"ひも":{"variants":"ひも/ヒモ/紐"},"ヒモ":{"variants":"ひも/ヒモ/紐"},"紐":{"variants":"ひも/ヒモ/紐"},"ひもすがら":{"variants":"ひもすがら/終日"},"終日":{"variants":"ひもすがら/終日"},"日もち":{"variants":"日もち/日持ち/日保ち"},"日保ち":{"variants":"日もち/日保ち"},"日持ち":{"variants":"日もち/日持ち"},"紐付":{"variants":"紐付/紐付き"},"紐付き":{"variants":"紐付/紐付き"},"ひもとく":{"variants":"ひもとく/紐解く/繙く"},"ひもとける":{"variants":"ひもとける/紐解ける"},"紐解ける":{"variants":"ひもとける/紐解ける"},"ひゃく":{"variants":"ひゃく/百"},"百":{"variants":"ひゃく/百"},"百日ぜき":{"variants":"百日ぜき/百日咳"},"百日咳":{"variants":"百日ぜき/百日咳"},"ヒャクニチソウ":{"variants":"ヒャクニチソウ/百日草"},"百日草":{"variants":"ヒャクニチソウ/百日草"},"百花りょう乱":{"variants":"百花りょう乱/百花繚乱"},"百花繚乱":{"variants":"百花りょう乱/百花繚乱"},"冷":{"variants":"冷/冷や"},"冷や":{"variants":"冷/冷や"},"冷や汗":{"variants":"冷や汗/冷汗"},"冷汗":{"variants":"冷や汗/冷汗"},"ひやかす":{"variants":"ひやかす/素見す/冷かす/冷やかす"},"冷やかす":{"variants":"ひやかす/冷かす/冷やかす"},"冷かす":{"variants":"ひやかす/冷かす/冷やかす"},"ひやかせる":{"variants":"ひやかせる/冷やかせる"},"冷やかせる":{"variants":"ひやかせる/冷やかせる"},"ヒヤシンス":{"variants":"ヒヤシンス/風信子"},"風信子":{"variants":"ヒヤシンス/風信子"},"ひやす":{"variants":"ひやす/冷す/冷やす"},"冷す":{"variants":"ひやす/冷す/冷やす"},"冷やす":{"variants":"ひやす/冷す/冷やす"},"ひやせる":{"variants":"ひやせる/冷やせる"},"冷やせる":{"variants":"ひやせる/冷やせる"},"ひやっこい":{"variants":"ひやっこい/冷っこい"},"冷っこい":{"variants":"ひやっこい/冷っこい"},"日雇":{"variants":"日雇/日雇い"},"日雇い":{"variants":"日雇/日雇い"},"ひやひや":{"variants":"ひやひや/冷やひや"},"冷やひや":{"variants":"冷やひや/冷や冷や"},"冷や冷や":{"variants":"冷やひや/冷や冷や"},"冷や麦":{"variants":"冷や麦/冷麦"},"冷麦":{"variants":"冷や麦/冷麦"},"冷や飯":{"variants":"冷や飯/冷飯"},"冷飯":{"variants":"冷や飯/冷飯"},"冷や飯食い":{"variants":"冷や飯食い/冷飯食"},"冷飯食":{"variants":"冷や飯食い/冷飯食"},"冷やか":{"variants":"冷やか/冷ややか"},"冷ややか":{"variants":"冷やか/冷ややか"},"冷や奴":{"variants":"冷や奴/冷奴"},"冷奴":{"variants":"冷や奴/冷奴"},"ヒユ":{"variants":"ヒユ/比ゆ/比喩/譬喩"},"比ゆ":{"variants":"ヒユ/比ゆ/比喩"},"比喩":{"variants":"ヒユ/比ゆ/比喩"},"ヒョウ":{"variants":"ヒョウ/票/表/豹/雹"},"ひょうげる":{"variants":"ひょうげる/剽げる"},"剽げる":{"variants":"ひょうげる/剽げる"},"ひょうする":{"variants":"ひょうする/表する/評する"},"ひょうたん":{"variants":"ひょうたん/ヒョウタン/氷炭/瓢箪"},"ヒョウタン":{"variants":"ひょうたん/ヒョウタン/氷炭/瓢箪"},"飄々":{"variants":"飄々/飄飄"},"飄飄":{"variants":"飄々/飄飄"},"ひょう変":{"variants":"ひょう変/豹変"},"豹変":{"variants":"ひょう変/豹変"},"標ぼう":{"variants":"標ぼう/標榜"},"標榜":{"variants":"標ぼう/標榜"},"ひょろながい":{"variants":"ひょろながい/ひょろ長い"},"ひょろ長い":{"variants":"ひょろながい/ひょろ長い"},"日除け":{"variants":"日除/日除け"},"日除":{"variants":"日除/日除け"},"ヒヨドリ":{"variants":"ヒヨドリ/鵯"},"鵯":{"variants":"ヒヨドリ/鵯"},"ひよわい":{"variants":"ひよわい/ひ弱い"},"ひ弱い":{"variants":"ひよわい/ひ弱い"},"平泳":{"variants":"平泳/平泳ぎ"},"平泳ぎ":{"variants":"平泳/平泳ぎ"},"平織":{"variants":"平織/平織り"},"平織り":{"variants":"平織/平織り"},"平がな":{"variants":"平がな/平仮名"},"平仮名":{"variants":"平がな/平仮名"},"ひらきなおる":{"variants":"ひらきなおる/開きなおる/開き直る"},"開きなおる":{"variants":"ひらきなおる/開きなおる/開き直る"},"開き直る":{"variants":"ひらきなおる/開きなおる/開き直る"},"ひらきなおれる":{"variants":"ひらきなおれる/開き直れる"},"開き直れる":{"variants":"ひらきなおれる/開き直れる"},"ひらく":{"variants":"ひらく/拓く"},"拓く":{"variants":"ひらく/拓く"},"ひらける":{"variants":"ひらける/拓ける"},"拓ける":{"variants":"ひらける/拓ける"},"ひらたい":{"variants":"ひらたい/平たい"},"平たい":{"variants":"ひらたい/平たい"},"ひらに":{"variants":"ひらに/平に"},"平に":{"variants":"ひらに/平に"},"ひらひら":{"variants":"ひらひら/ヒラヒラ"},"ヒラヒラ":{"variants":"ひらひら/ヒラヒラ"},"ヒラメ":{"variants":"ヒラメ/比目魚/平目/鮃"},"ひらめかす":{"variants":"ひらめかす/閃かす"},"閃かす":{"variants":"ひらめかす/閃かす"},"ひらめく":{"variants":"ひらめく/閃く"},"閃く":{"variants":"ひらめく/閃く"},"ひらめる":{"variants":"ひらめる/平める"},"平める":{"variants":"ひらめる/平める"},"ひりだす":{"variants":"ひりだす/ひり出す"},"ひり出す":{"variants":"ひりだす/ひり出す"},"ひる":{"variants":"ひる/干る/簸る"},"ヒル":{"variants":"ヒル/蒜/蛭"},"ひるがえす":{"variants":"ひるがえす/翻す"},"翻す":{"variants":"ひるがえす/翻す"},"ひるがえせる":{"variants":"ひるがえせる/翻せる"},"翻せる":{"variants":"ひるがえせる/翻せる"},"ひるがえって":{"variants":"ひるがえって/翻って"},"翻って":{"variants":"ひるがえって/翻って"},"ひるがえる":{"variants":"ひるがえる/翻る"},"翻る":{"variants":"ひるがえる/翻る"},"ヒルガオ":{"variants":"ヒルガオ/旋花/昼顔"},"昼げ":{"variants":"昼げ/昼餉"},"昼餉":{"variants":"昼げ/昼餉"},"昼下がり":{"variants":"昼下がり/昼下り"},"昼下り":{"variants":"昼下がり/昼下り"},"ひるむ":{"variants":"ひるむ/怯む"},"怯む":{"variants":"ひるむ/怯む"},"昼めし":{"variants":"昼めし/昼飯"},"昼飯":{"variants":"昼めし/昼飯"},"ヒレ":{"variants":"ヒレ/鰭/領巾"},"ひれふす":{"variants":"ひれふす/ひれ伏す/平伏す"},"ひれ伏す":{"variants":"ひれふす/ひれ伏す/平伏す"},"平伏す":{"variants":"ひれふす/ひれ伏す/平伏す"},"ひろい":{"variants":"ひろい/広い"},"広い":{"variants":"ひろい/広い"},"ひろいあげる":{"variants":"ひろいあげる/拾い上げる"},"拾い上げる":{"variants":"ひろいあげる/拾い上げる"},"拾いもの":{"variants":"拾いもの/拾い物/拾物"},"拾い物":{"variants":"拾いもの/拾い物/拾物"},"拾物":{"variants":"拾いもの/拾い物/拾物"},"ひろう":{"variants":"ひろう/拾う"},"拾う":{"variants":"ひろう/拾う"},"ひろえる":{"variants":"ひろえる/拾える"},"拾える":{"variants":"ひろえる/拾える"},"ひろがる":{"variants":"ひろがる/拡がる/広がる"},"ひろげる":{"variants":"ひろげる/拡げる/広げる"},"ひろば":{"variants":"ひろば/広場"},"広場":{"variants":"ひろば/広場"},"ひろびろ":{"variants":"ひろびろ/広々/広びろ"},"広々":{"variants":"広々/広広"},"広びろ":{"variants":"ひろびろ/広々/広びろ"},"広広":{"variants":"広々/広広"},"ひろまる":{"variants":"ひろまる/広まる"},"広まる":{"variants":"ひろまる/広まる"},"ひろめる":{"variants":"ひろめる/広める/弘める"},"ヒワ":{"variants":"ヒワ/悲話/秘話/鶸"},"卑猥":{"variants":"卑わい/卑猥"},"卑わい":{"variants":"卑わい/卑猥"},"桧皮葺":{"variants":"桧皮葺/桧皮葺き"},"桧皮葺き":{"variants":"桧皮葺/桧皮葺き"},"日割":{"variants":"日割/日割り"},"日割り":{"variants":"日割/日割り"},"ひわれる":{"variants":"ひわれる/干割れる"},"干割れる":{"variants":"ひわれる/干割れる"},"瀕死":{"variants":"ひん死/瀕死"},"ひん死":{"variants":"ひん死/瀕死"},"ひんする":{"variants":"ひんする/瀕する/貧する"},"ひん斥":{"variants":"ひん斥/擯斥"},"擯斥":{"variants":"ひん斥/擯斥"},"ひん発":{"variants":"ひん発/頻発"},"頻発":{"variants":"ひん発/頻発"},"ひんぱん":{"variants":"ひんぱん/頻繁"},"頻繁":{"variants":"ひんぱん/頻繁"},"頻々":{"variants":"頻々/頻頻"},"頻頻":{"variants":"頻々/頻頻"},"ひんまがる":{"variants":"ひんまがる/ひん曲がる"},"ひん曲がる":{"variants":"ひんまがる/ひん曲がる"},"ひんまげる":{"variants":"ひんまげる/ひん曲げる"},"ひん曲げる":{"variants":"ひんまげる/ひん曲げる"},"ビール":{"variants":"ビール/麦酒"},"麦酒":{"variants":"ビール/麦酒"},"びくびく":{"variants":"びくびく/ビクビク"},"ビクビク":{"variants":"びくびく/ビクビク"},"ビジョザクラ":{"variants":"ビジョザクラ/美女桜"},"美女桜":{"variants":"ビジョザクラ/美女桜"},"びた一文":{"variants":"びた一文/鐚一文"},"鐚一文":{"variants":"びた一文/鐚一文"},"びた銭":{"variants":"びた銭/鐚銭"},"鐚銭":{"variants":"びた銭/鐚銭"},"びっくり":{"variants":"びっくり/ビックリ/吃驚"},"ビックリ":{"variants":"びっくり/ビックリ/吃驚"},"吃驚":{"variants":"びっくり/ビックリ/吃驚"},"びっしり":{"variants":"びっしり/ビッシリ"},"ビッシリ":{"variants":"びっしり/ビッシリ"},"びてい骨":{"variants":"びてい骨/尾てい骨"},"尾てい骨":{"variants":"びてい骨/尾てい骨"},"ビナン":{"variants":"ビナン/美男"},"美男":{"variants":"ビナン/美男"},"ビナンカズラ":{"variants":"ビナンカズラ/美男葛"},"美男葛":{"variants":"ビナンカズラ/美男葛"},"微々":{"variants":"微々/微微"},"微微":{"variants":"微々/微微"},"びびしい":{"variants":"びびしい/美々しい/美美しい"},"美々しい":{"variants":"びびしい/美々しい/美美しい"},"美美しい":{"variants":"びびしい/美々しい/美美しい"},"びびたる":{"variants":"びびたる/微々たる"},"微々たる":{"variants":"びびたる/微々たる"},"びびと":{"variants":"びびと/微々と"},"微々と":{"variants":"びびと/微々と"},"びびる":{"variants":"びびる/ビビる"},"ビビる":{"variants":"びびる/ビビる"},"びほう":{"variants":"びほう/彌縫"},"彌縫":{"variants":"びほう/彌縫"},"びぼう":{"variants":"びぼう/備忘/美ぼう/美貌"},"美ぼう":{"variants":"びぼう/美ぼう/美貌"},"美貌":{"variants":"びぼう/美ぼう/美貌"},"びまん":{"variants":"びまん/瀰漫"},"瀰漫":{"variants":"びまん/瀰漫"},"ビャクダン":{"variants":"ビャクダン/白檀"},"白檀":{"variants":"ビャクダン/白檀"},"ビヤだる":{"variants":"ビヤだる/ビヤ樽"},"ビヤ樽":{"variants":"ビヤだる/ビヤ樽"},"渺々":{"variants":"渺々/渺渺"},"渺渺":{"variants":"渺々/渺渺"},"びょうぶ":{"variants":"びょうぶ/屏風"},"屏風":{"variants":"びょうぶ/屏風"},"ビヨウヤナギ":{"variants":"ビヨウヤナギ/未央柳"},"未央柳":{"variants":"ビヨウヤナギ/未央柳"},"びら":{"variants":"びら/ビラ"},"ビラ":{"variants":"びら/ビラ"},"びらき":{"variants":"びらき/開き"},"開き":{"variants":"びらき/開き"},"びりびり":{"variants":"びりびり/ビリビリ"},"ビリビリ":{"variants":"びりびり/ビリビリ"},"びれ":{"variants":"びれ/ビレ"},"ビレ":{"variants":"びれ/ビレ"},"ビロウ":{"variants":"ビロウ/蒲葵/檳榔"},"ビワ":{"variants":"ビワ/枇杷/琵琶"},"びん":{"variants":"びん/壜/鬢"},"敏しょう":{"variants":"敏しょう/敏捷"},"敏捷":{"variants":"敏しょう/敏捷"},"便せん":{"variants":"便せん/便船/便箋"},"瓶詰め":{"variants":"瓶詰/瓶詰め"},"瓶詰":{"variants":"瓶詰/瓶詰め"},"びんない":{"variants":"びんない/便無い"},"便無い":{"variants":"びんない/便無い"},"ビンナガ":{"variants":"ビンナガ/鬢長"},"鬢長":{"variants":"ビンナガ/鬢長"},"貧乏くじ":{"variants":"貧乏くじ/貧乏籤"},"貧乏籤":{"variants":"貧乏くじ/貧乏籤"},"貧乏揺すり":{"variants":"貧乏揺すり/貧乏揺り"},"貧乏揺り":{"variants":"貧乏揺すり/貧乏揺り"},"ビンロウジュ":{"variants":"ビンロウジュ/檳榔樹"},"檳榔樹":{"variants":"ビンロウジュ/檳榔樹"},"ｐｐｍ":{"variants":"ｐｐｍ/ピーピーエム"},"ピーピーエム":{"variants":"ｐｐｍ/ピーピーエム"},"ぴしゃり":{"variants":"ぴしゃり/ピシャリ"},"ピシャリ":{"variants":"ぴしゃり/ピシャリ"},"ぴちぴち":{"variants":"ぴちぴち/ピチピチ"},"ピチピチ":{"variants":"ぴちぴち/ピチピチ"},"ぴょんぴょん":{"variants":"ぴょんぴょん/ピョンピョン"},"ピョンピョン":{"variants":"ぴょんぴょん/ピョンピョン"},"ぴんと":{"variants":"ぴんと/ピンと"},"ピンと":{"variants":"ぴんと/ピンと"},"ぴんぴん":{"variants":"ぴんぴん/ピンピン"},"ピンピン":{"variants":"ぴんぴん/ピンピン"},"フートン":{"variants":"フートン/胡同"},"胡同":{"variants":"フートン/胡同"},"ＦＡＸ":{"variants":"ＦＡＸ/ファックス"},"ファックス":{"variants":"ＦＡＸ/ファックス"},"ｆｅｅｔ":{"variants":"ｆｅｅｔ/フィート"},"フィート":{"variants":"ｆｅｅｔ/フィート"},"ふう":{"variants":"ふう/風"},"風":{"variants":"ふう/風"},"封かん":{"variants":"封かん/封緘"},"封緘":{"variants":"封かん/封緘"},"風変り":{"variants":"風変り/風変わり"},"風変わり":{"variants":"風変り/風変わり"},"風しん":{"variants":"風しん/風疹"},"風疹":{"variants":"風しん/風疹"},"ふうじこむ":{"variants":"ふうじこむ/封じこむ/封じ込む"},"封じこむ":{"variants":"ふうじこむ/封じこむ/封じ込む"},"封じ込む":{"variants":"ふうじこむ/封じこむ/封じ込む"},"ふうじこめる":{"variants":"ふうじこめる/封じこめる/封じ込める"},"封じこめる":{"variants":"ふうじこめる/封じこめる/封じ込める"},"封じ込める":{"variants":"ふうじこめる/封じこめる/封じ込める"},"ふうじる":{"variants":"ふうじる/封じる"},"封じる":{"variants":"ふうじる/封じる"},"ふうする":{"variants":"ふうする/諷する"},"諷する":{"variants":"ふうする/諷する"},"ふうずる":{"variants":"ふうずる/封ずる"},"封ずる":{"variants":"ふうずる/封ずる"},"ふうせん":{"variants":"ふうせん/風船"},"風船":{"variants":"ふうせん/風船"},"フウチョウ":{"variants":"フウチョウ/風潮/風鳥"},"風び":{"variants":"風び/風靡"},"風靡":{"variants":"風び/風靡"},"夫婦づれ":{"variants":"夫婦づれ/夫婦連れ"},"夫婦連れ":{"variants":"夫婦づれ/夫婦連れ"},"風ぼう":{"variants":"風ぼう/風貌/風防"},"フウラン":{"variants":"フウラン/風蘭"},"風蘭":{"variants":"フウラン/風蘭"},"ふえる":{"variants":"ふえる/殖える/増える"},"ふぉーヴぃすむ":{"variants":"ふぉーヴぃすむ/フォーヴィスム"},"フォーヴィスム":{"variants":"ふぉーヴぃすむ/フォーヴィスム"},"ふ化":{"variants":"ふ化/孵化"},"孵化":{"variants":"ふ化/孵化"},"フカ":{"variants":"フカ/不可/府下/浮華/鱶"},"ふかい":{"variants":"ふかい/深い"},"深い":{"variants":"ふかい/深い"},"ふかす":{"variants":"ふかす/更かす/更す/蒸かす/吹かす"},"更かす":{"variants":"ふかす/更かす/更す"},"更す":{"variants":"ふかす/更かす/更す"},"ふかぶかと":{"variants":"ふかぶかと/深々と/深深と"},"深々と":{"variants":"ふかぶかと/深々と/深深と"},"深深と":{"variants":"ふかぶかと/深々と/深深と"},"ふかまる":{"variants":"ふかまる/深まる"},"深まる":{"variants":"ふかまる/深まる"},"フカミグサ":{"variants":"フカミグサ/深見草"},"深見草":{"variants":"フカミグサ/深見草"},"ふかめる":{"variants":"ふかめる/深める"},"深める":{"variants":"ふかめる/深める"},"ふがいない":{"variants":"ふがいない/不甲斐ない/腑甲斐無い"},"フキ":{"variants":"フキ/不帰/不軌/不羈/蕗"},"ふき上げ":{"variants":"ふき上げ/吹き上げ/吹上"},"吹き上げ":{"variants":"ふき上げ/吹き上げ/吹上"},"吹上":{"variants":"ふき上げ/吹き上げ/吹上"},"ふきあげる":{"variants":"ふきあげる/吹き上げる/噴き上げる"},"ふきあれる":{"variants":"ふきあれる/吹き荒れる"},"吹き荒れる":{"variants":"ふきあれる/吹き荒れる"},"吹井戸":{"variants":"吹き井戸/吹井戸"},"吹き井戸":{"variants":"吹き井戸/吹井戸"},"ふきおろす":{"variants":"ふきおろす/吹き降ろす"},"吹き降ろす":{"variants":"ふきおろす/吹き降ろす"},"葺替え":{"variants":"葺き替え/葺替え"},"葺き替え":{"variants":"葺き替え/葺替え"},"ふきかえす":{"variants":"ふきかえす/吹き返す"},"吹き返す":{"variants":"ふきかえす/吹き返す"},"ふきかける":{"variants":"ふきかける/吹きかける/吹き掛ける/吹掛ける"},"吹きかける":{"variants":"ふきかける/吹きかける/吹き掛ける/吹掛ける"},"吹き掛ける":{"variants":"ふきかける/吹きかける/吹き掛ける/吹掛ける"},"吹掛ける":{"variants":"ふきかける/吹きかける/吹き掛ける/吹掛ける"},"ふきこぼれる":{"variants":"ふきこぼれる/吹きこぼれる"},"吹きこぼれる":{"variants":"ふきこぼれる/吹きこぼれる"},"ふきこむ":{"variants":"ふきこむ/拭き込む/吹き込む"},"ふきこめる":{"variants":"ふきこめる/吹き込める"},"吹き込める":{"variants":"ふきこめる/吹き込める"},"吹きさらし":{"variants":"吹きさらし/吹き曝し/吹曝し"},"吹き曝し":{"variants":"吹きさらし/吹き曝し/吹曝し"},"吹曝し":{"variants":"吹きさらし/吹き曝し/吹曝し"},"ふきすさぶ":{"variants":"ふきすさぶ/吹きすさぶ/吹き荒ぶ"},"吹きすさぶ":{"variants":"ふきすさぶ/吹きすさぶ/吹き荒ぶ"},"吹き荒ぶ":{"variants":"ふきすさぶ/吹きすさぶ/吹き荒ぶ"},"拭きそうじ":{"variants":"拭きそうじ/拭き掃除"},"拭き掃除":{"variants":"拭きそうじ/拭き掃除"},"吹き竹":{"variants":"吹き竹/吹竹"},"吹竹":{"variants":"吹き竹/吹竹"},"ふきだす":{"variants":"ふきだす/吹きだす/吹き出す/吹出す/噴き出す"},"吹きだす":{"variants":"ふきだす/吹きだす/吹き出す/吹出す"},"吹出す":{"variants":"ふきだす/吹きだす/吹き出す/吹出す"},"吹き出す":{"variants":"ふきだす/吹きだす/吹き出す/吹出す"},"吹きだまり":{"variants":"吹きだまり/吹き溜まり/吹き溜り/吹溜り"},"吹き溜まり":{"variants":"吹きだまり/吹き溜まり/吹き溜り/吹溜り"},"吹き溜り":{"variants":"吹きだまり/吹き溜まり/吹き溜り/吹溜り"},"吹溜り":{"variants":"吹きだまり/吹き溜まり/吹き溜り/吹溜り"},"ふきつける":{"variants":"ふきつける/吹き付ける"},"吹き付ける":{"variants":"ふきつける/吹き付ける"},"吹き出物":{"variants":"吹き出物/吹出物"},"吹出物":{"variants":"吹き出物/吹出物"},"ふきでる":{"variants":"ふきでる/吹きでる/吹き出る"},"吹きでる":{"variants":"ふきでる/吹きでる/吹き出る"},"吹き出る":{"variants":"ふきでる/吹きでる/吹き出る"},"ふきとばす":{"variants":"ふきとばす/吹きとばす/吹き飛ばす/吹飛ばす"},"吹きとばす":{"variants":"ふきとばす/吹きとばす/吹き飛ばす/吹飛ばす"},"吹き飛ばす":{"variants":"ふきとばす/吹きとばす/吹き飛ばす/吹飛ばす"},"吹飛ばす":{"variants":"ふきとばす/吹きとばす/吹き飛ばす/吹飛ばす"},"ふきとばせる":{"variants":"ふきとばせる/吹き飛ばせる"},"吹き飛ばせる":{"variants":"ふきとばせる/吹き飛ばせる"},"ふきとぶ":{"variants":"ふきとぶ/吹き飛ぶ"},"吹き飛ぶ":{"variants":"ふきとぶ/吹き飛ぶ"},"ふきとる":{"variants":"ふきとる/ふき取る/拭き取る"},"ふき取る":{"variants":"ふきとる/ふき取る/拭き取る"},"拭き取る":{"variants":"ふきとる/ふき取る/拭き取る"},"ふきとれる":{"variants":"ふきとれる/拭き取れる"},"拭き取れる":{"variants":"ふきとれる/拭き取れる"},"吹き流し":{"variants":"吹き流し/吹流し"},"吹流し":{"variants":"吹き流し/吹流し"},"ふきならす":{"variants":"ふきならす/吹き鳴らす"},"吹き鳴らす":{"variants":"ふきならす/吹き鳴らす"},"吹貫き":{"variants":"吹き貫き/吹貫き"},"吹き貫き":{"variants":"吹き貫き/吹貫き"},"吹抜き":{"variants":"吹き抜き/吹抜き"},"吹き抜き":{"variants":"吹き抜き/吹抜き"},"吹きぬけ":{"variants":"吹きぬけ/吹き抜け/吹抜け"},"吹き抜け":{"variants":"吹きぬけ/吹き抜け/吹抜け"},"吹抜け":{"variants":"吹きぬけ/吹き抜け/吹抜け"},"ふきぬける":{"variants":"ふきぬける/吹き抜ける"},"吹き抜ける":{"variants":"ふきぬける/吹き抜ける"},"フキノトウ":{"variants":"フキノトウ/蕗の薹"},"蕗の薹":{"variants":"フキノトウ/蕗の薹"},"ふきはらう":{"variants":"ふきはらう/吹き払う"},"吹き払う":{"variants":"ふきはらう/吹き払う"},"ふきはらえる":{"variants":"ふきはらえる/吹き払える"},"吹き払える":{"variants":"ふきはらえる/吹き払える"},"吹き降り":{"variants":"吹き降り/吹降/吹降り"},"吹降":{"variants":"吹き降り/吹降/吹降り"},"吹降り":{"variants":"吹き降り/吹降/吹降り"},"ふきまくる":{"variants":"ふきまくる/吹きまくる"},"吹きまくる":{"variants":"ふきまくる/吹きまくる"},"吹きまわし":{"variants":"吹きまわし/吹き回し/吹回し"},"吹き回し":{"variants":"吹きまわし/吹き回し/吹回し"},"吹回し":{"variants":"吹きまわし/吹き回し/吹回し"},"吹き矢":{"variants":"吹き矢/吹矢"},"吹矢":{"variants":"吹き矢/吹矢"},"吹き寄せ":{"variants":"吹き寄せ/吹寄せ"},"吹寄せ":{"variants":"吹き寄せ/吹寄せ"},"ふきわける":{"variants":"ふきわける/吹き分ける/吹分ける"},"吹き分ける":{"variants":"ふきわける/吹き分ける/吹分ける"},"吹分ける":{"variants":"ふきわける/吹き分ける/吹分ける"},"ふきん":{"variants":"ふきん/付近/布巾/賦金/附近"},"ふく":{"variants":"ふく/拭く/吹く/葺く/噴く"},"ふく射熱":{"variants":"ふく射熱/輻射熱"},"輻射熱":{"variants":"ふく射熱/輻射熱"},"復しゅう":{"variants":"復しゅう/復習/復讐/復讎"},"フクジュソウ":{"variants":"フクジュソウ/福寿草"},"福寿草":{"variants":"フクジュソウ/福寿草"},"副じん":{"variants":"副じん/副腎"},"副腎":{"variants":"副じん/副腎"},"ふくす":{"variants":"ふくす/復す/服す"},"ふくする":{"variants":"ふくする/復する/服する"},"ふくせる":{"variants":"ふくせる/服せる"},"服せる":{"variants":"ふくせる/服せる"},"福引":{"variants":"福引/福引き"},"福引き":{"variants":"福引/福引き"},"複々線":{"variants":"複々線/複複線"},"複複線":{"variants":"複々線/複複線"},"ふくぶくしい":{"variants":"ふくぶくしい/福々しい/福福しい"},"福々しい":{"variants":"ふくぶくしい/福々しい/福福しい"},"福福しい":{"variants":"ふくぶくしい/福々しい/福福しい"},"フクベ":{"variants":"フクベ/匏"},"匏":{"variants":"フクベ/匏"},"ふくまる":{"variants":"ふくまる/含まる"},"含まる":{"variants":"ふくまる/含まる"},"含み笑い":{"variants":"含み笑い/含笑い"},"含笑い":{"variants":"含み笑い/含笑い"},"ふくむ":{"variants":"ふくむ/含む"},"含む":{"variants":"ふくむ/含む"},"ふくめる":{"variants":"ふくめる/含める"},"含める":{"variants":"ふくめる/含める"},"ふくらす":{"variants":"ふくらす/脹らす/膨らす"},"ふくら雀":{"variants":"ふくら雀/フクラスズメ"},"フクラスズメ":{"variants":"ふくら雀/フクラスズメ"},"ふくらせる":{"variants":"ふくらせる/膨らせる"},"膨らせる":{"variants":"ふくらせる/膨らせる"},"ふくら脛":{"variants":"ふくら脛/脹ら脛"},"脹ら脛":{"variants":"ふくら脛/脹ら脛"},"ふくらます":{"variants":"ふくらます/脹らます/膨らます"},"ふくらむ":{"variants":"ふくらむ/脹らむ/膨らむ"},"ふくれっツラ":{"variants":"ふくれっツラ/ふくれっ面/脹れっつら/脹れっ面/膨れっつら/膨れっ面"},"ふくれっ面":{"variants":"ふくれっツラ/ふくれっ面/脹れっつら/脹れっ面/膨れっつら/膨れっ面"},"脹れっつら":{"variants":"ふくれっツラ/ふくれっ面/脹れっつら/脹れっ面"},"脹れっ面":{"variants":"ふくれっツラ/ふくれっ面/脹れっつら/脹れっ面"},"膨れっつら":{"variants":"ふくれっツラ/ふくれっ面/膨れっつら/膨れっ面"},"膨れっ面":{"variants":"ふくれっツラ/ふくれっ面/膨れっつら/膨れっ面"},"ふくれる":{"variants":"ふくれる/脹れる/膨れる"},"フクロウ":{"variants":"フクロウ/梟"},"梟":{"variants":"フクロウ/梟"},"袋だたき":{"variants":"袋だたき/袋叩き"},"袋叩き":{"variants":"袋だたき/袋叩き"},"袋縫":{"variants":"袋縫/袋縫い"},"袋縫い":{"variants":"袋縫/袋縫い"},"袋もの":{"variants":"袋もの/袋物"},"袋物":{"variants":"袋もの/袋物"},"フグ":{"variants":"フグ/河豚/不具"},"ふけこむ":{"variants":"ふけこむ/老け込む"},"老け込む":{"variants":"ふけこむ/老け込む"},"ふける":{"variants":"ふける/耽る"},"フケる":{"variants":"ふける/フケる/更ける/蒸ける/拭ける/深ける/吹ける/耽ける/老ける"},"耽る":{"variants":"ふける/耽る"},"ふさがる":{"variants":"ふさがる/塞がる"},"塞がる":{"variants":"ふさがる/塞がる"},"ふさぎこむ":{"variants":"ふさぎこむ/ふさぎ込む/塞ぎ込む"},"ふさぎ込む":{"variants":"ふさぎこむ/ふさぎ込む/塞ぎ込む"},"塞ぎ込む":{"variants":"ふさぎこむ/ふさぎ込む/塞ぎ込む"},"ふさぐ":{"variants":"ふさぐ/塞ぐ/鬱ぐ"},"ふさげる":{"variants":"ふさげる/塞げる"},"塞げる":{"variants":"ふさげる/塞げる"},"ふさわしい":{"variants":"ふさわしい/相応しい"},"相応しい":{"variants":"ふさわしい/相応しい"},"ふざける":{"variants":"ふざける/巫山戯る"},"巫山戯る":{"variants":"ふざける/巫山戯る"},"ふし":{"variants":"ふし/フシ"},"フシ":{"variants":"ふし/フシ"},"ふしおがむ":{"variants":"ふしおがむ/伏し拝む/伏拝む"},"伏し拝む":{"variants":"ふしおがむ/伏し拝む/伏拝む"},"伏拝む":{"variants":"ふしおがむ/伏し拝む/伏拝む"},"ふしぎ":{"variants":"ふしぎ/不思議"},"不思議":{"variants":"ふしぎ/不思議"},"ふしくれだつ":{"variants":"ふしくれだつ/節くれだつ/節榑立つ"},"節くれだつ":{"variants":"ふしくれだつ/節くれだつ/節榑立つ"},"節榑立つ":{"variants":"ふしくれだつ/節くれだつ/節榑立つ"},"ふししずむ":{"variants":"ふししずむ/伏し沈む"},"伏し沈む":{"variants":"ふししずむ/伏し沈む"},"フシノキ":{"variants":"フシノキ/五倍子の木"},"五倍子の木":{"variants":"フシノキ/五倍子の木"},"節々":{"variants":"節々/節節"},"節節":{"variants":"節々/節節"},"節まわし":{"variants":"節まわし/節回し/節廻し"},"伏し目":{"variants":"伏し目/伏目"},"伏目":{"variants":"伏し目/伏目"},"ふしょうぶしょう":{"variants":"ふしょうぶしょう/不承不承"},"不承不承":{"variants":"ふしょうぶしょう/不承不承"},"フジ":{"variants":"フジ/藤/不時/不二"},"ふじつ":{"variants":"ふじつ/不日"},"不日":{"variants":"ふじつ/不日"},"フジバカマ":{"variants":"フジバカマ/藤袴"},"藤袴":{"variants":"フジバカマ/藤袴"},"ふす":{"variants":"ふす/臥す/付す/附す/伏す"},"ふすぼる":{"variants":"ふすぼる/燻ぼる"},"燻ぼる":{"variants":"ふすぼる/燻ぼる"},"ふする":{"variants":"ふする/付する/賦する/附する"},"ふせぐ":{"variants":"ふせぐ/禦ぐ/防ぐ"},"ふせげる":{"variants":"ふせげる/防げる"},"防げる":{"variants":"ふせげる/防げる"},"伏せ字":{"variants":"伏せ字/伏字"},"伏字":{"variants":"伏せ字/伏字"},"ふ節":{"variants":"ふ節/符節"},"符節":{"variants":"ふ節/符節"},"ふせる":{"variants":"ふせる/臥せる/伏せる"},"伏せる":{"variants":"ふせる/伏せる"},"付せん":{"variants":"付せん/付箋"},"付箋":{"variants":"付せん/付箋"},"ふそん":{"variants":"ふそん/不そん/不尊/不遜"},"不そん":{"variants":"ふそん/不そん/不尊/不遜"},"不ぞろい":{"variants":"不ぞろい/不揃い"},"不揃い":{"variants":"不ぞろい/不揃い"},"ふた":{"variants":"ふた/フタ/蓋"},"フタ":{"variants":"ふた/フタ/蓋"},"蓋":{"variants":"ふた/フタ/蓋"},"ふた親":{"variants":"ふた親/二親"},"二親":{"variants":"ふた親/二親"},"ふたたび":{"variants":"ふたたび/再び"},"再び":{"variants":"ふたたび/再び"},"ふたつ":{"variants":"２つ/ふたつ/二つ/貳"},"二つ":{"variants":"２つ/ふたつ/二つ"},"２つ":{"variants":"２つ/ふたつ/二つ"},"ふたつながら":{"variants":"ふたつながら/二つながら/両ながら"},"ふたつ返事":{"variants":"ふたつ返事/二つ返事"},"二つ返事":{"variants":"ふたつ返事/二つ返事"},"フタリシズカ":{"variants":"フタリシズカ/二人静"},"二人静":{"variants":"フタリシズカ/二人静"},"札つき":{"variants":"札つき/札付"},"札付":{"variants":"札つき/札付"},"札止":{"variants":"札止/札止め"},"札止め":{"variants":"札止/札止め"},"ふだん":{"variants":"ふだん/不断/普段"},"フダンソウ":{"variants":"フダンソウ/不断草"},"不断草":{"variants":"フダンソウ/不断草"},"ふち":{"variants":"ふち/不知/淵"},"ふちどる":{"variants":"ふちどる/縁どる"},"縁どる":{"variants":"ふちどる/縁どる"},"ふっかける":{"variants":"ふっかける/フッカケる/吹っかける/吹っ掛ける"},"フッカケる":{"variants":"ふっかける/フッカケる/吹っかける/吹っ掛ける"},"吹っかける":{"variants":"ふっかける/フッカケる/吹っかける/吹っ掛ける"},"吹っ掛ける":{"variants":"ふっかける/フッカケる/吹っかける/吹っ掛ける"},"ふっきる":{"variants":"ふっきる/吹っ切る"},"吹っ切る":{"variants":"ふっきる/吹っ切る"},"ふっきれる":{"variants":"ふっきれる/ふっ切れる/吹っきれる/吹っ切れる"},"ふっ切れる":{"variants":"ふっきれる/ふっ切れる/吹っきれる/吹っ切れる"},"吹っきれる":{"variants":"ふっきれる/ふっ切れる/吹っきれる/吹っ切れる"},"吹っ切れる":{"variants":"ふっきれる/ふっ切れる/吹っきれる/吹っ切れる"},"払しょく":{"variants":"払しょく/払拭"},"払拭":{"variants":"払しょく/払拭"},"ふっ素":{"variants":"ふっ素/フッ素/弗素"},"フッ素":{"variants":"ふっ素/フッ素/弗素"},"弗素":{"variants":"ふっ素/フッ素/弗素"},"ふっとぶ":{"variants":"ふっとぶ/吹っとぶ/吹っ飛ぶ"},"吹っとぶ":{"variants":"ふっとぶ/吹っとぶ/吹っ飛ぶ"},"吹っ飛ぶ":{"variants":"ふっとぶ/吹っとぶ/吹っ飛ぶ"},"ふつう":{"variants":"ふつう/不通"},"不通":{"variants":"ふつう/不通"},"二日酔":{"variants":"二日酔/二日酔い"},"二日酔い":{"variants":"二日酔/二日酔い"},"不束":{"variants":"不束/不束か"},"不束か":{"variants":"不束/不束か"},"不つりあい":{"variants":"不つりあい/不釣合"},"不釣合":{"variants":"不つりあい/不釣合"},"ふてくさる":{"variants":"ふてくさる/不貞腐る"},"不貞腐る":{"variants":"ふてくさる/不貞腐る"},"ふてくされる":{"variants":"ふてくされる/不貞腐れる"},"不貞腐れる":{"variants":"ふてくされる/不貞腐れる"},"ふて寝":{"variants":"ふて寝/不貞寝"},"不貞寝":{"variants":"ふて寝/不貞寝"},"ふとい":{"variants":"ふとい/太い"},"太い":{"variants":"ふとい/太い"},"フトイ":{"variants":"フトイ/莞/太藺"},"埠頭":{"variants":"ふ頭/埠頭"},"ふ頭":{"variants":"ふ頭/埠頭"},"ふところ":{"variants":"ふところ/懐"},"懐":{"variants":"ふところ/懐"},"ふとっちょ":{"variants":"ふとっちょ/太っちょ"},"太っちょ":{"variants":"ふとっちょ/太っちょ"},"ふとっ腹":{"variants":"ふとっ腹/太っ腹"},"太っ腹":{"variants":"ふとっ腹/太っ腹"},"不とどき":{"variants":"不とどき/不届き"},"不届き":{"variants":"不とどき/不届き"},"太もも":{"variants":"太もも/太股"},"太股":{"variants":"太もも/太股"},"ふとる":{"variants":"ふとる/太る/肥る"},"ふとれる":{"variants":"ふとれる/太れる/肥れる"},"フトン":{"variants":"フトン/蒲団/布団"},"フナ":{"variants":"フナ/鮒"},"鮒":{"variants":"フナ/鮒"},"フナムシ":{"variants":"フナムシ/船虫"},"船虫":{"variants":"フナムシ/船虫"},"フノリ":{"variants":"フノリ/布海苔"},"布海苔":{"variants":"フノリ/布海苔"},"ふぶく":{"variants":"ふぶく/吹雪く"},"吹雪く":{"variants":"ふぶく/吹雪く"},"ふほう":{"variants":"ふほう/ふ報/不法/訃報"},"訃報":{"variants":"ふほう/ふ報/訃報"},"ふ報":{"variants":"ふほう/ふ報/訃報"},"踏まえどころ":{"variants":"踏まえどころ/踏まえ所"},"踏まえ所":{"variants":"踏まえどころ/踏まえ所"},"ふまえる":{"variants":"ふまえる/踏まえる"},"踏まえる":{"variants":"ふまえる/踏まえる"},"踏み石":{"variants":"踏み石/踏石"},"踏石":{"variants":"踏み石/踏石"},"踏み板":{"variants":"踏み板/踏板"},"踏板":{"variants":"踏み板/踏板"},"踏み絵":{"variants":"踏み絵/踏絵"},"踏絵":{"variants":"踏み絵/踏絵"},"踏み切り":{"variants":"踏み切り/踏切"},"踏切":{"variants":"踏み切り/踏切"},"ふみきる":{"variants":"ふみきる/踏みきる/踏み切る/踏切る"},"踏みきる":{"variants":"ふみきる/踏みきる/踏み切る/踏切る"},"踏み切る":{"variants":"ふみきる/踏みきる/踏み切る/踏切る"},"踏切る":{"variants":"ふみきる/踏みきる/踏み切る/踏切る"},"ふみきれる":{"variants":"ふみきれる/踏み切れる"},"踏み切れる":{"variants":"ふみきれる/踏み切れる"},"ふみこえる":{"variants":"ふみこえる/踏み越える"},"踏み越える":{"variants":"ふみこえる/踏み越える"},"ふみこす":{"variants":"ふみこす/踏み越す"},"踏み越す":{"variants":"ふみこす/踏み越す"},"ふみこたえる":{"variants":"ふみこたえる/踏みこたえる"},"踏みこたえる":{"variants":"ふみこたえる/踏みこたえる"},"踏み込み":{"variants":"踏み込み/踏込み"},"踏込み":{"variants":"踏み込み/踏込み"},"ふみこむ":{"variants":"ふみこむ/踏みこむ/踏み込む/踏込む"},"踏みこむ":{"variants":"ふみこむ/踏みこむ/踏み込む/踏込む"},"踏み込む":{"variants":"ふみこむ/踏みこむ/踏み込む/踏込む"},"踏込む":{"variants":"ふみこむ/踏みこむ/踏み込む/踏込む"},"ふみこめる":{"variants":"ふみこめる/踏み込める"},"踏み込める":{"variants":"ふみこめる/踏み込める"},"ふみしだく":{"variants":"ふみしだく/踏みしだく"},"踏みしだく":{"variants":"ふみしだく/踏みしだく"},"ふみしめる":{"variants":"ふみしめる/踏みしめる/踏み締める"},"踏みしめる":{"variants":"ふみしめる/踏みしめる/踏み締める"},"踏み締める":{"variants":"ふみしめる/踏みしめる/踏み締める"},"ふみたおす":{"variants":"ふみたおす/踏み倒す/踏倒す"},"踏み倒す":{"variants":"ふみたおす/踏み倒す/踏倒す"},"踏倒す":{"variants":"ふみたおす/踏み倒す/踏倒す"},"ふみたおせる":{"variants":"ふみたおせる/踏み倒せる"},"踏み倒せる":{"variants":"ふみたおせる/踏み倒せる"},"踏み台":{"variants":"踏み台/踏台"},"踏台":{"variants":"踏み台/踏台"},"ふみだす":{"variants":"ふみだす/踏みだす/踏み出す/踏出す"},"踏みだす":{"variants":"ふみだす/踏みだす/踏み出す/踏出す"},"踏み出す":{"variants":"ふみだす/踏みだす/踏み出す/踏出す"},"踏出す":{"variants":"ふみだす/踏みだす/踏み出す/踏出す"},"ふみだせる":{"variants":"ふみだせる/踏み出せる"},"踏み出せる":{"variants":"ふみだせる/踏み出せる"},"踏み段":{"variants":"踏み段/踏段"},"踏段":{"variants":"踏み段/踏段"},"ふみつける":{"variants":"ふみつける/踏みつける/踏み付ける/踏付ける"},"踏みつける":{"variants":"ふみつける/踏みつける/踏み付ける/踏付ける"},"踏み付ける":{"variants":"ふみつける/踏みつける/踏み付ける/踏付ける"},"踏付ける":{"variants":"ふみつける/踏みつける/踏み付ける/踏付ける"},"ふみつぶす":{"variants":"ふみつぶす/踏みつぶす"},"踏みつぶす":{"variants":"ふみつぶす/踏みつぶす"},"ふみとどまる":{"variants":"ふみとどまる/踏みとどまる/踏み止まる"},"踏みとどまる":{"variants":"ふみとどまる/踏みとどまる/踏み止まる"},"踏み止まる":{"variants":"ふみとどまる/踏みとどまる/踏み止まる"},"ふみとどまれる":{"variants":"ふみとどまれる/踏みとどまれる"},"踏みとどまれる":{"variants":"ふみとどまれる/踏みとどまれる"},"ふみならす":{"variants":"ふみならす/踏みならす/踏み均す/踏み鳴らす"},"踏みならす":{"variants":"ふみならす/踏みならす/踏み均す/踏み鳴らす"},"ふみならせる":{"variants":"ふみならせる/踏みならせる"},"踏みならせる":{"variants":"ふみならせる/踏みならせる"},"ふみにじる":{"variants":"ふみにじる/踏みにじる/踏み躙る"},"踏みにじる":{"variants":"ふみにじる/踏みにじる/踏み躙る"},"踏み躙る":{"variants":"ふみにじる/踏みにじる/踏み躙る"},"ふみにじれる":{"variants":"ふみにじれる/踏みにじれる"},"踏みにじれる":{"variants":"ふみにじれる/踏みにじれる"},"ふみぬく":{"variants":"ふみぬく/踏み抜く/踏抜く"},"踏み抜く":{"variants":"ふみぬく/踏み抜く/踏抜く"},"踏抜く":{"variants":"ふみぬく/踏み抜く/踏抜く"},"ふみぬける":{"variants":"ふみぬける/踏み抜ける"},"踏み抜ける":{"variants":"ふみぬける/踏み抜ける"},"ふみはずす":{"variants":"ふみはずす/踏みはずす/踏み外す/踏外す"},"踏みはずす":{"variants":"ふみはずす/踏みはずす/踏み外す/踏外す"},"踏み外す":{"variants":"ふみはずす/踏みはずす/踏み外す/踏外す"},"踏外す":{"variants":"ふみはずす/踏みはずす/踏み外す/踏外す"},"ふみやぶる":{"variants":"ふみやぶる/踏みやぶる/踏み破る/踏破る"},"踏みやぶる":{"variants":"ふみやぶる/踏みやぶる/踏み破る/踏破る"},"踏み破る":{"variants":"ふみやぶる/踏みやぶる/踏み破る/踏破る"},"踏破る":{"variants":"ふみやぶる/踏みやぶる/踏み破る/踏破る"},"ふみわける":{"variants":"ふみわける/踏み分ける/踏分ける"},"踏み分ける":{"variants":"ふみわける/踏み分ける/踏分ける"},"踏分ける":{"variants":"ふみわける/踏み分ける/踏分ける"},"ふむ":{"variants":"ふむ/践む/踏む"},"ふむふむ":{"variants":"ふむふむ/フムフム"},"フムフム":{"variants":"ふむふむ/フムフム"},"不明りょう":{"variants":"不明りょう/不明瞭"},"不明瞭":{"variants":"不明りょう/不明瞭"},"ふめる":{"variants":"ふめる/踏める"},"踏める":{"variants":"ふめる/踏める"},"ふもと":{"variants":"ふもと/麓/梺"},"ふやす":{"variants":"ふやす/殖やす/増やす"},"ふやせる":{"variants":"ふやせる/殖やせる/増やせる"},"フユウ":{"variants":"フユウ/富有/富裕"},"不行き届き":{"variants":"不行き届き/不行届/不行届き"},"不行届":{"variants":"不行き届き/不行届/不行届き"},"不行届き":{"variants":"不行き届き/不行届/不行届き"},"冬ごもり":{"variants":"冬ごもり/冬篭り"},"冬篭り":{"variants":"冬ごもり/冬篭り"},"ふゆごもる":{"variants":"ふゆごもる/冬篭る"},"冬篭る":{"variants":"ふゆごもる/冬篭る"},"フヨウ":{"variants":"フヨウ/不溶/不用/不要/芙蓉"},"フヨウホウ":{"variants":"フヨウホウ/芙蓉峰"},"芙蓉峰":{"variants":"フヨウホウ/芙蓉峰"},"ふらす":{"variants":"ふらす/降らす"},"降らす":{"variants":"ふらす/降らす"},"ふらせる":{"variants":"ふらせる/降らせる"},"降らせる":{"variants":"ふらせる/降らせる"},"ふらふら":{"variants":"ふらふら/フラフラ"},"フラフラ":{"variants":"ふらふら/フラフラ"},"フラン":{"variants":"ふ卵/フラン/不乱/孵卵"},"ふ卵":{"variants":"ふ卵/フラン/孵卵"},"孵卵":{"variants":"ふ卵/フラン/孵卵"},"フリ":{"variants":"フリ/降り/振り/不離"},"振り合い":{"variants":"振り合い/振合い"},"振合い":{"variants":"振り合い/振合い"},"ふりあう":{"variants":"ふりあう/触り合う/触合う"},"触り合う":{"variants":"ふりあう/触り合う/触合う"},"触合う":{"variants":"ふりあう/触り合う/触合う"},"ふりあてる":{"variants":"ふりあてる/振り当てる/振当てる"},"振り当てる":{"variants":"ふりあてる/振り当てる/振当てる"},"振当てる":{"variants":"ふりあてる/振り当てる/振当てる"},"ふりおこす":{"variants":"ふりおこす/振り起す"},"振り起す":{"variants":"ふりおこす/振り起す"},"ふりおとす":{"variants":"ふりおとす/振り落とす"},"振り落とす":{"variants":"ふりおとす/振り落とす"},"ふりおとせる":{"variants":"ふりおとせる/振り落とせる"},"振り落とせる":{"variants":"ふりおとせる/振り落とせる"},"振り替え":{"variants":"振り替え/振替"},"振替":{"variants":"振り替え/振替"},"ふりかえる":{"variants":"ふりかえる/振り返る"},"振り替える":{"variants":"ふりかえる/振り替える/振替える"},"振替える":{"variants":"ふりかえる/振り替える/振替える"},"振り返る":{"variants":"ふりかえる/振り返る"},"ふりかかる":{"variants":"ふりかかる/降りかかる/降り掛かる/降り懸かる/降り懸る"},"降りかかる":{"variants":"ふりかかる/降りかかる/降り掛かる/降り懸かる/降り懸る"},"降り懸かる":{"variants":"ふりかかる/降りかかる/降り懸かる/降り懸る"},"降り懸る":{"variants":"ふりかかる/降りかかる/降り懸かる/降り懸る"},"振りかけ":{"variants":"振りかけ/振り掛け/振掛け"},"振り掛け":{"variants":"振りかけ/振り掛け/振掛け"},"振掛け":{"variants":"振りかけ/振り掛け/振掛け"},"ふりかける":{"variants":"ふりかける/振りかける/振り掛ける/振掛ける"},"振りかける":{"variants":"ふりかける/振りかける/振り掛ける/振掛ける"},"振り掛ける":{"variants":"ふりかける/振りかける/振り掛ける/振掛ける"},"振掛ける":{"variants":"ふりかける/振りかける/振り掛ける/振掛ける"},"ふりかざす":{"variants":"ふりかざす/振りかざす/振り翳す"},"振りかざす":{"variants":"ふりかざす/振りかざす/振り翳す"},"振り翳す":{"variants":"ふりかざす/振りかざす/振り翳す"},"ふりかぶる":{"variants":"ふりかぶる/振りかぶる"},"振りかぶる":{"variants":"ふりかぶる/振りかぶる"},"ふりがな":{"variants":"ふりがな/ふり仮名/振りがな/振仮名"},"ふり仮名":{"variants":"ふりがな/ふり仮名/振りがな/振仮名"},"振りがな":{"variants":"ふりがな/ふり仮名/振りがな/振仮名"},"振仮名":{"variants":"ふりがな/ふり仮名/振りがな/振仮名"},"ふりきる":{"variants":"ふりきる/振り切る/振切る"},"振り切る":{"variants":"ふりきる/振り切る/振切る"},"振切る":{"variants":"ふりきる/振り切る/振切る"},"ふりきれる":{"variants":"ふりきれる/振り切れる"},"振り切れる":{"variants":"ふりきれる/振り切れる"},"ふりくらす":{"variants":"ふりくらす/降り暮す"},"降り暮す":{"variants":"ふりくらす/降り暮す"},"振り込み":{"variants":"振り込み/振込"},"振込":{"variants":"振り込み/振込"},"ふりこむ":{"variants":"ふりこむ/降り込む/降込む/振り込む/振込む"},"振込む":{"variants":"ふりこむ/振り込む/振込む"},"降り込む":{"variants":"ふりこむ/降り込む/降込む"},"降込む":{"variants":"ふりこむ/降り込む/降込む"},"振り込む":{"variants":"ふりこむ/振り込む/振込む"},"ふりこめる":{"variants":"ふりこめる/降り篭める/振り込める"},"振りさけみる":{"variants":"ふりさけみる/振りさけみる"},"ふりさけみる":{"variants":"ふりさけみる/振りさけみる"},"ふりしきる":{"variants":"ふりしきる/降りしきる/降り頻る"},"降りしきる":{"variants":"ふりしきる/降りしきる/降り頻る"},"降り頻る":{"variants":"ふりしきる/降りしきる/降り頻る"},"ふりしく":{"variants":"ふりしく/降り敷く/降敷く"},"降り敷く":{"variants":"ふりしく/降り敷く/降敷く"},"降敷く":{"variants":"ふりしく/降り敷く/降敷く"},"ふりしぼる":{"variants":"ふりしぼる/振りしぼる/振り絞る/振絞る"},"振りしぼる":{"variants":"ふりしぼる/振りしぼる/振り絞る/振絞る"},"振り絞る":{"variants":"ふりしぼる/振りしぼる/振り絞る/振絞る"},"振絞る":{"variants":"ふりしぼる/振りしぼる/振り絞る/振絞る"},"ふりすてる":{"variants":"ふりすてる/振り捨てる/振捨てる"},"振り捨てる":{"variants":"ふりすてる/振り捨てる/振捨てる"},"振捨てる":{"variants":"ふりすてる/振り捨てる/振捨てる"},"ふりそそぐ":{"variants":"ふりそそぐ/降りそそぐ/降り注ぐ/降注ぐ"},"降りそそぐ":{"variants":"ふりそそぐ/降りそそぐ/降り注ぐ/降注ぐ"},"降り注ぐ":{"variants":"ふりそそぐ/降りそそぐ/降り注ぐ/降注ぐ"},"降注ぐ":{"variants":"ふりそそぐ/降りそそぐ/降り注ぐ/降注ぐ"},"振りそで":{"variants":"振りそで/振り袖/振袖"},"振り袖":{"variants":"振りそで/振り袖/振袖"},"振袖":{"variants":"振りそで/振り袖/振袖"},"ふりたてる":{"variants":"ふりたてる/振り立てる/振立てる"},"振り立てる":{"variants":"ふりたてる/振り立てる/振立てる"},"振立てる":{"variants":"ふりたてる/振り立てる/振立てる"},"振りだし":{"variants":"振りだし/振り出し/振出"},"振り出し":{"variants":"振りだし/振り出し/振出"},"振出":{"variants":"振りだし/振り出し/振出"},"ふりだす":{"variants":"ふりだす/降り出す/振りだす/振り出す/振出す"},"振りだす":{"variants":"ふりだす/振りだす/振り出す/振出す"},"振り出す":{"variants":"ふりだす/振りだす/振り出す/振出す"},"振出す":{"variants":"ふりだす/振りだす/振り出す/振出す"},"ふりだせる":{"variants":"ふりだせる/振り出せる"},"振り出せる":{"variants":"ふりだせる/振り出せる"},"振り付け":{"variants":"振り付け/振付け"},"振付け":{"variants":"振り付け/振付け"},"ふりつもる":{"variants":"ふりつもる/降り積もる/降り積る"},"降り積もる":{"variants":"ふりつもる/降り積もる/降り積る"},"降り積る":{"variants":"ふりつもる/降り積もる/降り積る"},"ふりはなす":{"variants":"ふりはなす/振り放す/振放す"},"振り放す":{"variants":"ふりはなす/振り放す/振放す"},"振放す":{"variants":"ふりはなす/振り放す/振放す"},"ふりはなつ":{"variants":"ふりはなつ/振り放つ/振放つ"},"振り放つ":{"variants":"ふりはなつ/振り放つ/振放つ"},"振放つ":{"variants":"ふりはなつ/振り放つ/振放つ"},"ふりはらう":{"variants":"ふりはらう/振りはらう/振り払う/振払う"},"振りはらう":{"variants":"ふりはらう/振りはらう/振り払う/振払う"},"振り払う":{"variants":"ふりはらう/振りはらう/振り払う/振払う"},"振払う":{"variants":"ふりはらう/振りはらう/振り払う/振払う"},"ふりはらえる":{"variants":"ふりはらえる/振り払える"},"振り払える":{"variants":"ふりはらえる/振り払える"},"ふりほどく":{"variants":"ふりほどく/振りほどく"},"振りほどく":{"variants":"ふりほどく/振りほどく"},"ふりまく":{"variants":"ふりまく/振りまく/振り撒く"},"振りまく":{"variants":"ふりまく/振りまく/振り撒く"},"振り撒く":{"variants":"ふりまく/振りまく/振り撒く"},"ふりまける":{"variants":"ふりまける/振りまける"},"振りまける":{"variants":"ふりまける/振りまける"},"ふりまわす":{"variants":"ふりまわす/振りまわす/振り回す/振回す"},"振りまわす":{"variants":"ふりまわす/振りまわす/振り回す/振回す"},"振り回す":{"variants":"ふりまわす/振りまわす/振り回す/振回す"},"振回す":{"variants":"ふりまわす/振りまわす/振り回す/振回す"},"ふりまわせる":{"variants":"ふりまわせる/振り回せる"},"振り回せる":{"variants":"ふりまわせる/振り回せる"},"ふりみだす":{"variants":"ふりみだす/振り乱す/振乱す"},"振り乱す":{"variants":"ふりみだす/振り乱す/振乱す"},"振乱す":{"variants":"ふりみだす/振り乱す/振乱す"},"ふりむく":{"variants":"ふりむく/ふり向く/振り向く"},"ふり向く":{"variants":"ふりむく/ふり向く/振り向く"},"振り向く":{"variants":"ふりむく/ふり向く/振り向く"},"ふりむける":{"variants":"ふりむける/振り向ける/振向ける"},"振り向ける":{"variants":"ふりむける/振り向ける/振向ける"},"振向ける":{"variants":"ふりむける/振り向ける/振向ける"},"振り分け":{"variants":"振り分け/振分け"},"振分け":{"variants":"振り分け/振分け"},"振分け髪":{"variants":"振分け髪/振分髪"},"振分髪":{"variants":"振分け髪/振分髪"},"振分け荷物":{"variants":"振分け荷物/振分荷物"},"振分荷物":{"variants":"振分け荷物/振分荷物"},"ふりわける":{"variants":"ふりわける/振りわける/振り分ける/振分ける"},"振りわける":{"variants":"ふりわける/振りわける/振り分ける/振分ける"},"振り分ける":{"variants":"ふりわける/振りわける/振り分ける/振分ける"},"振分ける":{"variants":"ふりわける/振りわける/振り分ける/振分ける"},"ふる":{"variants":"ふる/旧る/古る/振る/震る"},"ふるい":{"variants":"ふるい/旧い/古い"},"ふるいおこす":{"variants":"ふるいおこす/奮いおこす/奮い起こす/奮い起す"},"奮いおこす":{"variants":"ふるいおこす/奮いおこす/奮い起こす/奮い起す"},"奮い起こす":{"variants":"ふるいおこす/奮いおこす/奮い起こす/奮い起す"},"奮い起す":{"variants":"ふるいおこす/奮いおこす/奮い起こす/奮い起す"},"ふるいおこせる":{"variants":"ふるいおこせる/奮い起こせる"},"奮い起こせる":{"variants":"ふるいおこせる/奮い起こせる"},"ふるいおとす":{"variants":"ふるいおとす/ふるい落す/ふるい落とす/振い落す/篩い落す"},"ふるい落す":{"variants":"ふるいおとす/ふるい落す/ふるい落とす/振い落す/篩い落す"},"ふるい落とす":{"variants":"ふるいおとす/ふるい落す/ふるい落とす/振い落す/篩い落す"},"ふるいおとせる":{"variants":"ふるいおとせる/ふるい落とせる"},"ふるい落とせる":{"variants":"ふるいおとせる/ふるい落とせる"},"ふるいたつ":{"variants":"ふるいたつ/奮いたつ/奮い起つ/奮い立つ"},"奮いたつ":{"variants":"ふるいたつ/奮いたつ/奮い起つ/奮い立つ"},"ふるいつく":{"variants":"ふるいつく/震いつく/震い付く"},"震いつく":{"variants":"ふるいつく/震いつく/震い付く"},"震い付く":{"variants":"ふるいつく/震いつく/震い付く"},"ふるいわける":{"variants":"ふるいわける/ふるい分ける"},"ふるい分ける":{"variants":"ふるいわける/ふるい分ける"},"ふるう":{"variants":"ふるう/揮う/振るう/震う/奮う/篩う"},"ふるえあがる":{"variants":"ふるえあがる/ふるえ上がる/震えあがる/震え上がる"},"ふるえ上がる":{"variants":"ふるえあがる/ふるえ上がる/震えあがる/震え上がる"},"震えあがる":{"variants":"ふるえあがる/ふるえ上がる/震えあがる/震え上がる"},"震え上がる":{"variants":"ふるえあがる/ふるえ上がる/震えあがる/震え上がる"},"ふるえる":{"variants":"ふるえる/振るえる/震える"},"ふるくさい":{"variants":"ふるくさい/古くさい/古臭い"},"古くさい":{"variants":"ふるくさい/古くさい/古臭い"},"古臭い":{"variants":"ふるくさい/古くさい/古臭い"},"ふるさと":{"variants":"ふるさと/ふる里/古里/故里"},"ふる里":{"variants":"ふるさと/ふる里/古里/故里"},"ふるって":{"variants":"ふるって/奮って"},"奮って":{"variants":"ふるって/奮って"},"古漬":{"variants":"古漬/古漬け"},"古漬け":{"variants":"古漬/古漬け"},"ふるびる":{"variants":"ふるびる/旧びる/古びる"},"ふるぼける":{"variants":"ふるぼける/古ぼける"},"古ぼける":{"variants":"ふるぼける/古ぼける"},"振る舞い":{"variants":"振る舞い/振舞/振舞い"},"振舞":{"variants":"振る舞い/振舞/振舞い"},"振舞い":{"variants":"振る舞い/振舞/振舞い"},"ふるまう":{"variants":"ふるまう/振る舞う/振舞う"},"振る舞う":{"variants":"ふるまう/振る舞う/振舞う"},"振舞う":{"variants":"ふるまう/振る舞う/振舞う"},"ふるまえる":{"variants":"ふるまえる/振る舞える"},"振る舞える":{"variants":"ふるまえる/振る舞える"},"ふるめかしい":{"variants":"ふるめかしい/古めかしい"},"古めかしい":{"variants":"ふるめかしい/古めかしい"},"ふるわす":{"variants":"ふるわす/震わす"},"震わす":{"variants":"ふるわす/震わす"},"ふるわせる":{"variants":"ふるわせる/震わせる"},"震わせる":{"variants":"ふるわせる/震わせる"},"ふれ合い":{"variants":"ふれ合い/触れ合い"},"触れ合い":{"variants":"ふれ合い/触れ合い"},"ふれあう":{"variants":"ふれあう/ふれ合う/触れあう/触れ合う"},"ふれ合う":{"variants":"ふれあう/ふれ合う/触れあう/触れ合う"},"触れあう":{"variants":"ふれあう/ふれ合う/触れあう/触れ合う"},"触れ合う":{"variants":"ふれあう/ふれ合う/触れあう/触れ合う"},"ふれあえる":{"variants":"ふれあえる/触れ合える"},"触れ合える":{"variants":"ふれあえる/触れ合える"},"触れ書き":{"variants":"触れ書き/触書"},"触書":{"variants":"触れ書き/触書"},"ふれこみ":{"variants":"ふれこみ/触れ込み"},"触れ込み":{"variants":"ふれこみ/触れ込み"},"ふれこむ":{"variants":"ふれこむ/触れこむ/触れ込む/触込む"},"触れこむ":{"variants":"ふれこむ/触れこむ/触れ込む/触込む"},"触れ込む":{"variants":"ふれこむ/触れこむ/触れ込む/触込む"},"触込む":{"variants":"ふれこむ/触れこむ/触れ込む/触込む"},"ふれこめる":{"variants":"ふれこめる/触れ込める"},"触れ込める":{"variants":"ふれこめる/触れ込める"},"触れ太鼓":{"variants":"触れ太鼓/触太鼓"},"触太鼓":{"variants":"触れ太鼓/触太鼓"},"ふれまわる":{"variants":"ふれまわる/触れまわる/触れ回る/触回る"},"触れまわる":{"variants":"ふれまわる/触れまわる/触れ回る/触回る"},"触れ回る":{"variants":"ふれまわる/触れまわる/触れ回る/触回る"},"触回る":{"variants":"ふれまわる/触れまわる/触れ回る/触回る"},"ふれる":{"variants":"ふれる/狂れる/触れる/振れる"},"ふろ":{"variants":"ふろ/風呂/風炉"},"ふろしき":{"variants":"ふろしき/風呂敷"},"風呂敷":{"variants":"ふろしき/風呂敷"},"ふろ吹き":{"variants":"ふろ吹き/風呂吹き"},"風呂吹き":{"variants":"ふろ吹き/風呂吹き"},"腑分":{"variants":"腑分/腑分け"},"腑分け":{"variants":"腑分/腑分け"},"不渡":{"variants":"不渡/不渡り"},"不渡り":{"variants":"不渡/不渡り"},"ふわふわ":{"variants":"ふわふわ/フワフワ"},"フワフワ":{"variants":"ふわふわ/フワフワ"},"ふわり":{"variants":"ふわり/フワリ"},"フワリ":{"variants":"ふわり/フワリ"},"ふん":{"variants":"ふん/フン"},"フン":{"variants":"ふん/フン"},"踏んぎり":{"variants":"踏んぎり/踏ん切り"},"踏ん切り":{"variants":"踏んぎり/踏ん切り"},"ふんぎる":{"variants":"ふんぎる/踏ん切る"},"踏ん切る":{"variants":"ふんぎる/踏ん切る"},"ふんぎれる":{"variants":"ふんぎれる/踏ん切れる"},"踏ん切れる":{"variants":"ふんぎれる/踏ん切れる"},"ふんじばる":{"variants":"ふんじばる/ふん縛る"},"ふん縛る":{"variants":"ふんじばる/ふん縛る"},"粉じん":{"variants":"粉じん/粉塵"},"粉塵":{"variants":"粉じん/粉塵"},"ふんする":{"variants":"ふんする/扮する"},"扮する":{"variants":"ふんする/扮する"},"ふんぜんと":{"variants":"ふんぜんと/奮然と"},"奮然と":{"variants":"ふんぜんと/奮然と"},"扮装":{"variants":"ふん装/扮装"},"ふん装":{"variants":"ふん装/扮装"},"ふんぞりかえる":{"variants":"ふんぞりかえる/ふんぞり返る"},"ふんぞり返る":{"variants":"ふんぞりかえる/ふんぞり返る"},"ふんづける":{"variants":"ふんづける/踏んづける"},"踏んづける":{"variants":"ふんづける/踏んづける"},"ふん闘":{"variants":"ふん闘/奮闘"},"奮闘":{"variants":"ふん闘/奮闘"},"ふん尿":{"variants":"ふん尿/糞尿"},"糞尿":{"variants":"ふん尿/糞尿"},"ふんばる":{"variants":"ふんばる/踏んばる/踏ん張る"},"踏んばる":{"variants":"ふんばる/踏んばる/踏ん張る"},"踏ん張る":{"variants":"ふんばる/踏んばる/踏ん張る"},"ふんぱつ":{"variants":"ふんぱつ/奮発"},"奮発":{"variants":"ふんぱつ/奮発"},"紛紛":{"variants":"紛々/紛紛"},"芬芬":{"variants":"芬々/芬芬"},"紛々":{"variants":"紛々/紛紛"},"芬々":{"variants":"芬々/芬芬"},"ふんべつくさい":{"variants":"ふんべつくさい/分別臭い"},"分別臭い":{"variants":"ふんべつくさい/分別臭い"},"ふんべつらしい":{"variants":"ふんべつらしい/分別らしい"},"分別らしい":{"variants":"ふんべつらしい/分別らしい"},"ふん便":{"variants":"ふん便/糞便"},"糞便":{"variants":"ふん便/糞便"},"ふんまん":{"variants":"ふんまん/憤まん/憤懣/忿懣"},"憤懣":{"variants":"ふんまん/憤まん/憤懣"},"憤まん":{"variants":"ふんまん/憤まん/憤懣"},"ぶあつい":{"variants":"ぶあつい/ぶ厚い/分厚い"},"ぶ厚い":{"variants":"ぶあつい/ぶ厚い/分厚い"},"分厚い":{"variants":"ぶあつい/ぶ厚い/分厚い"},"ブイ":{"variants":"ブイ/武威/部位"},"ぶ告":{"variants":"ぶ告/誣告"},"誣告":{"variants":"ぶ告/誣告"},"ぶ告罪":{"variants":"ぶ告罪/誣告罪"},"誣告罪":{"variants":"ぶ告罪/誣告罪"},"ぶさた":{"variants":"ぶさた/無沙汰"},"無沙汰":{"variants":"ぶさた/無沙汰"},"ブシュカン":{"variants":"ブシュカン/仏手柑"},"仏手柑":{"variants":"ブシュカン/仏手柑"},"不精ひげ":{"variants":"不精ひげ/不精髭"},"不精髭":{"variants":"不精ひげ/不精髭"},"ぶす":{"variants":"ぶす/撫す"},"撫す":{"variants":"ぶす/撫す"},"ぶぜん":{"variants":"ぶぜん/ぶ然/憮然"},"ぶ然":{"variants":"ぶぜん/ぶ然/憮然"},"憮然":{"variants":"ぶぜん/ぶ然/憮然"},"ぶた":{"variants":"ぶた/ブタ/豚"},"ブタ":{"variants":"ぶた/ブタ/豚"},"豚":{"variants":"ぶた/ブタ/豚"},"ぶちあてる":{"variants":"ぶちあてる/ぶち当てる"},"ぶち当てる":{"variants":"ぶちあてる/ぶち当てる"},"ぶちこむ":{"variants":"ぶちこむ/ぶち込む"},"ぶち込む":{"variants":"ぶちこむ/ぶち込む"},"ぶちこわす":{"variants":"ぶちこわす/ぶち壊す"},"ぶち壊す":{"variants":"ぶちこわす/ぶち壊す"},"ぶっく":{"variants":"ぶっく/ブック"},"ブック":{"variants":"ぶっく/ブック"},"ぶったぎる":{"variants":"ぶったぎる/ぶった斬る/ぶった切る"},"ぶっつづける":{"variants":"ぶっつづける/ぶっ続ける"},"ぶっ続ける":{"variants":"ぶっつづける/ぶっ続ける"},"ぶっとばす":{"variants":"ぶっとばす/ぶっ殺す/ぶっ飛ばす/ブッ殺す"},"ブッ殺す":{"variants":"ぶっとばす/ぶっ殺す/ブッ殺す"},"ぶっ殺す":{"variants":"ぶっとばす/ぶっ殺す/ブッ殺す"},"ブッポウソウ":{"variants":"ブッポウソウ/仏法僧"},"仏法僧":{"variants":"ブッポウソウ/仏法僧"},"仏だん":{"variants":"仏だん/仏壇"},"仏壇":{"variants":"仏だん/仏壇"},"ぶつぶつ":{"variants":"ぶつぶつ/ブツブツ"},"ブツブツ":{"variants":"ぶつぶつ/ブツブツ"},"物々交換":{"variants":"物々交換/物物交換"},"物物交換":{"variants":"物々交換/物物交換"},"ぶどう":{"variants":"ぶどう/ブドウ/武道/葡萄/無道"},"ブドウ":{"variants":"ぶどう/ブドウ/武道/葡萄/無道"},"ぶどう色":{"variants":"ぶどう色/葡萄色"},"葡萄色":{"variants":"ぶどう色/葡萄色"},"ぶどう糖":{"variants":"ぶどう糖/ブドウ糖/葡萄糖"},"ブドウ糖":{"variants":"ぶどう糖/ブドウ糖/葡萄糖"},"葡萄糖":{"variants":"ぶどう糖/ブドウ糖/葡萄糖"},"歩留まり":{"variants":"歩留まり/歩留り"},"歩留り":{"variants":"歩留まり/歩留り"},"ブナ":{"variants":"ブナ/山毛欅/樗"},"ぶばる":{"variants":"ぶばる/武張る"},"武張る":{"variants":"ぶばる/武張る"},"ぶらさがる":{"variants":"ぶらさがる/ぶら下がる"},"ぶら下がる":{"variants":"ぶらさがる/ぶら下がる"},"ぶらさがれる":{"variants":"ぶらさがれる/ぶら下がれる"},"ぶら下がれる":{"variants":"ぶらさがれる/ぶら下がれる"},"ぶらさげる":{"variants":"ぶらさげる/ぶら下げる"},"ぶら下げる":{"variants":"ぶらさげる/ぶら下げる"},"ブラック・ユーモア":{"variants":"ブラック・ユーモア/ブラックユーモア"},"ブラックユーモア":{"variants":"ブラック・ユーモア/ブラックユーモア"},"ぶり":{"variants":"ぶり/ブリ/鰤"},"ブリ":{"variants":"ぶり/ブリ/鰤"},"鰤":{"variants":"ぶり/ブリ/鰤"},"ぶりかえす":{"variants":"ぶりかえす/ぶり返す"},"ぶり返す":{"variants":"ぶりかえす/ぶり返す"},"ぶるぶる":{"variants":"ぶるぶる/ブルブル"},"ブルブル":{"variants":"ぶるぶる/ブルブル"},"分水れい":{"variants":"分水れい/分水嶺"},"分水嶺":{"variants":"分水れい/分水嶺"},"ブンタン":{"variants":"ブンタン/文旦"},"文旦":{"variants":"ブンタン/文旦"},"ブンチョウ":{"variants":"ブンチョウ/文鳥"},"文鳥":{"variants":"ブンチョウ/文鳥"},"ぶんどる":{"variants":"ぶんどる/分捕る"},"分捕る":{"variants":"ぶんどる/分捕る"},"ぶんなぐる":{"variants":"ぶんなぐる/ぶん殴る"},"ぶん殴る":{"variants":"ぶんなぐる/ぶん殴る"},"ぶんなげる":{"variants":"ぶんなげる/ぶん投げる"},"ぶん投げる":{"variants":"ぶんなげる/ぶん投げる"},"分の":{"variants":"分の/分ノ"},"分ノ":{"variants":"分の/分ノ"},"分べん":{"variants":"分べん/分娩"},"分娩":{"variants":"分べん/分娩"},"ぷりぷり":{"variants":"ぷりぷり/プリプリ"},"プリプリ":{"variants":"ぷりぷり/プリプリ"},"へ":{"variants":"へ/ヘ"},"ヘ":{"variants":"へ/ヘ"},"へあがる":{"variants":"へあがる/経上がる"},"経上がる":{"variants":"へあがる/経上がる"},"ヘイケガニ":{"variants":"ヘイケガニ/平家蟹"},"平家蟹":{"variants":"ヘイケガニ/平家蟹"},"へいする":{"variants":"へいする/聘する"},"聘する":{"variants":"へいする/聘する"},"へいぜんと":{"variants":"へいぜんと/平然と"},"平然と":{"variants":"へいぜんと/平然と"},"閉塞":{"variants":"閉そく/閉塞"},"閉そく":{"variants":"閉そく/閉塞"},"兵たん":{"variants":"兵たん/兵端/兵站"},"兵站":{"variants":"兵たん/兵站"},"兵端":{"variants":"兵たん/兵端"},"平たん":{"variants":"平たん/平坦/平淡"},"平々凡々":{"variants":"平々凡々/平平凡凡"},"平平凡凡":{"variants":"平々凡々/平平凡凡"},"へき易":{"variants":"へき易/辟易"},"辟易":{"variants":"へき易/辟易"},"へきする":{"variants":"へきする/僻する"},"僻する":{"variants":"へきする/僻する"},"へき地":{"variants":"へき地/僻地"},"僻地":{"variants":"へき地/僻地"},"へきれき":{"variants":"へきれき/霹靂"},"霹靂":{"variants":"へきれき/霹靂"},"ｈａ":{"variants":"ｈａ/ヘクタール"},"ヘクタール":{"variants":"ｈａ/ヘクタール"},"ｈｐａ":{"variants":"ｈｐａ/ヘクトパスカル"},"ヘクトパスカル":{"variants":"ｈｐａ/ヘクトパスカル"},"へこます":{"variants":"へこます/凹ます"},"凹ます":{"variants":"へこます/凹ます"},"へこむ":{"variants":"へこむ/凹む"},"凹む":{"variants":"へこむ/凹む"},"へしあう":{"variants":"へしあう/へし合う"},"へし合う":{"variants":"へしあう/へし合う"},"へしおる":{"variants":"へしおる/へし折る"},"へし折る":{"variants":"へしおる/へし折る"},"へす":{"variants":"へす/減す"},"減す":{"variants":"へす/減す"},"へせる":{"variants":"へせる/減せる"},"減せる":{"variants":"へせる/減せる"},"へそくり":{"variants":"へそくり/ヘソクリ/臍繰り"},"ヘソクリ":{"variants":"へそくり/ヘソクリ/臍繰り"},"臍繰り":{"variants":"へそくり/ヘソクリ/臍繰り"},"へそ曲がり":{"variants":"へそ曲がり/臍曲り"},"臍曲り":{"variants":"へそ曲がり/臍曲り"},"へたくそ":{"variants":"へたくそ/下手くそ/下手糞"},"下手くそ":{"variants":"へたくそ/下手くそ/下手糞"},"下手糞":{"variants":"へたくそ/下手くそ/下手糞"},"へだたる":{"variants":"へだたる/隔たる"},"隔たる":{"variants":"へだたる/隔たる"},"へだてる":{"variants":"へだてる/隔てる"},"隔てる":{"variants":"へだてる/隔てる"},"ヘチマ":{"variants":"ヘチマ/糸瓜"},"糸瓜":{"variants":"ヘチマ/糸瓜"},"へっぴり腰":{"variants":"へっぴり腰/屁っ放り腰"},"屁っ放り腰":{"variants":"へっぴり腰/屁っ放り腰"},"へっぴり虫":{"variants":"へっぴり虫/ヘッピリムシ"},"ヘッピリムシ":{"variants":"へっぴり虫/ヘッピリムシ"},"へつらう":{"variants":"へつらう/諂う"},"諂う":{"variants":"へつらう/諂う"},"への河童":{"variants":"への河童/屁のかっぱ/屁の河童"},"屁のかっぱ":{"variants":"への河童/屁のかっぱ/屁の河童"},"屁の河童":{"variants":"への河童/屁のかっぱ/屁の河童"},"ヘビイチゴ":{"variants":"ヘビイチゴ/蛇苺"},"蛇苺":{"variants":"ヘビイチゴ/蛇苺"},"へめぐる":{"variants":"へめぐる/経巡る"},"経巡る":{"variants":"へめぐる/経巡る"},"部屋割":{"variants":"部屋割/部屋割り"},"部屋割り":{"variants":"部屋割/部屋割り"},"へらす":{"variants":"へらす/減らす"},"減らす":{"variants":"へらす/減らす"},"へらず口":{"variants":"へらず口/減らず口"},"減らず口":{"variants":"へらず口/減らず口"},"ヘラブナ":{"variants":"ヘラブナ/篦鮒"},"篦鮒":{"variants":"ヘラブナ/篦鮒"},"へりくだる":{"variants":"へりくだる/謙る/遜る"},"へる":{"variants":"へる/減る"},"減る":{"variants":"へる/減る"},"ｈｚ":{"variants":"ｈｚ/ヘルツ"},"ヘルツ":{"variants":"ｈｚ/ヘルツ"},"ヘン":{"variants":"ヘン/変/編"},"へん":{"variants":"へん/辺"},"辺":{"variants":"へん/辺"},"編さん":{"variants":"編さん/編纂"},"編纂":{"variants":"編さん/編纂"},"へんしん":{"variants":"へんしん/偏心/変心/変身/変針"},"へんじる":{"variants":"へんじる/変じる"},"変じる":{"variants":"へんじる/変じる"},"へんする":{"variants":"へんする/偏する/貶する"},"へんずる":{"variants":"へんずる/変ずる"},"変ずる":{"variants":"へんずる/変ずる"},"へんてつ":{"variants":"へんてつ/変哲"},"変哲":{"variants":"へんてつ/変哲"},"辺ぴ":{"variants":"辺ぴ/辺鄙"},"辺鄙":{"variants":"辺ぴ/辺鄙"},"へん平":{"variants":"へん平/偏平/扁平"},"へん平足":{"variants":"へん平足/偏平足/扁平足"},"片々":{"variants":"片々/片片"},"片片":{"variants":"片々/片片"},"変ぼう":{"variants":"変ぼう/変貌"},"変貌":{"variants":"変ぼう/変貌"},"へんりん":{"variants":"へんりん/片りん/片鱗"},"片りん":{"variants":"へんりん/片りん/片鱗"},"片鱗":{"variants":"へんりん/片りん/片鱗"},"ベータ線":{"variants":"ベータ線/β線"},"β線":{"variants":"ベータ線/β線"},"べい独楽":{"variants":"べい独楽/貝独楽"},"貝独楽":{"variants":"べい独楽/貝独楽"},"べた":{"variants":"べた/ベタ"},"ベタ":{"variants":"べた/ベタ"},"べたつく":{"variants":"べたつく/べた付く/ベタつく"},"べた付く":{"variants":"べたつく/べた付く/ベタつく"},"ベタつく":{"variants":"べたつく/べた付く/ベタつく"},"べたべた":{"variants":"べたべた/ベタベタ"},"ベタベタ":{"variants":"べたべた/ベタベタ"},"べっ甲":{"variants":"べっ甲/鼈甲"},"鼈甲":{"variants":"べっ甲/鼈甲"},"べっ視":{"variants":"べっ視/蔑視"},"蔑視":{"variants":"べっ視/蔑視"},"べっして":{"variants":"べっして/別して"},"別して":{"variants":"べっして/別して"},"べっ称":{"variants":"べっ称/別称/蔑称"},"ベット":{"variants":"ベット/別途"},"別途":{"variants":"ベット/別途"},"べっぴん":{"variants":"べっぴん/別品/別嬪"},"別刷":{"variants":"別刷/別刷り"},"別刷り":{"variants":"別刷/別刷り"},"べつに":{"variants":"べつに/別に"},"別に":{"variants":"べつに/別に"},"別々":{"variants":"別々/別別"},"別別":{"variants":"別々/別別"},"別もの":{"variants":"別もの/別物"},"別物":{"variants":"別もの/別物"},"べとつく":{"variants":"べとつく/べと付く"},"べと付く":{"variants":"べとつく/べと付く"},"べとべと":{"variants":"べとべと/ベトベト"},"ベトベト":{"variants":"べとべと/ベトベト"},"ベニザケ":{"variants":"ベニザケ/紅ざけ/紅鮭"},"紅ざけ":{"variants":"ベニザケ/紅ざけ/紅鮭"},"紅鮭":{"variants":"ベニザケ/紅ざけ/紅鮭"},"紅しょうが":{"variants":"紅しょうが/紅生姜/紅生薑"},"ベニスズメ":{"variants":"ベニスズメ/紅雀"},"紅雀":{"variants":"ベニスズメ/紅雀"},"べに花":{"variants":"べに花/ベニバナ/紅花"},"ベニバナ":{"variants":"べに花/ベニバナ/紅花"},"紅花":{"variants":"べに花/ベニバナ/紅花"},"ベニマス":{"variants":"ベニマス/紅鱒"},"紅鱒":{"variants":"ベニマス/紅鱒"},"ベン":{"variants":"ベン/弁"},"弁":{"variants":"ベン/弁"},"べんぎじょう":{"variants":"べんぎじょう/便宜上"},"便宜上":{"variants":"べんぎじょう/便宜上"},"ベンケイソウ":{"variants":"ベンケイソウ/弁慶草/辨慶草"},"べんじる":{"variants":"べんじる/便じる/弁じる"},"べんする":{"variants":"べんする/便する"},"便する":{"variants":"べんする/便する"},"べんずる":{"variants":"べんずる/便ずる/弁ずる"},"便々":{"variants":"便々/便便"},"便便":{"variants":"便々/便便"},"ページ":{"variants":"ページ/頁"},"頁":{"variants":"ページ/頁"},"ＰＨ":{"variants":"ＰＨ/ｐＨ/ペーハー"},"ｐＨ":{"variants":"ＰＨ/ｐＨ/ペーハー"},"ペーハー":{"variants":"ＰＨ/ｐＨ/ペーハー"},"ぺけ":{"variants":"ぺけ/ペケ"},"ペケ":{"variants":"ぺけ/ペケ"},"ぺしゃんこ":{"variants":"ぺしゃんこ/ペシャンコ"},"ペシャンコ":{"variants":"ぺしゃんこ/ペシャンコ"},"ぺちゃんこ":{"variants":"ぺちゃんこ/ペチャンコ"},"ペチャンコ":{"variants":"ぺちゃんこ/ペチャンコ"},"ぺてん師":{"variants":"ぺてん師/ペテン師"},"ペテン師":{"variants":"ぺてん師/ペテン師"},"ぺらぺら":{"variants":"ぺらぺら/ペラペラ"},"ペラペラ":{"variants":"ぺらぺら/ペラペラ"},"ぺんぺん草":{"variants":"ぺんぺん草/ペンペングサ/ペンペン草"},"ペンペングサ":{"variants":"ぺんぺん草/ペンペングサ/ペンペン草"},"ペンペン草":{"variants":"ぺんぺん草/ペンペングサ/ペンペン草"},"ほいない":{"variants":"ほいない/本意無い"},"本意無い":{"variants":"ほいない/本意無い"},"ほう":{"variants":"ほう/方"},"方":{"variants":"ほう/方"},"蜂起":{"variants":"ほう起/蜂起"},"ほう起":{"variants":"ほう起/蜂起"},"ほうき":{"variants":"ほうき/法器/法規/芳紀/箒"},"ホウキグサ":{"variants":"ホウキグサ/箒草"},"箒草":{"variants":"ホウキグサ/箒草"},"ほうき星":{"variants":"ほうき星/帚星/箒星"},"ほうこうづける":{"variants":"ほうこうづける/方向づける/方向付ける"},"方向づける":{"variants":"ほうこうづける/方向づける/方向付ける"},"方向付ける":{"variants":"ほうこうづける/方向づける/方向付ける"},"ほう酸":{"variants":"ほう酸/硼酸"},"硼酸":{"variants":"ほう酸/硼酸"},"ほうじ茶":{"variants":"ほうじ茶/焙じ茶"},"焙じ茶":{"variants":"ほうじ茶/焙じ茶"},"芳醇":{"variants":"芳じゅん/芳醇"},"芳じゅん":{"variants":"芳じゅん/芳醇"},"ほう助":{"variants":"ほう助/幇助"},"幇助":{"variants":"ほう助/幇助"},"ほうじょう":{"variants":"ほうじょう/放生/方丈/法城/法条/法帖/芳情/褒状/豊じょう/豊穣/豊饒"},"豊じょう":{"variants":"豊じょう/豊穣/豊饒"},"豊饒":{"variants":"ほうじょう/豊じょう/豊饒"},"豊穣":{"variants":"ほうじょう/豊じょう/豊穣"},"ほうじる":{"variants":"ほうじる/報じる/奉じる/焙じる"},"ほうずる":{"variants":"ほうずる/報ずる/奉ずる/崩ずる"},"ほうせんか":{"variants":"ほうせんか/ほうせん花/ホウセンカ/鳳仙花"},"ほうせん花":{"variants":"ほうせんか/ほうせん花/ホウセンカ/鳳仙花"},"ホウセンカ":{"variants":"ほうせんか/ほうせん花/ホウセンカ/鳳仙花"},"鳳仙花":{"variants":"ほうせんか/ほうせん花/ホウセンカ/鳳仙花"},"ホウ素":{"variants":"ホウ素/硼素"},"硼素":{"variants":"ホウ素/硼素"},"放とう":{"variants":"放とう/放蕩"},"放蕩":{"variants":"放とう/放蕩"},"ほうとう":{"variants":"ほうとう/宝刀/宝塔/朋党/法灯/法統/砲塔"},"ほうび":{"variants":"ほうび/褒美"},"褒美":{"variants":"ほうび/褒美"},"ホウボウ":{"variants":"ホウボウ/鋒鋩/魴ぼう"},"ほうぼう":{"variants":"ほうぼう/方々/方方"},"ほうむる":{"variants":"ほうむる/葬る"},"葬る":{"variants":"ほうむる/葬る"},"ほうむれる":{"variants":"ほうむれる/葬れる"},"葬れる":{"variants":"ほうむれる/葬れる"},"ほうりこむ":{"variants":"ほうりこむ/ほうり込む/放り込む"},"ほうり込む":{"variants":"ほうりこむ/ほうり込む/放り込む"},"放り込む":{"variants":"ほうりこむ/ほうり込む/放り込む"},"ほうりだす":{"variants":"ほうりだす/ほうり出す/放りだす/放り出す/抛り出す"},"ほうり出す":{"variants":"ほうりだす/ほうり出す/放りだす/放り出す/抛り出す"},"放りだす":{"variants":"ほうりだす/ほうり出す/放りだす/放り出す"},"放り出す":{"variants":"ほうりだす/ほうり出す/放りだす/放り出す"},"ほうる":{"variants":"ほうる/放る/抛る"},"ほうれん草":{"variants":"ほうれん草/ホウレンソウ/ホウレン草/法蓮草/菠薐草"},"ホウレンソウ":{"variants":"ほうれん草/ホウレンソウ/ホウレン草/法蓮草/菠薐草"},"ホウレン草":{"variants":"ほうれん草/ホウレンソウ/ホウレン草/法蓮草/菠薐草"},"ほうろう":{"variants":"ほうろう/報労/琺瑯"},"俸祿":{"variants":"俸ろく/俸祿"},"俸ろく":{"variants":"俸ろく/俸祿"},"ほえる":{"variants":"ほえる/吠える/吼える"},"ほお":{"variants":"ほお/ホオ/頬"},"ホオ":{"variants":"ほお/ホオ/頬"},"頬":{"variants":"ほお/ホオ/頬"},"頬かぶり":{"variants":"頬かぶり/頬被り"},"頬被り":{"variants":"頬かぶり/頬被り"},"頬かむり":{"variants":"頬かむり/頬被"},"頬被":{"variants":"頬かむり/頬被"},"ホオジロ":{"variants":"ホオジロ/頬白"},"頬白":{"variants":"ホオジロ/頬白"},"ホオズキ":{"variants":"ホオズキ/鬼灯/酸漿"},"頬ずり":{"variants":"頬ずり/頬擦り"},"頬擦り":{"variants":"頬ずり/頬擦り"},"ほおの木":{"variants":"ほおの木/ホオノキ"},"ホオノキ":{"variants":"ほおの木/ホオノキ"},"ほおばる":{"variants":"ほおばる/ほお張る/頬張る"},"ほお張る":{"variants":"ほおばる/ほお張る/頬張る"},"頬張る":{"variants":"ほおばる/ほお張る/頬張る"},"ホオブクロ":{"variants":"ホオブクロ/頬袋"},"頬袋":{"variants":"ホオブクロ/頬袋"},"ほお紅":{"variants":"ほお紅/頬紅"},"頬紅":{"variants":"ほお紅/頬紅"},"ほお骨":{"variants":"ほお骨/頬骨"},"頬骨":{"variants":"ほお骨/頬骨"},"帆掛舟":{"variants":"帆掛け舟/帆掛舟"},"帆掛け舟":{"variants":"帆掛け舟/帆掛舟"},"ほかす":{"variants":"ほかす/放下す"},"放下す":{"variants":"ほかす/放下す"},"ほくそえむ":{"variants":"ほくそえむ/ほくそ笑む/北叟笑む"},"ほくそ笑む":{"variants":"ほくそえむ/ほくそ笑む/北叟笑む"},"北叟笑む":{"variants":"ほくそえむ/ほくそ笑む/北叟笑む"},"ほくほく":{"variants":"ほくほく/ホクホク"},"ホクホク":{"variants":"ほくほく/ホクホク"},"ほぐせる":{"variants":"ほぐせる/解せる"},"解せる":{"variants":"ほぐせる/解せる"},"帆げた":{"variants":"帆げた/帆桁"},"帆桁":{"variants":"帆げた/帆桁"},"ほこ":{"variants":"ほこ/鉾/矛/戈"},"ほこうえい":{"variants":"ほこうえい/蒲公英"},"蒲公英":{"variants":"ほこうえい/蒲公英"},"ほこ先":{"variants":"ほこ先/矛先"},"矛先":{"variants":"ほこ先/矛先"},"ほこらしい":{"variants":"ほこらしい/誇らしい"},"誇らしい":{"variants":"ほこらしい/誇らしい"},"ほこり":{"variants":"ほこり/ホコリ/誇り/埃"},"ホコリ":{"variants":"ほこり/ホコリ/誇り/埃"},"ほこる":{"variants":"ほこる/誇る"},"誇る":{"variants":"ほこる/誇る"},"ほこれる":{"variants":"ほこれる/誇れる"},"誇れる":{"variants":"ほこれる/誇れる"},"ほころばす":{"variants":"ほころばす/綻ばす"},"綻ばす":{"variants":"ほころばす/綻ばす"},"ほころびる":{"variants":"ほころびる/綻びる"},"綻びる":{"variants":"ほころびる/綻びる"},"ほころぶ":{"variants":"ほころぶ/綻ぶ"},"綻ぶ":{"variants":"ほころぶ/綻ぶ"},"星あかり":{"variants":"星あかり/星明り"},"星明り":{"variants":"星あかり/星明り"},"ほしい":{"variants":"ほしい/欲しい"},"欲しい":{"variants":"ほしい/欲しい"},"干し柿":{"variants":"干し柿/干柿"},"干柿":{"variants":"干し柿/干柿"},"干し草":{"variants":"干し草/干草"},"干草":{"variants":"干し草/干草"},"星くず":{"variants":"星くず/星屑"},"星屑":{"variants":"星くず/星屑"},"ほしころす":{"variants":"ほしころす/乾し殺す"},"乾し殺す":{"variants":"ほしころす/乾し殺す"},"星取り表":{"variants":"星取り表/星取表"},"星取表":{"variants":"星取り表/星取表"},"星祭":{"variants":"星祭/星祭り"},"星祭り":{"variants":"星祭/星祭り"},"ほす":{"variants":"ほす/乾す/干す"},"ほする":{"variants":"ほする/保する/補する"},"捕捉":{"variants":"捕そく/捕捉"},"捕そく":{"variants":"捕そく/捕捉"},"ほそながい":{"variants":"ほそながい/細長い"},"細長い":{"variants":"ほそながい/細長い"},"ほそぼそ":{"variants":"ほそぼそ/細々"},"細々":{"variants":"ほそぼそ/細々"},"細み":{"variants":"細み/細身"},"細身":{"variants":"細み/細身"},"ほそめる":{"variants":"ほそめる/細める"},"細める":{"variants":"ほそめる/細める"},"ほそる":{"variants":"ほそる/細る"},"細る":{"variants":"ほそる/細る"},"ほぞの緒":{"variants":"ほぞの緒/臍緒"},"臍緒":{"variants":"ほぞの緒/臍緒"},"ホタテガイ":{"variants":"ホタテガイ/帆立貝"},"帆立貝":{"variants":"ホタテガイ/帆立貝"},"ホタル":{"variants":"ホタル/火垂る/蛍/螢"},"ホタルイカ":{"variants":"ホタルイカ/蛍烏賊"},"蛍烏賊":{"variants":"ホタルイカ/蛍烏賊"},"蛍狩":{"variants":"蛍狩/蛍狩り"},"蛍狩り":{"variants":"蛍狩/蛍狩り"},"ホタルグサ":{"variants":"ホタルグサ/蛍草"},"蛍草":{"variants":"ホタルグサ/蛍草"},"ホタルブクロ":{"variants":"ホタルブクロ/蛍袋/螢袋"},"ほだされる":{"variants":"ほだされる/絆される"},"絆される":{"variants":"ほだされる/絆される"},"ホッキガイ":{"variants":"ホッキガイ/北寄貝"},"北寄貝":{"variants":"ホッキガイ/北寄貝"},"ホッキョクグマ":{"variants":"ホッキョクグマ/北極熊"},"北極熊":{"variants":"ホッキョクグマ/北極熊"},"ホック":{"variants":"ホック/発句"},"発句":{"variants":"ホック/発句"},"ホッケ":{"variants":"ホッケ/法華"},"法華":{"variants":"ホッケ/法華"},"ほっする":{"variants":"ほっする/欲する"},"欲する":{"variants":"ほっする/欲する"},"掘っ立て":{"variants":"掘っ立て/掘立て"},"掘立て":{"variants":"掘っ立て/掘立て"},"ホテイソウ":{"variants":"ホテイソウ/布袋草"},"布袋草":{"variants":"ホテイソウ/布袋草"},"ほてる":{"variants":"ほてる/火照る/熱る"},"補てん":{"variants":"補てん/補填"},"補填":{"variants":"補てん/補填"},"ホトケノザ":{"variants":"ホトケノザ/仏の座"},"仏の座":{"variants":"ホトケノザ/仏の座"},"ほととぎす":{"variants":"ほととぎす/ホトトギス/時鳥"},"ホトトギス":{"variants":"ほととぎす/ホトトギス/時鳥"},"時鳥":{"variants":"ほととぎす/ホトトギス/時鳥"},"ほとばしる":{"variants":"ほとばしる/迸る"},"迸る":{"variants":"ほとばしる/迸る"},"ほとびる":{"variants":"ほとびる/潤びる"},"潤びる":{"variants":"ほとびる/潤びる"},"ほとり":{"variants":"ほとり/畔"},"畔":{"variants":"ほとり/畔"},"ほとんど":{"variants":"ほとんど/殆ど"},"殆ど":{"variants":"ほとんど/殆ど"},"ほど":{"variants":"ほど/程"},"程":{"variants":"ほど/程"},"程合":{"variants":"程合/程合い"},"程合い":{"variants":"程合/程合い"},"ほどこす":{"variants":"ほどこす/施す"},"施す":{"variants":"ほどこす/施す"},"ほどこせる":{"variants":"ほどこせる/施せる"},"施せる":{"variants":"ほどこせる/施せる"},"ほどとおい":{"variants":"ほどとおい/ほど遠い/程遠い"},"ほど遠い":{"variants":"ほどとおい/ほど遠い/程遠い"},"程遠い":{"variants":"ほどとおい/ほど遠い/程遠い"},"ほどなく":{"variants":"ほどなく/程なく"},"程なく":{"variants":"ほどなく/程なく"},"程々":{"variants":"程々/程程"},"程程":{"variants":"程々/程程"},"ほどよい":{"variants":"ほどよい/程よい"},"程よい":{"variants":"ほどよい/程よい"},"ほ乳":{"variants":"ほ乳/哺乳"},"哺乳":{"variants":"ほ乳/哺乳"},"ほ乳類":{"variants":"ほ乳類/哺乳類"},"哺乳類":{"variants":"ほ乳類/哺乳類"},"ほねおり損":{"variants":"ほねおり損/骨折り損"},"骨折り損":{"variants":"ほねおり損/骨折り損"},"ほねおる":{"variants":"ほねおる/骨折る"},"骨折る":{"variants":"ほねおる/骨折る"},"骨組":{"variants":"骨組/骨組み"},"骨組み":{"variants":"骨組/骨組み"},"骨っぷし":{"variants":"骨っぷし/骨っ節"},"骨っ節":{"variants":"骨っぷし/骨っ節"},"ほねっぽい":{"variants":"ほねっぽい/骨っぽい"},"骨っぽい":{"variants":"ほねっぽい/骨っぽい"},"ほねばる":{"variants":"ほねばる/骨張る"},"骨張る":{"variants":"ほねばる/骨張る"},"仄々明":{"variants":"仄々明/仄仄明"},"仄仄明":{"variants":"仄々明/仄仄明"},"ほのめかす":{"variants":"ほのめかす/仄めかす"},"仄めかす":{"variants":"ほのめかす/仄めかす"},"ほのめく":{"variants":"ほのめく/仄めく"},"仄めく":{"variants":"ほのめく/仄めく"},"ほふる":{"variants":"ほふる/屠る"},"屠る":{"variants":"ほふる/屠る"},"ほほ":{"variants":"ほほ/歩歩"},"歩歩":{"variants":"ほほ/歩歩"},"ほほえましい":{"variants":"ほほえましい/微笑ましい"},"微笑ましい":{"variants":"ほほえましい/微笑ましい"},"ほほえむ":{"variants":"ほほえむ/ほほ笑む/微笑む"},"ほほ笑む":{"variants":"ほほえむ/ほほ笑む/微笑む"},"微笑む":{"variants":"ほほえむ/ほほ笑む/微笑む"},"ほぼ":{"variants":"ほぼ/粗/略"},"ほめそやす":{"variants":"ほめそやす/褒めそやす/誉めそやす"},"ほめちぎる":{"variants":"ほめちぎる/褒めちぎる/誉めちぎる"},"ほめる":{"variants":"ほめる/褒める/誉める"},"ホヤ":{"variants":"ホヤ/火屋/海鞘"},"ほやほや":{"variants":"ほやほや/ホヤホヤ"},"ホヤホヤ":{"variants":"ほやほや/ホヤホヤ"},"ホラガイ":{"variants":"ホラガイ/法螺貝"},"法螺貝":{"variants":"ホラガイ/法螺貝"},"ほり":{"variants":"ほり/濠/彫り/捕吏/堀"},"ほりあげる":{"variants":"ほりあげる/彫りあげる/彫り上げる"},"彫りあげる":{"variants":"ほりあげる/彫りあげる/彫り上げる"},"彫り上げる":{"variants":"ほりあげる/彫りあげる/彫り上げる"},"ほりおこす":{"variants":"ほりおこす/掘りおこす/掘り起こす"},"掘りおこす":{"variants":"ほりおこす/掘りおこす/掘り起こす"},"掘り起こす":{"variants":"ほりおこす/掘りおこす/掘り起こす"},"ほりおこせる":{"variants":"ほりおこせる/掘り起こせる"},"掘り起こせる":{"variants":"ほりおこせる/掘り起こせる"},"ほりかえす":{"variants":"ほりかえす/掘り返す"},"掘り返す":{"variants":"ほりかえす/掘り返す"},"ほりかえせる":{"variants":"ほりかえせる/掘り返せる"},"掘り返せる":{"variants":"ほりかえせる/掘り返せる"},"ほりこむ":{"variants":"ほりこむ/彫りこむ/彫り込む"},"彫りこむ":{"variants":"ほりこむ/彫りこむ/彫り込む"},"彫り込む":{"variants":"ほりこむ/彫りこむ/彫り込む"},"ほりこめる":{"variants":"ほりこめる/彫り込める"},"彫り込める":{"variants":"ほりこめる/彫り込める"},"ほりさげる":{"variants":"ほりさげる/掘りさげる/掘り下げる/掘下げる"},"掘りさげる":{"variants":"ほりさげる/掘りさげる/掘り下げる/掘下げる"},"掘り下げる":{"variants":"ほりさげる/掘りさげる/掘り下げる/掘下げる"},"掘下げる":{"variants":"ほりさげる/掘りさげる/掘り下げる/掘下げる"},"ほりすすむ":{"variants":"ほりすすむ/掘り進む"},"掘り進む":{"variants":"ほりすすむ/掘り進む"},"掘り出し物":{"variants":"掘り出し物/掘出しもの/掘出し物"},"掘出しもの":{"variants":"掘り出し物/掘出しもの/掘出し物"},"掘出し物":{"variants":"掘り出し物/掘出しもの/掘出し物"},"ほりだす":{"variants":"ほりだす/掘りだす/掘り出す/掘出す"},"掘りだす":{"variants":"ほりだす/掘りだす/掘り出す/掘出す"},"掘り出す":{"variants":"ほりだす/掘りだす/掘り出す/掘出す"},"掘出す":{"variants":"ほりだす/掘りだす/掘り出す/掘出す"},"ほりだせる":{"variants":"ほりだせる/掘り出せる"},"掘り出せる":{"variants":"ほりだせる/掘り出せる"},"ほりつける":{"variants":"ほりつける/彫りつける"},"彫りつける":{"variants":"ほりつける/彫りつける"},"掘り抜き":{"variants":"掘り抜き/掘抜き"},"掘抜き":{"variants":"掘り抜き/掘抜き"},"彫り物":{"variants":"彫り物/彫物"},"彫物":{"variants":"彫り物/彫物"},"ホリュウ":{"variants":"ホリュウ/蒲柳"},"蒲柳":{"variants":"ホリュウ/蒲柳"},"ほる":{"variants":"ほる/掘る"},"掘る":{"variants":"ほる/掘る"},"ほれこむ":{"variants":"ほれこむ/ほれ込む/惚れこむ/惚れ込む"},"ほれ込む":{"variants":"ほれこむ/ほれ込む/惚れこむ/惚れ込む"},"惚れこむ":{"variants":"ほれこむ/ほれ込む/惚れこむ/惚れ込む"},"惚れ込む":{"variants":"ほれこむ/ほれ込む/惚れこむ/惚れ込む"},"ほれぼれ":{"variants":"ほれぼれ/惚れ惚れ"},"惚れ惚れ":{"variants":"ほれぼれ/惚れ惚れ"},"ほれる":{"variants":"ほれる/ホレる/掘れる/惚れる/彫れる"},"ホレる":{"variants":"ほれる/ホレる/掘れる/惚れる/彫れる"},"ほろにがい":{"variants":"ほろにがい/ほろ苦い"},"ほろ苦い":{"variants":"ほろにがい/ほろ苦い"},"ほろびる":{"variants":"ほろびる/亡びる/滅びる"},"ほろぶ":{"variants":"ほろぶ/亡ぶ/滅ぶ"},"ほろほろ":{"variants":"ほろほろ/ホロホロ"},"ホロホロ":{"variants":"ほろほろ/ホロホロ"},"ほろぼす":{"variants":"ほろぼす/亡ぼす/滅ぼす"},"ほろぼせる":{"variants":"ほろぼせる/滅ぼせる"},"滅ぼせる":{"variants":"ほろぼせる/滅ぼせる"},"ほろ酔い":{"variants":"ほろ酔い/微酔い"},"微酔い":{"variants":"ほろ酔い/微酔い"},"ホン":{"variants":"ホン/本"},"本":{"variants":"ホン/本"},"本決り":{"variants":"本決まり/本決り"},"本決まり":{"variants":"本決まり/本決り"},"ほんぜん":{"variants":"ほんぜん/翻然"},"翻然":{"variants":"ほんぜん/翻然"},"ホンゾウ":{"variants":"ホンゾウ/本草"},"本草":{"variants":"ホンゾウ/本草"},"ホンゾウガク":{"variants":"ホンゾウガク/本草学"},"本草学":{"variants":"ホンゾウガク/本草学"},"本立":{"variants":"本立/本立て"},"本立て":{"variants":"本立/本立て"},"ほんとう":{"variants":"ほんとう/本島/本当"},"ほんに":{"variants":"ほんに/本に"},"本に":{"variants":"ほんに/本に"},"ホンもの":{"variants":"ホンもの/ホンモノ/本物"},"ホンモノ":{"variants":"ホンもの/ホンモノ/本物"},"本物":{"variants":"ホンもの/ホンモノ/本物"},"ほんらい":{"variants":"ほんらい/本来"},"本来":{"variants":"ほんらい/本来"},"翻ろう":{"variants":"翻ろう/翻弄"},"翻弄":{"variants":"翻ろう/翻弄"},"防空ごう":{"variants":"防空ごう/防空壕"},"防空壕":{"variants":"防空ごう/防空壕"},"ぼうグラフ":{"variants":"ぼうグラフ/棒グラフ"},"棒グラフ":{"variants":"ぼうグラフ/棒グラフ"},"ぼうこう":{"variants":"ぼうこう/棒鋼/膀胱"},"防塵":{"variants":"防じん/防塵"},"防じん":{"variants":"防じん/防塵"},"ぼうする":{"variants":"ぼうする/忘する"},"忘する":{"variants":"ぼうする/忘する"},"ぼうぜん":{"variants":"ぼうぜん/ぼう然/呆然/惘然/茫然"},"ぼう然":{"variants":"ぼうぜん/ぼう然/呆然/惘然/茫然"},"ぼうぜんと":{"variants":"ぼうぜんと/呆然と"},"呆然と":{"variants":"ぼうぜんと/呆然と"},"棒高跳":{"variants":"棒高跳/棒高跳び"},"棒高跳び":{"variants":"棒高跳/棒高跳び"},"棒ダラ":{"variants":"棒ダラ/棒鱈"},"棒鱈":{"variants":"棒ダラ/棒鱈"},"冒とく":{"variants":"冒とく/冒涜"},"冒涜":{"variants":"冒とく/冒涜"},"棒引":{"variants":"棒引/棒引き"},"棒引き":{"variants":"棒引/棒引き"},"ボウフウ":{"variants":"ボウフウ/暴風/防風"},"ボウフラ":{"variants":"ボウフラ/孑孑"},"孑孑":{"variants":"ボウフラ/孑孑"},"某某":{"variants":"某々/某某"},"某々":{"variants":"某々/某某"},"茫茫":{"variants":"茫々/茫茫"},"茫々":{"variants":"茫々/茫茫"},"ぼうようと":{"variants":"ぼうようと/芒洋と"},"芒洋と":{"variants":"ぼうようと/芒洋と"},"ぼかし":{"variants":"ぼかし/暈し"},"暈し":{"variants":"ぼかし/暈し"},"ぼかす":{"variants":"ぼかす/暈す"},"暈す":{"variants":"ぼかす/暈す"},"ぼく":{"variants":"ぼく/ボク/僕"},"ボク":{"variants":"ぼく/ボク/僕"},"僕":{"variants":"ぼく/ボク/僕"},"ぼくする":{"variants":"ぼくする/卜する"},"卜する":{"variants":"ぼくする/卜する"},"僕たち":{"variants":"僕たち/僕達"},"僕達":{"variants":"僕たち/僕達"},"朴とつ":{"variants":"朴とつ/朴訥"},"朴訥":{"variants":"朴とつ/朴訥"},"ぼくねんじん":{"variants":"ぼくねんじん/朴念仁"},"朴念仁":{"variants":"ぼくねんじん/朴念仁"},"ぼけ":{"variants":"ぼけ/ボケ/呆け/木瓜"},"ボケ":{"variants":"ぼけ/ボケ/呆け/木瓜"},"ぼける":{"variants":"ぼける/暈ける"},"暈ける":{"variants":"ぼける/暈ける"},"ぼさぼさ":{"variants":"ぼさぼさ/ボサボサ"},"ボサボサ":{"variants":"ぼさぼさ/ボサボサ"},"ぼそぼそ":{"variants":"ぼそぼそ/ボソボソ"},"ボソボソ":{"variants":"ぼそぼそ/ボソボソ"},"ぼた餅":{"variants":"ぼた餅/牡丹餅"},"牡丹餅":{"variants":"ぼた餅/牡丹餅"},"ボタン":{"variants":"ボタン/牡丹/釦"},"ボタンキョウ":{"variants":"ボタンキョウ/牡丹杏"},"牡丹杏":{"variants":"ボタンキョウ/牡丹杏"},"ボタンザクラ":{"variants":"ボタンザクラ/牡丹桜"},"牡丹桜":{"variants":"ボタンザクラ/牡丹桜"},"ボタンバケ":{"variants":"ボタンバケ/牡丹刷毛"},"牡丹刷毛":{"variants":"ボタンバケ/牡丹刷毛"},"ぼたん雪":{"variants":"ぼたん雪/ボタンユキ/牡丹雪"},"ボタンユキ":{"variants":"ぼたん雪/ボタンユキ/牡丹雪"},"牡丹雪":{"variants":"ぼたん雪/ボタンユキ/牡丹雪"},"ぼだい樹":{"variants":"ぼだい樹/ボダイジュ/菩提樹"},"ボダイジュ":{"variants":"ぼだい樹/ボダイジュ/菩提樹"},"菩提樹":{"variants":"ぼだい樹/ボダイジュ/菩提樹"},"ぼちぼち":{"variants":"ぼちぼち/ボチボチ"},"ボチボチ":{"variants":"ぼちぼち/ボチボチ"},"ＢＯＸ":{"variants":"ＢＯＸ/Ｂｏｘ/ボックス"},"Ｂｏｘ":{"variants":"ＢＯＸ/Ｂｏｘ/ボックス"},"ボックス":{"variants":"ＢＯＸ/Ｂｏｘ/ボックス"},"坊ちゃん":{"variants":"坊ちゃん/坊っちゃん"},"坊っちゃん":{"variants":"坊ちゃん/坊っちゃん"},"ボツ":{"variants":"ボツ/没"},"没":{"variants":"ボツ/没"},"ぼつぼつ":{"variants":"ぼつぼつ/ボツボツ"},"ボツボツ":{"variants":"ぼつぼつ/ボツボツ"},"勃々":{"variants":"勃々/勃勃"},"勃勃":{"variants":"勃々/勃勃"},"ＢＯＤＹ":{"variants":"ＢＯＤＹ/ボディー"},"ボディー":{"variants":"ＢＯＤＹ/ボディー"},"ぼや":{"variants":"ぼや/ボヤ/小火/暮夜"},"ボヤ":{"variants":"ぼや/ボヤ/小火/暮夜"},"ぼやく":{"variants":"ぼやく/ボヤく"},"ボヤく":{"variants":"ぼやく/ボヤく"},"ボラ":{"variants":"ボラ/鰡"},"鰡":{"variants":"ボラ/鰡"},"ｖ":{"variants":"ｖ/ボルト"},"ボルト":{"variants":"ｖ/ボルト"},"ぼろ":{"variants":"ぼろ/梵論"},"梵論":{"variants":"ぼろ/梵論"},"盆おどり":{"variants":"盆おどり/盆踊り"},"盆踊り":{"variants":"盆おどり/盆踊り"},"盆暮":{"variants":"盆暮/盆暮れ"},"盆暮れ":{"variants":"盆暮/盆暮れ"},"ぼん鐘":{"variants":"ぼん鐘/梵鐘"},"梵鐘":{"variants":"ぼん鐘/梵鐘"},"ぽかぽか":{"variants":"ぽかぽか/ポカポカ"},"ポカポカ":{"variants":"ぽかぽか/ポカポカ"},"ぽしゃる":{"variants":"ぽしゃる/ポシャる"},"ポシャる":{"variants":"ぽしゃる/ポシャる"},"ポップ・アート":{"variants":"ポップ・アート/ポップアート"},"ポップアート":{"variants":"ポップ・アート/ポップアート"},"ぽつぽつ":{"variants":"ぽつぽつ/ポツポツ"},"ポツポツ":{"variants":"ぽつぽつ/ポツポツ"},"ぽつりぽつり":{"variants":"ぽつりぽつり/ポツリポツリ"},"ポツリポツリ":{"variants":"ぽつりぽつり/ポツリポツリ"},"ポンカン":{"variants":"ポンカン/ポン柑"},"ポン柑":{"variants":"ポンカン/ポン柑"},"マージャン":{"variants":"マージャン/麻雀"},"麻雀":{"variants":"マージャン/麻雀"},"まぁ":{"variants":"まぁ/まァ"},"まァ":{"variants":"まぁ/まァ"},"まあ":{"variants":"まあ/まア"},"まア":{"variants":"まあ/まア"},"間合":{"variants":"間合/間合い"},"間合い":{"variants":"間合/間合い"},"マアジ":{"variants":"マアジ/真鯵"},"真鯵":{"variants":"マアジ/真鯵"},"まあたらしい":{"variants":"まあたらしい/真新しい"},"真新しい":{"variants":"まあたらしい/真新しい"},"まいあがる":{"variants":"まいあがる/舞いあがる/舞い上がる/舞上がる"},"舞いあがる":{"variants":"まいあがる/舞いあがる/舞い上がる/舞上がる"},"舞い上がる":{"variants":"まいあがる/舞いあがる/舞い上がる/舞上がる"},"舞上がる":{"variants":"まいあがる/舞いあがる/舞い上がる/舞上がる"},"まいおりる":{"variants":"まいおりる/舞い降りる"},"舞い降りる":{"variants":"まいおりる/舞い降りる"},"まいくるう":{"variants":"まいくるう/舞い狂う"},"舞い狂う":{"variants":"まいくるう/舞い狂う"},"まいこ":{"variants":"まいこ/舞い子/舞子/毎戸"},"舞子":{"variants":"まいこ/舞い子/舞子"},"舞い子":{"variants":"まいこ/舞い子/舞子"},"まいこむ":{"variants":"まいこむ/舞いこむ/舞い込む/舞込む"},"舞いこむ":{"variants":"まいこむ/舞いこむ/舞い込む/舞込む"},"舞い込む":{"variants":"まいこむ/舞いこむ/舞い込む/舞込む"},"舞込む":{"variants":"まいこむ/舞いこむ/舞い込む/舞込む"},"迷児":{"variants":"迷い児/迷児"},"迷い児":{"variants":"迷い児/迷児"},"まい進":{"variants":"まい進/邁進"},"邁進":{"variants":"まい進/邁進"},"毎々":{"variants":"毎々/毎毎"},"毎毎":{"variants":"毎々/毎毎"},"まいもどる":{"variants":"まいもどる/舞い戻る/舞戻る"},"舞い戻る":{"variants":"まいもどる/舞い戻る/舞戻る"},"舞戻る":{"variants":"まいもどる/舞い戻る/舞戻る"},"まいもどれる":{"variants":"まいもどれる/舞い戻れる"},"舞い戻れる":{"variants":"まいもどれる/舞い戻れる"},"まいらす":{"variants":"まいらす/参らす"},"参らす":{"variants":"まいらす/参らす"},"まいらせる":{"variants":"まいらせる/参らせる"},"参らせる":{"variants":"まいらせる/参らせる"},"まいる":{"variants":"まいる/参る"},"参る":{"variants":"まいる/参る"},"マイル":{"variants":"マイル/哩"},"哩":{"variants":"マイル/哩"},"まいれる":{"variants":"まいれる/詣れる/参れる"},"マイワシ":{"variants":"マイワシ/真鰯"},"真鰯":{"variants":"マイワシ/真鰯"},"まう":{"variants":"まう/舞う"},"舞う":{"variants":"まう/舞う"},"前祝":{"variants":"前祝/前祝い"},"前祝い":{"variants":"前祝/前祝い"},"前売":{"variants":"前売/前売り"},"前売り":{"variants":"前売/前売り"},"前かけ":{"variants":"前かけ/前掛け"},"前掛け":{"variants":"前かけ/前掛け"},"前垂":{"variants":"前垂/前垂れ"},"前垂れ":{"variants":"前垂/前垂れ"},"前ぶれ":{"variants":"前ぶれ/前触れ"},"前触れ":{"variants":"前ぶれ/前触れ"},"まえもって":{"variants":"まえもって/前もって"},"前もって":{"variants":"まえもって/前もって"},"まえる":{"variants":"まえる/舞える"},"舞える":{"variants":"まえる/舞える"},"マオウ":{"variants":"マオウ/魔王/麻黄"},"まかす":{"variants":"まかす/任す/負かす"},"まかせる":{"variants":"まかせる/委せる/任せる/負かせる"},"賄":{"variants":"賄/賄い"},"賄い":{"variants":"賄/賄い"},"まかなう":{"variants":"まかなう/賄う"},"賄う":{"variants":"まかなう/賄う"},"まかなえる":{"variants":"まかなえる/賄える"},"賄える":{"variants":"まかなえる/賄える"},"まかりこす":{"variants":"まかりこす/罷り越す"},"罷り越す":{"variants":"まかりこす/罷り越す"},"まかりでる":{"variants":"まかりでる/まかり出る/罷りでる"},"まかり出る":{"variants":"まかりでる/まかり出る/罷りでる"},"罷りでる":{"variants":"まかりでる/まかり出る/罷りでる"},"まかりとおる":{"variants":"まかりとおる/まかり通る/罷り通る"},"まかり通る":{"variants":"まかりとおる/まかり通る/罷り通る"},"罷り通る":{"variants":"まかりとおる/まかり通る/罷り通る"},"まかりまちがう":{"variants":"まかりまちがう/まかり間違う/罷り間違う"},"まかり間違う":{"variants":"まかりまちがう/まかり間違う/罷り間違う"},"罷り間違う":{"variants":"まかりまちがう/まかり間違う/罷り間違う"},"まかる":{"variants":"まかる/罷る/負かる"},"まがい物":{"variants":"まがい物/紛いもの/紛い物"},"紛いもの":{"variants":"まがい物/紛いもの/紛い物"},"紛い物":{"variants":"まがい物/紛いもの/紛い物"},"まがう":{"variants":"まがう/紛う"},"紛う":{"variants":"まがう/紛う"},"まがえる":{"variants":"まがえる/紛える"},"紛える":{"variants":"まがえる/紛える"},"間貸":{"variants":"間貸/間貸し"},"間貸し":{"variants":"間貸/間貸し"},"まがまがしい":{"variants":"まがまがしい/禍々しい/禍禍しい/曲々しい/曲曲しい/枉々しい/枉枉しい"},"禍々しい":{"variants":"まがまがしい/禍々しい/禍禍しい"},"曲曲しい":{"variants":"まがまがしい/曲々しい/曲曲しい"},"枉枉しい":{"variants":"まがまがしい/枉々しい/枉枉しい"},"枉々しい":{"variants":"まがまがしい/枉々しい/枉枉しい"},"禍禍しい":{"variants":"まがまがしい/禍々しい/禍禍しい"},"曲々しい":{"variants":"まがまがしい/曲々しい/曲曲しい"},"マガモ":{"variants":"マガモ/真鴨"},"真鴨":{"variants":"マガモ/真鴨"},"まがり角":{"variants":"まがり角/曲がり角/曲りかど/曲り角"},"曲がり角":{"variants":"まがり角/曲がり角/曲りかど/曲り角"},"曲りかど":{"variants":"まがり角/曲がり角/曲りかど/曲り角"},"曲り角":{"variants":"まがり角/曲がり角/曲りかど/曲り角"},"まがりくねる":{"variants":"まがりくねる/曲がりくねる/曲りくねる"},"曲がりくねる":{"variants":"まがりくねる/曲がりくねる/曲りくねる"},"曲りくねる":{"variants":"まがりくねる/曲がりくねる/曲りくねる"},"まがりなりにも":{"variants":"まがりなりにも/曲がりなりにも"},"曲がりなりにも":{"variants":"まがりなりにも/曲がりなりにも"},"まがる":{"variants":"まがる/迂る/曲がる/曲る"},"曲る":{"variants":"まがる/曲がる/曲る"},"曲がる":{"variants":"まがる/曲がる/曲る"},"マガレイ":{"variants":"マガレイ/真鰈"},"真鰈":{"variants":"マガレイ/真鰈"},"まがれる":{"variants":"まがれる/曲がれる"},"曲がれる":{"variants":"まがれる/曲がれる"},"まき":{"variants":"まき/マキ/巻/巻き/真木/牧"},"マキ":{"variants":"まき/マキ/巻/巻き/真木/牧"},"巻":{"variants":"まき/マキ/巻/巻き"},"巻き":{"variants":"まき/マキ/巻/巻き"},"まきあげる":{"variants":"まきあげる/巻き上げる/巻上げる/捲き揚げる/捲揚げる"},"捲き揚げる":{"variants":"まきあげる/捲き揚げる/捲揚げる"},"巻上げる":{"variants":"まきあげる/巻き上げる/巻上げる"},"巻き上げる":{"variants":"まきあげる/巻き上げる/巻上げる"},"捲揚げる":{"variants":"まきあげる/捲き揚げる/捲揚げる"},"まき網":{"variants":"まき網/巻網/旋網"},"蒔絵":{"variants":"まき絵/蒔絵"},"撒餌":{"variants":"撒き餌/撒餌"},"撒き餌":{"variants":"撒き餌/撒餌"},"まき絵":{"variants":"まき絵/蒔絵"},"まきおこす":{"variants":"まきおこす/巻き起こす/巻き起す"},"巻き起こす":{"variants":"まきおこす/巻き起こす/巻き起す"},"巻き起す":{"variants":"まきおこす/巻き起こす/巻き起す"},"まきおこせる":{"variants":"まきおこせる/巻き起こせる"},"巻き起こせる":{"variants":"まきおこせる/巻き起こせる"},"巻きかえし":{"variants":"巻きかえし/巻き返し"},"巻き返し":{"variants":"巻きかえし/巻き返し"},"まきかえす":{"variants":"まきかえす/巻き返す"},"巻き返す":{"variants":"まきかえす/巻き返す"},"まきかえせる":{"variants":"まきかえせる/巻き返せる"},"巻き返せる":{"variants":"まきかえせる/巻き返せる"},"マキガイ":{"variants":"マキガイ/巻き貝/巻貝"},"巻き貝":{"variants":"マキガイ/巻き貝/巻貝"},"巻貝":{"variants":"マキガイ/巻き貝/巻貝"},"巻狩":{"variants":"巻狩/巻狩り"},"巻狩り":{"variants":"巻狩/巻狩り"},"まきこむ":{"variants":"まきこむ/巻きこむ/巻き込む/巻込む/捲き込む"},"巻込む":{"variants":"まきこむ/巻きこむ/巻き込む/巻込む"},"巻き込む":{"variants":"まきこむ/巻きこむ/巻き込む/巻込む"},"巻きこむ":{"variants":"まきこむ/巻きこむ/巻き込む/巻込む"},"まきこめる":{"variants":"まきこめる/巻き込める"},"巻き込める":{"variants":"まきこめる/巻き込める"},"巻き尺":{"variants":"巻き尺/巻尺"},"巻尺":{"variants":"巻き尺/巻尺"},"巻きずし":{"variants":"巻きずし/巻鮨"},"巻鮨":{"variants":"巻きずし/巻鮨"},"巻き添え":{"variants":"巻き添え/巻添え"},"巻添え":{"variants":"巻き添え/巻添え"},"巻きたばこ":{"variants":"巻きたばこ/巻煙草"},"巻煙草":{"variants":"巻きたばこ/巻煙草"},"まきちらす":{"variants":"まきちらす/まき散らす"},"まき散らす":{"variants":"まきちらす/まき散らす"},"まきつく":{"variants":"まきつく/巻き付く"},"巻き付く":{"variants":"まきつく/巻き付く"},"まきつける":{"variants":"まきつける/巻き付ける"},"巻き付ける":{"variants":"まきつける/巻き付ける"},"まきなおす":{"variants":"まきなおす/蒔き直す"},"蒔き直す":{"variants":"まきなおす/蒔き直す"},"まきなおせる":{"variants":"まきなおせる/蒔き直せる"},"蒔き直せる":{"variants":"まきなおせる/蒔き直せる"},"巻き物":{"variants":"巻き物/巻物"},"巻物":{"variants":"巻き物/巻物"},"まぎらかす":{"variants":"まぎらかす/紛らかす"},"紛らかす":{"variants":"まぎらかす/紛らかす"},"まぎらす":{"variants":"まぎらす/紛らす"},"紛らす":{"variants":"まぎらす/紛らす"},"まぎらせる":{"variants":"まぎらせる/紛らせる"},"紛らせる":{"variants":"まぎらせる/紛らせる"},"まぎらわしい":{"variants":"まぎらわしい/紛らわしい"},"紛らわしい":{"variants":"まぎらわしい/紛らわしい"},"まぎらわす":{"variants":"まぎらわす/紛らわす"},"紛らわす":{"variants":"まぎらわす/紛らわす"},"まぎらわせる":{"variants":"まぎらわせる/紛らわせる"},"紛らわせる":{"variants":"まぎらわせる/紛らわせる"},"まぎる":{"variants":"まぎる/間切る"},"間切る":{"variants":"まぎる/間切る"},"まぎれこむ":{"variants":"まぎれこむ/まぎれ込む/紛れこむ/紛れ込む"},"まぎれ込む":{"variants":"まぎれこむ/まぎれ込む/紛れこむ/紛れ込む"},"紛れこむ":{"variants":"まぎれこむ/まぎれ込む/紛れこむ/紛れ込む"},"紛れ込む":{"variants":"まぎれこむ/まぎれ込む/紛れこむ/紛れ込む"},"まぎれこめる":{"variants":"まぎれこめる/紛れ込める"},"紛れ込める":{"variants":"まぎれこめる/紛れ込める"},"まぎれる":{"variants":"まぎれる/紛れる"},"紛れる":{"variants":"まぎれる/紛れる"},"まく":{"variants":"まく/巻く/捲く/撒く/蒔く/播く/卷く"},"幕あい":{"variants":"幕あい/幕間"},"幕間":{"variants":"幕あい/幕間"},"幕あき":{"variants":"幕あき/幕開き"},"幕開き":{"variants":"幕あき/幕開き"},"幕ぎれ":{"variants":"幕ぎれ/幕切れ"},"幕切れ":{"variants":"幕ぎれ/幕切れ"},"まくしあげる":{"variants":"まくしあげる/捲し上げる"},"捲し上げる":{"variants":"まくしあげる/捲し上げる"},"まくしたてる":{"variants":"まくしたてる/まくし立てる/捲したてる/捲し立てる"},"まくし立てる":{"variants":"まくしたてる/まくし立てる/捲したてる/捲し立てる"},"捲したてる":{"variants":"まくしたてる/まくし立てる/捲したてる/捲し立てる"},"捲し立てる":{"variants":"まくしたてる/まくし立てる/捲したてる/捲し立てる"},"まくら":{"variants":"まくら/枕"},"枕":{"variants":"まくら/枕"},"まくら木":{"variants":"まくら木/枕木"},"枕木":{"variants":"まくら木/枕木"},"枕ことば":{"variants":"枕ことば/枕詞"},"枕詞":{"variants":"枕ことば/枕詞"},"まくらする":{"variants":"まくらする/枕する"},"枕する":{"variants":"まくらする/枕する"},"枕元":{"variants":"まくら元/枕元"},"まくら元":{"variants":"まくら元/枕元"},"マクリ":{"variants":"マクリ/海人草/海仁草"},"まくれる":{"variants":"まくれる/捲れる"},"捲れる":{"variants":"まくれる/捲れる"},"マクワウリ":{"variants":"マクワウリ/真桑瓜"},"真桑瓜":{"variants":"マクワウリ/真桑瓜"},"マグロ":{"variants":"マグロ/鮪"},"鮪":{"variants":"マグロ/鮪"},"負けいくさ":{"variants":"負けいくさ/負け軍/負け戦/負軍/負戦"},"負戦":{"variants":"負けいくさ/負け戦/負戦"},"負け軍":{"variants":"負けいくさ/負け軍/負軍"},"負け戦":{"variants":"負けいくさ/負け戦/負戦"},"負軍":{"variants":"負けいくさ/負け軍/負軍"},"負けおしみ":{"variants":"負けおしみ/負け惜しみ/負惜しみ"},"負け惜しみ":{"variants":"負けおしみ/負け惜しみ/負惜しみ"},"負惜しみ":{"variants":"負けおしみ/負け惜しみ/負惜しみ"},"負けぎらい":{"variants":"負けぎらい/負け嫌い"},"負け嫌い":{"variants":"負けぎらい/負け嫌い"},"まけこす":{"variants":"まけこす/負け越す"},"負け越す":{"variants":"まけこす/負け越す"},"負けずぎらい":{"variants":"負けずぎらい/負けず嫌い"},"負けず嫌い":{"variants":"負けずぎらい/負けず嫌い"},"まける":{"variants":"まける/巻ける/捲ける/撒ける/蒔ける/敗ける/負ける/卷ける"},"まげて":{"variants":"まげて/枉げて"},"枉げて":{"variants":"まげて/枉げて"},"曲げ物":{"variants":"曲げもの/曲げ物"},"曲げもの":{"variants":"曲げもの/曲げ物"},"まげる":{"variants":"まげる/曲げる/枉げる"},"まことに":{"variants":"まことに/誠に"},"誠に":{"variants":"まことに/誠に"},"マコモ":{"variants":"マコモ/真菰"},"真菰":{"variants":"マコモ/真菰"},"マゴイ":{"variants":"マゴイ/真鯉"},"真鯉":{"variants":"マゴイ/真鯉"},"マゴタロウムシ":{"variants":"マゴタロウムシ/孫太郎虫"},"孫太郎虫":{"variants":"マゴタロウムシ/孫太郎虫"},"まごの手":{"variants":"まごの手/孫の手"},"孫の手":{"variants":"まごの手/孫の手"},"マサキ":{"variants":"マサキ/正木/柾"},"まさに":{"variants":"まさに/正に"},"正に":{"variants":"まさに/正に"},"まさる":{"variants":"まさる/勝る/増さる/優る"},"まざる":{"variants":"まざる/交ざる/混ざる/雑ざる"},"まし":{"variants":"まし/増し"},"増し":{"variants":"まし/増し"},"まして":{"variants":"まして/況して"},"況して":{"variants":"まして/況して"},"まします":{"variants":"まします/在す"},"在す":{"variants":"まします/在す"},"マシン":{"variants":"マシン/麻しん"},"麻しん":{"variants":"マシン/麻しん"},"まじえる":{"variants":"まじえる/交える/混じえる"},"間仕切":{"variants":"間仕切/間仕切り"},"間仕切り":{"variants":"間仕切/間仕切り"},"まじめ":{"variants":"まじめ/真面目"},"真面目":{"variants":"まじめ/真面目"},"まじめくさる":{"variants":"まじめくさる/真面目くさる"},"真面目くさる":{"variants":"まじめくさる/真面目くさる"},"まじり気":{"variants":"まじり気/交じり気/混じりけ/混じり気"},"混じりけ":{"variants":"まじり気/混じりけ/混じり気"},"混じり気":{"variants":"まじり気/混じりけ/混じり気"},"まじり物":{"variants":"まじり物/交じりもの/交じり物/混じりもの/混じり物"},"混じり物":{"variants":"まじり物/混じりもの/混じり物"},"交じり物":{"variants":"まじり物/交じりもの/交じり物"},"混じりもの":{"variants":"まじり物/混じりもの/混じり物"},"交じりもの":{"variants":"まじり物/交じりもの/交じり物"},"まじる":{"variants":"まじる/交じる/混じる"},"まじろぐ":{"variants":"まじろぐ/瞬ぐ"},"瞬ぐ":{"variants":"まじろぐ/瞬ぐ"},"まじわる":{"variants":"まじわる/交わる"},"交わる":{"variants":"まじわる/交わる"},"まじわれる":{"variants":"まじわれる/交われる"},"交われる":{"variants":"まじわれる/交われる"},"ます":{"variants":"ます/マス/鱒/枡"},"増す":{"variants":"ます/増す"},"マス":{"variants":"ます/マス/鱒/枡"},"ますこみ":{"variants":"ますこみ/マスコミ"},"マスコミ":{"variants":"ますこみ/マスコミ"},"ます席":{"variants":"ます席/枡席"},"枡席":{"variants":"ます席/枡席"},"ます目":{"variants":"ます目/升目/桝目/枡目"},"まする":{"variants":"まする/摩する"},"摩する":{"variants":"まする/摩する"},"まず":{"variants":"まず/先ず"},"先ず":{"variants":"まず/先ず"},"まずい":{"variants":"まずい/不味い"},"不味い":{"variants":"まずい/不味い"},"まずしい":{"variants":"まずしい/貧しい"},"貧しい":{"variants":"まずしい/貧しい"},"ませる":{"variants":"ませる/増せる"},"増せる":{"variants":"ませる/増せる"},"まぜあわす":{"variants":"まぜあわす/混ぜ合わす"},"混ぜ合わす":{"variants":"まぜあわす/混ぜ合わす"},"まぜあわせる":{"variants":"まぜあわせる/混ぜ合わせる"},"混ぜ合わせる":{"variants":"まぜあわせる/混ぜ合わせる"},"まぜかえす":{"variants":"まぜかえす/まぜ返す/交ぜかえす/交ぜ返す/混ぜかえす/混ぜ返す"},"まぜ返す":{"variants":"まぜかえす/まぜ返す/交ぜかえす/交ぜ返す/混ぜかえす/混ぜ返す"},"混ぜかえす":{"variants":"まぜかえす/まぜ返す/混ぜかえす/混ぜ返す"},"交ぜかえす":{"variants":"まぜかえす/まぜ返す/交ぜかえす/交ぜ返す"},"混ぜ返す":{"variants":"まぜかえす/まぜ返す/混ぜかえす/混ぜ返す"},"交ぜ返す":{"variants":"まぜかえす/まぜ返す/交ぜかえす/交ぜ返す"},"まぜかえせる":{"variants":"まぜかえせる/混ぜ返せる"},"混ぜ返せる":{"variants":"まぜかえせる/混ぜ返せる"},"まぜっかえす":{"variants":"まぜっかえす/まぜっ返す/交ぜっかえす/交ぜっ返す/混ぜっかえす/混ぜっ返す"},"まぜっ返す":{"variants":"まぜっかえす/まぜっ返す/交ぜっかえす/交ぜっ返す/混ぜっかえす/混ぜっ返す"},"混ぜっかえす":{"variants":"まぜっかえす/まぜっ返す/混ぜっかえす/混ぜっ返す"},"交ぜっかえす":{"variants":"まぜっかえす/まぜっ返す/交ぜっかえす/交ぜっ返す"},"混ぜっ返す":{"variants":"まぜっかえす/まぜっ返す/混ぜっかえす/混ぜっ返す"},"交ぜっ返す":{"variants":"まぜっかえす/まぜっ返す/交ぜっかえす/交ぜっ返す"},"まぜる":{"variants":"まぜる/交ぜる/混ぜる"},"また":{"variants":"また/亦/又"},"またがる":{"variants":"またがる/股がる/跨る"},"またぐ":{"variants":"またぐ/跨ぐ"},"跨ぐ":{"variants":"またぐ/跨ぐ"},"股ぐら":{"variants":"股ぐら/股座"},"股座":{"variants":"股ぐら/股座"},"またげる":{"variants":"またげる/跨げる"},"跨げる":{"variants":"またげる/跨げる"},"また下":{"variants":"また下/股下"},"股下":{"variants":"また下/股下"},"またす":{"variants":"またす/待たす"},"待たす":{"variants":"またす/待たす"},"マタタビ":{"variants":"マタタビ/股旅"},"股旅":{"variants":"マタタビ/股旅"},"またの名":{"variants":"またの名/又の名"},"又の名":{"variants":"またの名/又の名"},"またの日":{"variants":"またの日/又の日"},"又の日":{"variants":"またの日/又の日"},"または":{"variants":"または/又は"},"又は":{"variants":"または/又は"},"またまた":{"variants":"またまた/又又"},"又又":{"variants":"またまた/又又"},"またもや":{"variants":"またもや/又もや"},"又もや":{"variants":"またもや/又もや"},"マダイ":{"variants":"マダイ/間代/真鯛"},"まだき":{"variants":"まだき/未だき"},"未だき":{"variants":"まだき/未だき"},"マダケ":{"variants":"マダケ/真竹"},"真竹":{"variants":"マダケ/真竹"},"マダコ":{"variants":"マダコ/真章魚/真蛸"},"まち":{"variants":"まち/街/待/待ち/町/襠"},"待":{"variants":"まち/待/待ち"},"待ち":{"variants":"まち/待/待ち"},"待ち合い":{"variants":"待ち合い/待合/待合い"},"待合":{"variants":"待ち合い/待合/待合い"},"待合い":{"variants":"待ち合い/待合/待合い"},"待合い室":{"variants":"待合い室/待合室"},"待合室":{"variants":"待合い室/待合室"},"まちあぐむ":{"variants":"まちあぐむ/待ちあぐむ"},"待ちあぐむ":{"variants":"まちあぐむ/待ちあぐむ"},"まちあわす":{"variants":"まちあわす/待ち合わす"},"待ち合わす":{"variants":"まちあわす/待ち合わす"},"待ち合わせ":{"variants":"待ち合わせ/待合せ"},"待合せ":{"variants":"待ち合わせ/待合せ"},"まちあわせる":{"variants":"まちあわせる/待ちあわせる/待ち合せる/待ち合わせる/待合せる"},"待ちあわせる":{"variants":"まちあわせる/待ちあわせる/待ち合せる/待ち合わせる/待合せる"},"待ち合せる":{"variants":"まちあわせる/待ちあわせる/待ち合せる/待ち合わせる/待合せる"},"待ち合わせる":{"variants":"まちあわせる/待ちあわせる/待ち合せる/待ち合わせる/待合せる"},"待合せる":{"variants":"まちあわせる/待ちあわせる/待ち合せる/待ち合わせる/待合せる"},"まちうける":{"variants":"まちうける/待ち受ける/待受ける"},"待ち受ける":{"variants":"まちうける/待ち受ける/待受ける"},"待受ける":{"variants":"まちうける/待ち受ける/待受ける"},"街かど":{"variants":"街かど/街角"},"街角":{"variants":"街かど/街角"},"まちかねる":{"variants":"まちかねる/待ちかねる/待ち兼ねる"},"待ちかねる":{"variants":"まちかねる/待ちかねる/待ち兼ねる"},"待ち兼ねる":{"variants":"まちかねる/待ちかねる/待ち兼ねる"},"まちかまえる":{"variants":"まちかまえる/待ちかまえる/待ち構える"},"待ちかまえる":{"variants":"まちかまえる/待ちかまえる/待ち構える"},"待ち構える":{"variants":"まちかまえる/待ちかまえる/待ち構える"},"まちがい":{"variants":"まちがい/間違い"},"間違い":{"variants":"まちがい/間違い"},"まちがう":{"variants":"まちがう/間違う"},"間違う":{"variants":"まちがう/間違う"},"まちがえる":{"variants":"まちがえる/間違える"},"間違える":{"variants":"まちがえる/間違える"},"まちくたびれる":{"variants":"まちくたびれる/待ちくたびれる"},"待ちくたびれる":{"variants":"まちくたびれる/待ちくたびれる"},"まちこがれる":{"variants":"まちこがれる/待ちこがれる/待ち焦がれる"},"待ちこがれる":{"variants":"まちこがれる/待ちこがれる/待ち焦がれる"},"待ち焦がれる":{"variants":"まちこがれる/待ちこがれる/待ち焦がれる"},"まちつける":{"variants":"まちつける/待ち付ける"},"待ち付ける":{"variants":"まちつける/待ち付ける"},"まちどおしい":{"variants":"まちどおしい/待ち遠しい/待遠しい"},"待ち遠しい":{"variants":"まちどおしい/待ち遠しい/待遠しい"},"待遠しい":{"variants":"まちどおしい/待ち遠しい/待遠しい"},"まちなか":{"variants":"まちなか/街なか/町中"},"町並み":{"variants":"町並/町並み"},"町並":{"variants":"町並/町並み"},"まちのぞむ":{"variants":"まちのぞむ/待ち望む"},"待ち望む":{"variants":"まちのぞむ/待ち望む"},"町はずれ":{"variants":"町はずれ/町外れ"},"町外れ":{"variants":"町はずれ/町外れ"},"まち針":{"variants":"まち針/待ち針/待針"},"待ち針":{"variants":"まち針/待ち針/待針"},"待針":{"variants":"まち針/待ち針/待針"},"待ち人":{"variants":"待ち人/待人"},"待人":{"variants":"待ち人/待人"},"待ち伏せ":{"variants":"待ち伏せ/待伏せ"},"待伏せ":{"variants":"待ち伏せ/待伏せ"},"まちぶせる":{"variants":"まちぶせる/待ち伏せる"},"待ち伏せる":{"variants":"まちぶせる/待ち伏せる"},"待ちぼうけ":{"variants":"待ちぼうけ/待ち惚け/待惚け"},"待ち惚け":{"variants":"待ちぼうけ/待ち惚け/待惚け"},"待惚け":{"variants":"待ちぼうけ/待ち惚け/待惚け"},"まちまち":{"variants":"まちまち/マチマチ"},"マチマチ":{"variants":"まちまち/マチマチ"},"まちもうける":{"variants":"まちもうける/待ち設ける/待設ける"},"待ち設ける":{"variants":"まちもうける/待ち設ける/待設ける"},"待設ける":{"variants":"まちもうける/待ち設ける/待設ける"},"まちわびる":{"variants":"まちわびる/待ちわびる/待ち侘びる"},"待ちわびる":{"variants":"まちわびる/待ちわびる/待ち侘びる"},"待ち侘びる":{"variants":"まちわびる/待ちわびる/待ち侘びる"},"まぢか":{"variants":"まぢか/間近"},"間近":{"variants":"まぢか/間近"},"まぢかい":{"variants":"まぢかい/間近い"},"間近い":{"variants":"まぢかい/間近い"},"まっ":{"variants":"まっ/真っ"},"真っ":{"variants":"まっ/真っ"},"真っ赤":{"variants":"真っ赤/真赤"},"真赤":{"variants":"真っ赤/真赤"},"まっ暗":{"variants":"まっ暗/真っ暗/真暗"},"真暗":{"variants":"まっ暗/真っ暗/真暗"},"真っ暗":{"variants":"まっ暗/真っ暗/真暗"},"まっ黒":{"variants":"まっ黒/真っ黒/真黒"},"真黒":{"variants":"まっ黒/真っ黒/真黒"},"真っ黒":{"variants":"まっ黒/真っ黒/真黒"},"まっくろい":{"variants":"まっくろい/真っ黒い/真黒い"},"真っ黒い":{"variants":"まっくろい/真っ黒い/真黒い"},"真黒い":{"variants":"まっくろい/真っ黒い/真黒い"},"真向":{"variants":"真っ向/真向"},"真っ向":{"variants":"真っ向/真向"},"まっこうくさい":{"variants":"まっこうくさい/抹香臭い"},"抹香臭い":{"variants":"まっこうくさい/抹香臭い"},"マッコウクジラ":{"variants":"マッコウクジラ/抹香鯨"},"抹香鯨":{"variants":"マッコウクジラ/抹香鯨"},"まっ最中":{"variants":"まっ最中/真っ最中/真最中"},"真っ最中":{"variants":"まっ最中/真っ最中/真最中"},"真最中":{"variants":"まっ最中/真っ最中/真最中"},"まっ青":{"variants":"まっ青/真っ青/真青"},"真っ青":{"variants":"まっ青/真っ青/真青"},"真青":{"variants":"まっ青/真っ青/真青"},"真っ逆さま":{"variants":"真っ逆さま/真逆様"},"真逆様":{"variants":"真っ逆さま/真逆様"},"真っ盛り":{"variants":"真っ盛り/真盛り"},"真盛り":{"variants":"真っ盛り/真盛り"},"真っ先":{"variants":"真っ先/真先"},"真先":{"variants":"真っ先/真先"},"まっさきに":{"variants":"まっさきに/まっ先に"},"まっ先に":{"variants":"まっさきに/まっ先に"},"末しょう":{"variants":"末しょう/末梢"},"末梢":{"variants":"末しょう/末梢"},"まっ白":{"variants":"まっ白/真っ白/真白"},"真白":{"variants":"まっ白/真っ白/真白"},"真っ白":{"variants":"まっ白/真っ白/真白"},"まっしろい":{"variants":"まっしろい/真っ白い/真白い"},"真っ白い":{"variants":"まっしろい/真っ白い/真白い"},"真白い":{"variants":"まっしろい/真っ白い/真白い"},"真っ直ぐ":{"variants":"まっすぐ/真っ直ぐ/真直/真直ぐ"},"真直ぐ":{"variants":"まっすぐ/真っ直ぐ/真直/真直ぐ"},"まっすぐ":{"variants":"まっすぐ/真っ直ぐ/真直/真直ぐ"},"真直":{"variants":"まっすぐ/真っ直ぐ/真直/真直ぐ"},"まったく":{"variants":"まったく/全く"},"全く":{"variants":"まったく/全く"},"まっただなか":{"variants":"まっただなか/まっただ中/真っ直中/真只中/真直中"},"まっただ中":{"variants":"まっただなか/まっただ中/真っ直中/真只中/真直中"},"真っ直中":{"variants":"まっただなか/まっただ中/真っ直中/真直中"},"真直中":{"variants":"まっただなか/まっただ中/真っ直中/真直中"},"真っ当":{"variants":"真っ当/真当"},"真当":{"variants":"真っ当/真当"},"まっとうする":{"variants":"まっとうする/全うする"},"全うする":{"variants":"まっとうする/全うする"},"真っ裸":{"variants":"真っ裸/真裸"},"真裸":{"variants":"真っ裸/真裸"},"まっぴら":{"variants":"まっぴら/真っ平/真平"},"真っ平":{"variants":"まっぴら/真っ平/真平"},"真平":{"variants":"まっぴら/真っ平/真平"},"真っ昼間":{"variants":"真っ昼間/真昼間"},"真昼間":{"variants":"真っ昼間/真昼間"},"まつ":{"variants":"まつ/待つ"},"待つ":{"variants":"まつ/待つ"},"マツ":{"variants":"マツ/松"},"松":{"variants":"マツ/松"},"末えい":{"variants":"末えい/末裔"},"末裔":{"variants":"末えい/末裔"},"松飾":{"variants":"松飾/松飾り"},"松飾り":{"variants":"松飾/松飾り"},"まつ毛":{"variants":"まつ毛/睫毛"},"睫毛":{"variants":"まつ毛/睫毛"},"マツゼミ":{"variants":"マツゼミ/松蝉"},"松蝉":{"variants":"マツゼミ/松蝉"},"マツタケ":{"variants":"マツタケ/松たけ/松茸"},"松たけ":{"variants":"マツタケ/松たけ/松茸"},"松茸":{"variants":"マツタケ/松たけ/松茸"},"マツバ":{"variants":"マツバ/松葉"},"松葉":{"variants":"マツバ/松葉"},"マツバギク":{"variants":"マツバギク/松葉菊"},"松葉菊":{"variants":"マツバギク/松葉菊"},"松葉づえ":{"variants":"松葉づえ/松葉杖"},"松葉杖":{"variants":"松葉づえ/松葉杖"},"マツバボタン":{"variants":"マツバボタン/松葉牡丹"},"松葉牡丹":{"variants":"マツバボタン/松葉牡丹"},"マツムシ":{"variants":"マツムシ/松虫"},"松虫":{"variants":"マツムシ/松虫"},"松やに":{"variants":"松やに/松脂"},"松脂":{"variants":"松やに/松脂"},"まつり":{"variants":"まつり/祭/祭り/祀り"},"祭":{"variants":"まつり/祭/祭り"},"祭り":{"variants":"まつり/祭/祭り"},"まつりあげる":{"variants":"まつりあげる/祭り上げる"},"祭り上げる":{"variants":"まつりあげる/祭り上げる"},"まつる":{"variants":"まつる/祭る/祀る"},"まつれる":{"variants":"まつれる/祭れる"},"祭れる":{"variants":"まつれる/祭れる"},"まつわる":{"variants":"まつわる/纏わる"},"纏わる":{"variants":"まつわる/纏わる"},"マテガイ":{"variants":"マテガイ/馬刀貝"},"馬刀貝":{"variants":"マテガイ/馬刀貝"},"まてる":{"variants":"まてる/待てる"},"待てる":{"variants":"まてる/待てる"},"まで":{"variants":"まで/迄"},"迄":{"variants":"まで/迄"},"マト":{"variants":"マト/的"},"的":{"variants":"マト/的"},"まとう":{"variants":"まとう/纏う"},"纏う":{"variants":"まとう/纏う"},"まとえる":{"variants":"まとえる/纏える"},"纏える":{"variants":"まとえる/纏える"},"的はずれ":{"variants":"的はずれ/的外れ"},"的外れ":{"variants":"的はずれ/的外れ"},"まとまる":{"variants":"まとまる/纏まる"},"纏まる":{"variants":"まとまる/纏まる"},"まとめる":{"variants":"まとめる/纏める"},"纏める":{"variants":"まとめる/纏める"},"まとも":{"variants":"まとも/マトモ"},"マトモ":{"variants":"まとも/マトモ"},"まどう":{"variants":"まどう/惑う"},"惑う":{"variants":"まどう/惑う"},"まどおい":{"variants":"まどおい/間遠い"},"間遠い":{"variants":"まどおい/間遠い"},"窓ぎわ":{"variants":"窓ぎわ/窓際"},"窓際":{"variants":"窓ぎわ/窓際"},"窓べ":{"variants":"窓べ/窓辺"},"窓辺":{"variants":"窓べ/窓辺"},"まどろむ":{"variants":"まどろむ/微睡む"},"微睡む":{"variants":"まどろむ/微睡む"},"まどわす":{"variants":"まどわす/惑わす"},"惑わす":{"variants":"まどわす/惑わす"},"まないた":{"variants":"まないた/まな板/俎/俎板"},"俎板":{"variants":"まないた/まな板/俎板"},"まな板":{"variants":"まないた/まな板/俎板"},"マナガツオ":{"variants":"マナガツオ/真魚鰹"},"真魚鰹":{"variants":"マナガツオ/真魚鰹"},"まなざし":{"variants":"まなざし/眼差し"},"眼差し":{"variants":"まなざし/眼差し"},"マナヅル":{"variants":"マナヅル/真鶴/真名鶴"},"まな弟子":{"variants":"まな弟子/愛弟子"},"愛弟子":{"variants":"まな弟子/愛弟子"},"まなびとる":{"variants":"まなびとる/学びとる/学び取る"},"学びとる":{"variants":"まなびとる/学びとる/学び取る"},"学び取る":{"variants":"まなびとる/学びとる/学び取る"},"まなびとれる":{"variants":"まなびとれる/学びとれる/学び取れる"},"学びとれる":{"variants":"まなびとれる/学びとれる/学び取れる"},"学び取れる":{"variants":"まなびとれる/学びとれる/学び取れる"},"学びや":{"variants":"学びや/学び舎"},"学び舎":{"variants":"学びや/学び舎"},"まなぶ":{"variants":"まなぶ/学ぶ/學ぶ"},"まなべる":{"variants":"まなべる/学べる"},"学べる":{"variants":"まなべる/学べる"},"まにあう":{"variants":"まにあう/間にあう/間に合う"},"間にあう":{"variants":"まにあう/間にあう/間に合う"},"間に合う":{"variants":"まにあう/間にあう/間に合う"},"間にあわせ":{"variants":"間にあわせ/間に合せ"},"間に合せ":{"variants":"間にあわせ/間に合せ"},"マニラあさ":{"variants":"マニラあさ/マニラアサ/マニラ麻"},"マニラアサ":{"variants":"マニラあさ/マニラアサ/マニラ麻"},"マニラ麻":{"variants":"マニラあさ/マニラアサ/マニラ麻"},"まね":{"variants":"まね/真似"},"真似":{"variants":"まね/真似"},"まねきいれる":{"variants":"まねきいれる/招き入れる"},"招き入れる":{"variants":"まねきいれる/招き入れる"},"まねき猫":{"variants":"まねき猫/招きねこ/招き猫"},"招きねこ":{"variants":"まねき猫/招きねこ/招き猫"},"招き猫":{"variants":"まねき猫/招きねこ/招き猫"},"まねく":{"variants":"まねく/招く"},"招く":{"variants":"まねく/招く"},"まねごと":{"variants":"まねごと/真似事"},"真似事":{"variants":"まねごと/真似事"},"まねる":{"variants":"まねる/真似る"},"真似る":{"variants":"まねる/真似る"},"まのあたり":{"variants":"まのあたり/目の当たり"},"目の当たり":{"variants":"目のあたり/目の当たり/目の当り"},"目のあたり":{"variants":"目のあたり/目の当たり/目の当り"},"目の当り":{"variants":"目のあたり/目の当たり/目の当り"},"まばゆい":{"variants":"まばゆい/目映い/眩い"},"マヒ":{"variants":"マヒ/麻痺"},"麻痺":{"variants":"マヒ/麻痺"},"間引":{"variants":"間引/間引き"},"間引き":{"variants":"間引/間引き"},"まびく":{"variants":"まびく/間引く"},"間引く":{"variants":"まびく/間引く"},"まびける":{"variants":"まびける/間引ける"},"間引ける":{"variants":"まびける/間引ける"},"まぶしい":{"variants":"まぶしい/眩しい"},"眩しい":{"variants":"まぶしい/眩しい"},"まぶた":{"variants":"まぶた/瞼"},"瞼":{"variants":"まぶた/瞼"},"魔法つかい":{"variants":"魔法つかい/魔法使/魔法使い"},"魔法使":{"variants":"魔法つかい/魔法使/魔法使い"},"魔法使い":{"variants":"魔法つかい/魔法使/魔法使い"},"魔法びん":{"variants":"魔法びん/魔法瓶"},"魔法瓶":{"variants":"魔法びん/魔法瓶"},"まま":{"variants":"まま/ママ/侭"},"間々":{"variants":"まま/間々/間間"},"間間":{"variants":"まま/間々/間間"},"ママ":{"variants":"まま/ママ/侭"},"侭":{"variants":"まま/ママ/侭"},"ままごと":{"variants":"ままごと/飯事"},"飯事":{"variants":"ままごと/飯事"},"まましい":{"variants":"まましい/継しい"},"継しい":{"variants":"まましい/継しい"},"マミ":{"variants":"マミ/魔魅/目見/猯"},"真向い":{"variants":"真向い/真向かい"},"真向かい":{"variants":"真向い/真向かい"},"マムシ":{"variants":"マムシ/蝮"},"蝮":{"variants":"マムシ/蝮"},"まめ":{"variants":"まめ/マメ/豆/肉刺"},"マメ":{"variants":"まめ/マメ/豆/肉刺"},"豆しぼり":{"variants":"豆しぼり/豆絞り"},"豆絞り":{"variants":"豆しぼり/豆絞り"},"まもなく":{"variants":"まもなく/間もなく"},"間もなく":{"variants":"まもなく/間もなく"},"守り神":{"variants":"守り神/守神"},"守神":{"variants":"守り神/守神"},"守り本尊":{"variants":"守り本尊/守本尊"},"守本尊":{"variants":"守り本尊/守本尊"},"まもる":{"variants":"まもる/護る/守る"},"まもれる":{"variants":"まもれる/護れる/守れる"},"まゆ":{"variants":"まゆ/眉/繭"},"まゆ毛":{"variants":"まゆ毛/マユ毛/眉毛"},"マユ毛":{"variants":"まゆ毛/マユ毛/眉毛"},"眉毛":{"variants":"まゆ毛/マユ毛/眉毛"},"眉唾もの":{"variants":"眉唾もの/眉唾物"},"眉唾物":{"variants":"眉唾もの/眉唾物"},"まよいこむ":{"variants":"まよいこむ/迷い込む"},"迷い込む":{"variants":"まよいこむ/迷い込む"},"まよう":{"variants":"まよう/迷う"},"迷う":{"variants":"まよう/迷う"},"魔よけ":{"variants":"魔よけ/魔除"},"魔除":{"variants":"魔よけ/魔除"},"まよわす":{"variants":"まよわす/迷わす"},"迷わす":{"variants":"まよわす/迷わす"},"マリモ":{"variants":"マリモ/毬藻"},"毬藻":{"variants":"マリモ/毬藻"},"マル":{"variants":"マル/丸"},"丸":{"variants":"マル/丸"},"まるい":{"variants":"まるい/円い/丸い"},"まるごと":{"variants":"まるごと/丸ごと"},"丸ごと":{"variants":"まるごと/丸ごと"},"丸だし":{"variants":"丸だし/丸出し"},"丸出し":{"variants":"丸だし/丸出し"},"マルチ・メディア":{"variants":"マルチ・メディア/マルチメディア"},"マルチメディア":{"variants":"マルチ・メディア/マルチメディア"},"まるっこい":{"variants":"まるっこい/丸っこい"},"丸っこい":{"variants":"まるっこい/丸っこい"},"丸つぶれ":{"variants":"丸つぶれ/丸潰れ"},"丸潰れ":{"variants":"丸つぶれ/丸潰れ"},"丸ぼうず":{"variants":"丸ぼうず/丸坊主"},"丸坊主":{"variants":"丸ぼうず/丸坊主"},"丸ぼし":{"variants":"丸ぼし/丸干"},"丸干":{"variants":"丸ぼし/丸干"},"まるぽちゃ":{"variants":"まるぽちゃ/丸ぽちゃ"},"丸ぽちゃ":{"variants":"まるぽちゃ/丸ぽちゃ"},"丸まげ":{"variants":"丸まげ/丸髷"},"丸髷":{"variants":"丸まげ/丸髷"},"まるまる":{"variants":"まるまる/丸々"},"丸まる":{"variants":"まるまる/丸まる"},"丸々":{"variants":"まるまる/丸々"},"まるめこむ":{"variants":"まるめこむ/まるめ込む/丸めこむ/丸め込む"},"まるめ込む":{"variants":"まるめこむ/まるめ込む/丸めこむ/丸め込む"},"丸めこむ":{"variants":"まるめこむ/まるめ込む/丸めこむ/丸め込む"},"丸め込む":{"variants":"まるめこむ/まるめ込む/丸めこむ/丸め込む"},"まるめる":{"variants":"まるめる/丸める"},"丸める":{"variants":"まるめる/丸める"},"まれ":{"variants":"まれ/希/稀"},"まろやか":{"variants":"まろやか/円やか"},"円やか":{"variants":"まろやか/円やか"},"まわし者":{"variants":"まわし者/回し者"},"回し者":{"variants":"まわし者/回し者"},"まわす":{"variants":"まわす/回す/廻す"},"まわせる":{"variants":"まわせる/回せる/廻せる"},"まわり":{"variants":"まわり/回り"},"回り":{"variants":"まわり/回り"},"まわりくどい":{"variants":"まわりくどい/回りくどい"},"回りくどい":{"variants":"まわりくどい/回りくどい"},"まわりこむ":{"variants":"まわりこむ/回り込む"},"回り込む":{"variants":"まわりこむ/回り込む"},"まわりこめる":{"variants":"まわりこめる/回り込める"},"回り込める":{"variants":"まわりこめる/回り込める"},"まわり灯篭":{"variants":"まわり灯篭/回り灯篭/回灯篭"},"回り灯篭":{"variants":"まわり灯篭/回り灯篭/回灯篭"},"回灯篭":{"variants":"まわり灯篭/回り灯篭/回灯篭"},"まわりどおい":{"variants":"まわりどおい/まわり遠い/回り遠い/回遠い"},"まわり遠い":{"variants":"まわりどおい/まわり遠い/回り遠い/回遠い"},"回り遠い":{"variants":"まわりどおい/まわり遠い/回り遠い/回遠い"},"回遠い":{"variants":"まわりどおい/まわり遠い/回り遠い/回遠い"},"まわり道":{"variants":"まわり道/回り道"},"回り道":{"variants":"まわり道/回り道"},"まわり路":{"variants":"まわり路/回り路"},"回り路":{"variants":"まわり路/回り路"},"まわる":{"variants":"まわる/回る"},"回る":{"variants":"まわる/回る"},"まわれる":{"variants":"まわれる/回れる/廻れる"},"まん延":{"variants":"まん延/蔓延"},"蔓延":{"variants":"まん延/蔓延"},"まんが":{"variants":"まんが/マンガ/漫画"},"マンガ":{"variants":"まんが/マンガ/漫画"},"漫画":{"variants":"まんが/マンガ/漫画"},"マンガン":{"variants":"マンガン/万巻/満款/満貫/満願"},"まん月":{"variants":"まん月/満月"},"満月":{"variants":"まん月/満月"},"マンサク":{"variants":"マンサク/万作/満作"},"まんざら":{"variants":"まんざら/満更"},"満更":{"variants":"まんざら/満更"},"まんじ巴":{"variants":"まんじ巴/卍巴"},"卍巴":{"variants":"まんじ巴/卍巴"},"まんじゅう":{"variants":"まんじゅう/饅頭"},"饅頭":{"variants":"まんじゅう/饅頭"},"マンジュシャゲ":{"variants":"マンジュシャゲ/曼珠沙華"},"曼珠沙華":{"variants":"マンジュシャゲ/曼珠沙華"},"まんずる":{"variants":"まんずる/慢ずる"},"慢ずる":{"variants":"まんずる/慢ずる"},"まん然":{"variants":"まん然/漫然"},"漫然":{"variants":"まん然/漫然"},"マントひひ":{"variants":"マントひひ/マントヒヒ/マント狒々/マント狒狒"},"マントヒヒ":{"variants":"マントひひ/マントヒヒ/マント狒々/マント狒狒"},"マント狒々":{"variants":"マントひひ/マントヒヒ/マント狒々/マント狒狒"},"マント狒狒":{"variants":"マントひひ/マントヒヒ/マント狒々/マント狒狒"},"まんなか":{"variants":"まんなか/まん中/真ん中/真ン中/真中"},"まん中":{"variants":"まんなか/まん中/真ん中/真ン中/真中"},"真ん中":{"variants":"まんなか/まん中/真ん中/真ン中/真中"},"真ン中":{"variants":"まんなか/まん中/真ん中/真ン中/真中"},"真中":{"variants":"まんなか/まん中/真ん中/真ン中/真中"},"満ぱい":{"variants":"満ぱい/満杯"},"満杯":{"variants":"満ぱい/満杯"},"まんべんなく":{"variants":"まんべんなく/満遍なく"},"満遍なく":{"variants":"まんべんなく/満遍なく"},"まんぼう":{"variants":"まんぼう/マンボウ"},"マンボウ":{"variants":"まんぼう/マンボウ"},"真ん前":{"variants":"真ん前/真前"},"真前":{"variants":"真ん前/真前"},"まん丸":{"variants":"まん丸/真ん丸/真丸"},"真丸":{"variants":"まん丸/真ん丸/真丸"},"真ん丸":{"variants":"まん丸/真ん丸/真丸"},"満満":{"variants":"満々/満満"},"満々":{"variants":"満々/満満"},"漫々":{"variants":"漫々/漫漫"},"漫漫":{"variants":"漫々/漫漫"},"万々一":{"variants":"万々一/万万一"},"万万一":{"variants":"万々一/万万一"},"マンリョウ":{"variants":"マンリョウ/万両"},"万両":{"variants":"マンリョウ/万両"},"み":{"variants":"み/未"},"未":{"variants":"み/未"},"みあう":{"variants":"みあう/見合う"},"見合う":{"variants":"みあう/見合う"},"みあきる":{"variants":"みあきる/見飽きる"},"見飽きる":{"variants":"みあきる/見飽きる"},"みあげる":{"variants":"みあげる/見上げる"},"見上げる":{"variants":"みあげる/見上げる"},"みあたる":{"variants":"みあたる/見あたる/見当たる/見当る"},"見あたる":{"variants":"みあたる/見あたる/見当たる/見当る"},"見当たる":{"variants":"みあたる/見あたる/見当たる/見当る"},"見当る":{"variants":"みあたる/見あたる/見当たる/見当る"},"みあらわす":{"variants":"みあらわす/見顕す"},"見顕す":{"variants":"みあらわす/見顕す"},"みあわす":{"variants":"みあわす/見合わす"},"見合わす":{"variants":"みあわす/見合わす"},"みあわせる":{"variants":"みあわせる/見合せる/見合わせる"},"見合せる":{"variants":"みあわせる/見合せる/見合わせる"},"見合わせる":{"variants":"みあわせる/見合せる/見合わせる"},"みいだす":{"variants":"みいだす/見いだす/見い出す/見出す"},"見いだす":{"variants":"みいだす/見いだす/見い出す/見出す"},"見い出す":{"variants":"みいだす/見いだす/見い出す/見出す"},"見出す":{"variants":"みいだす/見いだす/見い出す/見出す"},"みいだせる":{"variants":"みいだせる/見いだせる"},"見いだせる":{"variants":"みいだせる/見いだせる"},"ミイラ":{"variants":"ミイラ/木乃伊"},"木乃伊":{"variants":"ミイラ/木乃伊"},"みいる":{"variants":"みいる/見入る/魅入る"},"身うけ":{"variants":"身うけ/身受け/身請け"},"みうける":{"variants":"みうける/見受ける"},"見受ける":{"variants":"みうける/見受ける"},"みうしなう":{"variants":"みうしなう/見失う"},"見失う":{"variants":"みうしなう/見失う"},"見え":{"variants":"見え/見栄"},"見栄":{"variants":"見え/見栄"},"見えかくれ":{"variants":"見えかくれ/見え隠れ"},"見え隠れ":{"variants":"見えかくれ/見え隠れ"},"みえすく":{"variants":"みえすく/見えすく/見え透く"},"見えすく":{"variants":"みえすく/見えすく/見え透く"},"見え透く":{"variants":"みえすく/見えすく/見え透く"},"見えっぱり":{"variants":"見えっぱり/見栄っぱり/見栄っ張り/見栄張り"},"見栄っぱり":{"variants":"見えっぱり/見栄っぱり/見栄っ張り/見栄張り"},"見栄っ張り":{"variants":"見えっぱり/見栄っぱり/見栄っ張り/見栄張り"},"見栄張り":{"variants":"見えっぱり/見栄っぱり/見栄っ張り/見栄張り"},"みえみえ":{"variants":"みえみえ/ミエミエ"},"ミエミエ":{"variants":"みえみえ/ミエミエ"},"みおくる":{"variants":"みおくる/見送る"},"見送る":{"variants":"みおくる/見送る"},"みおくれる":{"variants":"みおくれる/見送れる"},"見送れる":{"variants":"みおくれる/見送れる"},"澪つくし":{"variants":"澪つくし/澪標"},"澪標":{"variants":"澪つくし/澪標"},"みおとす":{"variants":"みおとす/見落す/見落とす"},"見落す":{"variants":"みおとす/見落す/見落とす"},"見落とす":{"variants":"みおとす/見落す/見落とす"},"みおろす":{"variants":"みおろす/見おろす/見下ろす"},"見おろす":{"variants":"みおろす/見おろす/見下ろす"},"見下ろす":{"variants":"みおろす/見おろす/見下ろす"},"みおろせる":{"variants":"みおろせる/見おろせる"},"見おろせる":{"variants":"みおろせる/見おろせる"},"みかえす":{"variants":"みかえす/見返す"},"見返す":{"variants":"みかえす/見返す"},"みかえせる":{"variants":"みかえせる/見返せる"},"見返せる":{"variants":"みかえせる/見返せる"},"みかえる":{"variants":"みかえる/見返る"},"見返る":{"variants":"みかえる/見返る"},"みかぎる":{"variants":"みかぎる/見限る"},"見限る":{"variants":"みかぎる/見限る"},"見かけ":{"variants":"見かけ/見掛け"},"見掛け":{"variants":"見かけ/見掛け"},"見掛けだおし":{"variants":"見掛けだおし/見掛け倒し"},"見掛け倒し":{"variants":"見掛けだおし/見掛け倒し"},"みかける":{"variants":"みかける/見かける/見掛ける"},"見かける":{"variants":"みかける/見かける/見掛ける"},"見掛ける":{"variants":"みかける/見かける/見掛ける"},"みかげ石":{"variants":"みかげ石/御影石"},"御影石":{"variants":"みかげ石/御影石"},"みかねる":{"variants":"みかねる/見かねる/見兼ねる"},"見かねる":{"variants":"みかねる/見かねる/見兼ねる"},"見兼ねる":{"variants":"みかねる/見かねる/見兼ねる"},"みかわす":{"variants":"みかわす/見交す/見交わす"},"見交す":{"variants":"みかわす/見交す/見交わす"},"見交わす":{"variants":"みかわす/見交す/見交わす"},"ミカン":{"variants":"ミカン/未刊/未完/蜜柑"},"ミカンイロ":{"variants":"ミカンイロ/蜜柑色"},"蜜柑色":{"variants":"ミカンイロ/蜜柑色"},"みがき粉":{"variants":"みがき粉/磨き粉/磨粉"},"磨き粉":{"variants":"みがき粉/磨き粉/磨粉"},"磨粉":{"variants":"みがき粉/磨き粉/磨粉"},"みがきこむ":{"variants":"みがきこむ/磨き込む"},"磨き込む":{"variants":"みがきこむ/磨き込む"},"身欠きにしん":{"variants":"身欠きにしん/身欠き鰊/身欠鰊"},"身欠き鰊":{"variants":"身欠きにしん/身欠き鰊/身欠鰊"},"身欠鰊":{"variants":"身欠きにしん/身欠き鰊/身欠鰊"},"みがく":{"variants":"みがく/研く/磨く"},"みがける":{"variants":"みがける/研ける/磨ける"},"みがまえる":{"variants":"みがまえる/身構える"},"身構える":{"variants":"みがまえる/身構える"},"身代り":{"variants":"身代り/身代わり"},"身代わり":{"variants":"身代り/身代わり"},"みきる":{"variants":"みきる/見切る"},"見切る":{"variants":"みきる/見切る"},"みきれる":{"variants":"みきれる/見切れる"},"見切れる":{"variants":"みきれる/見切れる"},"みきわめる":{"variants":"みきわめる/見きわめる/見極める"},"見きわめる":{"variants":"みきわめる/見きわめる/見極める"},"見極める":{"variants":"みきわめる/見きわめる/見極める"},"みぎ":{"variants":"みぎ/右"},"右":{"variants":"みぎ/右"},"身ぎれい":{"variants":"身ぎれい/身奇麗"},"身奇麗":{"variants":"身ぎれい/身奇麗"},"みくだす":{"variants":"みくだす/見下す"},"見下す":{"variants":"みくだす/見下す"},"みくだせる":{"variants":"みくだせる/見下せる"},"見下せる":{"variants":"みくだせる/見下せる"},"みくびる":{"variants":"みくびる/見くびる/見縊る"},"見くびる":{"variants":"みくびる/見くびる/見縊る"},"見縊る":{"variants":"みくびる/見くびる/見縊る"},"みくらべる":{"variants":"みくらべる/見比べる"},"見比べる":{"variants":"みくらべる/見比べる"},"みぐるしい":{"variants":"みぐるしい/見苦しい"},"見苦しい":{"variants":"みぐるしい/見苦しい"},"みこす":{"variants":"みこす/見越す"},"見越す":{"variants":"みこす/見越す"},"みこせる":{"variants":"みこせる/見越せる"},"見越せる":{"variants":"みこせる/見越せる"},"見込":{"variants":"見込/見込み"},"見込み":{"variants":"見込/見込み"},"みこむ":{"variants":"みこむ/見込む"},"見込む":{"variants":"みこむ/見込む"},"みこめる":{"variants":"みこめる/見込める"},"見込める":{"variants":"みこめる/見込める"},"見ごたえ":{"variants":"見ごたえ/見応え"},"見応え":{"variants":"見ごたえ/見応え"},"みごと":{"variants":"みごと/見事"},"見事":{"variants":"みごと/見事"},"みごもる":{"variants":"みごもる/身ごもる/身篭る"},"身ごもる":{"variants":"みごもる/身ごもる/身篭る"},"身篭る":{"variants":"みごもる/身ごもる/身篭る"},"身ごろ":{"variants":"身ごろ/身頃"},"身頃":{"variants":"身ごろ/身頃"},"ミサ":{"variants":"ミサ/彌撒"},"彌撒":{"variants":"ミサ/彌撒"},"みさげる":{"variants":"みさげる/見下げる"},"見下げる":{"variants":"みさげる/見下げる"},"ミサゴ":{"variants":"ミサゴ"},"みさだめる":{"variants":"みさだめる/見定める"},"見定める":{"variants":"みさだめる/見定める"},"ミショウ":{"variants":"ミショウ/実生/未詳/未生"},"みしる":{"variants":"みしる/見知る"},"見知る":{"variants":"みしる/見知る"},"みじかい":{"variants":"みじかい/短い"},"短い":{"variants":"みじかい/短い"},"短め":{"variants":"短め/短目"},"短目":{"variants":"短め/短目"},"身じたく":{"variants":"身じたく/身支度"},"身支度":{"variants":"身じたく/身支度"},"みじめ":{"variants":"みじめ/惨め"},"惨め":{"variants":"みじめ/惨め"},"みじろぐ":{"variants":"みじろぐ/身じろぐ"},"身じろぐ":{"variants":"みじろぐ/身じろぐ"},"みじん":{"variants":"みじん/ミジン/微塵"},"ミジン":{"variants":"みじん/ミジン/微塵"},"微塵":{"variants":"みじん/ミジン/微塵"},"ミジンコ":{"variants":"ミジンコ/微塵子/微塵粉"},"みすえる":{"variants":"みすえる/見すえる/見据える"},"見すえる":{"variants":"みすえる/見すえる/見据える"},"見据える":{"variants":"みすえる/見すえる/見据える"},"みすかす":{"variants":"みすかす/見すかす/見透かす"},"見すかす":{"variants":"みすかす/見すかす/見透かす"},"見透かす":{"variants":"みすかす/見すかす/見透かす"},"みすかせる":{"variants":"みすかせる/見すかせる/見透かせる"},"見すかせる":{"variants":"みすかせる/見すかせる/見透かせる"},"見透かせる":{"variants":"みすかせる/見すかせる/見透かせる"},"みすごす":{"variants":"みすごす/見過ごす/見過す"},"見過ごす":{"variants":"みすごす/見過ごす/見過す"},"見過す":{"variants":"みすごす/見過ごす/見過す"},"みすごせる":{"variants":"みすごせる/見過ごせる"},"見過ごせる":{"variants":"みすごせる/見過ごせる"},"みすてる":{"variants":"みすてる/見棄てる/見捨てる"},"みすます":{"variants":"みすます/見澄ます"},"見澄ます":{"variants":"みすます/見澄ます"},"みすみす":{"variants":"みすみす/見すみす/見す見す"},"見すみす":{"variants":"みすみす/見すみす/見す見す"},"見す見す":{"variants":"みすみす/見すみす/見す見す"},"みする":{"variants":"みする/魅する"},"魅する":{"variants":"みする/魅する"},"水あか":{"variants":"水あか/水垢"},"水垢":{"variants":"水あか/水垢"},"水あげ":{"variants":"水あげ/水揚げ"},"水揚げ":{"variants":"水あげ/水揚げ"},"水あたり":{"variants":"水あたり/水中り"},"水中り":{"variants":"水あたり/水中り"},"水あめ":{"variants":"水あめ/水飴"},"水飴":{"variants":"水あめ/水飴"},"水掛け論":{"variants":"水掛け論/水掛論"},"水掛論":{"variants":"水掛け論/水掛論"},"水かさ":{"variants":"水かさ/水嵩"},"水嵩":{"variants":"水かさ/水嵩"},"水がめ":{"variants":"水がめ/水ガメ/水瓶/水甕"},"水ガメ":{"variants":"水がめ/水ガメ/水瓶/水甕"},"ミズキ":{"variants":"ミズキ/水木"},"水木":{"variants":"ミズキ/水木"},"水きり":{"variants":"水きり/水切り"},"水切り":{"variants":"水きり/水切り"},"水ぎわ":{"variants":"水ぎわ/水際"},"水際":{"variants":"水ぎわ/水際"},"みずぎわだつ":{"variants":"みずぎわだつ/水際立つ"},"水際立つ":{"variants":"みずぎわだつ/水際立つ"},"みずくさい":{"variants":"みずくさい/水臭い"},"水臭い":{"variants":"みずくさい/水臭い"},"水け":{"variants":"水け/水気"},"水気":{"variants":"水け/水気"},"ミズゴケ":{"variants":"ミズゴケ/水ごけ/水蘚"},"水ごけ":{"variants":"ミズゴケ/水ごけ/水蘚"},"水蘚":{"variants":"ミズゴケ/水ごけ/水蘚"},"水差":{"variants":"水差/水差し"},"水差し":{"variants":"水差/水差し"},"ミズスマシ":{"variants":"ミズスマシ/水すまし/水澄し"},"水すまし":{"variants":"ミズスマシ/水すまし/水澄し"},"水澄し":{"variants":"ミズスマシ/水すまし/水澄し"},"水たき":{"variants":"水たき/水炊/水炊き"},"水炊":{"variants":"水たき/水炊/水炊き"},"水炊き":{"variants":"水たき/水炊/水炊き"},"水たまり":{"variants":"水たまり/水溜まり"},"水溜まり":{"variants":"水たまり/水溜まり"},"水っぱな":{"variants":"水っぱな/水っ洟"},"水っ洟":{"variants":"水っぱな/水っ洟"},"みずっぽい":{"variants":"みずっぽい/水っぽい"},"水っぽい":{"variants":"みずっぽい/水っぽい"},"ミズナ":{"variants":"ミズナ/水菜"},"水菜":{"variants":"ミズナ/水菜"},"水呑み百姓":{"variants":"水呑み百姓/水呑百姓"},"水飲百姓":{"variants":"水飲み百姓/水飲百姓"},"水飲み百姓":{"variants":"水飲み百姓/水飲百姓"},"水呑百姓":{"variants":"水呑み百姓/水呑百姓"},"水はけ":{"variants":"水はけ/水捌け"},"水捌け":{"variants":"水はけ/水捌け"},"ミズバショウ":{"variants":"ミズバショウ/水芭蕉"},"水芭蕉":{"variants":"ミズバショウ/水芭蕉"},"水ばな":{"variants":"水ばな/水洟"},"水洟":{"variants":"水ばな/水洟"},"ミズヒキ":{"variants":"ミズヒキ/水引"},"水引":{"variants":"ミズヒキ/水引"},"水びたし":{"variants":"水びたし/水浸し"},"水浸し":{"variants":"水びたし/水浸し"},"水ぶろ":{"variants":"水ぶろ/水風呂"},"水風呂":{"variants":"水ぶろ/水風呂"},"みず穂":{"variants":"みず穂/瑞穂"},"瑞穂":{"variants":"みず穂/瑞穂"},"水ぼうそう":{"variants":"水ぼうそう/水疱瘡"},"水疱瘡":{"variants":"水ぼうそう/水疱瘡"},"水まくら":{"variants":"水まくら/水枕"},"水枕":{"variants":"水まくら/水枕"},"みずみずしい":{"variants":"みずみずしい/瑞々しい/瑞瑞しい"},"瑞々しい":{"variants":"みずみずしい/瑞々しい/瑞瑞しい"},"瑞瑞しい":{"variants":"みずみずしい/瑞々しい/瑞瑞しい"},"ミズムシ":{"variants":"ミズムシ/水虫"},"水虫":{"variants":"ミズムシ/水虫"},"水もの":{"variants":"水もの/水物"},"水物":{"variants":"水もの/水物"},"水割":{"variants":"水割/水割り"},"水割り":{"variants":"水割/水割り"},"見せかけ":{"variants":"見せかけ/見せ掛け"},"見せ掛け":{"variants":"見せかけ/見せ掛け"},"みせかける":{"variants":"みせかける/見せかける/見せ掛ける"},"見せかける":{"variants":"みせかける/見せかける/見せ掛ける"},"見せ掛ける":{"variants":"みせかける/見せかける/見せ掛ける"},"店構":{"variants":"店構/店構え"},"店構え":{"variants":"店構/店構え"},"店仕舞":{"variants":"店仕舞/店仕舞い"},"店仕舞い":{"variants":"店仕舞/店仕舞い"},"みせつける":{"variants":"みせつける/見せつける/見せ付ける"},"見せつける":{"variants":"みせつける/見せつける/見せ付ける"},"見せ付ける":{"variants":"みせつける/見せつける/見せ付ける"},"みせびらかす":{"variants":"みせびらかす/見せびらかす"},"見せびらかす":{"variants":"みせびらかす/見せびらかす"},"見せ物":{"variants":"見せ物/見世物"},"見世物":{"variants":"見せ物/見世物"},"みせる":{"variants":"みせる/見せる/魅せる"},"みそ":{"variants":"みそ/ミソ/味噌"},"ミソ":{"variants":"みそ/ミソ/味噌"},"味噌":{"variants":"みそ/ミソ/味噌"},"みそこなう":{"variants":"みそこなう/見そこなう/見損なう"},"見そこなう":{"variants":"みそこなう/見そこなう/見損なう"},"見損なう":{"variants":"みそこなう/見そこなう/見損なう"},"ミソサザイ":{"variants":"ミソサザイ/鷦鷯"},"鷦鷯":{"variants":"ミソサザイ/鷦鷯"},"みそ汁":{"variants":"みそ汁/味噌汁"},"味噌汁":{"variants":"みそ汁/味噌汁"},"みそすり坊主":{"variants":"みそすり坊主/味噌擂り坊主"},"味噌擂り坊主":{"variants":"みそすり坊主/味噌擂り坊主"},"味噌っかす":{"variants":"味噌っかす/味噌っ滓"},"味噌っ滓":{"variants":"味噌っかす/味噌っ滓"},"みそっ歯":{"variants":"みそっ歯/味噌っ歯/味噌歯"},"味噌っ歯":{"variants":"みそっ歯/味噌っ歯/味噌歯"},"味噌歯":{"variants":"みそっ歯/味噌っ歯/味噌歯"},"ミソハギ":{"variants":"ミソハギ/溝萩/千屈菜"},"みそめる":{"variants":"みそめる/見初める"},"見初める":{"variants":"みそめる/見初める"},"みそれる":{"variants":"みそれる/見逸れる"},"見逸れる":{"variants":"みそれる/見逸れる"},"みたす":{"variants":"みたす/充たす/満たす"},"みたせる":{"variants":"みたせる/満たせる"},"満たせる":{"variants":"みたせる/満たせる"},"見立":{"variants":"見立/見立て"},"見立て":{"variants":"見立/見立て"},"みたてる":{"variants":"みたてる/見立てる"},"見立てる":{"variants":"みたてる/見立てる"},"身だしなみ":{"variants":"身だしなみ/身嗜み"},"身嗜み":{"variants":"身だしなみ/身嗜み"},"みだす":{"variants":"みだす/乱す"},"乱す":{"variants":"みだす/乱す"},"みだせる":{"variants":"みだせる/見出せる/乱せる"},"みだら":{"variants":"みだら/淫ら"},"淫ら":{"variants":"みだら/淫ら"},"みだりがわしい":{"variants":"みだりがわしい/猥りがわしい"},"猥りがわしい":{"variants":"みだりがわしい/猥りがわしい"},"みだれとぶ":{"variants":"みだれとぶ/乱れ飛ぶ"},"乱れ飛ぶ":{"variants":"みだれとぶ/乱れ飛ぶ"},"みだれる":{"variants":"みだれる/乱れる"},"乱れる":{"variants":"みだれる/乱れる"},"みち":{"variants":"みち/道/未知/路"},"ミチオシエ":{"variants":"ミチオシエ/道教え"},"道教え":{"variants":"ミチオシエ/道教え"},"みちがえる":{"variants":"みちがえる/見違える"},"見違える":{"variants":"みちがえる/見違える"},"ミチシルベ":{"variants":"ミチシルベ/道しるべ"},"道しるべ":{"variants":"ミチシルベ/道しるべ"},"みちすがら":{"variants":"みちすがら/道すがら"},"道すがら":{"variants":"みちすがら/道すがら"},"道すじ":{"variants":"道すじ/道筋"},"道筋":{"variants":"道すじ/道筋"},"みちたりる":{"variants":"みちたりる/満ち足りる"},"満ち足りる":{"variants":"みちたりる/満ち足りる"},"道づれ":{"variants":"道づれ/道連れ"},"道連れ":{"variants":"道づれ/道連れ"},"道ばた":{"variants":"道ばた/道端"},"道端":{"variants":"道ばた/道端"},"みちびきだす":{"variants":"みちびきだす/導き出す"},"導き出す":{"variants":"みちびきだす/導き出す"},"みちびきだせる":{"variants":"みちびきだせる/導き出せる"},"導き出せる":{"variants":"みちびきだせる/導き出せる"},"みちびく":{"variants":"みちびく/導く"},"導く":{"variants":"みちびく/導く"},"みちびける":{"variants":"みちびける/導ける"},"導ける":{"variants":"みちびける/導ける"},"みちみち":{"variants":"みちみち/道道"},"道道":{"variants":"みちみち/道道"},"道行":{"variants":"道行/道行き"},"道行き":{"variants":"道行/道行き"},"みちゆく":{"variants":"みちゆく/道行く"},"道行く":{"variants":"みちゆく/道行く"},"みちる":{"variants":"みちる/盈ちる/充ちる/満ちる"},"３つ":{"variants":"３つ/三つ"},"三つ":{"variants":"３つ/三つ"},"みつ":{"variants":"みつ/密/蜜"},"みつかる":{"variants":"みつかる/見つかる/見付かる"},"見つかる":{"variants":"みつかる/見つかる/見付かる"},"見付かる":{"variants":"みつかる/見つかる/見付かる"},"みつくろう":{"variants":"みつくろう/見繕う"},"見繕う":{"variants":"みつくろう/見繕う"},"みつぐ":{"variants":"みつぐ/貢ぐ"},"貢ぐ":{"variants":"みつぐ/貢ぐ"},"三つ組":{"variants":"三つ組/三組"},"三組":{"variants":"三つ組/三組"},"見付":{"variants":"見付/見付け"},"見付け":{"variants":"見付/見付け"},"みつけだす":{"variants":"みつけだす/見つけだす/見つけ出す"},"見つけだす":{"variants":"みつけだす/見つけだす/見つけ出す"},"見つけ出す":{"variants":"みつけだす/見つけだす/見つけ出す"},"みつけだせる":{"variants":"みつけだせる/見つけ出せる"},"見つけ出せる":{"variants":"みつけだせる/見つけ出せる"},"みつける":{"variants":"みつける/見つける/見付ける"},"見つける":{"variants":"みつける/見つける/見付ける"},"見付ける":{"variants":"みつける/見つける/見付ける"},"みつ月":{"variants":"みつ月/蜜月"},"蜜月":{"variants":"みつ月/蜜月"},"みつげる":{"variants":"みつげる/貢げる"},"貢げる":{"variants":"みつげる/貢げる"},"三つ子":{"variants":"三つ子/三子"},"三子":{"variants":"三つ子/三子"},"ミツスイ":{"variants":"ミツスイ/蜜吸"},"蜜吸":{"variants":"ミツスイ/蜜吸"},"三つ揃い":{"variants":"三つ揃い/三揃い"},"三揃い":{"variants":"三つ揃い/三揃い"},"三つどもえ":{"variants":"三つどもえ/三つ巴/三巴"},"三つ巴":{"variants":"三つどもえ/三つ巴/三巴"},"三巴":{"variants":"三つどもえ/三つ巴/三巴"},"ミツバ":{"variants":"ミツバ/三つ葉/三葉"},"三つ葉":{"variants":"ミツバ/三つ葉/三葉"},"三葉":{"variants":"ミツバ/三つ葉/三葉"},"ミツバチ":{"variants":"ミツバチ/蜜蜂"},"蜜蜂":{"variants":"ミツバチ/蜜蜂"},"ミツマタ":{"variants":"ミツマタ/三つ又/三椏"},"みつみつ":{"variants":"みつみつ/密密"},"密密":{"variants":"みつみつ/密密"},"みつめる":{"variants":"みつめる/見つめる/見詰める"},"見つめる":{"variants":"みつめる/見つめる/見詰める"},"見詰める":{"variants":"みつめる/見つめる/見詰める"},"見積もり":{"variants":"見積もり/見積り"},"見積り":{"variants":"見積もり/見積り"},"みつもる":{"variants":"みつもる/見積もる/見積る"},"見積もる":{"variants":"みつもる/見積もる/見積る"},"見積る":{"variants":"みつもる/見積もる/見積る"},"みつもれる":{"variants":"みつもれる/見積もれる"},"見積もれる":{"variants":"みつもれる/見積もれる"},"三つ指":{"variants":"三つ指/三指"},"三指":{"variants":"三つ指/三指"},"みてとる":{"variants":"みてとる/見て取る"},"見て取る":{"variants":"みてとる/見て取る"},"みてとれる":{"variants":"みてとれる/見て取れる"},"見て取れる":{"variants":"みてとれる/見て取れる"},"みとおす":{"variants":"みとおす/見通す/見透す"},"みとおせる":{"variants":"みとおせる/見通せる/見透せる"},"みとどける":{"variants":"みとどける/見届ける"},"見届ける":{"variants":"みとどける/見届ける"},"認め印":{"variants":"認め印/認印"},"認印":{"variants":"認め印/認印"},"見取り算":{"variants":"見取り算/見取算"},"見取算":{"variants":"見取り算/見取算"},"見取り図":{"variants":"見取り図/見取図"},"見取図":{"variants":"見取り図/見取図"},"みとる":{"variants":"みとる/看取る/見取る"},"みとれる":{"variants":"みとれる/看取れる/見とれる/見蕩れる"},"見蕩れる":{"variants":"みとれる/見とれる/見蕩れる"},"見とれる":{"variants":"みとれる/見とれる/見蕩れる"},"みどころ":{"variants":"みどころ/見どころ/見処/見所"},"見どころ":{"variants":"みどころ/見どころ/見処/見所"},"みなおす":{"variants":"みなおす/見直す"},"見直す":{"variants":"みなおす/見直す"},"みなおせる":{"variants":"みなおせる/見直せる"},"見直せる":{"variants":"みなおせる/見直せる"},"みなぎる":{"variants":"みなぎる/漲る"},"漲る":{"variants":"みなぎる/漲る"},"皆さま":{"variants":"皆さま/皆様"},"皆様":{"variants":"皆さま/皆様"},"みなす":{"variants":"みなす/看做す/見なす/見倣す"},"見倣す":{"variants":"みなす/見なす/見倣す"},"見なす":{"variants":"みなす/見なす/見倣す"},"みなせる":{"variants":"みなせる/見なせる"},"見なせる":{"variants":"みなせる/見なせる"},"みなみ":{"variants":"みなみ/ミナミ/南"},"ミナミ":{"variants":"みなみ/ミナミ/南"},"南":{"variants":"みなみ/ミナミ/南"},"見習":{"variants":"見習/見習い"},"見習い":{"variants":"見習/見習い"},"みならう":{"variants":"みならう/見習う/見倣う"},"身なり":{"variants":"身なり/身形"},"身形":{"variants":"身なり/身形"},"みなれる":{"variants":"みなれる/見なれる/見慣れる/見馴れる"},"見なれる":{"variants":"みなれる/見なれる/見慣れる/見馴れる"},"みにくい":{"variants":"みにくい/見にくい/見憎い/醜い"},"見憎い":{"variants":"みにくい/見にくい/見憎い"},"見にくい":{"variants":"みにくい/見にくい/見憎い"},"みぬく":{"variants":"みぬく/見抜く"},"見抜く":{"variants":"みぬく/見抜く"},"みぬける":{"variants":"みぬける/見抜ける"},"見抜ける":{"variants":"みぬける/見抜ける"},"みねうち":{"variants":"みねうち/みね打ち/峰打ち"},"みね打ち":{"variants":"みねうち/みね打ち/峰打ち"},"峰打ち":{"variants":"みねうち/みね打ち/峰打ち"},"みのがす":{"variants":"みのがす/見のがす/見逃す"},"見のがす":{"variants":"みのがす/見のがす/見逃す"},"見逃す":{"variants":"みのがす/見のがす/見逃す"},"みのがせる":{"variants":"みのがせる/見逃せる"},"見逃せる":{"variants":"みのがせる/見逃せる"},"ミノガメ":{"variants":"ミノガメ/蓑龜"},"蓑龜":{"variants":"ミノガメ/蓑龜"},"身の代金":{"variants":"身の代金/身代金"},"身代金":{"variants":"身の代金/身代金"},"身のほど":{"variants":"身のほど/身の程"},"身の程":{"variants":"身のほど/身の程"},"ミノムシ":{"variants":"ミノムシ/蓑虫"},"蓑虫":{"variants":"ミノムシ/蓑虫"},"みのる":{"variants":"みのる/実る/稔る"},"みはからう":{"variants":"みはからう/見計らう"},"見計らう":{"variants":"みはからう/見計らう"},"みはからえる":{"variants":"みはからえる/見計らえる"},"見計らえる":{"variants":"みはからえる/見計らえる"},"みはなす":{"variants":"みはなす/見放す/見離す"},"みはらす":{"variants":"みはらす/見晴らす"},"見晴らす":{"variants":"みはらす/見晴らす"},"みはらせる":{"variants":"みはらせる/見晴らせる"},"見晴らせる":{"variants":"みはらせる/見晴らせる"},"みはる":{"variants":"みはる/見張る"},"見張る":{"variants":"みはる/見張る"},"みはるかす":{"variants":"みはるかす/見晴かす/見霽かす"},"みはれる":{"variants":"みはれる/見張れる"},"見張れる":{"variants":"みはれる/見張れる"},"見ばえ":{"variants":"見ばえ/見栄え"},"見栄え":{"variants":"見ばえ/見栄え"},"みひらく":{"variants":"みひらく/見開く"},"見開く":{"variants":"みひらく/見開く"},"身びいき":{"variants":"身びいき/身贔屓"},"身贔屓":{"variants":"身びいき/身贔屓"},"身振り":{"variants":"身ぶり/身振り"},"身ぶり":{"variants":"身ぶり/身振り"},"みほれる":{"variants":"みほれる/見ほれる/見惚れる"},"見ほれる":{"variants":"みほれる/見ほれる/見惚れる"},"見惚れる":{"variants":"みほれる/見ほれる/見惚れる"},"見舞":{"variants":"見舞/見舞い"},"見舞い":{"variants":"見舞/見舞い"},"みまう":{"variants":"みまう/見舞う"},"見舞う":{"variants":"みまう/見舞う"},"みまかる":{"variants":"みまかる/身罷る"},"身罷る":{"variants":"みまかる/身罷る"},"みまがう":{"variants":"みまがう/見まがう/見粉う/見紛う"},"見まがう":{"variants":"みまがう/見まがう/見粉う/見紛う"},"みまもる":{"variants":"みまもる/見守る"},"見守る":{"variants":"みまもる/見守る"},"みまもれる":{"variants":"みまもれる/見守れる"},"見守れる":{"variants":"みまもれる/見守れる"},"みまわす":{"variants":"みまわす/見回す/見廻す"},"みまわせる":{"variants":"みまわせる/見回せる"},"見回せる":{"variants":"みまわせる/見回せる"},"みまわる":{"variants":"みまわる/見回る/見廻る"},"みまわれる":{"variants":"みまわれる/見回れる"},"見回れる":{"variants":"みまわれる/見回れる"},"みみあたらしい":{"variants":"みみあたらしい/耳新しい"},"耳新しい":{"variants":"みみあたらしい/耳新しい"},"耳かき":{"variants":"耳かき/耳掻き"},"耳掻き":{"variants":"耳かき/耳掻き"},"みみざとい":{"variants":"みみざとい/耳聰い"},"耳聰い":{"variants":"みみざとい/耳聰い"},"耳ざわり":{"variants":"耳ざわり/耳障り/耳触り"},"ミミズ":{"variants":"ミミズ/蚯蚓"},"蚯蚓":{"variants":"ミミズ/蚯蚓"},"ミミズク":{"variants":"ミミズク/木菟"},"木菟":{"variants":"ミミズク/木菟"},"みみだつ":{"variants":"みみだつ/耳立つ"},"耳立つ":{"variants":"みみだつ/耳立つ"},"みみどおい":{"variants":"みみどおい/耳遠い"},"耳遠い":{"variants":"みみどおい/耳遠い"},"みみなれる":{"variants":"みみなれる/耳慣れる/耳馴れる"},"耳より":{"variants":"耳より/耳寄り"},"耳寄り":{"variants":"耳より/耳寄り"},"みむく":{"variants":"みむく/見向く"},"見向く":{"variants":"みむく/見向く"},"みめよい":{"variants":"みめよい/見目好い"},"見目好い":{"variants":"みめよい/見目好い"},"身もだえ":{"variants":"身もだえ/身悶え"},"身悶え":{"variants":"身もだえ/身悶え"},"みゃくうつ":{"variants":"みゃくうつ/脈打つ"},"脈打つ":{"variants":"みゃくうつ/脈打つ"},"脈々":{"variants":"脈々/脈脈"},"脈脈":{"variants":"脈々/脈脈"},"ミヤイリガイ":{"variants":"ミヤイリガイ/宮入貝"},"宮入貝":{"variants":"ミヤイリガイ/宮入貝"},"みやげ物":{"variants":"みやげ物/土産物"},"土産物":{"variants":"みやげ物/土産物"},"ミヤコドリ":{"variants":"ミヤコドリ/都鳥"},"都鳥":{"variants":"ミヤコドリ/都鳥"},"みやこ忘れ":{"variants":"みやこ忘れ/ミヤコワスレ/都忘れ"},"ミヤコワスレ":{"variants":"みやこ忘れ/ミヤコワスレ/都忘れ"},"都忘れ":{"variants":"みやこ忘れ/ミヤコワスレ/都忘れ"},"みやすい":{"variants":"みやすい/見易い"},"見易い":{"variants":"みやすい/見易い"},"雅びやか":{"variants":"雅びやか/雅やか"},"雅やか":{"variants":"雅びやか/雅やか"},"みやぶる":{"variants":"みやぶる/見破る"},"見破る":{"variants":"みやぶる/見破る"},"みやぶれる":{"variants":"みやぶれる/見破れる"},"見破れる":{"variants":"みやぶれる/見破れる"},"ミヤマキリシマ":{"variants":"ミヤマキリシマ/深山霧島"},"深山霧島":{"variants":"ミヤマキリシマ/深山霧島"},"みやる":{"variants":"みやる/見やる/見遣る"},"見やる":{"variants":"みやる/見やる/見遣る"},"見遣る":{"variants":"みやる/見やる/見遣る"},"Ｍｕｓｉｃ":{"variants":"Ｍｕｓｉｃ/ミュージック"},"ミュージック":{"variants":"Ｍｕｓｉｃ/ミュージック"},"ミョウガ":{"variants":"ミョウガ/冥加/茗荷"},"みょう字":{"variants":"みょう字/苗字/名字"},"みょうに":{"variants":"みょうに/妙に"},"妙に":{"variants":"みょうに/妙に"},"みょうばん":{"variants":"みょうばん/明礬"},"明礬":{"variants":"みょうばん/明礬"},"みょう利":{"variants":"みょう利/冥利/名利"},"みよい":{"variants":"みよい/見好い"},"見好い":{"variants":"みよい/見好い"},"みよし":{"variants":"みよし/三好"},"三好":{"variants":"みよし/三好"},"ｍＡ":{"variants":"ｍＡ/ミリアンペア"},"ミリアンペア":{"variants":"ｍＡ/ミリアンペア"},"ｍｇ":{"variants":"ｍｇ/ミリグラム"},"ミリグラム":{"variants":"ｍｇ/ミリグラム"},"ｍＶ":{"variants":"ｍＶ/ミリボルト"},"ミリボルト":{"variants":"ｍＶ/ミリボルト"},"ｍｍ":{"variants":"ｍｍ/ミリメートル/粍"},"ミリメートル":{"variants":"ｍｍ/ミリメートル/粍"},"粍":{"variants":"ｍｍ/ミリメートル/粍"},"ｍｌ":{"variants":"ｍｌ/ミリリットル"},"ミリリットル":{"variants":"ｍｌ/ミリリットル"},"ｍＷ":{"variants":"ｍＷ/ミリワット"},"ミリワット":{"variants":"ｍＷ/ミリワット"},"みりん":{"variants":"みりん/味醂"},"味醂":{"variants":"みりん/味醂"},"みる":{"variants":"みる/看る/観る/見る/視る/診る"},"ミル":{"variants":"ミル/海松/水松"},"みるみる間に":{"variants":"みるみる間に/見るみる間に/見る見る間に"},"見るみる間に":{"variants":"みるみる間に/見るみる間に/見る見る間に"},"見る見る間に":{"variants":"みるみる間に/見るみる間に/見る見る間に"},"みれる":{"variants":"みれる/見れる"},"見れる":{"variants":"みれる/見れる"},"みれんがましい":{"variants":"みれんがましい/未練がましい"},"未練がましい":{"variants":"みれんがましい/未練がましい"},"みろく":{"variants":"みろく/弥勒/彌勒"},"みわける":{"variants":"みわける/見分ける"},"見分ける":{"variants":"みわける/見分ける"},"みわたす":{"variants":"みわたす/見渡す"},"見渡す":{"variants":"みわたす/見渡す"},"みわたせる":{"variants":"みわたせる/見渡せる"},"見渡せる":{"variants":"みわたせる/見渡せる"},"みんな":{"variants":"みんな/皆んな"},"皆んな":{"variants":"みんな/皆んな"},"みんみん蝉":{"variants":"みんみん蝉/ミンミンゼミ"},"ミンミンゼミ":{"variants":"みんみん蝉/ミンミンゼミ"},"向かい":{"variants":"向い/向かい"},"向い":{"variants":"向い/向かい"},"むかいあう":{"variants":"むかいあう/向かいあう/向かい合う"},"向かいあう":{"variants":"むかいあう/向かいあう/向かい合う"},"向かい合う":{"variants":"むかいあう/向かいあう/向かい合う"},"むかいあえる":{"variants":"むかいあえる/向かい合える"},"向かい合える":{"variants":"むかいあえる/向かい合える"},"むかいあわす":{"variants":"むかいあわす/向かい合わす"},"向かい合わす":{"variants":"むかいあわす/向かい合わす"},"むかいあわせる":{"variants":"むかいあわせる/向かい合わせる"},"向かい合わせる":{"variants":"むかいあわせる/向かい合わせる"},"向い風":{"variants":"向い風/向かい風"},"向かい風":{"variants":"向い風/向かい風"},"むかう":{"variants":"むかう/向う/向かう"},"向う":{"variants":"向う/向こう"},"向かう":{"variants":"むかう/向う/向かう"},"むかえいれる":{"variants":"むかえいれる/迎え入れる"},"迎え入れる":{"variants":"むかえいれる/迎え入れる"},"むかえうつ":{"variants":"むかえうつ/迎え撃つ"},"迎え撃つ":{"variants":"むかえうつ/迎え撃つ"},"むかえる":{"variants":"むかえる/迎える/向かえる"},"むかし":{"variants":"むかし/昔"},"昔":{"variants":"むかし/昔"},"昔かたぎ":{"variants":"昔かたぎ/昔気質"},"昔気質":{"variants":"昔かたぎ/昔気質"},"昔なじみ":{"variants":"昔なじみ/昔馴染"},"昔馴染":{"variants":"昔なじみ/昔馴染"},"むかし話":{"variants":"むかし話/昔ばなし/昔話"},"昔ばなし":{"variants":"むかし話/昔ばなし/昔話"},"昔話":{"variants":"むかし話/昔ばなし/昔話"},"ムカデ":{"variants":"ムカデ/百足/蜈蚣"},"むき":{"variants":"むき/向き/無期/無機/無季"},"むきあう":{"variants":"むきあう/向き合う"},"向き合う":{"variants":"むきあう/向き合う"},"むきあえる":{"variants":"むきあえる/向き合える"},"向き合える":{"variants":"むきあえる/向き合える"},"むき出し":{"variants":"むき出し/剥き出し"},"剥き出し":{"variants":"むき出し/剥き出し"},"むきだす":{"variants":"むきだす/むき出す"},"むき出す":{"variants":"むきだす/むき出す"},"むきなおる":{"variants":"むきなおる/向き直る"},"向き直る":{"variants":"むきなおる/向き直る"},"むき身":{"variants":"むき身/剥き身"},"剥き身":{"variants":"むき身/剥き身"},"ムギ":{"variants":"ムギ/麦"},"麦":{"variants":"ムギ/麦"},"麦焦がし":{"variants":"麦焦がし/麦焦し"},"麦焦し":{"variants":"麦焦がし/麦焦し"},"麦めし":{"variants":"麦めし/麦飯"},"麦飯":{"variants":"麦めし/麦飯"},"麦わら":{"variants":"麦わら/麦ワラ/麦藁"},"麦ワラ":{"variants":"麦わら/麦ワラ/麦藁"},"麦藁":{"variants":"麦わら/麦ワラ/麦藁"},"ムギワラトンボ":{"variants":"ムギワラトンボ/麦藁蜻蛉"},"麦藁蜻蛉":{"variants":"ムギワラトンボ/麦藁蜻蛉"},"むく":{"variants":"むく/向く/剥く"},"ムク":{"variants":"ムク/無垢/椋"},"むくいる":{"variants":"むくいる/酬いる/報いる"},"むくう":{"variants":"むくう/報う"},"報う":{"variants":"むくう/報う"},"ムクゲ":{"variants":"むく毛/ムクゲ/木槿/尨毛"},"むく毛":{"variants":"むく毛/ムクゲ/尨毛"},"尨毛":{"variants":"むく毛/ムクゲ/尨毛"},"ムクドリ":{"variants":"ムクドリ/椋鳥"},"椋鳥":{"variants":"ムクドリ/椋鳥"},"むくの木":{"variants":"むくの木/ムクノキ/椋の木/椋木"},"ムクノキ":{"variants":"むくの木/ムクノキ/椋の木/椋木"},"椋の木":{"variants":"むくの木/ムクノキ/椋の木/椋木"},"椋木":{"variants":"むくの木/ムクノキ/椋の木/椋木"},"むくむ":{"variants":"むくむ/浮腫む"},"浮腫む":{"variants":"むくむ/浮腫む"},"ムクロジ":{"variants":"ムクロジ/無患子"},"無患子":{"variants":"ムクロジ/無患子"},"ムグラ":{"variants":"ムグラ/葎"},"葎":{"variants":"ムグラ/葎"},"むけなおす":{"variants":"むけなおす/向けなおす"},"向けなおす":{"variants":"むけなおす/向けなおす"},"むける":{"variants":"むける/向ける/剥ける"},"向こう":{"variants":"向う/向こう"},"向う岸":{"variants":"向う岸/向こう岸"},"向こう岸":{"variants":"向う岸/向こう岸"},"むこうずね":{"variants":"むこうずね/向う脛"},"向う脛":{"variants":"むこうずね/向う脛"},"むごい":{"variants":"むごい/惨い"},"惨い":{"variants":"むごい/惨い"},"むごたらしい":{"variants":"むごたらしい/惨たらしい"},"惨たらしい":{"variants":"むごたらしい/惨たらしい"},"むさぼる":{"variants":"むさぼる/貪る"},"貪る":{"variants":"むさぼる/貪る"},"むし":{"variants":"むし/虫/無死/無私"},"むしあつい":{"variants":"むしあつい/むし暑い/蒸し暑い/蒸暑い"},"むし暑い":{"variants":"むしあつい/むし暑い/蒸し暑い/蒸暑い"},"蒸し暑い":{"variants":"むしあつい/むし暑い/蒸し暑い/蒸暑い"},"蒸暑い":{"variants":"むしあつい/むし暑い/蒸し暑い/蒸暑い"},"むしかえす":{"variants":"むしかえす/むし返す/蒸し返す/蒸返す"},"むし返す":{"variants":"むしかえす/むし返す/蒸し返す/蒸返す"},"蒸し返す":{"variants":"むしかえす/むし返す/蒸し返す/蒸返す"},"蒸返す":{"variants":"むしかえす/むし返す/蒸し返す/蒸返す"},"ムシガレイ":{"variants":"ムシガレイ/虫鰈"},"虫鰈":{"variants":"ムシガレイ/虫鰈"},"蒸し器":{"variants":"蒸し器/蒸器"},"蒸器":{"variants":"蒸し器/蒸器"},"虫くい":{"variants":"虫くい/虫食い"},"虫食い":{"variants":"虫くい/虫食い"},"虫けら":{"variants":"虫けら/虫螻"},"虫螻":{"variants":"虫けら/虫螻"},"虫ず":{"variants":"虫ず/虫酸"},"虫酸":{"variants":"虫ず/虫酸"},"蒸しずし":{"variants":"蒸しずし/蒸し鮨/蒸寿司"},"蒸しなべ":{"variants":"蒸しなべ/蒸し鍋/蒸鍋"},"蒸し鍋":{"variants":"蒸しなべ/蒸し鍋/蒸鍋"},"蒸鍋":{"variants":"蒸しなべ/蒸し鍋/蒸鍋"},"むし歯":{"variants":"むし歯/虫歯"},"虫歯":{"variants":"むし歯/虫歯"},"むしばむ":{"variants":"むしばむ/蝕む"},"蝕む":{"variants":"むしばむ/蝕む"},"蒸しぶろ":{"variants":"蒸しぶろ/蒸し風呂/蒸風呂"},"蒸し風呂":{"variants":"蒸しぶろ/蒸し風呂/蒸風呂"},"蒸風呂":{"variants":"蒸しぶろ/蒸し風呂/蒸風呂"},"虫へん":{"variants":"虫へん/虫偏"},"虫偏":{"variants":"虫へん/虫偏"},"虫干":{"variants":"虫干/虫干し"},"虫干し":{"variants":"虫干/虫干し"},"虫めがね":{"variants":"虫めがね/虫眼鏡"},"虫眼鏡":{"variants":"虫めがね/虫眼鏡"},"蒸しもの":{"variants":"蒸しもの/蒸し物/蒸物"},"蒸し物":{"variants":"蒸しもの/蒸し物/蒸物"},"蒸物":{"variants":"蒸しもの/蒸し物/蒸物"},"蒸し焼き":{"variants":"蒸し焼き/蒸焼"},"蒸焼":{"variants":"蒸し焼き/蒸焼"},"むしょうに":{"variants":"むしょうに/無性に"},"無性に":{"variants":"むしょうに/無性に"},"むしる":{"variants":"むしる/ムシる/毟る"},"ムシる":{"variants":"むしる/ムシる/毟る"},"毟る":{"variants":"むしる/ムシる/毟る"},"むしろ":{"variants":"むしろ/筵/蓆"},"寧ろ":{"variants":"むしろ/寧ろ"},"ムジナ":{"variants":"ムジナ/狢/貉"},"むす":{"variants":"むす/産す"},"産す":{"variants":"むす/産す"},"むすびつく":{"variants":"むすびつく/結びつく/結び付く"},"結びつく":{"variants":"むすびつく/結びつく/結び付く"},"結び付く":{"variants":"むすびつく/結びつく/結び付く"},"むすびつける":{"variants":"むすびつける/結びつける/結び付ける"},"結びつける":{"variants":"むすびつける/結びつける/結び付ける"},"結び付ける":{"variants":"むすびつける/結びつける/結び付ける"},"むすぶ":{"variants":"むすぶ/掬ぶ/結ぶ"},"むすべる":{"variants":"むすべる/結べる"},"結べる":{"variants":"むすべる/結べる"},"むすぼれる":{"variants":"むすぼれる/結ぼれる"},"結ぼれる":{"variants":"むすぼれる/結ぼれる"},"むずかしい":{"variants":"むずかしい/難しい"},"難しい":{"variants":"むずかしい/難しい"},"むずがゆい":{"variants":"むずがゆい/むず痒い"},"むず痒い":{"variants":"むずがゆい/むず痒い"},"むずむず":{"variants":"むずむず/ムズムズ"},"ムズムズ":{"variants":"むずむず/ムズムズ"},"むせかえる":{"variants":"むせかえる/むせ返る/噎せ返る"},"むせ返る":{"variants":"むせかえる/むせ返る/噎せ返る"},"噎せ返る":{"variants":"むせかえる/むせ返る/噎せ返る"},"むせびなく":{"variants":"むせびなく/むせび泣く"},"むせび泣く":{"variants":"むせびなく/むせび泣く"},"むせぶ":{"variants":"むせぶ/咽ぶ/噎ぶ"},"むせる":{"variants":"むせる/蒸せる/噎せる"},"むぞうさ":{"variants":"むぞうさ/無造作"},"無造作":{"variants":"むぞうさ/無造作"},"ムダ":{"variants":"ムダ/無駄"},"無駄":{"variants":"ムダ/無駄"},"むだ話":{"variants":"むだ話/徒話"},"徒話":{"variants":"むだ話/徒話"},"ムチ":{"variants":"ムチ/鞭/無知/無恥"},"むちうち症":{"variants":"むちうち症/むち打ち症/鞭打ち症"},"むち打ち症":{"variants":"むちうち症/むち打ち症/鞭打ち症"},"鞭打ち症":{"variants":"むちうち症/むち打ち症/鞭打ち症"},"むちうつ":{"variants":"むちうつ/鞭打つ"},"鞭打つ":{"variants":"むちうつ/鞭打つ"},"６つ":{"variants":"６つ/六つ"},"六つ":{"variants":"６つ/六つ"},"むつ五郎":{"variants":"むつ五郎/ムツゴロウ"},"ムツゴロウ":{"variants":"むつ五郎/ムツゴロウ"},"むつまじい":{"variants":"むつまじい/睦まじい"},"睦まじい":{"variants":"むつまじい/睦まじい"},"むつむ":{"variants":"むつむ/睦む"},"睦む":{"variants":"むつむ/睦む"},"無届":{"variants":"無届/無届け"},"無届け":{"variants":"無届/無届け"},"胸ぐら":{"variants":"胸ぐら/胸倉"},"胸倉":{"variants":"胸ぐら/胸倉"},"むなぐるしい":{"variants":"むなぐるしい/胸苦しい"},"胸苦しい":{"variants":"むなぐるしい/胸苦しい"},"むなしい":{"variants":"むなしい/虚しい/空しい"},"胸突き八丁":{"variants":"胸突き八丁/胸突八丁"},"胸突八丁":{"variants":"胸突き八丁/胸突八丁"},"むね":{"variants":"むね/胸/旨"},"胸当":{"variants":"胸当/胸当て"},"胸当て":{"variants":"胸当/胸当て"},"むねと":{"variants":"むねと/宗と"},"宗と":{"variants":"むねと/宗と"},"むべ":{"variants":"むべ/宜"},"宜":{"variants":"むべ/宜"},"ムベ":{"variants":"ムベ/郁子"},"郁子":{"variants":"ムベ/郁子"},"むやみ":{"variants":"むやみ/無闇"},"無闇":{"variants":"むやみ/無闇"},"むら":{"variants":"むら/村"},"村":{"variants":"むら/村"},"むらがる":{"variants":"むらがる/群がる/叢る"},"ムラサキ":{"variants":"ムラサキ/紫"},"紫":{"variants":"ムラサキ/紫"},"紫いろ":{"variants":"紫いろ/紫色"},"紫色":{"variants":"紫いろ/紫色"},"ムラサキハシドイ":{"variants":"ムラサキハシドイ/紫丁香花"},"紫丁香花":{"variants":"ムラサキハシドイ/紫丁香花"},"むらす":{"variants":"むらす/蒸らす"},"蒸らす":{"variants":"むらす/蒸らす"},"村びと":{"variants":"村びと/村人"},"村人":{"variants":"村びと/村人"},"むら役":{"variants":"むら役/村役"},"村役":{"variants":"むら役/村役"},"むりやり":{"variants":"むりやり/無理やり/無理矢理"},"無理やり":{"variants":"無理やり/無理矢理"},"無理矢理":{"variants":"無理やり/無理矢理"},"むりょ":{"variants":"むりょ/無慮"},"無慮":{"variants":"むりょ/無慮"},"むれる":{"variants":"むれる/群れる/蒸れる"},"ムロアジ":{"variants":"ムロアジ/室鯵"},"室鯵":{"variants":"ムロアジ/室鯵"},"むろん":{"variants":"むろん/無論"},"無論":{"variants":"むろん/無論"},"むんむん":{"variants":"むんむん/ムンムン"},"ムンムン":{"variants":"むんむん/ムンムン"},"め":{"variants":"め/目"},"目":{"variants":"め/目"},"ｍ":{"variants":"ｍ/メートル/米"},"メートル":{"variants":"ｍ/メートル/米"},"米":{"variants":"ｍ/メートル/米"},"目明かし":{"variants":"目明かし/目明し"},"目明し":{"variants":"目明かし/目明し"},"めあたらしい":{"variants":"めあたらしい/目新しい"},"目新しい":{"variants":"めあたらしい/目新しい"},"目あて":{"variants":"目あて/目当て"},"目当て":{"variants":"目あて/目当て"},"めあわす":{"variants":"めあわす/娶す"},"娶す":{"variants":"めあわす/娶す"},"めあわせる":{"variants":"めあわせる/妻せる/娶せる"},"めい":{"variants":"めい/明/盟/銘/姪"},"めいうつ":{"variants":"めいうつ/銘打つ"},"銘打つ":{"variants":"めいうつ/銘打つ"},"めいじる":{"variants":"めいじる/命じる/銘じる"},"めいする":{"variants":"めいする/瞑する"},"瞑する":{"variants":"めいする/瞑する"},"めいずる":{"variants":"めいずる/命ずる/銘ずる"},"めいせき":{"variants":"めいせき/明せき/明晰"},"明せき":{"variants":"めいせき/明せき/明晰"},"明晰":{"variants":"めいせき/明せき/明晰"},"瞑想":{"variants":"めい想/瞑想"},"めい想":{"variants":"めい想/瞑想"},"メイド":{"variants":"メイド/冥途/冥土/明度"},"めい福":{"variants":"めい福/冥福"},"冥福":{"variants":"めい福/冥福"},"めいめい":{"variants":"めいめい/冥々/冥冥/銘々/銘銘"},"冥冥":{"variants":"めいめい/冥々/冥冥"},"冥々":{"variants":"めいめい/冥々/冥冥"},"銘々":{"variants":"めいめい/銘々/銘銘"},"銘銘":{"variants":"めいめい/銘々/銘銘"},"銘々皿":{"variants":"銘々皿/銘銘皿"},"銘銘皿":{"variants":"銘々皿/銘銘皿"},"めい目":{"variants":"めい目/瞑目"},"瞑目":{"variants":"めい目/瞑目"},"明りょう":{"variants":"明りょう/明瞭"},"明瞭":{"variants":"明りょう/明瞭"},"めいる":{"variants":"めいる/滅入る"},"滅入る":{"variants":"めいる/滅入る"},"めいわく":{"variants":"めいわく/迷惑"},"迷惑":{"variants":"めいわく/迷惑"},"Ｍ":{"variants":"Ｍ/メガ"},"メガ":{"variants":"Ｍ/メガ"},"めがける":{"variants":"めがける/目がける/目掛ける"},"目がける":{"variants":"めがける/目がける/目掛ける"},"目掛ける":{"variants":"めがける/目がける/目掛ける"},"めがね":{"variants":"めがね/メガネ/眼鏡"},"メガネ":{"variants":"めがね/メガネ/眼鏡"},"眼鏡":{"variants":"めがね/メガネ/眼鏡"},"メガネヘビ":{"variants":"メガネヘビ/眼鏡蛇"},"眼鏡蛇":{"variants":"メガネヘビ/眼鏡蛇"},"Ｍｂ":{"variants":"Ｍｂ/Ｍバイト/メガバイト"},"Ｍバイト":{"variants":"Ｍｂ/Ｍバイト/メガバイト"},"メガバイト":{"variants":"Ｍｂ/Ｍバイト/メガバイト"},"Ｍヘルツ":{"variants":"Ｍヘルツ/ｍｈｚ/メガヘルツ"},"ｍｈｚ":{"variants":"Ｍヘルツ/ｍｈｚ/メガヘルツ"},"メガヘルツ":{"variants":"Ｍヘルツ/ｍｈｚ/メガヘルツ"},"めキャベツ":{"variants":"めキャベツ/メキャベツ/芽キャベツ"},"メキャベツ":{"variants":"めキャベツ/メキャベツ/芽キャベツ"},"芽キャベツ":{"variants":"めキャベツ/メキャベツ/芽キャベツ"},"目くそ":{"variants":"目くそ/目糞/目屎"},"めくる":{"variants":"めくる/捲る"},"捲る":{"variants":"めくる/捲る"},"めぐまれる":{"variants":"めぐまれる/恵まれる"},"恵まれる":{"variants":"めぐまれる/恵まれる"},"めぐみ":{"variants":"めぐみ/恵み"},"恵み":{"variants":"めぐみ/恵み"},"めぐむ":{"variants":"めぐむ/芽ぐむ/恵む/萌む/恤む"},"めぐらす":{"variants":"めぐらす/廻らす/巡らす"},"めぐらせる":{"variants":"めぐらせる/巡らせる"},"巡らせる":{"variants":"めぐらせる/巡らせる"},"巡り合い":{"variants":"巡り合い/巡合い"},"巡合い":{"variants":"巡り合い/巡合い"},"めぐりあう":{"variants":"めぐりあう/巡り会う/巡り合う"},"めぐりあえる":{"variants":"めぐりあえる/巡り会える"},"巡り会える":{"variants":"めぐりあえる/巡り会える"},"めぐり合わせ":{"variants":"めぐり合わせ/廻り合せ/巡り合せ/巡合せ"},"巡合せ":{"variants":"めぐり合わせ/巡り合せ/巡合せ"},"巡り合せ":{"variants":"めぐり合わせ/巡り合せ/巡合せ"},"めぐる":{"variants":"めぐる/巡る"},"巡る":{"variants":"めぐる/巡る"},"めぐれる":{"variants":"めぐれる/巡れる"},"巡れる":{"variants":"めぐれる/巡れる"},"めざす":{"variants":"めざす/芽差す/目ざす/目差す/目指す"},"目指す":{"variants":"めざす/目ざす/目指す"},"目差す":{"variants":"めざす/目ざす/目差す"},"目ざす":{"variants":"めざす/目ざす/目差す/目指す"},"めざとい":{"variants":"めざとい/目ざとい/目敏い"},"目ざとい":{"variants":"めざとい/目ざとい/目敏い"},"目敏い":{"variants":"めざとい/目ざとい/目敏い"},"目ざまし":{"variants":"目ざまし/目覚し/目覚まし"},"目覚し":{"variants":"目ざまし/目覚し/目覚まし"},"目覚まし":{"variants":"目ざまし/目覚し/目覚まし"},"めざましい":{"variants":"めざましい/目ざましい/目覚しい/目覚ましい"},"目ざましい":{"variants":"めざましい/目ざましい/目覚しい/目覚ましい"},"目覚しい":{"variants":"めざましい/目ざましい/目覚しい/目覚ましい"},"目覚ましい":{"variants":"めざましい/目ざましい/目覚しい/目覚ましい"},"目ざめ":{"variants":"目ざめ/目覚め"},"目覚め":{"variants":"目ざめ/目覚め"},"めざめる":{"variants":"めざめる/目覚める"},"目覚める":{"variants":"めざめる/目覚める"},"目ざわり":{"variants":"目ざわり/目障り"},"目障り":{"variants":"目ざわり/目障り"},"めし":{"variants":"めし/飯"},"飯":{"variants":"めし/飯"},"めしあがる":{"variants":"めしあがる/召しあがる/召し上がる/召上がる"},"召しあがる":{"variants":"めしあがる/召しあがる/召し上がる/召上がる"},"召し上がる":{"variants":"めしあがる/召しあがる/召し上がる/召上がる"},"召上がる":{"variants":"めしあがる/召しあがる/召し上がる/召上がる"},"めしあがれる":{"variants":"めしあがれる/召し上がれる"},"召し上がれる":{"variants":"めしあがれる/召し上がれる"},"めしあげる":{"variants":"めしあげる/召しあげる/召し上げる"},"召しあげる":{"variants":"めしあげる/召しあげる/召し上げる"},"召し上げる":{"variants":"めしあげる/召しあげる/召し上げる"},"めしかかえる":{"variants":"めしかかえる/召しかかえる/召し抱える/召抱える"},"召しかかえる":{"variants":"めしかかえる/召しかかえる/召し抱える/召抱える"},"召し抱える":{"variants":"めしかかえる/召しかかえる/召し抱える/召抱える"},"召抱える":{"variants":"めしかかえる/召しかかえる/召し抱える/召抱える"},"めしぐす":{"variants":"めしぐす/召し具す"},"召し具す":{"variants":"めしぐす/召し具す"},"めしだす":{"variants":"めしだす/召し出す/召出す"},"召し出す":{"variants":"めしだす/召し出す/召出す"},"召出す":{"variants":"めしだす/召し出す/召出す"},"召使":{"variants":"召使/召使い"},"召使い":{"variants":"召使/召使い"},"めし粒":{"variants":"めし粒/飯粒"},"飯粒":{"variants":"めし粒/飯粒"},"めしとる":{"variants":"めしとる/召し捕る/召捕る"},"召し捕る":{"variants":"めしとる/召し捕る/召捕る"},"召捕る":{"variants":"めしとる/召し捕る/召捕る"},"飯びつ":{"variants":"飯びつ/飯櫃"},"飯櫃":{"variants":"飯びつ/飯櫃"},"メシベ":{"variants":"メシベ/雌しべ/雌蕊"},"雌しべ":{"variants":"メシベ/雌しべ/雌蕊"},"雌蕊":{"variants":"メシベ/雌しべ/雌蕊"},"めしよせる":{"variants":"めしよせる/召し寄せる/召寄せる"},"召し寄せる":{"variants":"めしよせる/召し寄せる/召寄せる"},"召寄せる":{"variants":"めしよせる/召し寄せる/召寄せる"},"メジ":{"variants":"メジ/眼路/目地/目路"},"めじ鮪":{"variants":"めじ鮪/メジマグロ"},"メジマグロ":{"variants":"めじ鮪/メジマグロ"},"目じり":{"variants":"目じり/目尻"},"目尻":{"variants":"目じり/目尻"},"メジロ":{"variants":"メジロ/目白"},"目白":{"variants":"メジロ/目白"},"めす":{"variants":"めす/召す"},"召す":{"variants":"めす/召す"},"メス":{"variants":"メス/雌/牝"},"めずらしい":{"variants":"めずらしい/珍しい"},"珍しい":{"variants":"めずらしい/珍しい"},"メダカ":{"variants":"メダカ/目高"},"目高":{"variants":"メダカ/目高"},"メダケ":{"variants":"メダケ/雌竹/女竹"},"めだつ":{"variants":"めだつ/芽立つ/目だつ/目立つ"},"目だつ":{"variants":"めだつ/目だつ/目立つ"},"目立つ":{"variants":"めだつ/目だつ/目立つ"},"めちゃくちゃ":{"variants":"めちゃくちゃ/滅茶苦茶/目茶苦茶"},"めちゃめちゃ":{"variants":"めちゃめちゃ/メチャメチャ/滅茶滅茶/滅茶目茶/目茶目茶"},"メチャメチャ":{"variants":"めちゃめちゃ/メチャメチャ/滅茶滅茶/滅茶目茶/目茶目茶"},"めっする":{"variants":"めっする/滅する"},"滅する":{"variants":"めっする/滅する"},"めった":{"variants":"めった/滅多"},"滅多":{"variants":"めった/滅多"},"めったに":{"variants":"めったに/滅多に"},"滅多に":{"variants":"めったに/滅多に"},"めっぽう":{"variants":"めっぽう/滅法"},"滅法":{"variants":"めっぽう/滅法"},"めっぽうかい":{"variants":"めっぽうかい/滅法界"},"滅法界":{"variants":"めっぽうかい/滅法界"},"目付":{"variants":"目付/目付け"},"目付け":{"variants":"目付/目付け"},"目つぶし":{"variants":"目つぶし/目潰し"},"目潰し":{"variants":"目つぶし/目潰し"},"めづらい":{"variants":"めづらい/愛づらい"},"愛づらい":{"variants":"めづらい/愛づらい"},"めでたい":{"variants":"めでたい/メデタい/目出度い"},"メデタい":{"variants":"めでたい/メデタい/目出度い"},"目出度い":{"variants":"めでたい/メデタい/目出度い"},"めでる":{"variants":"めでる/愛でる"},"愛でる":{"variants":"めでる/愛でる"},"めとる":{"variants":"めとる/娶る"},"娶る":{"variants":"めとる/娶る"},"めど":{"variants":"めど/メド/目処"},"メド":{"variants":"めど/メド/目処"},"目処":{"variants":"めど/メド/目処"},"メドギ":{"variants":"メドギ/蓍"},"蓍":{"variants":"メドギ/蓍"},"メドハギ":{"variants":"メドハギ/蓍萩"},"蓍萩":{"variants":"メドハギ/蓍萩"},"メナダ":{"variants":"メナダ/赤目魚"},"赤目魚":{"variants":"メナダ/赤目魚"},"めなれる":{"variants":"めなれる/目慣れる"},"目慣れる":{"variants":"めなれる/目慣れる"},"目のかたき":{"variants":"目のかたき/目の敵"},"目の敵":{"variants":"目のかたき/目の敵"},"芽ばえ":{"variants":"芽ばえ/芽生え"},"芽生え":{"variants":"芽ばえ/芽生え"},"めばえる":{"variants":"めばえる/芽生える"},"芽生える":{"variants":"めばえる/芽生える"},"メバナ":{"variants":"メバナ/雌花"},"雌花":{"variants":"メバナ/雌花"},"メバル":{"variants":"メバル/目張"},"目張":{"variants":"メバル/目張"},"めぶく":{"variants":"めぶく/芽吹く"},"芽吹く":{"variants":"めぶく/芽吹く"},"めまい":{"variants":"めまい/目まい/目眩"},"目まい":{"variants":"めまい/目まい/目眩"},"目眩":{"variants":"めまい/目まい/目眩"},"めまぐるしい":{"variants":"めまぐるしい/目まぐるしい"},"目まぐるしい":{"variants":"めまぐるしい/目まぐるしい"},"メマツ":{"variants":"メマツ/雌松"},"雌松":{"variants":"メマツ/雌松"},"めめしい":{"variants":"めめしい/女々しい/女女しい"},"女々しい":{"variants":"めめしい/女々しい/女女しい"},"女女しい":{"variants":"めめしい/女々しい/女女しい"},"メモリ":{"variants":"メモリ/目盛/目盛り"},"目盛":{"variants":"メモリ/目盛/目盛り"},"目盛り":{"variants":"メモリ/目盛/目盛り"},"めもる":{"variants":"めもる/目盛る"},"目盛る":{"variants":"めもる/目盛る"},"めやす":{"variants":"めやす/目安"},"目安":{"variants":"めやす/目安"},"目やに":{"variants":"目やに/目脂"},"目脂":{"variants":"目やに/目脂"},"めりこむ":{"variants":"めりこむ/めり込む/減り込む"},"めり込む":{"variants":"めりこむ/めり込む/減り込む"},"減り込む":{"variants":"めりこむ/めり込む/減り込む"},"メリハリ":{"variants":"メリハリ/減り張り"},"減り張り":{"variants":"メリハリ/減り張り"},"メリヤス":{"variants":"メリヤス/莫大小"},"莫大小":{"variants":"メリヤス/莫大小"},"めん":{"variants":"めん/メン/免/麺"},"メン":{"variants":"めん/メン/免/麺"},"めん食い":{"variants":"めん食い/面食い"},"面食い":{"variants":"めん食い/面食い"},"めんくらう":{"variants":"めんくらう/面食らう"},"面食らう":{"variants":"めんくらう/面食らう"},"めんじる":{"variants":"めんじる/免じる"},"免じる":{"variants":"めんじる/免じる"},"めんする":{"variants":"めんする/面する"},"面する":{"variants":"めんする/面する"},"めんずる":{"variants":"めんずる/免ずる"},"免ずる":{"variants":"めんずる/免ずる"},"メンタイ":{"variants":"メンタイ/明太"},"明太":{"variants":"メンタイ/明太"},"面とり":{"variants":"面とり/面取り"},"面取り":{"variants":"面とり/面取り"},"めんどう":{"variants":"めんどう/面倒"},"面倒":{"variants":"めんどう/面倒"},"めんどうい":{"variants":"めんどうい/面倒い"},"面倒い":{"variants":"めんどうい/面倒い"},"めんどうくさい":{"variants":"めんどうくさい/面倒くさい/面倒臭い"},"面倒くさい":{"variants":"めんどうくさい/面倒くさい/面倒臭い"},"面倒臭い":{"variants":"めんどうくさい/面倒くさい/面倒臭い"},"めん鳥":{"variants":"めん鳥/雌鳥"},"雌鳥":{"variants":"めん鳥/雌鳥"},"綿棒":{"variants":"めん棒/綿棒"},"麺棒":{"variants":"めん棒/麺棒"},"めん棒":{"variants":"めん棒/綿棒/麺棒"},"めんぼく":{"variants":"めんぼく/面目"},"面目":{"variants":"めんぼく/面目"},"面面":{"variants":"面々/面面"},"綿々":{"variants":"綿々/綿綿"},"面々":{"variants":"面々/面面"},"綿綿":{"variants":"綿々/綿綿"},"メンヨウ":{"variants":"メンヨウ/綿羊/緬羊/面妖/面容"},"めん類":{"variants":"めん類/麺類"},"麺類":{"variants":"めん類/麺類"},"モウオ":{"variants":"モウオ/藻魚"},"藻魚":{"variants":"モウオ/藻魚"},"もうかる":{"variants":"もうかる/儲かる"},"儲かる":{"variants":"もうかる/儲かる"},"猛きん":{"variants":"猛きん/猛禽"},"猛禽":{"variants":"猛きん/猛禽"},"もうけ":{"variants":"もうけ/設け/儲け"},"もうける":{"variants":"もうける/設ける/儲ける"},"もうこ":{"variants":"もうこ/猛虎"},"猛虎":{"variants":"もうこ/猛虎"},"もうしあげる":{"variants":"もうしあげる/申しあげる/申し上げる"},"申しあげる":{"variants":"もうしあげる/申しあげる/申し上げる"},"申し上げる":{"variants":"もうしあげる/申しあげる/申し上げる"},"もうしあわす":{"variants":"もうしあわす/申し合わす"},"申し合わす":{"variants":"もうしあわす/申し合わす"},"もうしあわせる":{"variants":"もうしあわせる/申しあわせる/申し合せる/申し合わせる"},"申しあわせる":{"variants":"もうしあわせる/申しあわせる/申し合せる/申し合わせる"},"申し合せる":{"variants":"もうしあわせる/申しあわせる/申し合せる/申し合わせる"},"申し合わせる":{"variants":"もうしあわせる/申しあわせる/申し合せる/申し合わせる"},"申し入れ":{"variants":"申し入れ/申入/申入れ"},"申入":{"variants":"申し入れ/申入/申入れ"},"申入れ":{"variants":"申し入れ/申入/申入れ"},"もうしいれる":{"variants":"もうしいれる/申し入れる"},"申し入れる":{"variants":"もうしいれる/申し入れる"},"もうしうける":{"variants":"もうしうける/申し受ける"},"申し受ける":{"variants":"もうしうける/申し受ける"},"もうしおくる":{"variants":"もうしおくる/申し送る/申送る"},"申し送る":{"variants":"もうしおくる/申し送る/申送る"},"申送る":{"variants":"もうしおくる/申し送る/申送る"},"もうしおくれる":{"variants":"もうしおくれる/申し送れる"},"申し送れる":{"variants":"もうしおくれる/申し送れる"},"もうしかねる":{"variants":"もうしかねる/申しかねる"},"申しかねる":{"variants":"もうしかねる/申しかねる"},"もうしきける":{"variants":"もうしきける/申し聞ける"},"申し聞ける":{"variants":"もうしきける/申し聞ける"},"もうしこす":{"variants":"もうしこす/申し越す/申越す"},"申し越す":{"variants":"もうしこす/申し越す/申越す"},"申越す":{"variants":"もうしこす/申し越す/申越す"},"申し込み":{"variants":"申し込み/申込"},"申込":{"variants":"申し込み/申込"},"もうしこむ":{"variants":"もうしこむ/申し込む/申込む"},"申し込む":{"variants":"もうしこむ/申し込む/申込む"},"申込む":{"variants":"もうしこむ/申し込む/申込む"},"もうしこめる":{"variants":"もうしこめる/申し込める"},"申し込める":{"variants":"もうしこめる/申し込める"},"申し立て":{"variants":"申し立て/申立"},"申立":{"variants":"申し立て/申立"},"もうしたてる":{"variants":"もうしたてる/申し立てる"},"申し立てる":{"variants":"もうしたてる/申し立てる"},"もうしつける":{"variants":"もうしつける/申しつける/申し付ける"},"申しつける":{"variants":"もうしつける/申しつける/申し付ける"},"申し付ける":{"variants":"もうしつける/申しつける/申し付ける"},"もうしつたえる":{"variants":"もうしつたえる/申し伝える"},"申し伝える":{"variants":"もうしつたえる/申し伝える"},"申し出る":{"variants":"もうしでる/申し出る/申出る"},"もうしでる":{"variants":"もうしでる/申し出る/申出る"},"申出る":{"variants":"もうしでる/申し出る/申出る"},"もうしのべる":{"variants":"もうしのべる/申し述べる"},"申し述べる":{"variants":"もうしのべる/申し述べる"},"もうしわけ":{"variants":"もうしわけ/申しわけ/申し訳/申訳"},"申しわけ":{"variants":"もうしわけ/申しわけ/申し訳/申訳"},"申し訳":{"variants":"もうしわけ/申しわけ/申し訳/申訳"},"申訳":{"variants":"もうしわけ/申しわけ/申し訳/申訳"},"もうしわたす":{"variants":"もうしわたす/申し渡す/申渡す"},"申し渡す":{"variants":"もうしわたす/申し渡す/申渡す"},"申渡す":{"variants":"もうしわたす/申し渡す/申渡す"},"もうす":{"variants":"もうす/申す"},"申す":{"variants":"もうす/申す"},"毛せん":{"variants":"毛せん/毛氈"},"毛氈":{"variants":"毛せん/毛氈"},"モウセンゴケ":{"variants":"モウセンゴケ/毛氈苔"},"毛氈苔":{"variants":"モウセンゴケ/毛氈苔"},"もうぜんと":{"variants":"もうぜんと/猛然と"},"猛然と":{"variants":"もうぜんと/猛然と"},"モウソウ":{"variants":"モウソウ/孟宗"},"孟宗":{"variants":"モウソウ/孟宗"},"もうでる":{"variants":"もうでる/詣でる"},"詣でる":{"variants":"もうでる/詣でる"},"もうとう":{"variants":"もうとう/毛頭"},"毛頭":{"variants":"もうとう/毛頭"},"濛濛":{"variants":"濛々/濛濛"},"朦朦":{"variants":"朦々/朦朦"},"朦々":{"variants":"朦々/朦朦"},"濛々":{"variants":"濛々/濛濛"},"もうろう":{"variants":"もうろう/孟浪/朦朧"},"もえあがる":{"variants":"もえあがる/燃え上がる"},"燃え上がる":{"variants":"もえあがる/燃え上がる"},"もえうつる":{"variants":"もえうつる/燃え移る"},"燃え移る":{"variants":"もえうつる/燃え移る"},"燃えがら":{"variants":"燃えがら/燃え殻"},"燃え殻":{"variants":"燃えがら/燃え殻"},"もえぎ色":{"variants":"もえぎ色/萌葱色"},"萌葱色":{"variants":"もえぎ色/萌葱色"},"もえさかる":{"variants":"もえさかる/燃えさかる/燃え盛る"},"燃えさかる":{"variants":"もえさかる/燃えさかる/燃え盛る"},"燃え盛る":{"variants":"もえさかる/燃えさかる/燃え盛る"},"もえたつ":{"variants":"もえたつ/燃えたつ/燃え立つ"},"燃えたつ":{"variants":"もえたつ/燃えたつ/燃え立つ"},"燃え立つ":{"variants":"もえたつ/燃えたつ/燃え立つ"},"もえつきる":{"variants":"もえつきる/燃えつきる/燃え尽きる"},"燃えつきる":{"variants":"もえつきる/燃えつきる/燃え尽きる"},"燃え尽きる":{"variants":"もえつきる/燃えつきる/燃え尽きる"},"もえつく":{"variants":"もえつく/燃えつく/燃え付く"},"燃えつく":{"variants":"もえつく/燃えつく/燃え付く"},"燃え付く":{"variants":"もえつく/燃えつく/燃え付く"},"もえでる":{"variants":"もえでる/萌え出る"},"萌え出る":{"variants":"もえでる/萌え出る"},"もえひろがる":{"variants":"もえひろがる/燃え広がる"},"燃え広がる":{"variants":"もえひろがる/燃え広がる"},"もえる":{"variants":"もえる/燃える/萌える"},"もぎとる":{"variants":"もぎとる/もぎ取る"},"もぎ取る":{"variants":"もぎとる/もぎ取る"},"もぎとれる":{"variants":"もぎとれる/もぎ取れる"},"もぎ取れる":{"variants":"もぎとれる/もぎ取れる"},"もくぎょ":{"variants":"もくぎょ/木魚"},"木魚":{"variants":"もくぎょ/木魚"},"もくする":{"variants":"もくする/黙する/目する"},"モクセイ":{"variants":"もく星/モクセイ/木犀/木星/木精/木製"},"木星":{"variants":"もく星/モクセイ/木星"},"もく星":{"variants":"もく星/モクセイ/木星"},"黙とう":{"variants":"黙とう/黙祷"},"黙祷":{"variants":"黙とう/黙祷"},"木ねじ":{"variants":"木ねじ/木捻子"},"木捻子":{"variants":"木ねじ/木捻子"},"黙々":{"variants":"黙々/黙黙"},"黙黙":{"variants":"黙々/黙黙"},"もくもくと":{"variants":"もくもくと/黙々と"},"黙々と":{"variants":"もくもくと/黙々と"},"もくらんじき":{"variants":"もくらんじき/木蘭色"},"木蘭色":{"variants":"もくらんじき/木蘭色"},"モクレン":{"variants":"モクレン/木蓮"},"木蓮":{"variants":"モクレン/木蓮"},"目論み":{"variants":"目論み/目論見"},"目論見":{"variants":"目論み/目論見"},"もくろむ":{"variants":"もくろむ/目論む"},"目論む":{"variants":"もくろむ/目論む"},"モグサ":{"variants":"モグサ/藻草"},"藻草":{"variants":"モグサ/藻草"},"もぐもぐ":{"variants":"もぐもぐ/モグモグ"},"モグモグ":{"variants":"もぐもぐ/モグモグ"},"もぐり":{"variants":"もぐり/潜り"},"潜り":{"variants":"もぐり/潜り"},"もぐりこむ":{"variants":"もぐりこむ/もぐり込む/潜り込む"},"もぐり込む":{"variants":"もぐりこむ/もぐり込む/潜り込む"},"潜り込む":{"variants":"もぐりこむ/もぐり込む/潜り込む"},"もぐりこめる":{"variants":"もぐりこめる/もぐり込める/潜り込める"},"もぐり込める":{"variants":"もぐりこめる/もぐり込める/潜り込める"},"潜り込める":{"variants":"もぐりこめる/もぐり込める/潜り込める"},"もごもご":{"variants":"もごもご/モゴモゴ"},"モゴモゴ":{"variants":"もごもご/モゴモゴ"},"もし":{"variants":"もし/若し"},"若し":{"variants":"もし/若し"},"もしくは":{"variants":"もしくは/若しくは"},"若しくは":{"variants":"もしくは/若しくは"},"もしもし":{"variants":"もしもし/モシモシ"},"モシモシ":{"variants":"もしもし/モシモシ"},"モジズリ":{"variants":"モジズリ/捩摺"},"捩摺":{"variants":"モジズリ/捩摺"},"もじもじ":{"variants":"もじもじ/モジモジ"},"モジモジ":{"variants":"もじもじ/モジモジ"},"もす":{"variants":"もす/燃す"},"燃す":{"variants":"もす/燃す"},"もすそ":{"variants":"もすそ/裳裾"},"裳裾":{"variants":"もすそ/裳裾"},"モズ":{"variants":"モズ/百舌/鵙"},"モズク":{"variants":"モズク/海蘊/水雲"},"もぞもぞ":{"variants":"もぞもぞ/モゾモゾ"},"モゾモゾ":{"variants":"もぞもぞ/モゾモゾ"},"もたげる":{"variants":"もたげる/擡げる"},"擡げる":{"variants":"もたげる/擡げる"},"もたす":{"variants":"もたす/持たす"},"持たす":{"variants":"もたす/持たす"},"もたせかける":{"variants":"もたせかける/もたせ掛ける/凭せかける/凭せ掛ける"},"もたせ掛ける":{"variants":"もたせかける/もたせ掛ける/凭せかける/凭せ掛ける"},"凭せかける":{"variants":"もたせかける/もたせ掛ける/凭せかける/凭せ掛ける"},"凭せ掛ける":{"variants":"もたせかける/もたせ掛ける/凭せかける/凭せ掛ける"},"もたもた":{"variants":"もたもた/モタモタ"},"モタモタ":{"variants":"もたもた/モタモタ"},"もたらす":{"variants":"もたらす/齎す"},"齎す":{"variants":"もたらす/齎す"},"もたれかかる":{"variants":"もたれかかる/もたれ掛かる"},"もたれ掛かる":{"variants":"もたれかかる/もたれ掛かる"},"もたれる":{"variants":"もたれる/凭れる/靠れる"},"もだえる":{"variants":"もだえる/悶える"},"悶える":{"variants":"もだえる/悶える"},"もだす":{"variants":"もだす/黙す"},"黙す":{"variants":"もだす/黙す"},"もち":{"variants":"もち/モチ/望/餅/糯/黐"},"モチ":{"variants":"もち/モチ/望/餅/糯/黐"},"もちあい":{"variants":"もちあい/持ち合い/持合い/保合い"},"持合い":{"variants":"もちあい/持ち合い/持合い"},"持ち合い":{"variants":"もちあい/持ち合い/持合い"},"もちあがる":{"variants":"もちあがる/持ち上がる"},"持ち上がる":{"variants":"もちあがる/持ち上がる"},"もちあげる":{"variants":"もちあげる/持ち上げる/持上げる"},"持ち上げる":{"variants":"もちあげる/持ち上げる/持上げる"},"持上げる":{"variants":"もちあげる/持ち上げる/持上げる"},"もち味":{"variants":"もち味/持ち味/持味"},"持ち味":{"variants":"もち味/持ち味/持味"},"持味":{"variants":"もち味/持ち味/持味"},"もちあるく":{"variants":"もちあるく/持ち歩く"},"持ち歩く":{"variants":"もちあるく/持ち歩く"},"もちあるける":{"variants":"もちあるける/持ち歩ける"},"持ち歩ける":{"variants":"もちあるける/持ち歩ける"},"もちあわす":{"variants":"もちあわす/持ち合わす"},"持ち合わす":{"variants":"もちあわす/持ち合わす"},"持ち合わせ":{"variants":"持ち合わせ/持合せ"},"持合せ":{"variants":"持ち合わせ/持合せ"},"もちあわせる":{"variants":"もちあわせる/持ち合わせる"},"持ち合わせる":{"variants":"もちあわせる/持ち合わせる"},"持ち家":{"variants":"持ち家/持家"},"持家":{"variants":"持ち家/持家"},"もちいる":{"variants":"もちいる/用いる"},"用いる":{"variants":"もちいる/用いる"},"もちかえる":{"variants":"もちかえる/持ちかえる/持ち帰る"},"持ちかえる":{"variants":"もちかえる/持ちかえる/持ち帰る"},"持ち帰る":{"variants":"もちかえる/持ちかえる/持ち帰る"},"もちかえれる":{"variants":"もちかえれる/持ちかえれる/持ち帰れる"},"持ちかえれる":{"variants":"もちかえれる/持ちかえれる/持ち帰れる"},"持ち帰れる":{"variants":"もちかえれる/持ちかえれる/持ち帰れる"},"もちかける":{"variants":"もちかける/持ちかける/持ち掛ける/持掛ける"},"持ちかける":{"variants":"もちかける/持ちかける/持ち掛ける/持掛ける"},"持ち掛ける":{"variants":"もちかける/持ちかける/持ち掛ける/持掛ける"},"持掛ける":{"variants":"もちかける/持ちかける/持ち掛ける/持掛ける"},"持ち株":{"variants":"持ち株/持株"},"持株":{"variants":"持ち株/持株"},"もち菓子":{"variants":"もち菓子/餅菓子"},"餅菓子":{"variants":"もち菓子/餅菓子"},"持ち切り":{"variants":"持ち切り/持切り"},"持切り":{"variants":"持ち切り/持切り"},"もちきる":{"variants":"もちきる/持ちきる/持ち切る/持切る"},"持ちきる":{"variants":"もちきる/持ちきる/持ち切る/持切る"},"持ち切る":{"variants":"もちきる/持ちきる/持ち切る/持切る"},"持切る":{"variants":"もちきる/持ちきる/持ち切る/持切る"},"もちくずす":{"variants":"もちくずす/持ち崩す/持崩す"},"持ち崩す":{"variants":"もちくずす/持ち崩す/持崩す"},"持崩す":{"variants":"もちくずす/持ち崩す/持崩す"},"持ち腐れ":{"variants":"持ち腐れ/持腐れ"},"持腐れ":{"variants":"持ち腐れ/持腐れ"},"もちこす":{"variants":"もちこす/持ち越す/持越す"},"持ち越す":{"variants":"もちこす/持ち越す/持越す"},"持越す":{"variants":"もちこす/持ち越す/持越す"},"もちこせる":{"variants":"もちこせる/持ち越せる"},"持ち越せる":{"variants":"もちこせる/持ち越せる"},"もちこたえる":{"variants":"もちこたえる/持ちこたえる/持ち堪える"},"持ちこたえる":{"variants":"もちこたえる/持ちこたえる/持ち堪える"},"持ち堪える":{"variants":"もちこたえる/持ちこたえる/持ち堪える"},"もちこむ":{"variants":"もちこむ/持ちこむ/持ち込む/持込む"},"持ちこむ":{"variants":"もちこむ/持ちこむ/持ち込む/持込む"},"持ち込む":{"variants":"もちこむ/持ちこむ/持ち込む/持込む"},"持込む":{"variants":"もちこむ/持ちこむ/持ち込む/持込む"},"もちこめる":{"variants":"もちこめる/持ち込める"},"持ち込める":{"variants":"もちこめる/持ち込める"},"持ち駒":{"variants":"持ち駒/持駒"},"持駒":{"variants":"持ち駒/持駒"},"もち米":{"variants":"もち米/糯米"},"糯米":{"variants":"もち米/糯米"},"もちさる":{"variants":"もちさる/持ち去る"},"持ち去る":{"variants":"もちさる/持ち去る"},"もちだす":{"variants":"もちだす/持ち出す/持出す"},"持ち出す":{"variants":"もちだす/持ち出す/持出す"},"持出す":{"variants":"もちだす/持ち出す/持出す"},"もちだせる":{"variants":"もちだせる/持ち出せる"},"持ち出せる":{"variants":"もちだせる/持ち出せる"},"もちなおす":{"variants":"もちなおす/持ち直す/持直す"},"持ち直す":{"variants":"もちなおす/持ち直す/持直す"},"持直す":{"variants":"もちなおす/持ち直す/持直す"},"持ち主":{"variants":"持ち主/持主"},"持主":{"variants":"持ち主/持主"},"もちの木":{"variants":"もちの木/モチノキ/黐の木"},"モチノキ":{"variants":"もちの木/モチノキ/黐の木"},"黐の木":{"variants":"もちの木/モチノキ/黐の木"},"もちはこぶ":{"variants":"もちはこぶ/持ち運ぶ/持運ぶ"},"持ち運ぶ":{"variants":"もちはこぶ/持ち運ぶ/持運ぶ"},"持運ぶ":{"variants":"もちはこぶ/持ち運ぶ/持運ぶ"},"もちはこべる":{"variants":"もちはこべる/持ち運べる"},"持ち運べる":{"variants":"もちはこべる/持ち運べる"},"もち肌":{"variants":"もち肌/餅肌"},"餅肌":{"variants":"もち肌/餅肌"},"持ち場":{"variants":"持ち場/持場"},"持場":{"variants":"持ち場/持場"},"持ち分":{"variants":"持ち分/持分"},"持分":{"variants":"持ち分/持分"},"もち前":{"variants":"もち前/持ち前/持前"},"持ち前":{"variants":"もち前/持ち前/持前"},"持前":{"variants":"もち前/持ち前/持前"},"持ち回り":{"variants":"持ち回り/持回り"},"持回り":{"variants":"持ち回り/持回り"},"もちまわる":{"variants":"もちまわる/持ち回る"},"持ち回る":{"variants":"もちまわる/持ち回る"},"もちまわれる":{"variants":"もちまわれる/持ち回れる"},"持ち回れる":{"variants":"もちまわれる/持ち回れる"},"持ち物":{"variants":"持ち物/持物"},"持物":{"variants":"持ち物/持物"},"もち屋":{"variants":"もち屋/餅屋"},"餅屋":{"variants":"もち屋/餅屋"},"もちよる":{"variants":"もちよる/持ち寄る/持寄る"},"持ち寄る":{"variants":"もちよる/持ち寄る/持寄る"},"持寄る":{"variants":"もちよる/持ち寄る/持寄る"},"もちよれる":{"variants":"もちよれる/持ち寄れる"},"持ち寄れる":{"variants":"もちよれる/持ち寄れる"},"もちろん":{"variants":"もちろん/勿論"},"勿論":{"variants":"もちろん/勿論"},"もっけの幸い":{"variants":"もっけの幸い/勿怪の幸い"},"勿怪の幸い":{"variants":"もっけの幸い/勿怪の幸い"},"モッコク":{"variants":"モッコク/木斛"},"木斛":{"variants":"モッコク/木斛"},"もったいない":{"variants":"もったいない/勿体ない"},"勿体ない":{"variants":"もったいない/勿体ない"},"もったいぶる":{"variants":"もったいぶる/勿体ぶる"},"勿体ぶる":{"variants":"もったいぶる/勿体ぶる"},"もったいらしい":{"variants":"もったいらしい/勿体らしい"},"勿体らしい":{"variants":"もったいらしい/勿体らしい"},"もっての外":{"variants":"もっての外/以てのほか/以ての外"},"以てのほか":{"variants":"もっての外/以てのほか/以ての外"},"以ての外":{"variants":"もっての外/以てのほか/以ての外"},"もっとも":{"variants":"もっとも/尤も"},"尤も":{"variants":"もっとも/尤も"},"もつ":{"variants":"もつ/持つ"},"持つ":{"variants":"もつ/持つ"},"もつれあう":{"variants":"もつれあう/もつれ合う"},"もつれ合う":{"variants":"もつれあう/もつれ合う"},"もつれこむ":{"variants":"もつれこむ/もつれ込む"},"もつれ込む":{"variants":"もつれこむ/もつれ込む"},"もつれる":{"variants":"もつれる/縺れる"},"縺れる":{"variants":"もつれる/縺れる"},"もてあそぶ":{"variants":"もてあそぶ/玩ぶ/弄ぶ"},"もてあつかう":{"variants":"もてあつかう/持て扱う"},"持て扱う":{"variants":"もてあつかう/持て扱う"},"もてあます":{"variants":"もてあます/持て余す"},"持て余す":{"variants":"もてあます/持て余す"},"もてなす":{"variants":"もてなす/持て成す"},"持て成す":{"variants":"もてなす/持て成す"},"もてはやす":{"variants":"もてはやす/持て囃す"},"持て囃す":{"variants":"もてはやす/持て囃す"},"もてる":{"variants":"もてる/持てる"},"持てる":{"variants":"もてる/持てる"},"もと":{"variants":"もと/下"},"元":{"variants":"もと/元"},"下":{"variants":"もと/下"},"もとづく":{"variants":"もとづく/基く/基づく"},"基く":{"variants":"もとづく/基く/基づく"},"基づく":{"variants":"もとづく/基く/基づく"},"元のもくあみ":{"variants":"もとの木阿彌/元のもくあみ/元の木阿彌"},"元の木阿弥":{"variants":"元のもくあみ/元の木阿弥"},"もとの木阿彌":{"variants":"もとの木阿彌/元のもくあみ/元の木阿彌"},"元の木阿彌":{"variants":"もとの木阿彌/元のもくあみ/元の木阿彌"},"もとまる":{"variants":"もとまる/求まる"},"求まる":{"variants":"もとまる/求まる"},"もとむ":{"variants":"もとむ/求む"},"求む":{"variants":"もとむ/求む"},"もとめる":{"variants":"もとめる/求める"},"求める":{"variants":"もとめる/求める"},"もともと":{"variants":"もともと/元々"},"元々":{"variants":"元々/元元"},"元元":{"variants":"元々/元元"},"もとる":{"variants":"もとる/悖る"},"悖る":{"variants":"もとる/悖る"},"もどす":{"variants":"もどす/戻す"},"戻す":{"variants":"もどす/戻す"},"もどせる":{"variants":"もどせる/戻せる"},"戻せる":{"variants":"もどせる/戻せる"},"もどる":{"variants":"もどる/戻る"},"戻る":{"variants":"もどる/戻る"},"もどれる":{"variants":"もどれる/戻れる"},"戻れる":{"variants":"もどれる/戻れる"},"もの":{"variants":"もの/モノ/者/物"},"モノ":{"variants":"もの/モノ/者/物"},"者":{"variants":"もの/モノ/者"},"もの言い":{"variants":"もの言い/物言い"},"物言い":{"variants":"もの言い/物言い"},"物忌":{"variants":"物忌/物忌み"},"物忌み":{"variants":"物忌/物忌み"},"物いり":{"variants":"物いり/物入り"},"物入り":{"variants":"物いり/物入り"},"ものうい":{"variants":"ものうい/もの憂い/物憂い/懶い"},"もの売り":{"variants":"もの売り/物売り"},"物売り":{"variants":"もの売り/物売り"},"物おじ":{"variants":"物おじ/物怖じ"},"物怖じ":{"variants":"物おじ/物怖じ"},"ものおそろしい":{"variants":"ものおそろしい/もの恐ろしい/物恐ろしい"},"もの恐ろしい":{"variants":"ものおそろしい/もの恐ろしい/物恐ろしい"},"物恐ろしい":{"variants":"ものおそろしい/もの恐ろしい/物恐ろしい"},"もの音":{"variants":"もの音/物音"},"物音":{"variants":"もの音/物音"},"ものおもう":{"variants":"ものおもう/物思う"},"物思う":{"variants":"ものおもう/物思う"},"物かき":{"variants":"物かき/物書き"},"物書き":{"variants":"物かき/物書き"},"ものがたい":{"variants":"ものがたい/もの堅い/物堅い"},"もの堅い":{"variants":"ものがたい/もの堅い/物堅い"},"物堅い":{"variants":"ものがたい/もの堅い/物堅い"},"ものがたり":{"variants":"ものがたり/物語"},"物語":{"variants":"ものがたり/物語"},"ものがたる":{"variants":"ものがたる/物語る"},"物語る":{"variants":"ものがたる/物語る"},"ものがなしい":{"variants":"ものがなしい/もの悲しい/物悲しい"},"もの悲しい":{"variants":"ものがなしい/もの悲しい/物悲しい"},"物悲しい":{"variants":"ものがなしい/もの悲しい/物悲しい"},"ものぐさ":{"variants":"ものぐさ/物ぐさ/物臭"},"物ぐさ":{"variants":"物ぐさ/物臭"},"物臭":{"variants":"物ぐさ/物臭"},"もの狂い":{"variants":"もの狂い/物狂い"},"物狂い":{"variants":"もの狂い/物狂い"},"ものぐるおしい":{"variants":"ものぐるおしい/もの狂おしい/物狂おしい"},"もの狂おしい":{"variants":"ものぐるおしい/もの狂おしい/物狂おしい"},"物狂おしい":{"variants":"ものぐるおしい/もの狂おしい/物狂おしい"},"ものごい":{"variants":"ものごい/物ごい/物乞い"},"物ごい":{"variants":"ものごい/物ごい/物乞い"},"物乞い":{"variants":"ものごい/物ごい/物乞い"},"物ごし":{"variants":"物ごし/物腰"},"物腰":{"variants":"物ごし/物腰"},"モノサシ":{"variants":"モノサシ/物差し/物指し"},"ものさびしい":{"variants":"ものさびしい/もの寂しい/もの淋しい/物寂しい/物淋しい"},"ものさわがしい":{"variants":"ものさわがしい/物騒がしい"},"物騒がしい":{"variants":"ものさわがしい/物騒がしい"},"もの静か":{"variants":"もの静か/物静か"},"物静か":{"variants":"もの静か/物静か"},"ものすごい":{"variants":"ものすごい/もの凄い/物凄い"},"もの凄い":{"variants":"ものすごい/もの凄い/物凄い"},"物凄い":{"variants":"ものすごい/もの凄い/物凄い"},"ものすさまじい":{"variants":"ものすさまじい/もの凄まじい/物凄まじい"},"もの凄まじい":{"variants":"ものすさまじい/もの凄まじい/物凄まじい"},"物凄まじい":{"variants":"ものすさまじい/もの凄まじい/物凄まじい"},"ものたりない":{"variants":"ものたりない/物足りない"},"物足りない":{"variants":"ものたりない/物足りない"},"物づくし":{"variants":"物づくし/物尽し"},"物尽し":{"variants":"物づくし/物尽し"},"ものなれる":{"variants":"ものなれる/物慣れる"},"物慣れる":{"variants":"ものなれる/物慣れる"},"物の怪":{"variants":"ものの怪/物の怪"},"ものの怪":{"variants":"ものの怪/物の怪"},"モノまね":{"variants":"モノまね/モノマネ/物まね/物真似"},"モノマネ":{"variants":"モノまね/モノマネ/物まね/物真似"},"物まね":{"variants":"モノまね/モノマネ/物まね/物真似"},"物真似":{"variants":"モノまね/モノマネ/物まね/物真似"},"ものみだかい":{"variants":"ものみだかい/物見高い"},"物見高い":{"variants":"ものみだかい/物見高い"},"ものめずらしい":{"variants":"ものめずらしい/もの珍しい/物珍しい"},"もの珍しい":{"variants":"ものめずらしい/もの珍しい/物珍しい"},"物珍しい":{"variants":"ものめずらしい/もの珍しい/物珍しい"},"ものもうす":{"variants":"ものもうす/もの申す/物申す"},"もの申す":{"variants":"ものもうす/もの申す/物申す"},"物申す":{"variants":"ものもうす/もの申す/物申す"},"ものものしい":{"variants":"ものものしい/物々しい/物物しい"},"物々しい":{"variants":"ものものしい/物々しい/物物しい"},"物物しい":{"variants":"ものものしい/物々しい/物物しい"},"物わかり":{"variants":"物わかり/物分り"},"物分り":{"variants":"物わかり/物分り"},"もの別れ":{"variants":"もの別れ/物別れ"},"物別れ":{"variants":"もの別れ/物別れ"},"も本":{"variants":"も本/摸本/模本"},"もみ":{"variants":"もみ/モミ/紅絹/籾/樅"},"モミ":{"variants":"もみ/モミ/紅絹/籾/樅"},"もみあう":{"variants":"もみあう/もみ合う/揉み合う"},"もみ合う":{"variants":"もみあう/もみ合う/揉み合う"},"揉み合う":{"variants":"もみあう/もみ合う/揉み合う"},"もみ上げ":{"variants":"もみ上げ/揉み上げ"},"揉み上げ":{"variants":"もみ上げ/揉み上げ"},"もみくちゃ":{"variants":"もみくちゃ/揉みくちゃ"},"揉みくちゃ":{"variants":"もみくちゃ/揉みくちゃ"},"もみけす":{"variants":"もみけす/もみ消す/揉み消す"},"もみ消す":{"variants":"もみけす/もみ消す/揉み消す"},"揉み消す":{"variants":"もみけす/もみ消す/揉み消す"},"もみけせる":{"variants":"もみけせる/もみ消せる"},"もみ消せる":{"variants":"もみけせる/もみ消せる"},"モミジアオイ":{"variants":"モミジアオイ/紅葉葵"},"紅葉葵":{"variants":"モミジアオイ/紅葉葵"},"紅葉狩":{"variants":"紅葉狩/紅葉狩り"},"紅葉狩り":{"variants":"紅葉狩/紅葉狩り"},"もみ手":{"variants":"もみ手/揉み手"},"揉み手":{"variants":"もみ手/揉み手"},"もむ":{"variants":"もむ/揉む"},"揉む":{"variants":"もむ/揉む"},"もめごと":{"variants":"もめごと/もめ事/揉めごと/揉め事"},"もめ事":{"variants":"もめごと/もめ事/揉めごと/揉め事"},"揉めごと":{"variants":"もめごと/もめ事/揉めごと/揉め事"},"揉め事":{"variants":"もめごと/もめ事/揉めごと/揉め事"},"もめる":{"variants":"もめる/揉める"},"揉める":{"variants":"もめる/揉める"},"もも":{"variants":"もも/モモ/腿/桃"},"モモ":{"variants":"もも/モモ/腿/桃"},"桃の節句":{"variants":"桃の節句/桃節句"},"桃節句":{"variants":"桃の節句/桃節句"},"モヤシ":{"variants":"モヤシ/萌やし"},"萌やし":{"variants":"モヤシ/萌やし"},"もやす":{"variants":"もやす/燃やす"},"燃やす":{"variants":"もやす/燃やす"},"もやせる":{"variants":"もやせる/燃やせる"},"燃やせる":{"variants":"もやせる/燃やせる"},"もやもや":{"variants":"もやもや/モヤモヤ"},"モヤモヤ":{"variants":"もやもや/モヤモヤ"},"模様替":{"variants":"模様替/模様替え"},"模様替え":{"variants":"模様替/模様替え"},"もよおし":{"variants":"もよおし/催し"},"催し":{"variants":"もよおし/催し"},"催し物":{"variants":"催し物/催物"},"催物":{"variants":"催し物/催物"},"もよおす":{"variants":"もよおす/催す"},"催す":{"variants":"もよおす/催す"},"もより":{"variants":"もより/最寄り"},"最寄り":{"variants":"もより/最寄り"},"貰":{"variants":"貰/貰い"},"貰い":{"variants":"貰/貰い"},"もらい食い":{"variants":"もらい食い/貰い食い"},"貰い食い":{"variants":"もらい食い/貰い食い"},"もらい子":{"variants":"もらい子/貰い子"},"貰い子":{"variants":"もらい子/貰い子"},"もらい乳":{"variants":"もらい乳/貰い乳"},"貰い乳":{"variants":"もらい乳/貰い乳"},"もらい手":{"variants":"もらい手/貰い手"},"貰い手":{"variants":"もらい手/貰い手"},"貰い泣き":{"variants":"貰い泣き/貰泣き"},"貰泣き":{"variants":"貰い泣き/貰泣き"},"もらい火":{"variants":"もらい火/貰い火"},"貰い火":{"variants":"もらい火/貰い火"},"もらい水":{"variants":"もらい水/貰い水"},"貰い水":{"variants":"もらい水/貰い水"},"もらい物":{"variants":"もらい物/貰いもの/貰い物"},"貰いもの":{"variants":"もらい物/貰いもの/貰い物"},"貰い物":{"variants":"もらい物/貰いもの/貰い物"},"もらい湯":{"variants":"もらい湯/貰い湯"},"貰い湯":{"variants":"もらい湯/貰い湯"},"もらい笑い":{"variants":"もらい笑い/貰い笑い"},"貰い笑い":{"variants":"もらい笑い/貰い笑い"},"もらう":{"variants":"もらう/貰う"},"貰う":{"variants":"もらう/貰う"},"もらえる":{"variants":"もらえる/貰える"},"貰える":{"variants":"もらえる/貰える"},"もらす":{"variants":"もらす/洩らす/漏らす"},"もりあがる":{"variants":"もりあがる/盛りあがる/盛り上がる/盛上がる"},"盛りあがる":{"variants":"もりあがる/盛りあがる/盛り上がる/盛上がる"},"盛り上がる":{"variants":"もりあがる/盛りあがる/盛り上がる/盛上がる"},"盛上がる":{"variants":"もりあがる/盛りあがる/盛り上がる/盛上がる"},"もりあげる":{"variants":"もりあげる/盛り上げる/盛上げる"},"盛り上げる":{"variants":"もりあげる/盛り上げる/盛上げる"},"盛上げる":{"variants":"もりあげる/盛り上げる/盛上げる"},"もりあわす":{"variants":"もりあわす/盛り合わす"},"盛り合わす":{"variants":"もりあわす/盛り合わす"},"盛り合わせ":{"variants":"盛り合わせ/盛合せ"},"盛合せ":{"variants":"盛り合わせ/盛合せ"},"もりあわせる":{"variants":"もりあわせる/盛り合わせる"},"盛り合わせる":{"variants":"もりあわせる/盛り合わせる"},"もりかえす":{"variants":"もりかえす/盛りかえす/盛り返す/盛返す"},"盛りかえす":{"variants":"もりかえす/盛りかえす/盛り返す/盛返す"},"盛り返す":{"variants":"もりかえす/盛りかえす/盛り返す/盛返す"},"盛返す":{"variants":"もりかえす/盛りかえす/盛り返す/盛返す"},"もりこむ":{"variants":"もりこむ/盛り込む/盛込む"},"盛り込む":{"variants":"もりこむ/盛り込む/盛込む"},"盛込む":{"variants":"もりこむ/盛り込む/盛込む"},"もりこめる":{"variants":"もりこめる/盛り込める"},"盛り込める":{"variants":"もりこめる/盛り込める"},"もりころす":{"variants":"もりころす/盛り殺す"},"盛り殺す":{"variants":"もりころす/盛り殺す"},"盛り砂":{"variants":"盛り砂/盛砂"},"盛砂":{"variants":"盛り砂/盛砂"},"もりたてる":{"variants":"もりたてる/もり立てる/守り立てる/守立てる"},"もり立てる":{"variants":"もりたてる/もり立てる/守り立てる/守立てる"},"守り立てる":{"variants":"もりたてる/もり立てる/守り立てる/守立てる"},"守立てる":{"variants":"もりたてる/もり立てる/守り立てる/守立てる"},"盛り沢山":{"variants":"盛り沢山/盛沢山"},"盛沢山":{"variants":"盛り沢山/盛沢山"},"もりつける":{"variants":"もりつける/盛りつける/盛り付ける"},"盛りつける":{"variants":"もりつける/盛りつける/盛り付ける"},"盛り付ける":{"variants":"もりつける/盛りつける/盛り付ける"},"盛り土":{"variants":"盛り土/盛土"},"盛土":{"variants":"盛り土/盛土"},"もりつぶす":{"variants":"もりつぶす/盛り潰す"},"盛り潰す":{"variants":"もりつぶす/盛り潰す"},"盛り花":{"variants":"盛り花/盛花"},"盛花":{"variants":"盛り花/盛花"},"もりわける":{"variants":"もりわける/盛り分ける"},"盛り分ける":{"variants":"もりわける/盛り分ける"},"もる":{"variants":"もる/洩る/盛る/漏る"},"ｍｏｌ":{"variants":"ｍｏｌ/モル"},"モル":{"variants":"ｍｏｌ/モル"},"もれ":{"variants":"もれ/漏れ"},"漏れ":{"variants":"もれ/漏れ"},"もれきく":{"variants":"もれきく/もれ聞く/漏れ聞く"},"もれ聞く":{"variants":"もれきく/もれ聞く/漏れ聞く"},"漏れ聞く":{"variants":"もれきく/もれ聞く/漏れ聞く"},"もれる":{"variants":"もれる/洩れる/盛れる/漏れる"},"もろい":{"variants":"もろい/脆い"},"脆い":{"variants":"もろい/脆い"},"モロコシ":{"variants":"モロコシ/蜀黍"},"蜀黍":{"variants":"モロコシ/蜀黍"},"もろさ":{"variants":"もろさ/モロさ"},"モロさ":{"variants":"もろさ/モロさ"},"もろ差し":{"variants":"もろ差し/諸差し"},"諸差し":{"variants":"もろ差し/諸差し"},"もろ手":{"variants":"もろ手/諸手"},"諸手":{"variants":"もろ手/諸手"},"もろに":{"variants":"もろに/モロに/諸に"},"モロに":{"variants":"もろに/モロに/諸に"},"諸に":{"variants":"もろに/モロに/諸に"},"もろ刃":{"variants":"もろ刃/諸刃"},"諸刃":{"variants":"もろ刃/諸刃"},"もろ肌":{"variants":"もろ肌/諸肌"},"諸肌":{"variants":"もろ肌/諸肌"},"もろみ":{"variants":"もろみ/諸味/醪"},"もろもろ":{"variants":"もろもろ/諸々/諸諸"},"諸々":{"variants":"もろもろ/諸々/諸諸"},"諸諸":{"variants":"もろもろ/諸々/諸諸"},"モンシロチョウ":{"variants":"モンシロチョウ/紋白蝶"},"紋白蝶":{"variants":"モンシロチョウ/紋白蝶"},"紋付":{"variants":"紋付/紋付き"},"紋付き":{"variants":"紋付/紋付き"},"紋どころ":{"variants":"紋どころ/紋所"},"紋所":{"variants":"紋どころ/紋所"},"悶々":{"variants":"悶々/悶悶"},"悶悶":{"variants":"悶々/悶悶"},"や":{"variants":"や/屋"},"屋":{"variants":"や/屋"},"やぁ":{"variants":"やぁ/やァ"},"やァ":{"variants":"やぁ/やァ"},"ヤエザクラ":{"variants":"ヤエザクラ/八重桜"},"八重桜":{"variants":"ヤエザクラ/八重桜"},"ヤエムグラ":{"variants":"ヤエムグラ/八重葎"},"八重葎":{"variants":"ヤエムグラ/八重葎"},"やかす":{"variants":"やかす/焼かす"},"焼かす":{"variants":"やかす/焼かす"},"やかましい":{"variants":"やかましい/喧しい"},"喧しい":{"variants":"やかましい/喧しい"},"やかまし屋":{"variants":"やかまし屋/喧し屋"},"喧し屋":{"variants":"やかまし屋/喧し屋"},"矢がすり":{"variants":"矢がすり/矢飛白/矢絣"},"やがて":{"variants":"やがて/軈て"},"軈て":{"variants":"やがて/軈て"},"焼":{"variants":"焼/焼き"},"焼き":{"variants":"焼/焼き"},"やきあげる":{"variants":"やきあげる/焼き上げる"},"焼き上げる":{"variants":"やきあげる/焼き上げる"},"ヤキイモ":{"variants":"ヤキイモ/焼きいも/焼きイモ/焼き芋/焼イモ"},"焼きいも":{"variants":"ヤキイモ/焼きいも/焼きイモ/焼き芋/焼イモ"},"焼きイモ":{"variants":"ヤキイモ/焼きいも/焼きイモ/焼き芋/焼イモ"},"焼き芋":{"variants":"ヤキイモ/焼きいも/焼きイモ/焼き芋/焼イモ"},"焼イモ":{"variants":"ヤキイモ/焼きいも/焼きイモ/焼き芋/焼イモ"},"焼き印":{"variants":"焼き印/焼印"},"焼印":{"variants":"焼き印/焼印"},"焼き討ち":{"variants":"焼き討ち/焼討"},"焼討":{"variants":"焼き討ち/焼討"},"焼き絵":{"variants":"焼き絵/焼絵"},"焼絵":{"variants":"焼き絵/焼絵"},"やききる":{"variants":"やききる/焼き切る/焼切る"},"焼き切る":{"variants":"やききる/焼き切る/焼切る"},"焼切る":{"variants":"やききる/焼き切る/焼切る"},"焼きごて":{"variants":"焼きごて/焼鏝"},"焼鏝":{"variants":"焼きごて/焼鏝"},"焼魚":{"variants":"焼き魚/焼魚"},"焼き魚":{"variants":"焼き魚/焼魚"},"焼き塩":{"variants":"焼き塩/焼塩"},"焼塩":{"variants":"焼き塩/焼塩"},"やきすてる":{"variants":"やきすてる/焼き捨てる"},"焼き捨てる":{"variants":"やきすてる/焼き捨てる"},"やきつく":{"variants":"やきつく/焼き付く"},"焼き付く":{"variants":"やきつく/焼き付く"},"焼き付け":{"variants":"焼き付け/焼付け"},"焼付け":{"variants":"焼き付け/焼付け"},"やきつける":{"variants":"やきつける/焼きつける/焼き付ける/焼付ける"},"焼きつける":{"variants":"やきつける/焼きつける/焼き付ける/焼付ける"},"焼き付ける":{"variants":"やきつける/焼きつける/焼き付ける/焼付ける"},"焼付ける":{"variants":"やきつける/焼きつける/焼き付ける/焼付ける"},"焼きとり":{"variants":"焼きとり/焼き鳥/焼鳥"},"焼き鳥":{"variants":"焼きとり/焼き鳥/焼鳥"},"焼鳥":{"variants":"焼きとり/焼き鳥/焼鳥"},"焼き豆腐":{"variants":"焼き豆腐/焼豆腐"},"焼豆腐":{"variants":"焼き豆腐/焼豆腐"},"焼き鈍し":{"variants":"焼き鈍し/焼鈍し"},"焼鈍し":{"variants":"焼き鈍し/焼鈍し"},"やきなます":{"variants":"やきなます/焼き鈍す"},"焼き鈍す":{"variants":"やきなます/焼き鈍す"},"焼き肉":{"variants":"焼き肉/焼肉"},"焼肉":{"variants":"焼き肉/焼肉"},"やきはらう":{"variants":"やきはらう/焼き払う/焼払う"},"焼き払う":{"variants":"やきはらう/焼き払う/焼払う"},"焼払う":{"variants":"やきはらう/焼き払う/焼払う"},"焼き場":{"variants":"焼き場/焼場"},"焼場":{"variants":"焼き場/焼場"},"焼き豚":{"variants":"焼き豚/焼豚"},"焼豚":{"variants":"焼き豚/焼豚"},"焼き増し":{"variants":"焼き増し/焼増し"},"焼増し":{"variants":"焼き増し/焼増し"},"焼き飯":{"variants":"焼き飯/焼飯"},"焼飯":{"variants":"焼き飯/焼飯"},"焼きもち":{"variants":"焼きもち/焼き餅/焼餅"},"焼き餅":{"variants":"焼きもち/焼き餅/焼餅"},"焼餅":{"variants":"焼きもち/焼き餅/焼餅"},"焼きもの":{"variants":"焼きもの/焼き物/焼物"},"焼き物":{"variants":"焼きもの/焼き物/焼物"},"焼物":{"variants":"焼きもの/焼き物/焼物"},"ヤギ":{"variants":"ヤギ/山羊/野羊"},"ヤギュウ":{"variants":"ヤギュウ/野牛"},"野牛":{"variants":"ヤギュウ/野牛"},"やく":{"variants":"やく/灼く/焼く/妬く"},"厄落し":{"variants":"厄落し/厄落とし"},"厄落とし":{"variants":"厄落し/厄落とし"},"やくざ":{"variants":"やくざ/ヤクザ"},"ヤクザ":{"variants":"やくざ/ヤクザ"},"やくす":{"variants":"やくす/約す/訳す"},"やくする":{"variants":"やくする/約する/訳する/扼する"},"やくせる":{"variants":"やくせる/訳せる"},"訳せる":{"variants":"やくせる/訳せる"},"約束ごと":{"variants":"約束ごと/約束事"},"約束事":{"variants":"約束ごと/約束事"},"やくだつ":{"variants":"やくだつ/役だつ/役立つ"},"役だつ":{"variants":"やくだつ/役だつ/役立つ"},"役立つ":{"variants":"やくだつ/役だつ/役立つ"},"やくだてる":{"variants":"やくだてる/役立てる"},"役立てる":{"variants":"やくだてる/役立てる"},"役付":{"variants":"役付/役付き"},"役付き":{"variants":"役付/役付き"},"ヤク物":{"variants":"ヤク物/薬物"},"薬物":{"variants":"ヤク物/薬物"},"やくほう":{"variants":"やくほう/薬方"},"薬方":{"variants":"やくほう/薬方"},"やくも":{"variants":"やくも/八雲"},"八雲":{"variants":"やくも/八雲"},"厄除":{"variants":"厄除/厄除け"},"厄除け":{"variants":"厄除/厄除け"},"ヤグラ":{"variants":"ヤグラ/矢倉"},"矢倉":{"variants":"ヤグラ/矢倉"},"やぐら太鼓":{"variants":"やぐら太鼓/櫓太鼓"},"櫓太鼓":{"variants":"やぐら太鼓/櫓太鼓"},"ヤグルマギク":{"variants":"ヤグルマギク/矢車菊"},"矢車菊":{"variants":"ヤグルマギク/矢車菊"},"ヤグルマソウ":{"variants":"ヤグルマソウ/矢車草"},"矢車草":{"variants":"ヤグルマソウ/矢車草"},"焼け跡":{"variants":"焼け跡/焼跡"},"焼跡":{"variants":"焼け跡/焼跡"},"焼け石":{"variants":"焼け石/焼石"},"焼石":{"variants":"焼け石/焼石"},"やけおちる":{"variants":"やけおちる/焼け落ちる"},"焼け落ちる":{"variants":"やけおちる/焼け落ちる"},"やけぎょう":{"variants":"やけぎょう/焼経"},"焼経":{"variants":"やけぎょう/焼経"},"やけくそ":{"variants":"やけくそ/ヤケ糞/自棄糞"},"ヤケ糞":{"variants":"やけくそ/ヤケ糞/自棄糞"},"自棄糞":{"variants":"やけくそ/ヤケ糞/自棄糞"},"焼けこげ":{"variants":"焼けこげ/焼け焦げ"},"焼け焦げ":{"variants":"焼けこげ/焼け焦げ"},"やけ酒":{"variants":"やけ酒/自棄酒"},"自棄酒":{"variants":"やけ酒/自棄酒"},"やけしぬ":{"variants":"やけしぬ/焼け死ぬ"},"焼け死ぬ":{"variants":"やけしぬ/焼け死ぬ"},"やけだす":{"variants":"やけだす/焼け出す"},"焼け出す":{"variants":"やけだす/焼け出す"},"ヤケっぱち":{"variants":"ヤケっぱち/自棄っぱち"},"自棄っぱち":{"variants":"ヤケっぱち/自棄っぱち"},"やけっ腹":{"variants":"やけっ腹/自棄っ腹"},"自棄っ腹":{"variants":"やけっ腹/自棄っ腹"},"やけつく":{"variants":"やけつく/焼け付く"},"焼け付く":{"variants":"やけつく/焼け付く"},"焼け野":{"variants":"焼け野/焼野"},"焼野":{"variants":"焼け野/焼野"},"焼け野が原":{"variants":"焼け野が原/焼野が原"},"焼野が原":{"variants":"焼け野が原/焼野が原"},"焼けぼっくい":{"variants":"焼けぼっくい/焼け棒杭/焼け木杭"},"焼け山":{"variants":"焼け山/焼山"},"焼山":{"variants":"焼け山/焼山"},"やける":{"variants":"やける/焼ける/妬ける"},"ヤコウチュウ":{"variants":"ヤコウチュウ/夜光虫"},"夜光虫":{"variants":"ヤコウチュウ/夜光虫"},"やさい":{"variants":"やさい/恥い"},"恥い":{"variants":"やさい/恥い"},"やさ男":{"variants":"やさ男/優男"},"優男":{"variants":"やさ男/優男"},"やさしい":{"variants":"やさしい/易しい/優しい"},"ヤシ":{"variants":"ヤシ/野史/野師/椰子"},"やしなう":{"variants":"やしなう/養う"},"養う":{"variants":"やしなう/養う"},"やしなえる":{"variants":"やしなえる/養える"},"養える":{"variants":"やしなえる/養える"},"やじ":{"variants":"やじ/ヤジ/野次/彌次"},"ヤジ":{"variants":"やじ/ヤジ/野次/彌次"},"やじ馬":{"variants":"やじ馬/野次馬/彌次馬"},"矢じり":{"variants":"矢じり/矢尻"},"矢尻":{"variants":"矢じり/矢尻"},"やじる":{"variants":"やじる/ヤジる/野次る/彌次る"},"ヤジる":{"variants":"やじる/ヤジる/野次る/彌次る"},"やじれる":{"variants":"やじれる/野次れる"},"野次れる":{"variants":"やじれる/野次れる"},"安上がり":{"variants":"安上がり/安上り"},"安上り":{"variants":"安上がり/安上り"},"やすい":{"variants":"やすい/安い/易い"},"安請け合い":{"variants":"安請け合い/安請合い"},"安請合い":{"variants":"安請け合い/安請合い"},"やすっぽい":{"variants":"やすっぽい/安っぽい"},"安っぽい":{"variants":"やすっぽい/安っぽい"},"ヤスデ":{"variants":"ヤスデ/安手/馬陸"},"やすまる":{"variants":"やすまる/休まる"},"休まる":{"variants":"やすまる/休まる"},"やすまれる":{"variants":"やすまれる/休まれる"},"休まれる":{"variants":"やすまれる/休まれる"},"やすみやすみ":{"variants":"やすみやすみ/休みやすみ/休み休み"},"休みやすみ":{"variants":"やすみやすみ/休みやすみ/休み休み"},"休み休み":{"variants":"やすみやすみ/休みやすみ/休み休み"},"やすむ":{"variants":"やすむ/休む"},"休む":{"variants":"やすむ/休む"},"やすめる":{"variants":"やすめる/休める"},"休める":{"variants":"やすめる/休める"},"やすやす":{"variants":"やすやす/安安/易易"},"やすらう":{"variants":"やすらう/安らう/休らう"},"やすらぐ":{"variants":"やすらぐ/安らぐ"},"安らぐ":{"variants":"やすらぐ/安らぐ"},"やすんずる":{"variants":"やすんずる/安んずる"},"安んずる":{"variants":"やすんずる/安んずる"},"痩せうで":{"variants":"痩せうで/痩せ腕"},"痩せ腕":{"variants":"痩せうで/痩せ腕"},"やせおとろえる":{"variants":"やせおとろえる/やせ衰える"},"やせ衰える":{"variants":"やせおとろえる/やせ衰える"},"痩せがまん":{"variants":"痩せがまん/痩せ我慢/痩我慢"},"痩せ我慢":{"variants":"痩せがまん/痩せ我慢/痩我慢"},"痩我慢":{"variants":"痩せがまん/痩せ我慢/痩我慢"},"やせこける":{"variants":"やせこける/痩せこける"},"痩せこける":{"variants":"やせこける/痩せこける"},"やせさらばえる":{"variants":"やせさらばえる/痩せさらばえる"},"痩せさらばえる":{"variants":"やせさらばえる/痩せさらばえる"},"やせ地":{"variants":"やせ地/痩せ地"},"痩せ地":{"variants":"やせ地/痩せ地"},"やせほそる":{"variants":"やせほそる/やせ細る"},"やせ細る":{"variants":"やせほそる/やせ細る"},"やせる":{"variants":"やせる/痩せる/瘠せる"},"屋台ばやし":{"variants":"屋台ばやし/屋台囃子"},"屋台囃子":{"variants":"屋台ばやし/屋台囃子"},"ヤチョ":{"variants":"ヤチョ/野猪"},"野猪":{"variants":"ヤチョ/野猪"},"やっかい":{"variants":"やっかい/厄介"},"厄介":{"variants":"やっかい/厄介"},"薬きょう":{"variants":"薬きょう/薬莢"},"薬莢":{"variants":"薬きょう/薬莢"},"やっこ":{"variants":"やっこ/奴"},"奴":{"variants":"やっこ/奴"},"８つ":{"variants":"８つ/八つ"},"八つ":{"variants":"８つ/八つ"},"やってのける":{"variants":"やってのける/やって退ける"},"やって退ける":{"variants":"やってのける/やって退ける"},"ヤツガシラ":{"variants":"ヤツガシラ/八頭"},"八頭":{"variants":"ヤツガシラ/八頭"},"八つ裂き":{"variants":"八つ裂き/八裂き"},"八裂き":{"variants":"八つ裂き/八裂き"},"やつす":{"variants":"やつす/窶す"},"窶す":{"variants":"やつす/窶す"},"ヤツデ":{"variants":"ヤツデ/八つ手/八手"},"八つ手":{"variants":"ヤツデ/八つ手/八手"},"八手":{"variants":"ヤツデ/八つ手/八手"},"ヤツメウナギ":{"variants":"ヤツメウナギ/八目鰻"},"八目鰻":{"variants":"ヤツメウナギ/八目鰻"},"奴ら":{"variants":"奴ら/奴等"},"奴等":{"variants":"奴ら/奴等"},"やつれる":{"variants":"やつれる/窶れる"},"窶れる":{"variants":"やつれる/窶れる"},"雇い人":{"variants":"雇い人/雇人"},"雇人":{"variants":"雇い人/雇人"},"雇い主":{"variants":"雇い主/雇主"},"雇主":{"variants":"雇い主/雇主"},"やとう":{"variants":"やとう/雇う/傭う"},"やとえる":{"variants":"やとえる/雇える"},"雇える":{"variants":"やとえる/雇える"},"ヤドカリ":{"variants":"ヤドカリ/宿借り"},"宿借り":{"variants":"ヤドカリ/宿借り"},"宿下がり":{"variants":"宿下がり/宿下り"},"宿下り":{"variants":"宿下がり/宿下り"},"やどり木":{"variants":"やどり木/ヤドリギ/寄生木/宿り木/宿木"},"ヤドリギ":{"variants":"やどり木/ヤドリギ/寄生木/宿り木/宿木"},"宿り木":{"variants":"やどり木/ヤドリギ/宿り木/宿木"},"宿木":{"variants":"やどり木/ヤドリギ/宿り木/宿木"},"やどる":{"variants":"やどる/宿る"},"宿る":{"variants":"やどる/宿る"},"やどれる":{"variants":"やどれる/宿れる"},"宿れる":{"variants":"やどれる/宿れる"},"ヤナギ":{"variants":"ヤナギ/柳"},"柳":{"variants":"ヤナギ/柳"},"柳ごうり":{"variants":"柳ごうり/柳行李"},"柳行李":{"variants":"柳ごうり/柳行李"},"やにさがる":{"variants":"やにさがる/脂下がる"},"脂下がる":{"variants":"やにさがる/脂下がる"},"やぶ医者":{"variants":"やぶ医者/薮医者"},"薮医者":{"variants":"やぶ医者/薮医者"},"ヤブカ":{"variants":"ヤブカ/薮蚊"},"薮蚊":{"variants":"ヤブカ/薮蚊"},"ヤブガラシ":{"variants":"ヤブガラシ/薮枯し"},"薮枯し":{"variants":"ヤブガラシ/薮枯し"},"やぶく":{"variants":"やぶく/破く"},"破く":{"variants":"やぶく/破く"},"やぶける":{"variants":"やぶける/破ける"},"破ける":{"variants":"やぶける/破ける"},"ヤブコウジ":{"variants":"ヤブコウジ/薮柑子"},"薮柑子":{"variants":"ヤブコウジ/薮柑子"},"やぶさか":{"variants":"やぶさか/吝か"},"吝か":{"variants":"やぶさか/吝か"},"やぶさめ":{"variants":"やぶさめ/流鏑馬"},"流鏑馬":{"variants":"やぶさめ/流鏑馬"},"ヤブジラミ":{"variants":"ヤブジラミ/薮蝨"},"薮蝨":{"variants":"ヤブジラミ/薮蝨"},"やぶ蛇":{"variants":"やぶ蛇/薮蛇"},"薮蛇":{"variants":"やぶ蛇/薮蛇"},"やぶる":{"variants":"やぶる/破る"},"破る":{"variants":"やぶる/破る"},"やぶれる":{"variants":"やぶれる/敗れる"},"敗れる":{"variants":"やぶれる/敗れる"},"ヤボ":{"variants":"やぼ/ヤボ/野暮"},"野暮":{"variants":"やぼ/ヤボ/野暮"},"やぼ":{"variants":"やぼ/ヤボ/野暮"},"やぼくさい":{"variants":"やぼくさい/野暮臭い"},"野暮臭い":{"variants":"やぼくさい/野暮臭い"},"やぼったい":{"variants":"やぼったい/野暮ったい"},"野暮ったい":{"variants":"やぼったい/野暮ったい"},"ヤマ":{"variants":"ヤマ/山"},"山":{"variants":"ヤマ/山"},"ヤマアラシ":{"variants":"ヤマアラシ/山荒し/山嵐"},"ヤマイヌ":{"variants":"ヤマイヌ/山犬/病犬"},"ヤマイモ":{"variants":"ヤマイモ/山芋"},"山芋":{"variants":"ヤマイモ/山芋"},"ヤマカガシ":{"variants":"ヤマカガシ/赤楝蛇"},"赤楝蛇":{"variants":"ヤマカガシ/赤楝蛇"},"山かけ":{"variants":"山かけ/山掛け"},"山掛け":{"variants":"山かけ/山掛け"},"山かげ":{"variants":"山かげ/山陰"},"山陰":{"variants":"山かげ/山陰"},"ヤマ勘":{"variants":"ヤマ勘/山勘"},"山勘":{"variants":"ヤマ勘/山勘"},"ヤマガラ":{"variants":"ヤマガラ/山雀"},"山雀":{"variants":"ヤマガラ/山雀"},"山ぎわ":{"variants":"山ぎわ/山際"},"山際":{"variants":"山ぎわ/山際"},"山ごもり":{"variants":"山ごもり/山篭り"},"山篭り":{"variants":"山ごもり/山篭り"},"ヤマザクラ":{"variants":"ヤマザクラ/山ざくら/山桜"},"山ざくら":{"variants":"ヤマザクラ/山ざくら/山桜"},"山桜":{"variants":"ヤマザクラ/山ざくら/山桜"},"やましい":{"variants":"やましい/疾しい/疚しい"},"山すそ":{"variants":"山すそ/山裾"},"山裾":{"variants":"山すそ/山裾"},"ヤマトイモ":{"variants":"ヤマトイモ/大和芋"},"大和芋":{"variants":"ヤマトイモ/大和芋"},"やまと絵":{"variants":"やまと絵/大和絵/倭絵"},"ヤマトナデシコ":{"variants":"ヤマトナデシコ/大和なでしこ/大和撫子"},"大和なでしこ":{"variants":"ヤマトナデシコ/大和なでしこ/大和撫子"},"大和撫子":{"variants":"ヤマトナデシコ/大和なでしこ/大和撫子"},"ヤマドリ":{"variants":"ヤマドリ/山鳥"},"山鳥":{"variants":"ヤマドリ/山鳥"},"山並":{"variants":"山並/山並み"},"山並み":{"variants":"山並/山並み"},"ヤマネコ":{"variants":"ヤマネコ/山猫"},"山猫":{"variants":"ヤマネコ/山猫"},"やまねこスト":{"variants":"やまねこスト/山ねこスト/山猫スト"},"山ねこスト":{"variants":"やまねこスト/山ねこスト/山猫スト"},"山猫スト":{"variants":"やまねこスト/山ねこスト/山猫スト"},"ヤマノイモ":{"variants":"ヤマノイモ/山の芋"},"山の芋":{"variants":"ヤマノイモ/山の芋"},"やま場":{"variants":"やま場/ヤマ場/山場"},"ヤマ場":{"variants":"やま場/ヤマ場/山場"},"山場":{"variants":"やま場/ヤマ場/山場"},"ヤマバチ":{"variants":"ヤマバチ/山蜂"},"山蜂":{"variants":"ヤマバチ/山蜂"},"ヤマバト":{"variants":"ヤマバト/山鳩"},"山鳩":{"variants":"ヤマバト/山鳩"},"山ひだ":{"variants":"山ひだ/山襞"},"山襞":{"variants":"山ひだ/山襞"},"山びこ":{"variants":"山びこ/山彦"},"山彦":{"variants":"山びこ/山彦"},"山ふところ":{"variants":"山ふところ/山懐"},"山懐":{"variants":"山ふところ/山懐"},"ヤマブキ":{"variants":"ヤマブキ/山ぶき/山吹/山吹き"},"山ぶき":{"variants":"ヤマブキ/山ぶき/山吹/山吹き"},"山吹":{"variants":"ヤマブキ/山ぶき/山吹/山吹き"},"山吹き":{"variants":"ヤマブキ/山ぶき/山吹/山吹き"},"ヤマブドウ":{"variants":"ヤマブドウ/山葡萄"},"山葡萄":{"variants":"ヤマブドウ/山葡萄"},"山へん":{"variants":"山へん/山偏"},"山偏":{"variants":"山へん/山偏"},"ヤマボウシ":{"variants":"ヤマボウシ/山帽子"},"山帽子":{"variants":"ヤマボウシ/山帽子"},"ヤママユ":{"variants":"ヤママユ/山繭"},"山繭":{"variants":"ヤママユ/山繭"},"ヤマメ":{"variants":"ヤマメ/山女"},"山女":{"variants":"ヤマメ/山女"},"やまもも":{"variants":"やまもも/ヤマモモ/山桃/楊梅"},"ヤマモモ":{"variants":"やまもも/ヤマモモ/山桃/楊梅"},"山々":{"variants":"山々/山山"},"山山":{"variants":"山々/山山"},"ヤマユリ":{"variants":"ヤマユリ/山百合"},"山百合":{"variants":"ヤマユリ/山百合"},"やみ":{"variants":"やみ/ヤミ/闇"},"ヤミ":{"variants":"やみ/ヤミ/闇"},"闇":{"variants":"やみ/ヤミ/闇"},"病みあがり":{"variants":"病みあがり/病み上がり/病み上り"},"病み上がり":{"variants":"病みあがり/病み上がり/病み上り"},"病み上り":{"variants":"病みあがり/病み上がり/病み上り"},"やみ市":{"variants":"やみ市/闇市"},"闇市":{"variants":"やみ市/闇市"},"やみ討ち":{"variants":"やみ討ち/闇討"},"闇討":{"variants":"やみ討ち/闇討"},"やみくも":{"variants":"やみくも/闇雲"},"闇雲":{"variants":"やみくも/闇雲"},"やみ相場":{"variants":"やみ相場/闇相場"},"闇相場":{"variants":"やみ相場/闇相場"},"病みつき":{"variants":"病みつき/病み付き"},"病み付き":{"variants":"病みつき/病み付き"},"やみつく":{"variants":"やみつく/病みつく"},"病みつく":{"variants":"やみつく/病みつく"},"やみ取引":{"variants":"やみ取引/闇取引"},"闇取引":{"variants":"やみ取引/闇取引"},"やみほおける":{"variants":"やみほおける/病みほおける"},"病みほおける":{"variants":"やみほおける/病みほおける"},"やみ屋":{"variants":"やみ屋/闇屋"},"闇屋":{"variants":"やみ屋/闇屋"},"やみ夜":{"variants":"やみ夜/闇夜"},"闇夜":{"variants":"やみ夜/闇夜"},"やむ":{"variants":"やむ/止む/病む"},"やむをえない":{"variants":"やむをえない/やむを得ない"},"やむを得ない":{"variants":"やむをえない/やむを得ない"},"やむをえる":{"variants":"やむをえる/やむを得る"},"やむを得る":{"variants":"やむをえる/やむを得る"},"やめる":{"variants":"やめる/辞める/罷める/病める/已める"},"ヤモリ":{"variants":"ヤモリ/守宮"},"守宮":{"variants":"ヤモリ/守宮"},"やゆ":{"variants":"やゆ/揶揄"},"揶揄":{"variants":"やゆ/揶揄"},"やりあう":{"variants":"やりあう/やり合う/遣り合う"},"やり合う":{"variants":"やりあう/やり合う/遣り合う"},"遣り合う":{"variants":"やりあう/やり合う/遣り合う"},"ヤリイカ":{"variants":"ヤリイカ/槍烏賊"},"槍烏賊":{"variants":"ヤリイカ/槍烏賊"},"やりかえす":{"variants":"やりかえす/やり返す/遣り返す"},"やり返す":{"variants":"やりかえす/やり返す/遣り返す"},"遣り返す":{"variants":"やりかえす/やり返す/遣り返す"},"やりかえせる":{"variants":"やりかえせる/やり返せる"},"やり返せる":{"variants":"やりかえせる/やり返せる"},"やりきれない":{"variants":"やりきれない/やり切れない"},"やり切れない":{"variants":"やりきれない/やり切れない"},"やり口":{"variants":"やり口/遣り口"},"遣り口":{"variants":"やり口/遣り口"},"やり繰り":{"variants":"やり繰り/遣り繰り"},"遣り繰り":{"variants":"やり繰り/遣り繰り"},"やりこなす":{"variants":"やりこなす/遣りこなす"},"遣りこなす":{"variants":"やりこなす/遣りこなす"},"やりこめる":{"variants":"やりこめる/やり込める/遣り込める"},"やり込める":{"variants":"やりこめる/やり込める/遣り込める"},"遣り込める":{"variants":"やりこめる/やり込める/遣り込める"},"やりすごす":{"variants":"やりすごす/やり過ごす/やり過す/遣り過す"},"やり過ごす":{"variants":"やりすごす/やり過ごす/やり過す/遣り過す"},"やり過す":{"variants":"やりすごす/やり過ごす/やり過す/遣り過す"},"遣り過す":{"variants":"やりすごす/やり過ごす/やり過す/遣り過す"},"やりすごせる":{"variants":"やりすごせる/やり過ごせる"},"やり過ごせる":{"variants":"やりすごせる/やり過ごせる"},"やり玉":{"variants":"やり玉/槍玉"},"槍玉":{"variants":"やり玉/槍玉"},"やりっ放し":{"variants":"やりっ放し/遣りっ放し"},"遣りっ放し":{"variants":"やりっ放し/遣りっ放し"},"やり手":{"variants":"やり手/遣手"},"遣手":{"variants":"やり手/遣手"},"やりとげる":{"variants":"やりとげる/やり遂げる/遣り遂げる"},"やり遂げる":{"variants":"やりとげる/やり遂げる/遣り遂げる"},"遣り遂げる":{"variants":"やりとげる/やり遂げる/遣り遂げる"},"やり取り":{"variants":"やり取り/遣り取り"},"遣り取り":{"variants":"やり取り/遣り取り"},"やりなおす":{"variants":"やりなおす/やり直す"},"やり直す":{"variants":"やりなおす/やり直す"},"やりなおせる":{"variants":"やりなおせる/やり直せる"},"やり直せる":{"variants":"やりなおせる/やり直せる"},"やり投げ":{"variants":"やり投げ/槍投げ"},"槍投げ":{"variants":"やり投げ/槍投げ"},"やり場":{"variants":"やり場/遣り場"},"遣り場":{"variants":"やり場/遣り場"},"やる":{"variants":"やる/遣る/殺る"},"やれやれ":{"variants":"やれやれ/ヤレヤレ"},"ヤレヤレ":{"variants":"やれやれ/ヤレヤレ"},"やれる":{"variants":"やれる/遣れる"},"遣れる":{"variants":"やれる/遣れる"},"やわ":{"variants":"やわ/ヤワ"},"ヤワ":{"variants":"やわ/ヤワ"},"柔":{"variants":"柔/柔ら"},"柔ら":{"variants":"柔/柔ら"},"やわらかい":{"variants":"やわらかい/柔かい/柔らかい/軟かい/軟らかい"},"柔らかい":{"variants":"やわらかい/柔かい/柔らかい"},"柔かい":{"variants":"やわらかい/柔かい/柔らかい"},"軟らかい":{"variants":"やわらかい/軟かい/軟らかい"},"軟かい":{"variants":"やわらかい/軟かい/軟らかい"},"柔らかもの":{"variants":"柔らかもの/柔らか物"},"柔らか物":{"variants":"柔らかもの/柔らか物"},"やわらぐ":{"variants":"やわらぐ/和らぐ"},"和らぐ":{"variants":"やわらぐ/和らぐ"},"やわらげる":{"variants":"やわらげる/和らげる"},"和らげる":{"variants":"やわらげる/和らげる"},"Ｕターン":{"variants":"Ｕターン/ユーターン"},"ユーターン":{"variants":"Ｕターン/ユーターン"},"湯あか":{"variants":"湯あか/湯垢"},"湯垢":{"variants":"湯あか/湯垢"},"湯あがり":{"variants":"湯あがり/湯上がり/湯上り"},"湯上がり":{"variants":"湯あがり/湯上がり/湯上り"},"湯上り":{"variants":"湯あがり/湯上がり/湯上り"},"ゆいあげる":{"variants":"ゆいあげる/結い上げる/結上げる"},"結い上げる":{"variants":"ゆいあげる/結い上げる/結上げる"},"結上げる":{"variants":"ゆいあげる/結い上げる/結上げる"},"ゆう":{"variants":"ゆう/結う"},"結う":{"variants":"ゆう/結う"},"ゆううつ":{"variants":"ゆううつ/ユウウツ/憂うつ/憂鬱"},"ユウウツ":{"variants":"ゆううつ/ユウウツ/憂うつ/憂鬱"},"憂うつ":{"variants":"憂うつ/憂鬱"},"憂鬱":{"variants":"憂うつ/憂鬱"},"有がい":{"variants":"有がい/有害"},"有蓋":{"variants":"有がい/有蓋"},"有害":{"variants":"有がい/有害"},"ユウガオ":{"variants":"ユウガオ/夕顔"},"夕顔":{"variants":"ユウガオ/夕顔"},"ゆうきづく":{"variants":"ゆうきづく/勇気づく"},"勇気づく":{"variants":"ゆうきづく/勇気づく"},"ゆうきづける":{"variants":"ゆうきづける/勇気づける"},"勇気づける":{"variants":"ゆうきづける/勇気づける"},"ゆうぎ":{"variants":"ゆうぎ/友誼/遊技"},"夕ぐれ":{"variants":"夕ぐれ/夕暮"},"夕暮":{"variants":"夕ぐれ/夕暮"},"夕げ":{"variants":"夕げ/夕餉"},"夕餉":{"variants":"夕げ/夕餉"},"ゆうげん":{"variants":"ゆうげん/幽玄/有限"},"ゆうこん":{"variants":"ゆうこん/雄渾"},"雄渾":{"variants":"ゆうこん/雄渾"},"夕ごはん":{"variants":"夕ごはん/夕御飯"},"夕御飯":{"variants":"夕ごはん/夕御飯"},"ゆうする":{"variants":"ゆうする/幽する/有する"},"ゆうぜんと":{"variants":"ゆうぜんと/悠然と"},"悠然と":{"variants":"ゆうぜんと/悠然と"},"夕立":{"variants":"夕立/夕立ち"},"夕立ち":{"variants":"夕立/夕立ち"},"夕なぎ":{"variants":"夕なぎ/夕凪"},"夕凪":{"variants":"夕なぎ/夕凪"},"ゆうに":{"variants":"ゆうに/優に"},"優に":{"variants":"ゆうに/優に"},"夕映":{"variants":"夕映/夕映え"},"夕映え":{"variants":"夕映/夕映え"},"夕やけ":{"variants":"夕やけ/夕焼け"},"夕焼け":{"variants":"夕やけ/夕焼け"},"夕やみ":{"variants":"夕やみ/夕闇"},"夕闇":{"variants":"夕やみ/夕闇"},"ゆうゆう":{"variants":"ゆうゆう/悠々"},"悠々":{"variants":"悠々/悠悠"},"悠悠":{"variants":"悠々/悠悠"},"悠々閑々":{"variants":"悠々閑々/悠悠閑閑"},"悠悠閑閑":{"variants":"悠々閑々/悠悠閑閑"},"悠々自適":{"variants":"悠々自適/悠悠自適"},"悠悠自適":{"variants":"悠々自適/悠悠自適"},"遊よく":{"variants":"遊よく/遊弋"},"遊弋":{"variants":"遊よく/遊弋"},"ゆえ":{"variants":"ゆえ/故"},"故":{"variants":"ゆえ/故"},"ゆえに":{"variants":"ゆえに/故に"},"故に":{"variants":"ゆえに/故に"},"ゆえん":{"variants":"ゆえん/所以/油煙/由縁"},"ゆかしい":{"variants":"ゆかしい/床しい"},"床しい":{"variants":"ゆかしい/床しい"},"浴衣がけ":{"variants":"浴衣がけ/浴衣掛け"},"浴衣掛け":{"variants":"浴衣がけ/浴衣掛け"},"ゆがく":{"variants":"ゆがく/湯掻く"},"湯掻く":{"variants":"ゆがく/湯掻く"},"ゆがみ":{"variants":"ゆがみ/歪み"},"歪み":{"variants":"ゆがみ/歪み"},"ゆがめる":{"variants":"ゆがめる/歪める"},"歪める":{"variants":"ゆがめる/歪める"},"ゆき":{"variants":"ゆき/往き/雪/裄"},"雪あかり":{"variants":"雪あかり/雪明り"},"雪明り":{"variants":"雪あかり/雪明り"},"雪うさぎ":{"variants":"雪うさぎ/雪兎"},"雪兎":{"variants":"雪うさぎ/雪兎"},"雪おろし":{"variants":"雪おろし/雪下ろし"},"雪下ろし":{"variants":"雪おろし/雪下ろし"},"雪かき":{"variants":"雪かき/雪掻き"},"雪掻き":{"variants":"雪かき/雪掻き"},"雪けむり":{"variants":"雪けむり/雪煙"},"雪煙":{"variants":"雪けむり/雪煙"},"雪だるま":{"variants":"雪だるま/雪達磨"},"雪達磨":{"variants":"雪だるま/雪達磨"},"雪どけ":{"variants":"雪どけ/雪解け"},"雪解け":{"variants":"雪どけ/雪解け"},"ユキノシタ":{"variants":"ユキノシタ/雪の下"},"雪の下":{"variants":"ユキノシタ/雪の下"},"ユキヤナギ":{"variants":"ユキヤナギ/雪柳"},"雪柳":{"variants":"ユキヤナギ/雪柳"},"ユキワリソウ":{"variants":"ユキワリソウ/雪割草"},"雪割草":{"variants":"ユキワリソウ/雪割草"},"ゆく":{"variants":"ゆく/行く"},"行く先":{"variants":"行く先/行先"},"行先":{"variants":"行く先/行先"},"行く末":{"variants":"行く末/行末"},"行末":{"variants":"行く末/行末"},"行く手":{"variants":"行く手/行手"},"行手":{"variants":"行く手/行手"},"ゆくゆく":{"variants":"ゆくゆく/行くゆく/行く行く"},"行くゆく":{"variants":"ゆくゆく/行くゆく/行く行く"},"行く行く":{"variants":"ゆくゆく/行くゆく/行く行く"},"湯けむり":{"variants":"湯けむり/湯煙/湯烟"},"ゆける":{"variants":"ゆける/往ける"},"往ける":{"variants":"ゆける/往ける"},"ゆさぶる":{"variants":"ゆさぶる/揺さぶる"},"揺さぶる":{"variants":"ゆさぶる/揺さぶる"},"ゆさぶれる":{"variants":"ゆさぶれる/揺さぶれる"},"揺さぶれる":{"variants":"ゆさぶれる/揺さぶれる"},"湯ざまし":{"variants":"湯ざまし/湯冷まし"},"湯冷まし":{"variants":"湯ざまし/湯冷まし"},"ゆすぶる":{"variants":"ゆすぶる/揺すぶる"},"揺すぶる":{"variants":"ゆすぶる/揺すぶる"},"ユスラウメ":{"variants":"ユスラウメ/梅桃"},"梅桃":{"variants":"ユスラウメ/梅桃"},"ゆする":{"variants":"ゆする/揺する"},"輸する":{"variants":"ゆする/輸する"},"揺する":{"variants":"ゆする/揺する"},"ユズ":{"variants":"ユズ/柚/柚子"},"ゆずりあう":{"variants":"ゆずりあう/譲り合う"},"譲り合う":{"variants":"ゆずりあう/譲り合う"},"ゆずりうける":{"variants":"ゆずりうける/譲り受ける"},"譲り受ける":{"variants":"ゆずりうける/譲り受ける"},"ゆずり葉":{"variants":"ゆずり葉/ユズリハ/譲葉"},"ユズリハ":{"variants":"ゆずり葉/ユズリハ/譲葉"},"譲葉":{"variants":"ゆずり葉/ユズリハ/譲葉"},"ゆずりわたす":{"variants":"ゆずりわたす/譲り渡す"},"譲り渡す":{"variants":"ゆずりわたす/譲り渡す"},"ゆずりわたせる":{"variants":"ゆずりわたせる/譲り渡せる"},"譲り渡せる":{"variants":"ゆずりわたせる/譲り渡せる"},"ゆずる":{"variants":"ゆずる/譲る"},"譲る":{"variants":"ゆずる/譲る"},"ゆずれる":{"variants":"ゆずれる/譲れる"},"譲れる":{"variants":"ゆずれる/譲れる"},"湯せん":{"variants":"湯せん/湯煎/湯銭"},"ゆたか":{"variants":"ゆたか/豊か"},"豊か":{"variants":"ゆたか/豊か"},"湯たんぽ":{"variants":"湯たんぽ/湯湯婆"},"湯湯婆":{"variants":"湯たんぽ/湯湯婆"},"ゆだねる":{"variants":"ゆだねる/委ねる"},"委ねる":{"variants":"ゆだねる/委ねる"},"ゆ着":{"variants":"ゆ着/癒着"},"癒着":{"variants":"ゆ着/癒着"},"ゆでダコ":{"variants":"ゆでダコ/ゆで蛸/茹でダコ/茹で蛸"},"ゆで蛸":{"variants":"ゆでダコ/ゆで蛸/茹でダコ/茹で蛸"},"茹でダコ":{"variants":"ゆでダコ/ゆで蛸/茹でダコ/茹で蛸"},"茹で蛸":{"variants":"ゆでダコ/ゆで蛸/茹でダコ/茹で蛸"},"ゆでる":{"variants":"ゆでる/茹でる"},"茹でる":{"variants":"ゆでる/茹でる"},"湯桶読":{"variants":"湯桶読/湯桶読み"},"湯桶読み":{"variants":"湯桶読/湯桶読み"},"湯のみ":{"variants":"湯のみ/湯飲み/湯呑/湯呑み"},"湯呑":{"variants":"湯のみ/湯呑/湯呑み"},"湯呑み":{"variants":"湯のみ/湯呑/湯呑み"},"ゆびく":{"variants":"ゆびく/湯引く"},"湯引く":{"variants":"ゆびく/湯引く"},"ゆびさす":{"variants":"ゆびさす/指さす"},"指さす":{"variants":"ゆびさす/指さす"},"指ぬき":{"variants":"指ぬき/指貫"},"指貫":{"variants":"指ぬき/指貫"},"湯ぶね":{"variants":"湯ぶね/湯船/湯槽"},"弓取":{"variants":"弓取/弓取り"},"弓取り":{"variants":"弓取/弓取り"},"ゆみひく":{"variants":"ゆみひく/弓引く"},"弓引く":{"variants":"ゆみひく/弓引く"},"ユメ":{"variants":"ユメ/夢"},"夢":{"variants":"ユメ/夢"},"夢うつつ":{"variants":"夢うつつ/夢現"},"夢現":{"variants":"夢うつつ/夢現"},"ゆめさら":{"variants":"ゆめさら/夢更"},"夢更":{"variants":"ゆめさら/夢更"},"夢まくら":{"variants":"夢まくら/夢枕"},"夢枕":{"variants":"夢まくら/夢枕"},"ゆめみる":{"variants":"ゆめみる/夢みる/夢見る"},"夢みる":{"variants":"ゆめみる/夢みる/夢見る"},"夢見る":{"variants":"ゆめみる/夢みる/夢見る"},"ゆゆしい":{"variants":"ゆゆしい/由々しい/由由しい"},"由々しい":{"variants":"ゆゆしい/由々しい/由由しい"},"由由しい":{"variants":"ゆゆしい/由々しい/由由しい"},"ゆらい":{"variants":"ゆらい/由来"},"由来":{"variants":"ゆらい/由来"},"ゆらぎ":{"variants":"ゆらぎ/揺らぎ"},"揺らぎ":{"variants":"ゆらぎ/揺らぎ"},"ゆらぐ":{"variants":"ゆらぐ/揺らぐ"},"揺らぐ":{"variants":"ゆらぐ/揺らぐ"},"ゆらす":{"variants":"ゆらす/揺らす"},"揺らす":{"variants":"ゆらす/揺らす"},"ゆらせる":{"variants":"ゆらせる/揺らせる"},"揺らせる":{"variants":"ゆらせる/揺らせる"},"ゆらめく":{"variants":"ゆらめく/揺らめく"},"揺らめく":{"variants":"ゆらめく/揺らめく"},"ゆらゆら":{"variants":"ゆらゆら/ユラユラ"},"ユラユラ":{"variants":"ゆらゆら/ユラユラ"},"ユリ":{"variants":"ユリ/百合"},"百合":{"variants":"ユリ/百合"},"ゆりうごかす":{"variants":"ゆりうごかす/揺り動かす"},"揺り動かす":{"variants":"ゆりうごかす/揺り動かす"},"ゆりうごかせる":{"variants":"ゆりうごかせる/揺り動かせる"},"揺り動かせる":{"variants":"ゆりうごかせる/揺り動かせる"},"ゆりおこす":{"variants":"ゆりおこす/揺り起こす"},"揺り起こす":{"variants":"ゆりおこす/揺り起こす"},"揺りかご":{"variants":"揺りかご/揺り篭"},"揺り篭":{"variants":"揺りかご/揺り篭"},"ユリカモメ":{"variants":"ユリカモメ/百合鴎"},"百合鴎":{"variants":"ユリカモメ/百合鴎"},"ゆる":{"variants":"ゆる/揺る"},"揺る":{"variants":"ゆる/揺る"},"ゆるい":{"variants":"ゆるい/緩い"},"緩い":{"variants":"ゆるい/緩い"},"ゆるがす":{"variants":"ゆるがす/揺がす/揺るがす"},"揺がす":{"variants":"ゆるがす/揺がす/揺るがす"},"揺るがす":{"variants":"ゆるがす/揺がす/揺るがす"},"揺ぎ":{"variants":"揺ぎ/揺るぎ"},"揺るぎ":{"variants":"揺ぎ/揺るぎ"},"揺出る":{"variants":"ゆるぎでる/ゆるぎ出る/揺出る"},"ゆるぎでる":{"variants":"ゆるぎでる/ゆるぎ出る/揺出る"},"ゆるぎ出る":{"variants":"ゆるぎでる/ゆるぎ出る/揺出る"},"ゆるぐ":{"variants":"ゆるぐ/揺ぐ/揺るぐ"},"揺ぐ":{"variants":"ゆるぐ/揺ぐ/揺るぐ"},"揺るぐ":{"variants":"ゆるぐ/揺ぐ/揺るぐ"},"ゆるす":{"variants":"ゆるす/許す/赦す"},"ゆるせる":{"variants":"ゆるせる/許せる"},"許せる":{"variants":"ゆるせる/許せる"},"ゆるまる":{"variants":"ゆるまる/緩まる"},"緩まる":{"variants":"ゆるまる/緩まる"},"ゆるむ":{"variants":"ゆるむ/緩む"},"緩む":{"variants":"ゆるむ/緩む"},"ゆるめる":{"variants":"ゆるめる/緩める/弛める"},"ゆるやか":{"variants":"ゆるやか/緩やか"},"緩やか":{"variants":"ゆるやか/緩やか"},"ゆれうごく":{"variants":"ゆれうごく/揺れ動く"},"揺れ動く":{"variants":"ゆれうごく/揺れ動く"},"ゆれる":{"variants":"ゆれる/揺れる/搖れる"},"ゆわえつける":{"variants":"ゆわえつける/ゆわえ付ける/結えつける/結え付ける/結わえ付ける"},"ゆわえ付ける":{"variants":"ゆわえつける/ゆわえ付ける/結えつける/結え付ける/結わえ付ける"},"結えつける":{"variants":"ゆわえつける/ゆわえ付ける/結えつける/結え付ける/結わえ付ける"},"結え付ける":{"variants":"ゆわえつける/ゆわえ付ける/結えつける/結え付ける/結わえ付ける"},"結わえ付ける":{"variants":"ゆわえつける/ゆわえ付ける/結えつける/結え付ける/結わえ付ける"},"ゆわえる":{"variants":"ゆわえる/結える/結わえる"},"結える":{"variants":"ゆわえる/結える/結わえる"},"結わえる":{"variants":"ゆわえる/結える/結わえる"},"湯わかし":{"variants":"湯わかし/湯沸かし/湯沸し"},"湯沸かし":{"variants":"湯わかし/湯沸かし/湯沸し"},"湯沸し":{"variants":"湯わかし/湯沸かし/湯沸し"},"ゆわく":{"variants":"ゆわく/結く"},"結く":{"variants":"ゆわく/結く"},"よ":{"variants":"よ/ヨ"},"ヨ":{"variants":"よ/ヨ"},"よー":{"variants":"よー/ヨー"},"ヨー":{"variants":"よー/ヨー"},"夜明かし":{"variants":"夜明かし/夜明し"},"夜明し":{"variants":"夜明かし/夜明し"},"よい":{"variants":"よい/佳い/好い/善い"},"酔い":{"variants":"酔/酔い"},"酔":{"variants":"酔/酔い"},"酔い心地":{"variants":"酔い心地/酔心地"},"酔心地":{"variants":"酔い心地/酔心地"},"酔いざめ":{"variants":"酔いざめ/酔い覚め/酔い醒め"},"よいしれる":{"variants":"よいしれる/酔いしれる"},"酔いしれる":{"variants":"よいしれる/酔いしれる"},"宵っぱり":{"variants":"宵っぱり/宵っ張り/宵張り"},"宵っ張り":{"variants":"宵っぱり/宵っ張り/宵張り"},"宵張り":{"variants":"宵っぱり/宵っ張り/宵張り"},"よいつぶれる":{"variants":"よいつぶれる/酔いつぶれる/酔い潰れる/酔潰れる"},"酔いつぶれる":{"variants":"よいつぶれる/酔いつぶれる/酔い潰れる/酔潰れる"},"酔い潰れる":{"variants":"よいつぶれる/酔いつぶれる/酔い潰れる/酔潰れる"},"酔潰れる":{"variants":"よいつぶれる/酔いつぶれる/酔い潰れる/酔潰れる"},"ヨイマチグサ":{"variants":"ヨイマチグサ/宵待草"},"宵待草":{"variants":"ヨイマチグサ/宵待草"},"宵祭":{"variants":"宵祭/宵祭り"},"宵祭り":{"variants":"宵祭/宵祭り"},"宵やみ":{"variants":"宵やみ/宵闇"},"宵闇":{"variants":"宵やみ/宵闇"},"よう":{"variants":"よう/様"},"酔う":{"variants":"よう/酔う"},"用":{"variants":"よう/用"},"ヨウエキ":{"variants":"ヨウエキ/溶液/用益/用役/葉腋"},"洋かん":{"variants":"洋かん/洋館"},"羊羹":{"variants":"羊かん/羊羹"},"羊かん":{"variants":"羊かん/羊羹"},"洋館":{"variants":"洋かん/洋館"},"要さい":{"variants":"要さい/要塞"},"要塞":{"variants":"要さい/要塞"},"ようじ":{"variants":"ようじ/幼児/幼時/楊子/楊枝/用事/用字/要事"},"ヨウジュ":{"variants":"ヨウジュ/榕樹"},"榕樹":{"variants":"ヨウジュ/榕樹"},"ようじんぶかい":{"variants":"ようじんぶかい/用心深い/要心深い"},"ようする":{"variants":"ようする/擁する/要する"},"ようするに":{"variants":"ようするに/要するに"},"要するに":{"variants":"ようするに/要するに"},"用せん":{"variants":"用せん/用箋"},"用箋":{"variants":"用せん/用箋"},"用達":{"variants":"用達/用達し"},"用足し":{"variants":"用足/用足し"},"用足":{"variants":"用足/用足し"},"用達し":{"variants":"用達/用達し"},"ようだいぶる":{"variants":"ようだいぶる/容体ぶる/容態ぶる"},"ようだてる":{"variants":"ようだてる/用立てる"},"用立てる":{"variants":"ようだてる/用立てる"},"夜討":{"variants":"夜討/夜討ち"},"夜討ち":{"variants":"夜討/夜討ち"},"よう度チンキ":{"variants":"よう度チンキ/沃度チンキ"},"沃度チンキ":{"variants":"よう度チンキ/沃度チンキ"},"よう度ホルム":{"variants":"よう度ホルム/沃度ホルム"},"沃度ホルム":{"variants":"よう度ホルム/沃度ホルム"},"ヨウナシ":{"variants":"ヨウナシ/洋梨"},"洋梨":{"variants":"ヨウナシ/洋梨"},"ようは":{"variants":"ようは/要は"},"要は":{"variants":"ようは/要は"},"ヨウヘイ":{"variants":"ヨウヘイ/傭兵/用兵/葉柄"},"容ぼう":{"variants":"容ぼう/容貌"},"容貌":{"variants":"容ぼう/容貌"},"ようやく":{"variants":"ようやく/漸く"},"漸く":{"variants":"ようやく/漸く"},"ようよう":{"variants":"ようよう/漸う"},"漸う":{"variants":"ようよう/漸う"},"洋々":{"variants":"洋々/洋洋"},"洋洋":{"variants":"洋々/洋洋"},"揚揚":{"variants":"揚々/揚揚"},"揚々":{"variants":"揚々/揚揚"},"よえる":{"variants":"よえる/酔える"},"酔える":{"variants":"よえる/酔える"},"よがる":{"variants":"よがる/善がる"},"善がる":{"variants":"よがる/善がる"},"よぎない":{"variants":"よぎない/余儀ない"},"余儀ない":{"variants":"よぎない/余儀ない"},"よぎる":{"variants":"よぎる/過ぎる/過る"},"過る":{"variants":"よぎる/過ぎる/過る"},"よく":{"variants":"よく/良く"},"良く":{"variants":"よく/良く"},"よくする":{"variants":"よくする/能くする/浴する"},"欲得ずく":{"variants":"欲得ずく/欲得尽く"},"欲得尽く":{"variants":"欲得ずく/欲得尽く"},"欲ばり":{"variants":"欲ばり/欲張り"},"欲張り":{"variants":"欲ばり/欲張り"},"よくばる":{"variants":"よくばる/欲張る"},"欲張る":{"variants":"よくばる/欲張る"},"翼翼":{"variants":"翼々/翼翼"},"翼々":{"variants":"翼々/翼翼"},"翌々月":{"variants":"翌々月/翌翌月"},"翌翌月":{"variants":"翌々月/翌翌月"},"翌々週":{"variants":"翌々週/翌翌週"},"翌翌週":{"variants":"翌々週/翌翌週"},"翌々日":{"variants":"翌々日/翌翌日"},"翌翌日":{"variants":"翌々日/翌翌日"},"翌々年":{"variants":"翌々年/翌翌年"},"翌翌年":{"variants":"翌々年/翌翌年"},"よけい":{"variants":"よけい/余計"},"余計":{"variants":"よけい/余計"},"余慶":{"variants":"よけい/余慶"},"ヨコ":{"variants":"ヨコ/横"},"横":{"variants":"ヨコ/横"},"横あい":{"variants":"横あい/横合い"},"横合い":{"variants":"横あい/横合い"},"よこ糸":{"variants":"よこ糸/横糸"},"横糸":{"variants":"よこ糸/横糸"},"よこぎる":{"variants":"よこぎる/横切る"},"横切る":{"variants":"よこぎる/横切る"},"よこぎれる":{"variants":"よこぎれる/横切れる"},"横切れる":{"variants":"よこぎれる/横切れる"},"横ざま":{"variants":"横ざま/横様"},"横様":{"variants":"横ざま/横様"},"よこしま":{"variants":"よこしま/邪"},"邪":{"variants":"よこしま/邪"},"よこす":{"variants":"よこす/寄こす/寄越す"},"寄こす":{"variants":"よこす/寄こす/寄越す"},"寄越す":{"variants":"よこす/寄こす/寄越す"},"横すべり":{"variants":"横すべり/横滑り/横辷り"},"よこずき":{"variants":"よこずき/横好き"},"横好き":{"variants":"よこずき/横好き"},"よこたえる":{"variants":"よこたえる/横たえる"},"横たえる":{"variants":"よこたえる/横たえる"},"よこたわる":{"variants":"よこたわる/横たわる"},"横たわる":{"variants":"よこたわる/横たわる"},"横っつら":{"variants":"横っつら/横っ面"},"横っ面":{"variants":"横っつら/横っ面"},"横っとび":{"variants":"横っとび/横っ跳び/横っ飛び"},"横っぱら":{"variants":"横っぱら/横っ腹"},"横っ腹":{"variants":"横っぱら/横っ腹"},"横ならび":{"variants":"横ならび/横並び"},"横並び":{"variants":"横ならび/横並び"},"ヨコバイ":{"variants":"ヨコバイ/横バイ/横這い"},"横バイ":{"variants":"ヨコバイ/横バイ/横這い"},"横這い":{"variants":"ヨコバイ/横バイ/横這い"},"横やり":{"variants":"横やり/横槍"},"横槍":{"variants":"横やり/横槍"},"よし":{"variants":"よし/ヨシ/由"},"縦し":{"variants":"よし/縦し"},"ヨシ":{"variants":"よし/ヨシ/由"},"由":{"variants":"よし/ヨシ/由"},"よしあし":{"variants":"よしあし/善しあし/善し悪し/良しあし"},"善し悪し":{"variants":"よしあし/善しあし/善し悪し"},"善しあし":{"variants":"よしあし/善しあし/善し悪し"},"ヨシキリ":{"variants":"ヨシキリ/葦切り"},"葦切り":{"variants":"ヨシキリ/葦切り"},"よしない":{"variants":"よしない/由無い"},"由無い":{"variants":"よしない/由無い"},"よしなに":{"variants":"よしなに/良しなに"},"良しなに":{"variants":"よしなに/良しなに"},"ヨシノザクラ":{"variants":"ヨシノザクラ/吉野桜"},"吉野桜":{"variants":"ヨシノザクラ/吉野桜"},"ヨシノボリ":{"variants":"ヨシノボリ/葦登"},"葦登":{"variants":"ヨシノボリ/葦登"},"ヨシワラスズメ":{"variants":"ヨシワラスズメ/葦原雀"},"葦原雀":{"variants":"ヨシワラスズメ/葦原雀"},"よしんば":{"variants":"よしんば/縦しんば"},"縦しんば":{"variants":"よしんば/縦しんば"},"よじのぼる":{"variants":"よじのぼる/よじ登る/攀じ登る"},"よじ登る":{"variants":"よじのぼる/よじ登る/攀じ登る"},"攀じ登る":{"variants":"よじのぼる/よじ登る/攀じ登る"},"よじのぼれる":{"variants":"よじのぼれる/よじ登れる"},"よじ登れる":{"variants":"よじのぼれる/よじ登れる"},"よじる":{"variants":"よじる/攀じる"},"攀じる":{"variants":"よじる/攀じる"},"余じん":{"variants":"余じん/余塵/余燼"},"よす":{"variants":"よす/止す"},"止す":{"variants":"よす/止す"},"世捨て人":{"variants":"世捨て人/世捨人"},"世捨人":{"variants":"世捨て人/世捨人"},"寄せ":{"variants":"寄せ/寄席"},"寄席":{"variants":"寄せ/寄席"},"よせかける":{"variants":"よせかける/寄せかける/寄せ掛ける"},"寄せかける":{"variants":"よせかける/寄せかける/寄せ掛ける"},"寄せ掛ける":{"variants":"よせかける/寄せかける/寄せ掛ける"},"寄せ書き":{"variants":"寄せ書き/寄書き"},"寄書き":{"variants":"寄せ書き/寄書き"},"寄せ木":{"variants":"寄せ木/寄木"},"寄木":{"variants":"寄せ木/寄木"},"寄せ切れ":{"variants":"寄せ切れ/寄切れ"},"寄切れ":{"variants":"寄せ切れ/寄切れ"},"よせつける":{"variants":"よせつける/寄せつける/寄せ付ける"},"寄せつける":{"variants":"よせつける/寄せつける/寄せ付ける"},"寄せ付ける":{"variants":"よせつける/寄せつける/寄せ付ける"},"寄せ手":{"variants":"寄せ手/寄手"},"寄手":{"variants":"寄せ手/寄手"},"寄せ鍋":{"variants":"寄せ鍋/寄鍋"},"寄鍋":{"variants":"寄せ鍋/寄鍋"},"寄せ場":{"variants":"寄せ場/寄場"},"寄場":{"variants":"寄せ場/寄場"},"よせる":{"variants":"よせる/寄せる"},"寄せる":{"variants":"よせる/寄せる"},"よそ":{"variants":"よそ/余所"},"余所":{"variants":"よそ/余所"},"よそおう":{"variants":"よそおう/粧う"},"粧う":{"variants":"よそおう/粧う"},"よそおえる":{"variants":"よそおえる/装える"},"装える":{"variants":"よそおえる/装える"},"よそ事":{"variants":"よそ事/余所事"},"余所事":{"variants":"よそ事/余所事"},"よそ見":{"variants":"よそ見/余所見"},"余所見":{"variants":"よそ見/余所見"},"よそ目":{"variants":"よそ目/余所目"},"余所目":{"variants":"よそ目/余所目"},"よそ者":{"variants":"よそ者/余所者"},"余所者":{"variants":"よそ者/余所者"},"ヨタカ":{"variants":"ヨタカ/夜鷹"},"夜鷹":{"variants":"ヨタカ/夜鷹"},"よたる":{"variants":"よたる/与太る"},"与太る":{"variants":"よたる/与太る"},"よだつ":{"variants":"よだつ/弥立つ"},"弥立つ":{"variants":"よだつ/弥立つ"},"よだれかけ":{"variants":"よだれかけ/涎掛け"},"涎掛け":{"variants":"よだれかけ/涎掛け"},"よちよち":{"variants":"よちよち/ヨチヨチ"},"ヨチヨチ":{"variants":"よちよち/ヨチヨチ"},"４つ":{"variants":"４つ/四つ"},"四つ":{"variants":"４つ/四つ"},"酔っぱらい":{"variants":"酔っぱらい/酔払い"},"酔払い":{"variants":"酔っぱらい/酔払い"},"よっぱらう":{"variants":"よっぱらう/酔っぱらう/酔っ払う/酔払う"},"酔っぱらう":{"variants":"よっぱらう/酔っぱらう/酔っ払う/酔払う"},"酔っ払う":{"variants":"よっぱらう/酔っぱらう/酔っ払う/酔払う"},"酔払う":{"variants":"よっぱらう/酔っぱらう/酔っ払う/酔払う"},"よっぱらえる":{"variants":"よっぱらえる/酔っぱらえる"},"酔っぱらえる":{"variants":"よっぱらえる/酔っぱらえる"},"よっぴて":{"variants":"よっぴて/夜っぴて"},"夜っぴて":{"variants":"よっぴて/夜っぴて"},"四つ切り":{"variants":"四つ切り/四切り"},"四切り":{"variants":"四つ切り/四切り"},"四つ相撲":{"variants":"四つ相撲/四相撲"},"四相撲":{"variants":"四つ相撲/四相撲"},"よつ葉":{"variants":"よつ葉/四葉"},"四葉":{"variants":"よつ葉/四葉"},"四つ身":{"variants":"四つ身/四身"},"四身":{"variants":"四つ身/四身"},"四つ目":{"variants":"四つ目/四目"},"四目":{"variants":"四つ目/四目"},"よつん這い":{"variants":"よつん這い/四つんばい/四つん這い"},"四つんばい":{"variants":"よつん這い/四つんばい/四つん這い"},"四つん這い":{"variants":"よつん這い/四つんばい/四つん這い"},"よづく":{"variants":"よづく/世づく"},"世づく":{"variants":"よづく/世づく"},"ヨトウムシ":{"variants":"ヨトウムシ/夜盗虫"},"夜盗虫":{"variants":"ヨトウムシ/夜盗虫"},"よどおし":{"variants":"よどおし/夜どおし/夜通し"},"夜どおし":{"variants":"夜どおし/夜通し"},"夜通し":{"variants":"夜どおし/夜通し"},"よどみ":{"variants":"よどみ/澱み/淀み"},"よどむ":{"variants":"よどむ/澱む/淀む"},"よなよな":{"variants":"よなよな/夜な夜な"},"夜な夜な":{"variants":"よなよな/夜な夜な"},"よなれる":{"variants":"よなれる/世慣れる/世馴れる"},"よに":{"variants":"よに/世に"},"世に":{"variants":"よに/世に"},"夜這":{"variants":"夜這/夜這い"},"夜這い":{"variants":"夜這/夜這い"},"よばなれる":{"variants":"よばなれる/世離れる"},"世離れる":{"variants":"よばなれる/世離れる"},"よばれる":{"variants":"よばれる/呼ばれる"},"呼ばれる":{"variants":"よばれる/呼ばれる"},"よばわる":{"variants":"よばわる/呼ばわる"},"呼ばわる":{"variants":"よばわる/呼ばわる"},"よびあげる":{"variants":"よびあげる/呼び上げる"},"呼び上げる":{"variants":"よびあげる/呼び上げる"},"よびいれる":{"variants":"よびいれる/呼びいれる/呼び入れる/呼入れる"},"呼びいれる":{"variants":"よびいれる/呼びいれる/呼び入れる/呼入れる"},"呼び入れる":{"variants":"よびいれる/呼びいれる/呼び入れる/呼入れる"},"呼入れる":{"variants":"よびいれる/呼びいれる/呼び入れる/呼入れる"},"よびおこす":{"variants":"よびおこす/呼び起こす"},"呼び起こす":{"variants":"よびおこす/呼び起こす"},"呼び掛け":{"variants":"呼び掛け/呼掛け"},"呼掛け":{"variants":"呼び掛け/呼掛け"},"よびかける":{"variants":"よびかける/呼びかける/呼び掛ける/呼掛ける"},"呼びかける":{"variants":"よびかける/呼びかける/呼び掛ける/呼掛ける"},"呼び掛ける":{"variants":"よびかける/呼びかける/呼び掛ける/呼掛ける"},"呼掛ける":{"variants":"よびかける/呼びかける/呼び掛ける/呼掛ける"},"よびかわす":{"variants":"よびかわす/呼び交す"},"呼び交す":{"variants":"よびかわす/呼び交す"},"呼び子":{"variants":"呼び子/呼子"},"呼子":{"variants":"呼び子/呼子"},"よびこむ":{"variants":"よびこむ/呼び込む/呼込む"},"呼び込む":{"variants":"よびこむ/呼び込む/呼込む"},"呼込む":{"variants":"よびこむ/呼び込む/呼込む"},"よびこめる":{"variants":"よびこめる/呼び込める"},"呼び込める":{"variants":"よびこめる/呼び込める"},"呼び声":{"variants":"呼び声/呼声"},"呼声":{"variants":"呼び声/呼声"},"よびさけぶ":{"variants":"よびさけぶ/呼び叫ぶ"},"呼び叫ぶ":{"variants":"よびさけぶ/呼び叫ぶ"},"よびさます":{"variants":"よびさます/呼び覚ます"},"呼び覚ます":{"variants":"よびさます/呼び覚ます"},"呼び塩":{"variants":"呼び塩/呼塩"},"呼塩":{"variants":"呼び塩/呼塩"},"呼びすて":{"variants":"呼びすて/呼捨て"},"呼捨て":{"variants":"呼びすて/呼捨て"},"よびたてる":{"variants":"よびたてる/呼び立てる"},"呼び立てる":{"variants":"よびたてる/呼び立てる"},"呼び出し":{"variants":"呼び出し/呼出し"},"呼出し":{"variants":"呼び出し/呼出し"},"呼びだし":{"variants":"呼びだし/呼出"},"呼出":{"variants":"呼びだし/呼出"},"よびだす":{"variants":"よびだす/呼び出す/呼出す"},"呼び出す":{"variants":"よびだす/呼び出す/呼出す"},"呼出す":{"variants":"よびだす/呼び出す/呼出す"},"よびだせる":{"variants":"よびだせる/呼び出せる"},"呼び出せる":{"variants":"よびだせる/呼び出せる"},"よびつける":{"variants":"よびつける/呼びつける/呼び付ける/呼付ける"},"呼びつける":{"variants":"よびつける/呼びつける/呼び付ける/呼付ける"},"呼び付ける":{"variants":"よびつける/呼びつける/呼び付ける/呼付ける"},"呼付ける":{"variants":"よびつける/呼びつける/呼び付ける/呼付ける"},"よびつづける":{"variants":"よびつづける/呼び続ける"},"呼び続ける":{"variants":"よびつづける/呼び続ける"},"よびとめる":{"variants":"よびとめる/呼び止める"},"呼び止める":{"variants":"よびとめる/呼び止める"},"よび名":{"variants":"よび名/呼び名/呼名"},"呼び名":{"variants":"よび名/呼び名/呼名"},"呼名":{"variants":"よび名/呼び名/呼名"},"呼び値":{"variants":"呼び値/呼値"},"呼値":{"variants":"呼び値/呼値"},"呼び水":{"variants":"呼び水/呼水"},"呼水":{"variants":"呼び水/呼水"},"よびもどす":{"variants":"よびもどす/呼び戻す/呼戻す"},"呼び戻す":{"variants":"よびもどす/呼び戻す/呼戻す"},"呼戻す":{"variants":"よびもどす/呼び戻す/呼戻す"},"よびもどせる":{"variants":"よびもどせる/呼び戻せる"},"呼び戻せる":{"variants":"よびもどせる/呼び戻せる"},"呼びもの":{"variants":"呼びもの/呼び物/呼物"},"呼び物":{"variants":"呼びもの/呼び物/呼物"},"呼物":{"variants":"呼びもの/呼び物/呼物"},"よびよせる":{"variants":"よびよせる/呼び寄せる/呼寄せる"},"呼び寄せる":{"variants":"よびよせる/呼び寄せる/呼寄せる"},"呼寄せる":{"variants":"よびよせる/呼び寄せる/呼寄せる"},"呼び鈴":{"variants":"呼び鈴/呼鈴"},"呼鈴":{"variants":"呼び鈴/呼鈴"},"夜ふかし":{"variants":"夜ふかし/夜更し"},"夜更し":{"variants":"夜ふかし/夜更し"},"夜ふけ":{"variants":"夜ふけ/夜更け"},"夜更け":{"variants":"夜ふけ/夜更け"},"よぶ":{"variants":"よぶ/喚ぶ/呼ぶ"},"ヨブコドリ":{"variants":"ヨブコドリ/呼子鳥"},"呼子鳥":{"variants":"ヨブコドリ/呼子鳥"},"よべる":{"variants":"よべる/呼べる"},"呼べる":{"variants":"よべる/呼べる"},"よぼう":{"variants":"よぼう/輿望"},"輿望":{"variants":"よぼう/輿望"},"世迷い言":{"variants":"世迷い言/世迷言"},"世迷言":{"variants":"世迷い言/世迷言"},"よみあげる":{"variants":"よみあげる/読み上げる/読上げる"},"読み上げる":{"variants":"よみあげる/読み上げる/読上げる"},"読上げる":{"variants":"よみあげる/読み上げる/読上げる"},"よみあさる":{"variants":"よみあさる/読みあさる"},"読みあさる":{"variants":"よみあさる/読みあさる"},"よみあわす":{"variants":"よみあわす/読み合わす"},"読み合わす":{"variants":"よみあわす/読み合わす"},"読みあわせ":{"variants":"読みあわせ/読み合せ"},"読み合せ":{"variants":"読みあわせ/読み合せ"},"よみあわせる":{"variants":"よみあわせる/読み合わせる"},"読み合わせる":{"variants":"よみあわせる/読み合わせる"},"よみかえす":{"variants":"よみかえす/読み返す"},"読み返す":{"variants":"よみかえす/読み返す"},"よみかえせる":{"variants":"よみかえせる/読み返せる"},"読み返せる":{"variants":"よみかえせる/読み返せる"},"よみかえる":{"variants":"よみかえる/読みかえる/読み替える/読替える"},"読みかえる":{"variants":"よみかえる/読みかえる/読み替える/読替える"},"読み替える":{"variants":"よみかえる/読みかえる/読み替える/読替える"},"読替える":{"variants":"よみかえる/読みかえる/読み替える/読替える"},"よみかける":{"variants":"よみかける/読みかける"},"読みかける":{"variants":"よみかける/読みかける"},"読み方":{"variants":"読み方/読方"},"読方":{"variants":"読み方/読方"},"よみがえる":{"variants":"よみがえる/蘇る/甦る"},"読みきり":{"variants":"読みきり/読み切り/読切り"},"読み切り":{"variants":"読みきり/読み切り/読切り"},"読切り":{"variants":"読みきり/読み切り/読切り"},"よみきる":{"variants":"よみきる/読み切る"},"読み切る":{"variants":"よみきる/読み切る"},"よみきれる":{"variants":"よみきれる/読み切れる"},"読み切れる":{"variants":"よみきれる/読み切れる"},"よみくさ":{"variants":"よみくさ/詠草"},"詠草":{"variants":"よみくさ/詠草"},"読み癖":{"variants":"読み癖/読癖"},"読癖":{"variants":"読み癖/読癖"},"よみくだす":{"variants":"よみくだす/読みくだす/読み下す"},"読みくだす":{"variants":"よみくだす/読みくだす/読み下す"},"読み下す":{"variants":"よみくだす/読みくだす/読み下す"},"よみくらべる":{"variants":"よみくらべる/読み比べる"},"読み比べる":{"variants":"よみくらべる/読み比べる"},"よみこなす":{"variants":"よみこなす/読みこなす"},"読みこなす":{"variants":"よみこなす/読みこなす"},"よみこなせる":{"variants":"よみこなせる/読みこなせる"},"読みこなせる":{"variants":"よみこなせる/読みこなせる"},"読み込み":{"variants":"読み込み/読込み"},"読込み":{"variants":"読み込み/読込み"},"よみこむ":{"variants":"よみこむ/詠みこむ/詠み込む/詠込む/読み込む"},"詠み込む":{"variants":"よみこむ/詠みこむ/詠み込む/詠込む"},"詠みこむ":{"variants":"よみこむ/詠みこむ/詠み込む/詠込む"},"詠込む":{"variants":"よみこむ/詠みこむ/詠み込む/詠込む"},"よみこめる":{"variants":"よみこめる/詠み込める/読み込める"},"よみさす":{"variants":"よみさす/読みさす"},"読みさす":{"variants":"よみさす/読みさす"},"よみする":{"variants":"よみする/嘉する"},"嘉する":{"variants":"よみする/嘉する"},"読み出し":{"variants":"読み出し/読出し"},"読出し":{"variants":"読み出し/読出し"},"よみだす":{"variants":"よみだす/読み出す"},"読み出す":{"variants":"よみだす/読み出す"},"読手":{"variants":"読み手/読手"},"読み手":{"variants":"読み手/読手"},"よみとおす":{"variants":"よみとおす/読み通す/読通す"},"読み通す":{"variants":"よみとおす/読み通す/読通す"},"読通す":{"variants":"よみとおす/読み通す/読通す"},"読みとり":{"variants":"読みとり/読み取り/読取り"},"読み取り":{"variants":"読みとり/読み取り/読取り"},"読取り":{"variants":"読みとり/読み取り/読取り"},"よみとる":{"variants":"よみとる/読みとる/読み取る/読取る"},"読みとる":{"variants":"よみとる/読みとる/読み取る/読取る"},"読み取る":{"variants":"よみとる/読みとる/読み取る/読取る"},"読取る":{"variants":"よみとる/読みとる/読み取る/読取る"},"よみとれる":{"variants":"よみとれる/読み取れる"},"読み取れる":{"variants":"よみとれる/読み取れる"},"よみながす":{"variants":"よみながす/読み流す/読流す"},"読み流す":{"variants":"よみながす/読み流す/読流す"},"読流す":{"variants":"よみながす/読み流す/読流す"},"よみながせる":{"variants":"よみながせる/読み流せる"},"読み流せる":{"variants":"よみながせる/読み流せる"},"よみふける":{"variants":"よみふける/読みふける/読み耽る"},"読みふける":{"variants":"よみふける/読みふける/読み耽る"},"読み耽る":{"variants":"よみふける/読みふける/読み耽る"},"読みもの":{"variants":"読みもの/読み物/読物"},"読み物":{"variants":"読みもの/読み物/読物"},"読物":{"variants":"読みもの/読み物/読物"},"よみやぶる":{"variants":"よみやぶる/読み破る"},"読み破る":{"variants":"よみやぶる/読み破る"},"よみわける":{"variants":"よみわける/読み分ける"},"読み分ける":{"variants":"よみわける/読み分ける"},"よむ":{"variants":"よむ/詠む/読む/讀む"},"嫁とり":{"variants":"嫁とり/嫁取り"},"嫁取り":{"variants":"嫁とり/嫁取り"},"ヨメナ":{"variants":"ヨメナ/嫁菜"},"嫁菜":{"variants":"ヨメナ/嫁菜"},"よめる":{"variants":"よめる/詠める/読める/讀める"},"ヨモギ":{"variants":"ヨモギ/蓬"},"蓬":{"variants":"ヨモギ/蓬"},"よもすがら":{"variants":"よもすがら/夜もすがら"},"夜もすがら":{"variants":"よもすがら/夜もすがら"},"よもやま話":{"variants":"よもやま話/四方山話"},"四方山話":{"variants":"よもやま話/四方山話"},"余裕しゃくしゃく":{"variants":"余裕しゃくしゃく/余裕綽々/余裕綽綽"},"余裕綽々":{"variants":"余裕しゃくしゃく/余裕綽々/余裕綽綽"},"余裕綽綽":{"variants":"余裕しゃくしゃく/余裕綽々/余裕綽綽"},"夜々":{"variants":"夜々/夜夜"},"夜夜":{"variants":"夜々/夜夜"},"寄り合い":{"variants":"寄り合い/寄合い"},"寄合い":{"variants":"寄り合い/寄合い"},"よりあう":{"variants":"よりあう/寄り合う"},"寄り合う":{"variants":"よりあう/寄り合う"},"より糸":{"variants":"より糸/撚り糸/縒り糸"},"よりかかる":{"variants":"よりかかる/寄りかかる/寄り掛かる/寄り掛る"},"寄りかかる":{"variants":"よりかかる/寄りかかる/寄り掛かる/寄り掛る"},"寄り掛かる":{"variants":"よりかかる/寄りかかる/寄り掛かる/寄り掛る"},"寄り掛る":{"variants":"よりかかる/寄りかかる/寄り掛かる/寄り掛る"},"よりきる":{"variants":"よりきる/寄り切る"},"寄り切る":{"variants":"よりきる/寄り切る"},"よりきれる":{"variants":"よりきれる/寄り切れる"},"寄り切れる":{"variants":"よりきれる/寄り切れる"},"よりすがる":{"variants":"よりすがる/寄りすがる/寄り縋る"},"寄りすがる":{"variants":"よりすがる/寄りすがる/寄り縋る"},"寄り縋る":{"variants":"よりすがる/寄りすがる/寄り縋る"},"よりそう":{"variants":"よりそう/寄り添う/寄添う"},"寄り添う":{"variants":"よりそう/寄り添う/寄添う"},"寄添う":{"variants":"よりそう/寄り添う/寄添う"},"よりそえる":{"variants":"よりそえる/寄り添える"},"寄り添える":{"variants":"よりそえる/寄り添える"},"よりたおす":{"variants":"よりたおす/寄り倒す"},"寄り倒す":{"variants":"よりたおす/寄り倒す"},"よりたおせる":{"variants":"よりたおせる/寄り倒せる"},"寄り倒せる":{"variants":"よりたおせる/寄り倒せる"},"寄り付き":{"variants":"寄り付き/寄付き"},"寄付き":{"variants":"寄り付き/寄付き"},"よりつく":{"variants":"よりつく/寄りつく/寄り付く/寄付く"},"寄りつく":{"variants":"よりつく/寄りつく/寄り付く/寄付く"},"寄り付く":{"variants":"よりつく/寄りつく/寄り付く/寄付く"},"寄付く":{"variants":"よりつく/寄りつく/寄り付く/寄付く"},"拠":{"variants":"拠/拠り所/拠所"},"拠り所":{"variants":"拠/拠り所/拠所"},"拠所":{"variants":"拠/拠り所/拠所"},"選りどり":{"variants":"選りどり/選り取り"},"選り取り":{"variants":"選りどり/選り取り"},"よりぬく":{"variants":"よりぬく/より抜く"},"より抜く":{"variants":"よりぬく/より抜く"},"よりぬける":{"variants":"よりぬける/より抜ける"},"より抜ける":{"variants":"よりぬける/より抜ける"},"より目":{"variants":"より目/寄り目/寄目"},"寄り目":{"variants":"より目/寄り目/寄目"},"寄目":{"variants":"より目/寄り目/寄目"},"よりより":{"variants":"よりより/寄り寄り"},"寄り寄り":{"variants":"よりより/寄り寄り"},"よりわける":{"variants":"よりわける/より分ける"},"より分ける":{"variants":"よりわける/より分ける"},"よる":{"variants":"よる/依る/因る/縁る/寄る/拠る/選る/撚る/由る"},"ヨルガオ":{"variants":"ヨルガオ/夜顔"},"夜顔":{"variants":"ヨルガオ/夜顔"},"寄るべ":{"variants":"寄るべ/寄る辺"},"寄る辺":{"variants":"寄るべ/寄る辺"},"よれる":{"variants":"よれる/寄れる/縒れる"},"よろい":{"variants":"よろい/鎧"},"鎧":{"variants":"よろい/鎧"},"よろいかぶと":{"variants":"よろいかぶと/鎧兜"},"鎧兜":{"variants":"よろいかぶと/鎧兜"},"よろい戸":{"variants":"よろい戸/鎧戸"},"鎧戸":{"variants":"よろい戸/鎧戸"},"よろう":{"variants":"よろう/鎧う"},"鎧う":{"variants":"よろう/鎧う"},"よろこばしい":{"variants":"よろこばしい/悦ばしい/喜ばしい"},"よろこばす":{"variants":"よろこばす/喜ばす"},"喜ばす":{"variants":"よろこばす/喜ばす"},"よろこぶ":{"variants":"よろこぶ/悦ぶ/歓ぶ/喜ぶ/慶ぶ"},"よろこべる":{"variants":"よろこべる/悦べる/歓べる/喜べる/慶べる"},"よろしい":{"variants":"よろしい/宜しい"},"宜しい":{"variants":"よろしい/宜しい"},"よろしく":{"variants":"よろしく/宜しく"},"宜しく":{"variants":"よろしく/宜しく"},"よわい":{"variants":"よわい/齢"},"弱い":{"variants":"よわい/弱い"},"齢":{"variants":"よわい/齢"},"よわいする":{"variants":"よわいする/歯する"},"歯する":{"variants":"よわいする/歯する"},"弱き":{"variants":"弱き/弱気"},"弱気":{"variants":"弱き/弱気"},"よわまる":{"variants":"よわまる/弱まる"},"弱まる":{"variants":"よわまる/弱まる"},"弱み":{"variants":"弱み/弱味"},"弱味":{"variants":"弱み/弱味"},"よわめる":{"variants":"よわめる/弱める"},"弱める":{"variants":"よわめる/弱める"},"よわよわしい":{"variants":"よわよわしい/弱々しい/弱弱しい"},"弱々しい":{"variants":"よわよわしい/弱々しい/弱弱しい"},"弱弱しい":{"variants":"よわよわしい/弱々しい/弱弱しい"},"よわる":{"variants":"よわる/弱る"},"弱る":{"variants":"よわる/弱る"},"４":{"variants":"４/四"},"四":{"variants":"４/四"},"ライギョ":{"variants":"ライギョ/雷魚"},"雷魚":{"variants":"ライギョ/雷魚"},"ライチョウ":{"variants":"ライチョウ/雷鳥"},"雷鳥":{"variants":"ライチョウ/雷鳥"},"らい病":{"variants":"らい病/癩病"},"癩病":{"variants":"らい病/癩病"},"ライむぎ":{"variants":"ライむぎ/ライムギ/ライ麦"},"ライムギ":{"variants":"ライむぎ/ライムギ/ライ麦"},"ライ麦":{"variants":"ライむぎ/ライムギ/ライ麦"},"烙印":{"variants":"らく印/烙印"},"らく印":{"variants":"らく印/烙印"},"落書":{"variants":"落書/落書き"},"落書き":{"variants":"落書/落書き"},"らくがん":{"variants":"らくがん/落雁"},"落雁":{"variants":"らくがん/落雁"},"ラクダ":{"variants":"ラクダ/駱駝"},"駱駝":{"variants":"ラクダ/駱駝"},"らくに":{"variants":"らくに/楽に"},"楽に":{"variants":"らくに/楽に"},"楽焼":{"variants":"楽焼/楽焼き"},"楽焼き":{"variants":"楽焼/楽焼き"},"らくらく":{"variants":"らくらく/楽楽"},"楽楽":{"variants":"らくらく/楽楽"},"らせん":{"variants":"らせん/螺旋"},"螺旋":{"variants":"らせん/螺旋"},"らち":{"variants":"らち/埒"},"埒":{"variants":"らち/埒"},"らち外":{"variants":"らち外/埒外"},"埒外":{"variants":"らち外/埒外"},"ラッカセイ":{"variants":"ラッカセイ/落花生"},"落花生":{"variants":"ラッカセイ/落花生"},"ラッキョウ":{"variants":"ラッキョウ/辣韮"},"辣韮":{"variants":"ラッキョウ/辣韮"},"ラッコ":{"variants":"ラッコ/猟虎"},"猟虎":{"variants":"ラッコ/猟虎"},"らっする":{"variants":"らっする/拉する"},"拉する":{"variants":"らっする/拉する"},"らっぱ":{"variants":"らっぱ/ラッパ/喇叭"},"ラッパ":{"variants":"らっぱ/ラッパ/喇叭"},"喇叭":{"variants":"らっぱ/ラッパ/喇叭"},"らつ腕":{"variants":"らつ腕/辣腕"},"辣腕":{"variants":"らつ腕/辣腕"},"らでん":{"variants":"らでん/螺鈿"},"螺鈿":{"variants":"らでん/螺鈿"},"ラバ":{"variants":"ラバ/騾馬"},"騾馬":{"variants":"ラバ/騾馬"},"ラン":{"variants":"ＬＡＮ/ラン/乱/欄/蘭/覧"},"らんじゅく":{"variants":"らんじゅく/らん熟/爛熟"},"らん熟":{"variants":"らんじゅく/らん熟/爛熟"},"爛熟":{"variants":"らんじゅく/らん熟/爛熟"},"ラン数":{"variants":"ラン数/乱数"},"乱数":{"variants":"ラン数/乱数"},"らんちき騒ぎ":{"variants":"らんちき騒ぎ/乱痴気さわぎ/乱痴気騒ぎ"},"乱痴気さわぎ":{"variants":"らんちき騒ぎ/乱痴気さわぎ/乱痴気騒ぎ"},"乱痴気騒ぎ":{"variants":"らんちき騒ぎ/乱痴気さわぎ/乱痴気騒ぎ"},"ランチュウ":{"variants":"ランチュウ/蘭鋳"},"蘭鋳":{"variants":"ランチュウ/蘭鋳"},"爛々":{"variants":"爛々/爛爛"},"爛爛":{"variants":"爛々/爛爛"},"りかいしあう":{"variants":"りかいしあう/理解し合う"},"理解し合う":{"variants":"りかいしあう/理解し合う"},"りかいしあえる":{"variants":"りかいしあえる/理解し合える"},"理解し合える":{"variants":"りかいしあえる/理解し合える"},"り患":{"variants":"り患/罹患"},"罹患":{"variants":"り患/罹患"},"りきむ":{"variants":"りきむ/力む"},"力む":{"variants":"りきむ/力む"},"りくつっぽい":{"variants":"りくつっぽい/理屈っぽい/理窟っぽい"},"利ざや":{"variants":"利ざや/利ザヤ/利鞘"},"利ザヤ":{"variants":"利ざや/利ザヤ/利鞘"},"利鞘":{"variants":"利ざや/利ザヤ/利鞘"},"リス":{"variants":"リス/栗鼠"},"栗鼠":{"variants":"リス/栗鼠"},"りっする":{"variants":"りっする/律する"},"律する":{"variants":"りっする/律する"},"リッチ":{"variants":"リッチ/立地"},"立地":{"variants":"リッチ/立地"},"ｌ":{"variants":"ｌ/リットル"},"リットル":{"variants":"ｌ/リットル"},"利付":{"variants":"利付/利付き"},"利付き":{"variants":"利付/利付き"},"りつ然":{"variants":"りつ然/慄然"},"慄然":{"variants":"りつ然/慄然"},"理詰":{"variants":"理詰/理詰め"},"理詰め":{"variants":"理詰/理詰め"},"リネン":{"variants":"リネン/理念"},"理念":{"variants":"リネン/理念"},"りゃくす":{"variants":"りゃくす/略す"},"略す":{"variants":"りゃくす/略す"},"りゃくする":{"variants":"りゃくする/略する"},"略する":{"variants":"りゃくする/略する"},"りゃくせる":{"variants":"りゃくせる/略せる"},"略せる":{"variants":"りゃくせる/略せる"},"りゅう":{"variants":"りゅう/リュウ/流/竜/龍"},"リュウ":{"variants":"りゅう/リュウ/流/竜/龍"},"リュウガン":{"variants":"リュウガン/竜眼/竜顔"},"リュウガンニク":{"variants":"リュウガンニク/竜眼肉"},"竜眼肉":{"variants":"リュウガンニク/竜眼肉"},"リュウキン":{"variants":"リュウキン/琉金"},"琉金":{"variants":"リュウキン/琉金"},"リュウゼツラン":{"variants":"リュウゼツラン/竜舌蘭"},"竜舌蘭":{"variants":"リュウゼツラン/竜舌蘭"},"リュウチョウ":{"variants":"リュウチョウ/留鳥"},"留鳥":{"variants":"リュウチョウ/留鳥"},"流ちょう":{"variants":"流ちょう/流暢"},"流暢":{"variants":"流ちょう/流暢"},"リュウノヒゲ":{"variants":"リュウノヒゲ/竜のひげ/竜の鬚"},"竜のひげ":{"variants":"リュウノヒゲ/竜のひげ/竜の鬚"},"竜の鬚":{"variants":"リュウノヒゲ/竜のひげ/竜の鬚"},"りゅうりたん":{"variants":"りゅうりたん/流離譚"},"流離譚":{"variants":"りゅうりたん/流離譚"},"隆隆":{"variants":"隆々/隆隆"},"隆々":{"variants":"隆々/隆隆"},"粒々辛苦":{"variants":"粒々辛苦/粒粒辛苦"},"粒粒辛苦":{"variants":"粒々辛苦/粒粒辛苦"},"りょう":{"variants":"りょう/漁/了/寮/料/涼/猟/稜/良/量/陵/領/令"},"両さん":{"variants":"両さん/両三"},"両三":{"variants":"両さん/両三"},"領しゅう":{"variants":"領しゅう/領収"},"領収":{"variants":"領しゅう/領収"},"りょうする":{"variants":"りょうする/了する/諒する/領する"},"リョウセイルイ":{"variants":"リョウセイルイ/リョウセイ類/両棲類/両生類"},"リョウセイ類":{"variants":"リョウセイルイ/リョウセイ類/両棲類/両生類"},"りょうせん":{"variants":"りょうせん/りょう線/僚船/両船/稜線"},"りょう線":{"variants":"りょうせん/りょう線/稜線"},"稜線":{"variants":"りょうせん/りょう線/稜線"},"両てんびん":{"variants":"両てんびん/両天秤"},"両天秤":{"variants":"両てんびん/両天秤"},"寥寥":{"variants":"寥々/寥寥"},"両々":{"variants":"両々/両両"},"喨々":{"variants":"喨々/喨喨"},"両両":{"variants":"両々/両両"},"喨喨":{"variants":"喨々/喨喨"},"稜稜":{"variants":"稜々/稜稜"},"寥々":{"variants":"寥々/寥寥"},"稜々":{"variants":"稜々/稜稜"},"りょうる":{"variants":"りょうる/料る"},"料る":{"variants":"りょうる/料る"},"リョクソウ":{"variants":"リョクソウ/緑藻"},"緑藻":{"variants":"リョクソウ/緑藻"},"りりしい":{"variants":"りりしい/凛々しい/凛凛しい"},"凛々しい":{"variants":"りりしい/凛々しい/凛凛しい"},"凛凛しい":{"variants":"りりしい/凛々しい/凛凛しい"},"リン":{"variants":"リン/倫/厘/燐"},"リンカ":{"variants":"リンカ/燐火/輪禍/隣家"},"りん議":{"variants":"りん議/稟議"},"稟議":{"variants":"りん議/稟議"},"リンケイ":{"variants":"リンケイ/輪形/鱗形/鱗茎"},"りんご":{"variants":"りんご/リンゴ/林檎/苹果"},"リンゴ":{"variants":"りんご/リンゴ/林檎/苹果"},"りんし":{"variants":"りんし/臨死/鱗翅"},"吝しょく":{"variants":"吝しょく/吝嗇"},"吝嗇":{"variants":"吝しょく/吝嗇"},"リンシルイ":{"variants":"リンシルイ/鱗翅類"},"鱗翅類":{"variants":"リンシルイ/鱗翅類"},"リンチ":{"variants":"リンチ/林地/臨地/臨池/隣地"},"りんと":{"variants":"りんと/凛と"},"凛と":{"variants":"りんと/凛と"},"リンドウ":{"variants":"リンドウ/竜胆/林道"},"リンパ":{"variants":"リンパ/淋巴"},"淋巴":{"variants":"リンパ/淋巴"},"リンパ液":{"variants":"リンパ液/淋巴液"},"淋巴液":{"variants":"リンパ液/淋巴液"},"リンパしゅ":{"variants":"リンパしゅ/リンパ腫"},"リンパ腫":{"variants":"リンパしゅ/リンパ腫"},"リンパせん":{"variants":"リンパせん/リンパ腺/淋巴腺"},"リンパ腺":{"variants":"リンパせん/リンパ腺/淋巴腺"},"淋巴腺":{"variants":"リンパせん/リンパ腺/淋巴腺"},"りん病":{"variants":"りん病/淋病/痳病"},"リンプン":{"variants":"リンプン/リン粉/鱗粉"},"リン粉":{"variants":"リンプン/リン粉/鱗粉"},"鱗粉":{"variants":"リンプン/リン粉/鱗粉"},"臨も":{"variants":"臨も/臨模"},"臨模":{"variants":"臨も/臨模"},"リンモウ":{"variants":"リンモウ/厘毛/鱗毛"},"凛々":{"variants":"凛々/凛凛"},"凛凛":{"variants":"凛々/凛凛"},"るいする":{"variants":"るいする/類する"},"類する":{"variants":"るいする/類する"},"涙せん":{"variants":"涙せん/涙腺"},"涙腺":{"variants":"涙せん/涙腺"},"累々":{"variants":"累々/累累"},"累累":{"variants":"累々/累累"},"るしゃなぶつ":{"variants":"るしゃなぶつ/盧遮那仏"},"盧遮那仏":{"variants":"るしゃなぶつ/盧遮那仏"},"るび":{"variants":"るび/ルビ"},"ルビ":{"variants":"るび/ルビ"},"るり":{"variants":"るり/瑠璃"},"瑠璃":{"variants":"るり/瑠璃"},"ルリチョウ":{"variants":"ルリチョウ/瑠璃鳥"},"瑠璃鳥":{"variants":"ルリチョウ/瑠璃鳥"},"るる":{"variants":"るる/縷縷"},"縷縷":{"variants":"るる/縷縷"},"レイ":{"variants":"レイ/例/礼/霊"},"〇":{"variants":"〇/○/零"},"○":{"variants":"〇/○/零"},"零":{"variants":"〇/○/零"},"霊きゅう":{"variants":"霊きゅう/霊柩"},"霊柩":{"variants":"霊きゅう/霊柩"},"レイシ":{"variants":"レイシ/令嗣/令姉/麗姿/茘枝"},"れいする":{"variants":"れいする/令する"},"令する":{"variants":"れいする/令する"},"れい声":{"variants":"れい声/励声"},"励声":{"variants":"れい声/励声"},"レイヨウ":{"variants":"レイヨウ/麗容"},"麗容":{"variants":"レイヨウ/麗容"},"れいれいしい":{"variants":"れいれいしい/麗々しい/麗麗しい"},"麗々しい":{"variants":"れいれいしい/麗々しい/麗麗しい"},"麗麗しい":{"variants":"れいれいしい/麗々しい/麗麗しい"},"れいれいと":{"variants":"れいれいと/麗麗と"},"麗麗と":{"variants":"れいれいと/麗麗と"},"れき死":{"variants":"れき死/轢死"},"轢死":{"variants":"れき死/轢死"},"れきぜんと":{"variants":"れきぜんと/歴然と"},"歴然と":{"variants":"れきぜんと/歴然と"},"歴々":{"variants":"歴々/歴歴"},"歴歴":{"variants":"歴々/歴歴"},"れっする":{"variants":"れっする/列する"},"列する":{"variants":"れっする/列する"},"烈々":{"variants":"烈々/烈烈"},"烈烈":{"variants":"烈々/烈烈"},"レン":{"variants":"レン/聯/連"},"れんが":{"variants":"れんが/レンガ/煉瓦/連歌/連火"},"レンガ":{"variants":"れんが/レンガ/煉瓦/連歌/連火"},"レンギョウ":{"variants":"レンギョウ/連翹"},"連翹":{"variants":"レンギョウ/連翹"},"レンゲ":{"variants":"レンゲ/蓮華"},"蓮華":{"variants":"レンゲ/蓮華"},"レンゲソウ":{"variants":"レンゲソウ/紫雲英/蓮華草"},"レンコダイ":{"variants":"レンコダイ/連子鯛"},"連子鯛":{"variants":"レンコダイ/連子鯛"},"レンコン":{"variants":"レンコン/蓮根"},"蓮根":{"variants":"レンコン/蓮根"},"レンジ":{"variants":"レンジ/櫺子"},"櫺子":{"variants":"レンジ/櫺子"},"レンジャク":{"variants":"レンジャク/連尺/連雀"},"レンチ":{"variants":"レンチ/廉恥"},"廉恥":{"variants":"レンチ/廉恥"},"恋々":{"variants":"恋々/恋恋"},"恋恋":{"variants":"恋々/恋恋"},"ロイドめがね":{"variants":"ロイドめがね/ロイドメガネ/ロイド眼鏡"},"ロイドメガネ":{"variants":"ロイドめがね/ロイドメガネ/ロイド眼鏡"},"ロイド眼鏡":{"variants":"ロイドめがね/ロイドメガネ/ロイド眼鏡"},"ろう":{"variants":"ろう/労/廊/朗/牢/蝋/郎/鑞/隴"},"ろうあ":{"variants":"ろうあ/聾唖"},"聾唖":{"variants":"ろうあ/聾唖"},"漏えい":{"variants":"漏えい/漏洩"},"漏洩":{"variants":"漏えい/漏洩"},"聾者":{"variants":"ろう者/聾者"},"ろう者":{"variants":"ろう者/聾者"},"ろう城":{"variants":"ろう城/篭城"},"篭城":{"variants":"ろう城/篭城"},"ろうする":{"variants":"ろうする/労する/弄する/聾する"},"ろうそく":{"variants":"ろうそく/ロウソク/蝋燭"},"ロウソク":{"variants":"ろうそく/ロウソク/蝋燭"},"蝋燭":{"variants":"ろうそく/ロウソク/蝋燭"},"ろうの木":{"variants":"ろうの木/ロウノキ/蝋の木"},"ロウノキ":{"variants":"ろうの木/ロウノキ/蝋の木"},"蝋の木":{"variants":"ろうの木/ロウノキ/蝋の木"},"狼ばい":{"variants":"狼ばい/狼狽"},"狼狽":{"variants":"狼ばい/狼狽"},"ロウバイ":{"variants":"ロウバイ/蝋梅/臘梅"},"ろうらい":{"variants":"ろうらい/老来"},"老来":{"variants":"ろうらい/老来"},"浪浪":{"variants":"浪々/浪浪"},"朗々":{"variants":"朗々/朗朗"},"浪々":{"variants":"浪々/浪浪"},"朗朗":{"variants":"朗々/朗朗"},"労々い":{"variants":"労々い/労労い"},"労労い":{"variants":"労々い/労労い"},"ろ過":{"variants":"ろ過/濾過"},"濾過":{"variants":"ろ過/濾過"},"ロク":{"variants":"ロク/禄/碌"},"６":{"variants":"６/六"},"六":{"variants":"６/六"},"６月":{"variants":"６月/六月"},"六月":{"variants":"６月/六月"},"ろくする":{"variants":"ろくする/録する"},"録する":{"variants":"ろくする/録する"},"碌々":{"variants":"碌々/碌碌"},"碌碌":{"variants":"碌々/碌碌"},"ろくろ首":{"variants":"ろくろ首/轆轤首"},"轆轤首":{"variants":"ろくろ首/轆轤首"},"ろ水":{"variants":"ろ水/濾水"},"濾水":{"variants":"ろ水/濾水"},"ロップ":{"variants":"ロップ/六腑"},"六腑":{"variants":"ロップ/六腑"},"露天ぶろ":{"variants":"露天ぶろ/露天風呂"},"露天風呂":{"variants":"露天ぶろ/露天風呂"},"ロバ":{"variants":"ロバ/驢馬"},"驢馬":{"variants":"ロバ/驢馬"},"ろんじる":{"variants":"ろんじる/論じる"},"論じる":{"variants":"ろんじる/論じる"},"ろんずる":{"variants":"ろんずる/論ずる"},"論ずる":{"variants":"ろんずる/論ずる"},"わ":{"variants":"わ/ワ"},"ワ":{"variants":"わ/ワ"},"わぁー":{"variants":"わぁー/ワァー"},"ワァー":{"variants":"わぁー/ワァー"},"わい曲":{"variants":"わい曲/歪曲"},"歪曲":{"variants":"わい曲/歪曲"},"わい雑":{"variants":"わい雑/猥雑"},"猥雑":{"variants":"わい雑/猥雑"},"わい小":{"variants":"わい小/矮小"},"矮小":{"variants":"わい小/矮小"},"わいせつ":{"variants":"わいせつ/猥褻"},"猥褻":{"variants":"わいせつ/猥褻"},"わい談":{"variants":"わい談/ワイ談/猥談"},"ワイ談":{"variants":"わい談/ワイ談/猥談"},"猥談":{"variants":"わい談/ワイ談/猥談"},"わいろ":{"variants":"わいろ/賄賂"},"賄賂":{"variants":"わいろ/賄賂"},"わかい":{"variants":"わかい/若い"},"若い":{"variants":"わかい/若い"},"わかいしあう":{"variants":"わかいしあう/和解し合う"},"和解し合う":{"variants":"わかいしあう/和解し合う"},"わかいしあえる":{"variants":"わかいしあえる/和解し合える"},"和解し合える":{"variants":"わかいしあえる/和解し合える"},"わかがえる":{"variants":"わかがえる/若返る"},"若返る":{"variants":"わかがえる/若返る"},"わかがえれる":{"variants":"わかがえれる/若返れる"},"若返れる":{"variants":"わかがえれる/若返れる"},"若げ":{"variants":"わかげ/若げ/若気"},"若気":{"variants":"わかげ/若げ/若気"},"わかげ":{"variants":"わかげ/若げ/若気"},"ワカサギ":{"variants":"ワカサギ/公魚"},"公魚":{"variants":"ワカサギ/公魚"},"若さま":{"variants":"若さま/若様"},"若様":{"variants":"若さま/若様"},"沸かし湯":{"variants":"沸かし湯/沸湯"},"沸湯":{"variants":"沸かし湯/沸湯"},"若死":{"variants":"若死/若死に"},"若死に":{"variants":"若死/若死に"},"わかす":{"variants":"わかす/沸かす/湧かす/涌かす"},"若だんな":{"variants":"若だんな/若旦那"},"若旦那":{"variants":"若だんな/若旦那"},"わかち書き":{"variants":"わかち書き/分かち書き/分ち書き/別ち書き"},"分かち書き":{"variants":"わかち書き/分かち書き/分ち書き"},"分ち書き":{"variants":"わかち書き/分かち書き/分ち書き"},"わかつ":{"variants":"わかつ/分かつ/分つ"},"分かつ":{"variants":"わかつ/分かつ/分つ"},"分つ":{"variants":"わかつ/分かつ/分つ"},"若づくり":{"variants":"若づくり/若作り"},"若作り":{"variants":"若づくり/若作り"},"ワカメ":{"variants":"ワカメ/若芽/若布/和布"},"若もの":{"variants":"若もの/若者"},"若者":{"variants":"若もの/若者"},"わかやぐ":{"variants":"わかやぐ/若やぐ"},"若やぐ":{"variants":"わかやぐ/若やぐ"},"わからず屋":{"variants":"わからず屋/分らず屋"},"分らず屋":{"variants":"わからず屋/分らず屋"},"わかる":{"variants":"わかる/解る/判る/分かる/分る"},"分かる":{"variants":"わかる/分かる/分る"},"分る":{"variants":"わかる/分かる/分る"},"別れぎわ":{"variants":"別れぎわ/別れ際"},"別れ際":{"variants":"別れぎわ/別れ際"},"わかれ道":{"variants":"わかれ道/分かれ道/分れ道/別れ道"},"分かれ道":{"variants":"わかれ道/分かれ道/分れ道"},"分れ道":{"variants":"わかれ道/分かれ道/分れ道"},"わかれ目":{"variants":"わかれ目/分かれ目/分れ目"},"分かれ目":{"variants":"わかれ目/分かれ目/分れ目"},"分れ目":{"variants":"わかれ目/分かれ目/分れ目"},"わかれる":{"variants":"わかれる/訣れる/分かれる/別れる"},"別れわかれ":{"variants":"別れわかれ/別れ別れ"},"別れ別れ":{"variants":"別れわかれ/別れ別れ"},"わかわかしい":{"variants":"わかわかしい/若々しい/若若しい"},"若々しい":{"variants":"わかわかしい/若々しい/若若しい"},"若若しい":{"variants":"わかわかしい/若々しい/若若しい"},"わが":{"variants":"わが/我が/吾が"},"わが国":{"variants":"わが国/我が国/我国"},"我が国":{"variants":"わが国/我が国/我国"},"我国":{"variants":"わが国/我が国/我国"},"わが輩":{"variants":"わが輩/我輩"},"我輩":{"variants":"わが輩/我輩"},"わがはい":{"variants":"わがはい/吾輩"},"吾輩":{"variants":"わがはい/吾輩"},"我がまま":{"variants":"わがまま/我がまま/我侭/我儘"},"わがまま":{"variants":"わがまま/我がまま/我侭/我儘"},"わが身":{"variants":"わが身/我が身"},"我が身":{"variants":"わが身/我が身"},"わが物顔":{"variants":"わが物顔/我が物顔"},"我が物顔":{"variants":"わが物顔/我が物顔"},"わが家":{"variants":"わが家/我が家/我家"},"我が家":{"variants":"わが家/我が家/我家"},"我家":{"variants":"わが家/我が家/我家"},"わき":{"variants":"わき/和気/脇/腋"},"和気あいあい":{"variants":"和気あいあい/和気合い合い"},"和気合い合い":{"variants":"和気あいあい/和気合い合い"},"和気藹々":{"variants":"和気藹々/和気藹藹"},"和気藹藹":{"variants":"和気藹々/和気藹藹"},"わきあがる":{"variants":"わきあがる/沸きあがる/沸き上がる"},"沸きあがる":{"variants":"わきあがる/沸きあがる/沸き上がる"},"沸き上がる":{"variants":"わきあがる/沸きあがる/沸き上がる"},"わきおこす":{"variants":"わきおこす/わき起こす"},"わき起こす":{"variants":"わきおこす/わき起こす"},"わきおこせる":{"variants":"わきおこせる/わき起こせる"},"わき起こせる":{"variants":"わきおこせる/わき起こせる"},"わきおこる":{"variants":"わきおこる/わき起こる/沸き起こる/沸き起る"},"わき起こる":{"variants":"わきおこる/わき起こる/沸き起こる/沸き起る"},"沸き起こる":{"variants":"わきおこる/わき起こる/沸き起こる/沸き起る"},"沸き起る":{"variants":"わきおこる/わき起こる/沸き起こる/沸き起る"},"わきおこれる":{"variants":"わきおこれる/わき起これる/沸き起これる"},"わき起これる":{"variants":"わきおこれる/わき起これる/沸き起これる"},"沸き起これる":{"variants":"わきおこれる/わき起これる/沸き起これる"},"わきかえる":{"variants":"わきかえる/わき返る/沸き返る"},"わき返る":{"variants":"わきかえる/わき返る/沸き返る"},"沸き返る":{"variants":"わきかえる/わき返る/沸き返る"},"わき毛":{"variants":"わき毛/脇毛/腋毛"},"脇差":{"variants":"脇差/脇差し"},"脇差し":{"variants":"脇差/脇差し"},"わきたつ":{"variants":"わきたつ/沸き立つ"},"沸き立つ":{"variants":"わきたつ/沸き立つ"},"脇付":{"variants":"脇付/脇付け"},"脇付け":{"variants":"脇付/脇付け"},"わきでる":{"variants":"わきでる/わき出る/湧き出る"},"わき出る":{"variants":"わきでる/わき出る/湧き出る"},"湧き出る":{"variants":"わきでる/わき出る/湧き出る"},"わきの下":{"variants":"わきの下/脇の下/腋の下"},"わきばさむ":{"variants":"わきばさむ/脇挟む"},"脇挟む":{"variants":"わきばさむ/脇挟む"},"わき腹":{"variants":"わき腹/脇腹"},"脇腹":{"variants":"わき腹/脇腹"},"わきまえる":{"variants":"わきまえる/弁える"},"弁える":{"variants":"わきまえる/弁える"},"わき水":{"variants":"わき水/湧き水/涌き水"},"わき道":{"variants":"わき道/脇道"},"脇道":{"variants":"わき道/脇道"},"わき目":{"variants":"わき目/脇目"},"脇目":{"variants":"わき目/脇目"},"わき役":{"variants":"わき役/傍役/脇役"},"ワキン":{"variants":"ワキン/和金"},"和金":{"variants":"ワキン/和金"},"わく":{"variants":"わく/沸く/湧く/涌く"},"枠組":{"variants":"枠組/枠組み"},"枠組み":{"variants":"枠組/枠組み"},"わくわく":{"variants":"わくわく/ワクワク"},"ワクワク":{"variants":"わくわく/ワクワク"},"わけ":{"variants":"わけ/訳"},"分け":{"variants":"わけ/分け"},"訳":{"variants":"わけ/訳"},"分け合う":{"variants":"分け合う/分合う"},"分合う":{"variants":"分け合う/分合う"},"わけあたえる":{"variants":"わけあたえる/分け与える"},"分け与える":{"variants":"わけあたえる/分け与える"},"ワケギ":{"variants":"ワケギ/冬葱/分葱"},"わけ目":{"variants":"わけ目/分け目"},"分け目":{"variants":"わけ目/分け目"},"わける":{"variants":"わける/分ける/別ける"},"ワゴン":{"variants":"ワゴン/和琴"},"和琴":{"variants":"ワゴン/和琴"},"ワサビ":{"variants":"ワサビ/山葵"},"山葵":{"variants":"ワサビ/山葵"},"わさび漬け":{"variants":"わさび漬け/山葵漬"},"山葵漬":{"variants":"わさび漬け/山葵漬"},"わさん":{"variants":"わさん/和算/和讃/和讚"},"わざ師":{"variants":"わざ師/業師"},"業師":{"variants":"わざ師/業師"},"わざとがましい":{"variants":"わざとがましい/態とがましい"},"態とがましい":{"variants":"わざとがましい/態とがましい"},"わざとらしい":{"variants":"わざとらしい/態とらしい"},"態とらしい":{"variants":"わざとらしい/態とらしい"},"わし":{"variants":"わし/ワシ/和紙/鷲/儂"},"ワシ":{"variants":"わし/ワシ/和紙/鷲/儂"},"わする":{"variants":"わする/和する"},"和する":{"variants":"わする/和する"},"わすれかける":{"variants":"わすれかける/忘れかける"},"忘れかける":{"variants":"わすれかける/忘れかける"},"忘れがたみ":{"variants":"忘れがたみ/忘れ形見"},"忘れ形見":{"variants":"忘れがたみ/忘れ形見"},"わすれ草":{"variants":"わすれ草/ワスレグサ/忘れ草"},"ワスレグサ":{"variants":"わすれ草/ワスレグサ/忘れ草"},"忘れ草":{"variants":"わすれ草/ワスレグサ/忘れ草"},"わすれさる":{"variants":"わすれさる/忘れ去る"},"忘れ去る":{"variants":"わすれさる/忘れ去る"},"わすれっぽい":{"variants":"わすれっぽい/忘れっぽい"},"忘れっぽい":{"variants":"わすれっぽい/忘れっぽい"},"ワスレナグサ":{"variants":"ワスレナグサ/忘れな草/勿忘草"},"忘れもの":{"variants":"忘れもの/忘れ物"},"忘れ物":{"variants":"忘れもの/忘れ物"},"わすれる":{"variants":"わすれる/忘れる"},"忘れる":{"variants":"わすれる/忘れる"},"わずらいつく":{"variants":"わずらいつく/煩いつく/煩い付く"},"煩いつく":{"variants":"わずらいつく/煩いつく/煩い付く"},"煩い付く":{"variants":"わずらいつく/煩いつく/煩い付く"},"わずらう":{"variants":"わずらう/患う/煩う"},"わずらわしい":{"variants":"わずらわしい/煩わしい"},"煩わしい":{"variants":"わずらわしい/煩わしい"},"わずらわす":{"variants":"わずらわす/煩わす"},"煩わす":{"variants":"わずらわす/煩わす"},"わずらわせる":{"variants":"わずらわせる/煩わせる"},"煩わせる":{"variants":"わずらわせる/煩わせる"},"ワセ":{"variants":"ワセ/早稲/早生"},"ワタ":{"variants":"ワタ/棉"},"棉":{"variants":"ワタ/棉"},"わたくしする":{"variants":"わたくしする/私する"},"私する":{"variants":"わたくしする/私する"},"綿繰りぐるま":{"variants":"綿繰りぐるま/綿繰り車"},"綿繰り車":{"variants":"綿繰りぐるま/綿繰り車"},"わた毛":{"variants":"わた毛/綿毛"},"綿毛":{"variants":"わた毛/綿毛"},"渡し守":{"variants":"渡し守/渡守"},"渡守":{"variants":"渡し守/渡守"},"わたしゃ":{"variants":"わたしゃ/私しゃ/私ゃ"},"私しゃ":{"variants":"わたしゃ/私しゃ/私ゃ"},"私ゃ":{"variants":"わたしゃ/私しゃ/私ゃ"},"わたす":{"variants":"わたす/渡す"},"渡す":{"variants":"わたす/渡す"},"わたせる":{"variants":"わたせる/渡せる"},"渡せる":{"variants":"わたせる/渡せる"},"わたの原":{"variants":"わたの原/海の原"},"海の原":{"variants":"わたの原/海の原"},"わたぼうし":{"variants":"わたぼうし/綿帽子"},"綿帽子":{"variants":"わたぼうし/綿帽子"},"わたりあう":{"variants":"わたりあう/渡りあう/渡り合う"},"渡りあう":{"variants":"わたりあう/渡りあう/渡り合う"},"渡り合う":{"variants":"わたりあう/渡りあう/渡り合う"},"わたりあえる":{"variants":"わたりあえる/渡り合える"},"渡り合える":{"variants":"わたりあえる/渡り合える"},"わたりあるく":{"variants":"わたりあるく/渡り歩く"},"渡り歩く":{"variants":"わたりあるく/渡り歩く"},"渡り板":{"variants":"渡り板/渡板"},"渡板":{"variants":"渡り板/渡板"},"渡り初め":{"variants":"渡り初め/渡初め"},"渡初め":{"variants":"渡り初め/渡初め"},"ワタリドリ":{"variants":"ワタリドリ/渡り鳥/渡鳥"},"渡り鳥":{"variants":"ワタリドリ/渡り鳥/渡鳥"},"渡鳥":{"variants":"ワタリドリ/渡り鳥/渡鳥"},"渡り廊下":{"variants":"渡り廊下/渡廊下"},"渡廊下":{"variants":"渡り廊下/渡廊下"},"わたる":{"variants":"わたる/航る/渡る/亙る/亘る"},"わたれる":{"variants":"わたれる/航れる/渡れる/亙れる"},"わだかまる":{"variants":"わだかまる/蟠る"},"蟠る":{"variants":"わだかまる/蟠る"},"ｗ":{"variants":"ｗ/ワット"},"ワット":{"variants":"ｗ/ワット"},"和とじ":{"variants":"和とじ/和綴じ"},"和綴じ":{"variants":"和とじ/和綴じ"},"ワナ":{"variants":"ワナ/罠"},"罠":{"variants":"ワナ/罠"},"輪なげ":{"variants":"輪なげ/輪投げ"},"輪投げ":{"variants":"輪なげ/輪投げ"},"わななく":{"variants":"わななく/戦慄く"},"戦慄く":{"variants":"わななく/戦慄く"},"ワニ":{"variants":"ワニ/鰐"},"鰐":{"variants":"ワニ/鰐"},"ワニザメ":{"variants":"ワニザメ/鰐鮫"},"鰐鮫":{"variants":"ワニザメ/鰐鮫"},"わび":{"variants":"わび/詫び/侘/侘び"},"侘び":{"variants":"わび/侘/侘び"},"侘":{"variants":"わび/侘/侘び"},"わびいる":{"variants":"わびいる/詫び入る"},"詫び入る":{"variants":"わびいる/詫び入る"},"詫びごと":{"variants":"詫びごと/詫び言/詫び事"},"わびしい":{"variants":"わびしい/詫びしい/侘しい"},"わび状":{"variants":"わび状/詫び状/詫状"},"詫び状":{"variants":"わび状/詫び状/詫状"},"詫状":{"variants":"わび状/詫び状/詫状"},"ワビスケ":{"variants":"ワビスケ/侘助"},"侘助":{"variants":"ワビスケ/侘助"},"侘住い":{"variants":"侘住い/侘住居"},"侘住居":{"variants":"侘住い/侘住居"},"わびる":{"variants":"わびる/詫びる/侘びる"},"わめく":{"variants":"わめく/喚く"},"喚く":{"variants":"わめく/喚く"},"わら":{"variants":"わら/ワラ/藁"},"ワラ":{"variants":"わら/ワラ/藁"},"藁":{"variants":"わら/ワラ/藁"},"笑いぐさ":{"variants":"笑いぐさ/笑い種/笑い草"},"わらいこける":{"variants":"わらいこける/笑いこける"},"笑いこける":{"variants":"わらいこける/笑いこける"},"笑いころげる":{"variants":"笑いころげる/笑い転げる"},"笑い転げる":{"variants":"笑いころげる/笑い転げる"},"笑いごと":{"variants":"笑いごと/笑い事"},"笑い事":{"variants":"笑いごと/笑い事"},"わらい茸":{"variants":"わらい茸/ワライダケ/笑い茸/笑茸"},"ワライダケ":{"variants":"わらい茸/ワライダケ/笑い茸/笑茸"},"笑い茸":{"variants":"わらい茸/ワライダケ/笑い茸/笑茸"},"笑茸":{"variants":"わらい茸/ワライダケ/笑い茸/笑茸"},"わらいとばす":{"variants":"わらいとばす/笑いとばす/笑い飛ばす"},"笑いとばす":{"variants":"わらいとばす/笑いとばす/笑い飛ばす"},"笑い飛ばす":{"variants":"わらいとばす/笑いとばす/笑い飛ばす"},"わらいとばせる":{"variants":"わらいとばせる/笑い飛ばせる"},"笑い飛ばせる":{"variants":"わらいとばせる/笑い飛ばせる"},"わらい話":{"variants":"わらい話/笑いばなし/笑い話"},"笑いばなし":{"variants":"わらい話/笑いばなし/笑い話"},"笑い話":{"variants":"わらい話/笑いばなし/笑い話"},"わらい物":{"variants":"わらい物/笑いもの/笑い物"},"笑いもの":{"variants":"わらい物/笑いもの/笑い物"},"笑い物":{"variants":"わらい物/笑いもの/笑い物"},"わらう":{"variants":"わらう/笑う"},"笑う":{"variants":"わらう/笑う"},"わらえる":{"variants":"わらえる/笑える"},"笑える":{"variants":"わらえる/笑える"},"ワラサ":{"variants":"ワラサ/雅鰤"},"雅鰤":{"variants":"ワラサ/雅鰤"},"わらしべ":{"variants":"わらしべ/藁しべ"},"藁しべ":{"variants":"わらしべ/藁しべ"},"わらじ":{"variants":"わらじ/草鞋"},"草鞋":{"variants":"わらじ/草鞋"},"わらじ虫":{"variants":"わらじ虫/ワラジムシ/草鞋虫"},"ワラジムシ":{"variants":"わらじ虫/ワラジムシ/草鞋虫"},"草鞋虫":{"variants":"わらじ虫/ワラジムシ/草鞋虫"},"わら半紙":{"variants":"わら半紙/藁半紙"},"藁半紙":{"variants":"わら半紙/藁半紙"},"ワラビ":{"variants":"ワラビ/藁火/蕨"},"わら布団":{"variants":"わら布団/藁布団"},"藁布団":{"variants":"わら布団/藁布団"},"わらわす":{"variants":"わらわす/笑わす"},"笑わす":{"variants":"わらわす/笑わす"},"わらわせる":{"variants":"わらわせる/笑わせる"},"笑わせる":{"variants":"わらわせる/笑わせる"},"わらわれる":{"variants":"わらわれる/笑われる"},"笑われる":{"variants":"わらわれる/笑われる"},"割":{"variants":"割/割り"},"割り":{"variants":"割/割り"},"わりあい":{"variants":"わりあい/割合"},"割合":{"variants":"わりあい/割合"},"割り当て":{"variants":"割り当て/割当"},"割当":{"variants":"割り当て/割当"},"わりあてる":{"variants":"わりあてる/割りあてる/割り当てる/割当てる"},"割りあてる":{"variants":"わりあてる/割りあてる/割り当てる/割当てる"},"割り当てる":{"variants":"わりあてる/割りあてる/割り当てる/割当てる"},"割当てる":{"variants":"わりあてる/割りあてる/割り当てる/割当てる"},"割り印":{"variants":"割り印/割印"},"割印":{"variants":"割り印/割印"},"わりかた":{"variants":"わりかた/割り方/割方"},"割り方":{"variants":"わりかた/割り方/割方"},"割方":{"variants":"わりかた/割り方/割方"},"割り勘":{"variants":"割り勘/割勘"},"割勘":{"variants":"割り勘/割勘"},"わりきる":{"variants":"わりきる/割り切る"},"割り切る":{"variants":"わりきる/割り切る"},"わりきれる":{"variants":"わりきれる/割りきれる/割り切れる/割切れる"},"割りきれる":{"variants":"わりきれる/割りきれる/割り切れる/割切れる"},"割り切れる":{"variants":"わりきれる/割りきれる/割り切れる/割切れる"},"割切れる":{"variants":"わりきれる/割りきれる/割り切れる/割切れる"},"わりこむ":{"variants":"わりこむ/割り込む/割込む"},"割り込む":{"variants":"わりこむ/割り込む/割込む"},"割込む":{"variants":"わりこむ/割り込む/割込む"},"わりこめる":{"variants":"わりこめる/割り込める"},"割り込める":{"variants":"わりこめる/割り込める"},"わり算":{"variants":"わり算/割り算/割算"},"割り算":{"variants":"わり算/割り算/割算"},"割算":{"variants":"わり算/割り算/割算"},"割り下":{"variants":"割り下/割下"},"割下":{"variants":"割り下/割下"},"割り出し":{"variants":"割り出し/割出し"},"割出し":{"variants":"割り出し/割出し"},"わりだす":{"variants":"わりだす/割り出す/割出す"},"割り出す":{"variants":"わりだす/割り出す/割出す"},"割出す":{"variants":"わりだす/割り出す/割出す"},"わりだせる":{"variants":"わりだせる/割り出せる"},"割り出せる":{"variants":"わりだせる/割り出せる"},"割り注":{"variants":"割り注/割注"},"割注":{"variants":"割り注/割注"},"割り付け":{"variants":"割り付け/割付/割付け"},"割付":{"variants":"割り付け/割付/割付け"},"割付け":{"variants":"割り付け/割付/割付け"},"わりつける":{"variants":"わりつける/割り付ける"},"割り付ける":{"variants":"わりつける/割り付ける"},"わりに":{"variants":"わりに/割に"},"割に":{"variants":"わりに/割に"},"わり箸":{"variants":"わり箸/割りばし/割り箸/割箸"},"割りばし":{"variants":"わり箸/割りばし/割り箸/割箸"},"割り箸":{"variants":"わり箸/割りばし/割り箸/割箸"},"割箸":{"variants":"わり箸/割りばし/割り箸/割箸"},"割り引き":{"variants":"割り引き/割引/割引き"},"割引":{"variants":"割り引き/割引/割引き"},"割引き":{"variants":"割り引き/割引/割引き"},"わりびく":{"variants":"わりびく/割り引く/割引く"},"割り引く":{"variants":"わりびく/割り引く/割引く"},"割引く":{"variants":"わりびく/割り引く/割引く"},"わりびける":{"variants":"わりびける/割り引ける"},"割り引ける":{"variants":"わりびける/割り引ける"},"割り振り":{"variants":"割り振り/割振り"},"割振り":{"variants":"割り振り/割振り"},"わりふる":{"variants":"わりふる/割りふる/割り振る/割振る"},"割りふる":{"variants":"わりふる/割りふる/割り振る/割振る"},"割り振る":{"variants":"わりふる/割りふる/割り振る/割振る"},"割振る":{"variants":"わりふる/割りふる/割り振る/割振る"},"わりふれる":{"variants":"わりふれる/割り振れる"},"割り振れる":{"variants":"わりふれる/割り振れる"},"割り前":{"variants":"割り前/割前"},"割前":{"variants":"割り前/割前"},"割り増し":{"variants":"割り増し/割増/割増し"},"割増":{"variants":"割り増し/割増/割増し"},"割増し":{"variants":"割り増し/割増/割増し"},"わりもどす":{"variants":"わりもどす/割り戻す/割戻す"},"割り戻す":{"variants":"わりもどす/割り戻す/割戻す"},"割戻す":{"variants":"わりもどす/割り戻す/割戻す"},"わりもどせる":{"variants":"わりもどせる/割り戻せる"},"割り戻せる":{"variants":"わりもどせる/割り戻せる"},"わる":{"variants":"わる/割る"},"割る":{"variants":"われる/割る/割れる"},"悪あがき":{"variants":"悪あがき/悪足掻き"},"悪足掻き":{"variants":"悪あがき/悪足掻き"},"わるい":{"variants":"わるい/悪い"},"悪い":{"variants":"わるい/悪い"},"わるがしこい":{"variants":"わるがしこい/悪賢い"},"悪賢い":{"variants":"わるがしこい/悪賢い"},"わるびれる":{"variants":"わるびれる/悪びれる"},"悪びれる":{"variants":"わるびれる/悪びれる"},"悪もの":{"variants":"悪もの/悪者"},"悪者":{"variants":"悪もの/悪者"},"悪酔":{"variants":"悪酔/悪酔い"},"悪酔い":{"variants":"悪酔/悪酔い"},"われと":{"variants":"われと/我と"},"我と":{"variants":"われと/我と"},"われ鍋":{"variants":"われ鍋/破れ鍋"},"破れ鍋":{"variants":"われ鍋/破れ鍋"},"われ目":{"variants":"われ目/割れ目/割目/破れ目"},"割目":{"variants":"われ目/割れ目/割目"},"割れ目":{"variants":"われ目/割れ目/割目"},"ワレモコウ":{"variants":"ワレモコウ/吾亦紅/吾木香"},"割れ物":{"variants":"割れもの/割れ物"},"割れもの":{"variants":"割れもの/割れ物"},"われる":{"variants":"われる/割る/割れる"},"割れる":{"variants":"われる/割る/割れる"},"われわれ":{"variants":"われわれ/我々"},"我々":{"variants":"われわれ/我々"},"わん":{"variants":"わん/ワン/椀/湾/碗"},"ワン":{"variants":"わん/ワン/椀/湾/碗"},"ワンタン":{"variants":"ワンタン/雲呑"},"雲呑":{"variants":"ワンタン/雲呑"},"を":{"variants":"を/ヲ"},"ヲ":{"variants":"を/ヲ"},"をもって":{"variants":"をもって/を以て"},"を以て":{"variants":"をもって/を以て"},"ん":{"variants":"ん/ン"},"ン":{"variants":"ん/ン"}}'
);

const module: TextlintRuleModule = (context) => {
  const { getSource, report, RuleError, Syntax } = context;

  return {
    async [Syntax.Str](node) {
      const text = getSource(node);
      const tokens = await tokenize(text);
      const surfaceForms = tokens.map(({ surface_form }) => surface_form);

      tokens.forEach(({ surface_form, word_position }) => {
        const word = htdic[surface_form];

        if (!word) {
          return;
        }

        const variants = word.variants
          .split("/")
          .filter((variant) => variant !== surface_form);

        const existedVariants = variants.filter((variant) =>
          surfaceForms.includes(variant)
        );

        if (existedVariants.length === 0) {
          return;
        }

        const ruleError = new RuleError(
          `${[surface_form, ...existedVariants]
            .map((variant) => `「${variant}」`)
            .join("、")}の表記ゆれがあります。`,
          { index: word_position - 1 }
        );

        report(node, ruleError);
      });
    },
  };
};

export default module;
